-- calendar-api.sql
-- PL/SQL functions providing an API for the ArsDigita Calendar

-- @creation-date 2000-08-25
-- @author W. Scott Meeks (smeeks@arsdigita.com)
-- @cvs-id $Id: 03-calendar-api.sql,v 1.1.1.1 2001/01/24 18:03:15 tarik Exp $

create or replace procedure cal_insert_item_with_ids
	(v_parent_id IN integer,
	 v_item_id IN integer,
	 v_start_date IN date,
	 v_end_date IN date,
	 v_title IN varchar,
	 v_user_id IN integer,
	 v_group_id IN integer,
	 v_description IN varchar,
	 v_html_p IN varchar,
	 v_related_link_url IN varchar,
	 v_related_link_text IN varchar,
	 v_redirect_to_related_link_p IN varchar,
	 v_creator_id IN integer,
	 v_editable_p IN varchar )
AS
BEGIN
  INSERT INTO cal_items
  (item_id, title, description, html_p,
   related_link_url, related_link_text, redirect_to_related_link_p,
   creator_id, creation_date, editable_p)
  VALUES
  (v_parent_id, v_title, v_description, v_html_p,
   v_related_link_url, v_related_link_text, v_redirect_to_related_link_p,
   v_creator_id, sysdate, v_editable_p);

  INSERT INTO cal_items
  (parent_id, item_id, start_date, end_date, last_modifying_user)
  VALUES
  (v_parent_id, v_item_id, v_start_date, v_end_date, v_creator_id);

  INSERT INTO cal_user_group_item_map 
  (item_id, user_id, group_id)
  VALUES 
  (v_parent_id, v_user_id, v_group_id);

END;
.
/
show errors

-- Generates parent_id and item_id, inserts into appropriate tables, 
-- and returns item_id
create or replace function cal_insert_item 
	(v_start_date IN date,
	 v_end_date IN date,
	 v_title IN varchar,
	 v_user_id IN integer,
	 v_group_id IN integer,
	 v_description IN varchar,
         v_html_p IN varchar,
	 v_related_link_url IN varchar,
	 v_related_link_text IN varchar,
	 v_redirect_to_related_link_p IN varchar,
	 v_creator_id IN integer,
	 v_editable_p IN varchar )
RETURN INTEGER
AS
  v_parent_id INTEGER;
  v_item_id INTEGER;
BEGIN
  SELECT cal_id_sequence.nextval
  INTO v_parent_id
  FROM DUAL;
  SELECT cal_id_sequence.nextval
  INTO v_item_id
  FROM DUAL;

  cal_insert_item_with_ids
	(v_parent_id, v_item_id,
	 v_start_date, v_end_date, v_title,
	 v_user_id, v_group_id, v_description, v_html_p,
	 v_related_link_url, v_related_link_text, v_redirect_to_related_link_p,
	 v_creator_id, v_editable_p);

  RETURN v_item_id;
END;
.
/
show errors

-- Calls cal_insert_item and adds mapping to given id and table
create or replace function cal_ins_item_on_id_table
	(v_on_which_table IN varchar,
	 v_on_what_id IN integer,
	 v_start_date IN date,
	 v_end_date IN date,
	 v_title IN varchar,
	 v_user_id IN integer,
	 v_group_id IN integer,
	 v_description IN varchar,
	 v_html_p IN varchar,
	 v_related_link_url IN varchar,
	 v_related_link_text IN varchar,
	 v_redirect_to_related_link_p IN varchar,
	 v_creator_id IN integer,
	 v_editable_p IN varchar )
RETURN INTEGER
AS
  v_item_id INTEGER;
BEGIN
  v_item_id := cal_insert_item(
			v_start_date, v_end_date, v_title,
			v_user_id, v_group_id, v_description, v_html_p,
			v_related_link_url, v_related_link_text,
			v_redirect_to_related_link_p,
			v_creator_id, v_editable_p);

  INSERT INTO cal_item_db_row_map
  (item_id, on_which_table, on_what_id)
  VALUES
  (v_item_id, upper(trim(v_on_which_table)), v_on_what_id);

  RETURN v_item_id;
END;
.
/
show errors

create or replace procedure cal_update_item (v_parent_id IN integer)
AS
BEGIN
return;
END;
.
/
show errors
