# packages/calendar/calendar-page-procs.tcl

ad_library {
    Tcl procedures displaying calendar page components

    @creation-date Jul 20 07:27:12 2000
    @author W. Scott Meeks (smeeks@arsdigita.com)
    @author Bryan Che (bryanche@arsdigita.com)
    @author Tarik Alatovic (tarik@arsdigita.com)
    @cvs-id $Id: calendar-page-procs.tcl,v 1.6 2001/02/13 22:12:31 caroline Exp $
}

# TODO
# The following is a list of minor but useful improvements that should be made
# * hours_span should probably be handled in initialize_calendar_parameters
# * See if calendar_display_attachment_add can be made more generic
# * memoize week_list_of_lists and month_list_of_lists
# * Optimize use of cal_get_user_groups query.  The results of this query 
#   should be stored in ad_calendar variables and the toggles should manipulate
#   these variables so that the query doesn't have to be repeated every time.
#   Also, the results of this query can be used by the other item queries
#   rather than repeating the select for the list of group_ids every time.

ad_proc calendar_display_day_view { {} {view_mode "modular"} } {
    Displays day calendar for user or group
} {
    initialize_calendar_parameters $view_mode
    set compress_day_view_p [ad_calendar compress_day_view_p]
    global ad_calendar
    set ad_calendar(current_view) "day"

    set return_url [ns_conn url]
    set query [ns_conn query]
    if {[info exists query] && ![empty_string_p $query]} {
	append return_url "?$query"
    }
    set return_url_for_toggle [ns_urlencode "[ns_conn url]?group_id=[ad_calendar group_id]&current_view=[ad_calendar current_view]&current_date=[ad_calendar current_date]&view_mode=[ns_urlencode $view_mode]&action=[ad_calendar action]"]
    
    append result "
    <table cellpadding=2 cellspacing=0 border=0 width=100%>
    <tr>
    <td>
    [calendar_view_title]
    </td>
    </tr>
    "

    if {![string compare $compress_day_view_p "f"]} {
	append result "
	<tr>
	<td>
	<a href=\"/calendar/toggle-compress-day-view?return_url=$return_url_for_toggle\">
	only show hours with items</a>"
    } else {
	append result "
	<tr>
	<td>
	<a href=\"/calendar/toggle-compress-day-view?return_url=$return_url_for_toggle\">
	show all hours</a>"
    }

    append result "
    </td>
    </tr>
    <tr>
    <td>
    "

    db_1row cal_get_hours_span "
    select nvl(hours_span, '0023') as hours_span
    from cal_user_prefs
    where user_id = [ad_calendar logged_in_user_id]"
    
    set start_hour [string range $hours_span 0 1]
    set end_hour [string range $hours_span 2 3] 
    
    set day_html [calendar_day_view [ad_calendar current_date] \
	    [ad_calendar logged_in_user_id] \
	    [ad_calendar group_id] $compress_day_view_p \
	    $start_hour $end_hour $view_mode]
    
    if [empty_string_p $day_html] {
	append result [calendar_no_items]
    } else {
	append result $day_html
    }

    append result "
    </td>
    </tr>
    "

    append result "
    </table>
    "
    return $result
}

ad_proc -public calendar_display_item_aev { {-all_day_checked_string ""} {form_action "/calendar/item-aev-2.tcl"}} {
    displays pages for add, editing, and viewing calendar files
} {
    initialize_calendar_parameters 

    ad_page_variables {
	{item_id 0}
	{parent_id 0}
	{def_title ""}
	{description ""}
	{start_date "___LOOKUP_DEFAULT"} 
	{end_date "___LOOKUP_DEFAULT"} 
	{duration "___LOOKUP_DEFAULT"}
	{return_url ""}
    }
    return [calendar_item_aev -form_name "item-aev"\
	    -action [ad_calendar action]\
	    -item_id $item_id\
	    -parent_id $parent_id\
	    -pass_through_current_view [ad_calendar current_view]\
	    -pass_through_current_date [ad_calendar current_date]\
	    -def_title $def_title\
	    -def_start_date $start_date\
	    -def_end_date $end_date\
	    -duration $duration\
	    -def_description $description\
	    -user_id [ad_calendar user_id]\
	    -group_id [ad_calendar group_id]\
	    -group_member_p [ad_calendar group_member_p]\
	    -group_admin_p [ad_calendar group_admin_p]\
	    -show_debug_info_p f\
	    -read_only_p f\
	    -return_url $return_url\
	    -all_day_checked_string $all_day_checked_string\
	    "$form_action"\
	    [ad_calendar logged_in_user_id]]
}

# This is very education specific....
ad_proc calendar_display_attachment_add {} {
    displays pages for attaching documents to calendar items
} {
    initialize_calendar_parameters 

    ad_page_variables {
	{item_id}
	{parent_id}
	{return_url ""}
	{group_id ""}
	{current_date ""}
    }
    
    set attach_file_allowed_p [calendar_item_write_access_p $item_id $group_id]
    
    db_1row cal_get_file_ids_and_item_info "
    select fs_file_id_seq.nextval as file_id,
           fs_version_id_seq.nextval as version_id,
           nvl(ii.title, i.title) as cal_item_title
    from cal_items i, cal_items ii
    where ii.item_id = :item_id
      and ii.parent_id = i.item_id
    "

    set personal_calendar_p [db_string cal_get_personal_p "
    select decode(group_id, NULL, 1, 0) 
    from cal_user_group_item_map 
    where item_id = :parent_id"]
    set group_id [ad_calendar group_id]
    set group_type [db_string cal_get_group_type "
    select group_type 
    from user_groups 
    where group_id = :group_id" -default ""]

    if ![info exists return_url] {
	set return_url "[ns_conn url]?group_id=$group_id&action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]&current_date=[ad_calendar current_date]"
    }
    if $personal_calendar_p {
	set doc_type personal
    }

    if !$attach_file_allowed_p {
	return "
	<blockquote>
	<h4>Insufficient permission to attach a file</h4>
	</blockquote>
	"
    }

    switch [ad_calendar action] {
	attachment-add {
	    set pretty_doc_type Attachment
	}
# unused! besides we don't want to hard-code the kinds of attachments -ejc@arsdigita.com 1/17/2001
#	handout-add {
#	    set pretty_doc_type Handout
#	}
#	lecture-notes-add {
#	    set pretty_doc_type "Lecture Notes"
#	}
#	assignment-add {
#	    set pretty_doc_type Assignment
#	}
    }

    if { !$personal_calendar_p && $group_type == "edu_class"} {
	set type_html "
	<th align=right>Type:</th>
	<td valign=top align=left>
	[edu_calendar_attachment_folder_widget $group_id]
	</td>
	</tr>"

	set search_link "<a href=\"/calendar/add-existing-attachment?[export_url_vars item_id doc_type group_id parent_id return_url current_date]\">Use an existing $pretty_doc_type</a>"
    } else {
	set type_html ""
	set search_link ""
    }

    append page_content "
    <h3>Add $pretty_doc_type to $cal_item_title</h3>
    $search_link
    <form enctype=multipart/form-data method=post action=/calendar/attachment-add-2>
    [export_form_vars parent_id item_id file_id version_id doc_type group_id return_url current_date]
    <table>
    
    <tr>
    <th align=right>Title: </th>
    <td valign=top>
    <input type=text size=30 maxsize=100 name=file_title>
    </td>
    </tr>

    $type_html

    <tr><td>
    </td>
    </tr>

    <tr><td></td><td>Upload a file from your computer by clicking \"Browse...\"
    
    <tr>
    <td align=right>Filename: </td>
    <td><input type=file name=upload_file size=20></td>
    </tr>

    
    <tr><td></td></tr>

    <tr><th align=right>OR</th><td>Enter the URL of a file on the World Wide Web</td></tr>

    <tr>
    <td align=right>URL: </td>
    <td><input type=input name=url size=40 value=\"http://\"></td>
    </tr>
    
    <tr><td></td></tr>

    <tr><th valign=top align=right>OR</th><td>Enter the text of your attachment
    <br>
    <input type=radio name=text_or_html value=\"text\" checked> Plain text
    <input type=radio name=text_or_html value=\"html\"> HTML
    </td></tr>

    <tr>
    <td align=right valign=top>Text:</td>
    <td valign=top>
    <textarea cols=50 rows=6 wrap name=file_text></textarea>
    </td>
    </tr>
    
    
    <tr>
    <td colspan=2 align=center>
    <br>
    <input type=submit value=\"Attach\">
    </td>
    </tr>
    </table>
    </form>
    "
    
    return $page_content
}

ad_proc calendar_display_year_view {} {
    Displays year calendar for user or group
} { 
    initialize_calendar_parameters 

    regexp {^([0-9][0-9][0-9][0-9])-} [ad_calendar current_date] match current_year
    set year_html [cal_year_calendar -group_id [ad_calendar group_id] -view_mode [ad_calendar view_mode] $current_year [ad_calendar current_date]]

    return " 
    <table border=0 cellspacing=10 cellpadding=10>
    <tr align=center>
    <td colspan=3 bgcolor=lavender>
    [calendar_view_title]
    </td>
    </tr>
    $year_html
    </table>
    "
}

ad_proc calendar_display_month_view {} {
    Displays month calendar for user or group
} { 
    initialize_calendar_parameters 

    # Display month, year, and weekday labels
    append page_content "
    [calendar_view_title]
    <br>

    <table cellpadding=3 cellspacing=0 border=1 width=90%>

    <tr bgcolor=lavender>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Sunday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Monday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Tuesday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Wednesday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Thursday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Friday</font>
    </th>
    <th ALIGN=center width=14%>
    <font face=\"Arial,Helvetica\" size=-1>Saturday</font>
    </th>
    </tr>
    "

    set current_date [ad_calendar current_date]
    set group_id [ad_calendar group_id]
    set user_id [ad_calendar user_id]
    set logged_in_user_id [ad_calendar logged_in_user_id]

    # Set up variables containing information about this month's display
    db_1row cal_month_display_vars " 
    select to_char(to_date(:current_date), 'fmMonth') as month, 
           to_char(to_date(:current_date), 'YYYY') as year, 
	   trunc(last_day(to_date(:current_date))) as last_day_of_month,
	   to_char(last_day(to_date(:current_date)), 'DD') as num_days_in_month,
	   trunc(add_months(to_date(:current_date), 1)) as next_month,
	   trunc(add_months(to_date(:current_date), -1)) as prev_month,
	   trunc(to_date(:current_date), 'yyyy') as beginning_of_year,
	   to_char(last_day(add_months(to_date(:current_date), -1)), 'DD') as days_in_last_month,
	   trunc(last_day(add_months(to_date(:current_date), -1))) as last_day_last_month,
	   trunc(add_months(to_date(:current_date), 1)) as first_day_next_month,
	   to_char(add_months(to_date(:current_date), 1), 'fmMonth') as next_month_name,
	   to_char(add_months(to_date(:current_date), -1), 'fmMonth') as prev_month_name,
	   to_char(next_day(trunc(to_date(:current_date), 'Month') - 7, 'SUNDAY'), 'J') as first_julian_date,
	   next_day(trunc(to_date(:current_date), 'Month') - 7, 'SUNDAY') as first_displayed_date,
	   to_char(next_day(last_day(to_date(:current_date)), 'SATURDAY'), 'J') as last_julian_date,
	   next_day(last_day(to_date(:current_date)), 'SATURDAY') as last_displayed_date
    from dual
    "

    # Select all items for this month and generate calendar
    set month_list_of_lists [db_list_of_lists cal_month_list_of_lists "
    select to_date(:first_displayed_date) + day_num as the_date,
  	   to_char(to_date(:first_displayed_date) + day_num, 'fmMonth') as the_month,
	   to_char(to_date(:first_displayed_date) + day_num, 'fmDD') as pretty_date,
   	   to_char(to_date(:first_displayed_date) + day_num, 'fmDay') as weekday
    from cal_month_days
    where to_date(:first_displayed_date) + day_num < = to_date('${last_displayed_date}')
    order by day_num"]

    set last_output_date [expr $first_julian_date - 1]
    set finish_day 0
    set prev_weekday "Saturday"

    if {$group_id == 0} {
	# user calendar
	set group_id_list [join [db_list cal_groups_displayed "
	select unique ugm.group_id
                    from user_group_map ugm, cal_user_update_prefs ugp
                    where ugm.user_id = :logged_in_user_id
                      and ugp.user_id = ugm.user_id
                      and ugm.group_id = ugp.group_id
                      and ugp.update_type = 'automatically'
	"] ", "]
	if [empty_string_p $group_id_list] {
	    set user_or_group_sql "and m.user_id = :logged_in_user_id"
	} else {
	    set user_or_group_sql "and (m.user_id = :logged_in_user_id
	    or m.group_id in ($group_id_list))
	    "
	}
    } else {
	# Group calendar
	set user_or_group_sql "and m.group_id in (select ug3.group_id
                                                  from user_groups ug3
                                                  start with ug3.group_id= :group_id
                                                  connect by prior ug3.group_id = ug3.parent_group_id)"
    }

    # For some reason the performance of the cost-based optimizer is
    # extremely poor for this query.  This is apparent even on moderate sizes
    # e.g. selecting 215 items out of 3100.  The time difference can be almost
    # an order of magnitude on the system I tested it on.  Thus the hint
    # to use the rule-based optimizer.
    db_foreach cal_month_items "
    select /*+ RULE */ ii.item_id, ii.parent_id,
      combine_type_names(ii.item_id, ', ') as type_list,
      ug2.group_id as item_group_id, ug2.short_name as item_group_name, 
      ug2.short_name as item_group_short_name, ug2.group_type as item_group_type,
      first_names || ' ' || substr(last_name, 1, 1) as name,
      decode(m.group_id, NULL, 'f', 't') as group_p,
      to_char(ii.start_date, 'J') as julian_date,
      to_char(ii.start_date, 'YYYY-MM-DD HH24:MI') as start_time,
      to_char(ii.start_date, 'fmHH:fmMIam') as pretty_start_time,
      to_char(ii.end_date, 'YYYY-MM-DD HH24:MI') as end_time,
      to_char(ii.end_date, 'fmHH:fmMIam') as pretty_end_time,
      nvl(ii.title, i.title) as title,
      nvl(ii.related_link_url, i.related_link_url) as related_link_url, 
      nvl(ii.related_link_text, i.related_link_text) as related_link_text, 
      nvl(ii.redirect_to_related_link_p, i.redirect_to_related_link_p) as redirect_to_related_link_p
    from cal_items i, cal_items ii, cal_user_group_item_map m, 
      user_groups ug2, users u
    where i.item_id = ii.parent_id
      and ii.start_date between 
            to_date(:first_displayed_date) and
            to_date(:last_displayed_date) + 1 - 1/(60*60*24)
      and i.item_id = m.item_id 
      and m.group_id = ug2.group_id(+)
      and m.user_id = u.user_id(+)
      $user_or_group_sql
    order by ii.start_date" {
	# At least one item displayed, will need to close.
	set finish_day 1

	# See if this is either the very first day or a new day
	if {$julian_date != $last_output_date} {
	    set index [expr $julian_date - $first_julian_date]
	    set row [lindex $month_list_of_lists $index]
	    set the_date [lindex $row 0]
	    set the_month [lindex $row 1]
	    set pretty_date [lindex $row 2]
	    set weekday [lindex $row 3]

	    # If not the first day, close the previous day.
	    if {$last_output_date >= $first_julian_date} {
		append page_content "</table></td>"
		if {$prev_weekday == "Saturday"} {
		    append page_content "</tr>"
		}
	    }
	    # Output intervening days with no items.
	    append page_content \
		    [calendar_month_empty_days $month $month_list_of_lists $first_julian_date [expr $last_output_date + 1] [expr $julian_date - 1]]

	    # Output the right combination of tr/td
	    if {$weekday == "Sunday"} {
		append page_content "<tr>"
	    }
	    if {[string compare $the_date [ad_calendar current_date]]==0} {
		append page_content "<td width=14% valign=top bgcolor=FFF8DC>"
	    } elseif {[string compare $the_month $month]!=0} {
		append page_content "<td width=14% valign=top bgcolor=DCDCDC>"
	    } elseif {[string compare $the_month $month]==0 && [string compare $the_date [ad_calendar current_date]]!=0 } {
		append page_content "<td width=14% valign=top>"
	    }
	    append page_content "<a href=\"[ad_calendar day_link]current_date=$the_date&group_id=[ad_calendar group_id]\"><b>$pretty_date</b></a>&nbsp;&nbsp;<a href=\"[ad_calendar current_view_link]start_date=$the_date&group_id=[ad_calendar group_id]&action=item-add\"><img src=/calendar/graphics/add.gif width=20 height=8 border=0></a>
	    "
	    # Start for outputting items
	    append page_content "<table border=0 width=100%>"

	    set last_output_date $julian_date
	    set prev_weekday $weekday
	} 
	# Output this item
	append page_content "
	<tr>
	<td>
	<font point-size=-1>
	"
	if ![empty_string_p $end_time] {
	    append page_content <b>$pretty_start_time</b>
	} 
	if { $group_p == "f" || [ad_calendar type]=="group" } {
	    if {"$redirect_to_related_link_p" == "t"} {
		append page_content "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	    } else {
		if { $group_id==$item_group_id || [empty_string_p $item_group_id] } {
		    append page_content "
		    <a href=[ad_calendar add_link][ad_calendar view_mode_var]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a>"
		} else {
		    append page_content "
		    <a href=[ad_calendar add_link][ad_calendar view_mode_var]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a> ($item_group_name)"
		}
	    }
	    append page_content "
	    </font>
	    </td>      
	    </tr>
	    "
	} else {
	    if {"$redirect_to_related_link_p" == "t"} {
		append page_content "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	    } else {
		#code with group for Sloan. Also takes you out of portals to a scoped page if you click on an item.
		append page_content "	
		<a href=/calendar/?[ad_calendar view_mode_var]action=item-view&group_id=$item_group_id&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a> ($item_group_name)"
		#This is the code without the group and staying in portals
#		<a href=[ad_calendar add_link][ad_calendar view_mode_var]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a>"
	    }
	    append page_content "
	    </font>
	    </td>      
	    </tr>
	    "
	} 
    } 
    # Close up
    if $finish_day {
	append page_content "</table></td>"
	if {$weekday == "Saturday"} {
	    append page_content "</tr>"
	}
    }
    append page_content \
	    [calendar_month_empty_days $month $month_list_of_lists $first_julian_date [expr $last_output_date + 1] $last_julian_date]

    append page_content "
    </table>
    "
}

ad_proc calendar_month_empty_days { {} month month_list_of_lists base_julian_date start_julian_date end_julian_date} {
    Generate HTML for calendar month days containing no items.
} {
    set result ""

    set start_index [expr $start_julian_date - $base_julian_date]
    set end_index [expr $end_julian_date - $base_julian_date]

    for {set index $start_index} {$index <= $end_index} {incr index} {
	set row [lindex $month_list_of_lists $index]
	set the_date [lindex $row 0]
	set the_month [lindex $row 1]
	set pretty_date [lindex $row 2 ]
	set weekday [lindex $row 3]

	if {$weekday == "Sunday"} {
	    append result "<tr>\n"
	}
	if {[string compare $the_date [ad_calendar current_date]]==0} {
	    append result "<td width=14% valign=top bgcolor=FFF8DC>\n"
	} elseif {[string compare $the_month $month]!=0} {
	    append result "<td width=14% valign=top bgcolor=DCDCDC>\n"
	} elseif {[string compare $the_month $month]==0 && [string compare $the_date [ad_calendar current_date]]!=0 } {
	    append result "<td width=14% valign=top>\n"
	}
	append result "<a href=[ad_calendar day_link]current_date=$the_date&group_id=[ad_calendar group_id]><b>$pretty_date</b></a>&nbsp;&nbsp;<a href=\"[ad_calendar current_view_link]start_date=$the_date&group_id=[ad_calendar group_id]&action=item-add\"><img src=/calendar/graphics/add.gif width=20 height=8 border=0></a>
	</td>\n"
	if {$weekday == "Saturday"} {
	    append result "</tr>\n"
	}
    }
    return "$result"
}

ad_proc calendar_display_week_view {} {
    Displays week calendar for user or group
} { 
    initialize_calendar_parameters 
    set current_date [ad_calendar current_date]

    append page_content "
    <blockquote>
    <table CELLPADDING=3 CELLSPACING=0 BORDER=0 width=85%>
    <TR>
    <TD>
    [calendar_view_title]
    </TD>
    </TR>
    <tr>
    <td>
    <table cellpadding=3 cellspacing=0 border=1 width=90%>"

    db_1row cal_week_display_vars "     
    select next_day(to_date(:current_date) - 7, 'SUNDAY') as this_begin,
	   next_day(to_date(:current_date) - 1, 'SATURDAY') as this_end,
           to_char(next_day(to_date(:current_date) - 7, 'SUNDAY'), 'J') as first_julian_date,
	   to_char(next_day(to_date(:current_date) - 1, 'SATURDAY'), 'J') as last_julian_date,
	   next_day(to_date(:current_date), 'SUNDAY') as next_begin,
	   next_day(to_date(:current_date) + 7, 'SATURDAY') as next_end,
	   next_day(to_date(:current_date) - 14, 'SUNDAY') as previous_begin,
	   next_day(to_date(:current_date) - 7, 'SATURDAY') as previous_end
    from dual"

    set week_list_of_lists [db_list_of_lists cal_week_list_of_lists "
    select to_date(:this_begin) + day_num as day, 
   	   to_char(to_date(:this_begin) + day_num, 'fmMonth fmDD, YYYY') as pretty_day,
	   to_char(to_date(:this_begin) + day_num, 'fmDay') as day_name
    from cal_week_days
    order by day"]

    set group_id [ad_calendar group_id]
    set user_id [ad_calendar user_id]
    set logged_in_user_id [ad_calendar logged_in_user_id]

    if {$group_id == 0} {
	# user calendar
	set user_or_group_sql "and (m.user_id = :logged_in_user_id
                or m.group_id in 
                   (select ugm.group_id
                    from user_group_map ugm, cal_user_update_prefs ugp
                    where ugm.user_id = :logged_in_user_id
                      and ugp.user_id = ugm.user_id
                      and ugm.group_id = ugp.group_id
                      and ugp.update_type = 'automatically')
                )
	"
    } else {
	# Group calendar
	set user_or_group_sql "and m.group_id in (select ug2.group_id
                                                  from user_groups ug2
                                                  start with ug2.group_id= :group_id
                                                  connect by prior ug2.group_id = ug2.parent_group_id)"
    }
    
    set last_output_date [expr $first_julian_date - 1]
    set finish_day 0
    # For some reason the performance of the cost-based optimizer is
    # extremely poor for this query.  Thus the hint
    # to use the rule-based optimizer.
    db_foreach cal_week_items "
    select /*+ RULE */ ii.item_id, ii.parent_id,
      decode(m.group_id, NULL, 'f', 't') as group_p,
      to_char(ii.start_date, 'J') as julian_date,
      to_char(ii.start_date, 'YYYY-MM-DD HH24:MI') as start_time,
      to_char(ii.start_date, 'fmHH:fmMIam') as pretty_start_time,
      to_char(ii.end_date, 'YYYY-MM-DD HH24:MI') as end_time,
      to_char(ii.end_date, 'fmHH:fmMIam') as pretty_end_time,
      nvl(ii.title, i.title) as title,
      nvl(ii.related_link_url, i.related_link_url) as related_link_url, 
      nvl(ii.related_link_text, i.related_link_text) as related_link_text, 
      nvl(ii.redirect_to_related_link_p, i.redirect_to_related_link_p) as redirect_to_related_link_p,
      ug.short_name as group_name, ug.group_id as item_group_id
    from cal_items i, cal_items ii, cal_user_group_item_map m, user_groups ug
    where  i.item_id = ii.parent_id
      and ii.start_date between 
            to_date(:this_begin) and
            to_date(:this_end) + 1 - 1/(60*60*24)
      and i.item_id = m.item_id 
      and m.group_id=ug.group_id(+)
      $user_or_group_sql
    order by ii.start_date" {
	# At least one item displayed, will need to close.
	set finish_day 1

	# See if this is either the very first day or a new day
	if {$julian_date != $last_output_date} {
	    set index [expr $julian_date - $first_julian_date]
	    set row [lindex $week_list_of_lists $index]
	    set day [lindex $row 0]
	    set pretty_day [lindex $row 1]
	    set day_name [lindex $row 2]

	    # If not the first day, close the previous day.
	    if {$last_output_date >= $first_julian_date} {
		append page_content "</table></td></tr>\n"
	    }
	    # Output intervening days with no items.
	    append page_content \
		    [calendar_week_empty_days $week_list_of_lists $first_julian_date [expr $last_output_date + 1] [expr $julian_date - 1]]

	    append page_content "<tr>"
	    if {[string compare $day [ad_calendar current_date]]==0} {
		append page_content "<td bgcolor=FFF8DC>"
	    } else {
		append page_content "<td bgcolor=DCDCDC>"
	    }

	    append page_content "<b>$day_name</b>,
	    <a href=[ad_calendar day_link][ad_calendar view_mode_var]group_id=[ad_calendar group_id]&current_date=$day>$pretty_day</a>
	    &nbsp
	    <font size=-1> 
	    <a href=[ad_calendar add_link][ad_calendar view_mode_var]current_date=$day&start_date=$day&action=item-add>Add Item</a>
	    </font>
	    </td>
	    </tr>
	    <tr>
	    <td>
	    <table border=0 width=100%>
	    "
	    set last_output_date $julian_date    
	}
	# Output this item
	append page_content "
	<tr>
	<td>
	<font size=-1>
	"
	if ![empty_string_p $end_time] {
	    append page_content <b>$pretty_start_time</b>
	} 
	if { $group_p == "f" || [ad_calendar type]=="group" } {
	    if {"$redirect_to_related_link_p" == "t"} {
		append page_content "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	    } else {
		if { $group_id == $item_group_id || [empty_string_p $item_group_id]} {
		    append page_content "
		    <a href=[ad_calendar add_link][ad_calendar view_mode_var]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a>"
		} else {
		    append page_content "
		    <a href=[ad_calendar add_link][ad_calendar view_mode_var]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a> (for $group_name)"
		}
	    }
	    append page_content "
	    </font>
	    </td>      
	    </tr>
	    "
	} else {
	    if {"$redirect_to_related_link_p" == "t"} {
		append page_content "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	    } else {
		append page_content "
<a href=/calendar/?[ad_calendar view_mode_var]action=item-view&item_id=$item_id&group_id=$item_group_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a> (for $group_name)"
	    }
	    append page_content "
	    </font>
	    </td>      
	    </tr>
	    "
	} 
    } 
    # Close up
    if $finish_day {
	append page_content "</table></td></tr>"
    }

    # Now output any remaining days
    append page_content \
	    [calendar_week_empty_days $week_list_of_lists $first_julian_date [expr $last_output_date + 1] $last_julian_date]

  append page_content "
    </table>
    </td>
    </tr>
    </table>
    </blockquote>
    "
    return $page_content
}

ad_proc calendar_week_empty_days { {} week_list_of_lists base_julian_date start_julian_date end_julian_date} {
    Generate HTML for calendar week days containing no items.
} {
    set result ""

    set start_index [expr $start_julian_date - $base_julian_date]
    set end_index [expr $end_julian_date - $base_julian_date]

    for {set index $start_index} {$index <= $end_index} {incr index} {
	set row [lindex $week_list_of_lists $index]
	set day [lindex $row 0]
	set pretty_day [lindex $row 1]
	set day_name [lindex $row 2]

	append result "<tr>"
	if {[string compare $day [ad_calendar current_date]]==0} {
	    append result "<td bgcolor=FFF8DC>"
	} else {
	    append result "<td bgcolor=DCDCDC>"
	}

	append result "<b>$day_name</b>,
	<a href=[ad_calendar day_link][ad_calendar view_mode_var]group_id=[ad_calendar group_id]&current_date=$day>$pretty_day</a>
	&nbsp
	<font size=-1> 

	<a href=[ad_calendar add_link][ad_calendar view_mode_var]&current_date=$day&start_date=$day&action=item-add>Add Item</a>
	</font>
	</td>
	</tr>
	<tr><td>
	&nbsp;
	</td></tr>"
    }
    return "$result"
}

ad_proc calendar_display_upcoming {{} {upcoming_items_days ""} {past_items_days 0} {upcoming_items_length ""} } {
    Displays list of calendar items for the next upcoming_items_days and in to the past for past_items_day.  Displays the first upcoming_items_length number of items.
} { 

    ad_page_variables {{orderby ""}}

    if {![info exists orderby] || [empty_string_p $orderby]} {
	set orderby "orderby_type"
    }

    initialize_calendar_parameters
    set current_date [ad_calendar current_date]

    set prefs_for_select [list]
    if { ![exists_and_not_null upcoming_items_days] } {
	lappend prefs_for_select "upcoming_items_days"
    }
    if { ![exists_and_not_null upcoming_items_length] } {
	lappend prefs_for_select "upcoming_items_length"
    }

    if { [exists_and_not_null prefs_for_select] } {
	db_1row prefs_select "select [join $prefs_for_select ,]
	from cal_user_prefs
	where user_id = [ad_calendar logged_in_user_id]"
    }

    if { [exists_and_not_null upcoming_items_length] } {
	set length_where "where rownum < = $upcoming_items_length" 
    } else {
	set length_where ""
    }


    db_1row cal_get_upcoming_date "select
    to_char((to_date(:current_date) + :upcoming_items_days), 'Month DD, YYYY') as upcoming_end_pretty_date,
    to_char((to_date(:current_date) - :past_items_days), 'Month DD, YYYY') as upcoming_start_pretty_date
    from dual"

    set num_upcoming_items 0

    set table_def {
	{day_start_day {Day of Week} {} c}
	{pretty_start_day {Date} {start_date $order} c}
	{pretty_start_time {Start Time} {orderby_start_time $order} {<td align=center>[
	if [empty_string_p $pretty_end_time] {
	    return "No Time"
	} else {
	    return $pretty_start_time
	}]</td>} }
	{pretty_end_time {End Time} {orderby_end_time $order} {} c}
	{item_group_name {Group Name} {} \
		{<td>$item_group_name</td>} }
	{title {Title} {} {<td>[
	if {$redirect_to_related_link_p == "t"} {
	    return "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	} else {
	    return "<a href=/calendar/?action=item-view&group_id=$item_group_id&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a>"
	}]</td>} }
	{orderby_type {Types} {} c}
    }

    set sql_query "
    select /*+ RULE */ *
    from (select ii.item_id, ii.parent_id,
          ug.group_id as item_group_id, nvl(ug.short_name,'Personal') as item_group_name, ug.short_name as item_group_short_name, nvl(ug.group_type, 'Personal') as item_group_type,
         combine_type_names(ii.item_id, '<BR>') as item_types,
         type as orderby_type,
          decode(m.user_id, NULL, 'f', 't') as user_p,
          ii.start_date,
          to_char(ii.start_date, 'MM/DD/YY') as pretty_start_day,
	  to_char(ii.start_date, 'Day') as day_start_day,
          to_char(ii.end_date, 'fmMonth fmDD, YYYY') as pretty_end_day,
          to_char(ii.end_date, 'Day') as day_end_day,
          to_char(ii.start_date, 'fmHH:fmMIam') as pretty_start_time,
          to_char(ii.end_date, 'fmHH:fmMIam') as pretty_end_time,
          to_char(ii.start_date, 'amHH:MI') as orderby_start_time,
          to_char(ii.end_date, 'amHH:MI') as orderby_end_time,
	  nvl(ii.title, i.title) as title, m.user_id,
          nvl(ii.related_link_url, i.related_link_url) as related_link_url, 
          nvl(ii.related_link_text, i.related_link_text) as related_link_text, 
          nvl(ii.redirect_to_related_link_p, i.redirect_to_related_link_p) as redirect_to_related_link_p
          from cal_items i, cal_items ii, cal_user_group_item_map m, 
               cal_user_prefs u, user_groups ug,
               cal_item_types ct, cal_item_type_map ctm
	  where ug.group_id(+) = m.group_id
            and u.user_id = [ad_calendar logged_in_user_id]
            and i.item_id = ii.parent_id  
	    and u.list_upcoming_p = 't'
  	    and i.item_id = m.item_id
	    and ii.start_date between 
                  to_date('[ad_calendar current_date]') and
 		  to_date('[ad_calendar current_date]') + $upcoming_items_days
	    and [calendar_user_group_sql]
            and ii.item_id = ctm.item_id(+)
            and ctm.type_id = ct.type_id(+))
     $length_where 
     [ad_order_by_from_sort_spec $orderby $table_def]"

    set rowcode {}
    set remove_column [list]
    switch [ad_sort_primary_key $orderby] {
	orderby_type {
	    lappend remove_column orderby_type
	    set rowcode {
		[if {![ad_table_same orderby_type]} {
		    ad_table_span [switch $orderby_type {
			"" {subst {<b>No Type</b>}}
			default {subst {<b>Type: $orderby_type</b>}}
		    }] "bgcolor=cccccc"
		}]
		}
	    }
	}


	#
	# generate the columns we really want to see given the list of removes
	#
	
	set all_columns {}
	foreach column $table_def {
	    lappend all_columns [lindex $column 0]
	}
	set col [list]
	foreach acol $all_columns { 
	    if {[lsearch -exact $remove_column $acol] < 0} { 
		lappend col $acol
	    }
	}

	set upcoming_items_html [ad_table -Taudit {item_id} -Tcolumns $col -Tpre_row_code $rowcode -Torderby $orderby -Tmissing_text "" cal_upcoming_items  $sql_query $table_def]

    if [empty_string_p $upcoming_items_html] {
	append page_content "
	<ul><li><em>No upcoming items.</em></ul>"
    } else {

	append page_content "
	<b>Upcoming Items: $upcoming_start_pretty_date"
	
	if { $upcoming_items_days > 1 } {
	    append page_content " - $upcoming_end_pretty_date"
	}
	
	append page_content "
	</b>
	<blockquote>
	$upcoming_items_html
	</blockquote>
	<br>
	"
    }

    return $page_content
}

ad_proc calendar_display_list_view {{} {view_mode "modular"}} {
    Produces a list of upcoming items and new items by calling two different procs.
} {
    initialize_calendar_parameters $view_mode
    db_1row cal_get_upcoming_items "
    select upcoming_items_days, upcoming_items_length
    from cal_user_prefs
    where user_id = [ad_calendar logged_in_user_id]"
    
    set past_items_days 0

    return "[calendar_display_upcoming $upcoming_items_days $past_items_days $upcoming_items_length] 
            [calendar_display_new [ad_calendar new_items_age]]"
}


ad_proc calendar_display_new {{} {new_items_age "[ad_calendar new_items_age]"} {past_items_days 0} {upcoming_items_length ""} } {
    Display items added in the last new_items_age days.
} {
    ad_page_variables {{orderby ""}}

    if {![info exists orderby] || [empty_string_p $orderby]} {
	set orderby "orderby_type"
    }

    initialize_calendar_parameters
    
    ## if n_past_days exists, use it.
    if {[apm_package_enabled_p "education"]} {
	set new_items_age [edu_get_n_past_days]
    } else {
	set new_items_age [ad_calendar new_items_age]
    }

    set num_new_items 0

    set table_def {
	{day_start_day {Day of Week} {} c}
	{pretty_start_day {Date} {start_date $order} c}
	{pretty_start_time {Start Time} {orderby_start_time $order} {<td align=center>[
	if [empty_string_p $pretty_end_time] {
	    return "No Time"
	} else {
	    return $pretty_start_time
	}]</td>} }
	{pretty_end_time {End Time} {orderby_end_time $order} c}
	{item_group_name {Group Name} {} \
		{<td>[cal_group_home_link $item_group_id $item_group_type $item_group_short_name $item_group_name]</td>} }
	{title {Title} {} {<td>[
	if {$redirect_to_related_link_p == "t"} {
	    return "[cal_related_link_html $title "" $related_link_url $related_link_text]"
	} else {
	    return "<a href=[ad_calendar add_link]action=item-view&item_id=$item_id&parent_id=$parent_id&current_view=[ad_calendar current_view]>$title</a>"
	}]</td>} }
	{orderby_type {Types} {} c}
    }

    set sql_query "
    select /*+ RULE */ ii.item_id, ii.parent_id,
           ug.group_id as item_group_id, ug.short_name as item_group_name, ug.short_name as item_group_short_name, ug.group_type as item_group_type,
           combine_type_names(ii.item_id, '<BR>') as item_types,
           type as orderby_type,
           decode(m.user_id, NULL, 'f', 't') as user_p,
           ii.start_date,
           to_char(ii.start_date, 'MM/DD/YY') as pretty_start_day,
	   to_char(ii.start_date, 'Day') as day_start_day,
           to_char(ii.end_date, 'fmMonth fmDD, YYYY') as pretty_end_day,
           to_char(ii.end_date, 'Day') as day_end_day,
           to_char(ii.start_date, 'fmHH:fmMIam') as pretty_start_time,
           to_char(ii.end_date, 'fmHH:fmMIam') as pretty_end_time,
          to_char(ii.start_date, 'amHH:MI') as orderby_start_time,
          to_char(ii.end_date, 'amHH:MI') as orderby_end_time,
           nvl(ii.title, i.title) as title,
           m.user_id,
           nvl(ii.related_link_url, i.related_link_url) as related_link_url, 
           nvl(ii.related_link_text, i.related_link_text) as related_link_text, 
           nvl(ii.redirect_to_related_link_p, i.redirect_to_related_link_p) as redirect_to_related_link_p
    from cal_items i, cal_items ii, cal_user_group_item_map m, cal_user_prefs u,
         user_groups ug, cal_item_types ct, cal_item_type_map ctm
    where ug.group_id(+) = m.group_id
      and u.user_id = [ad_calendar logged_in_user_id]
      and i.item_id = ii.parent_id
    and u.list_new_p = 't'
    and i.item_id = m.item_id
    and i.creation_date > sysdate - $new_items_age
    and [calendar_user_group_sql]
    and ii.item_id=ctm.item_id(+)
    and ct.type_id(+)=ctm.type_id
    [ad_order_by_from_sort_spec $orderby $table_def]"

    set rowcode {}
    set remove_column [list]
    switch [ad_sort_primary_key $orderby] {
	orderby_type {
	    lappend remove_column orderby_type
	    set rowcode {
		[if {![ad_table_same orderby_type]} {
		    ad_table_span [switch $orderby_type {
			"" {subst {<b>No Type</b>}}
			default {subst {<b>Type: $orderby_type</b>}}
		    }] "bgcolor=cccccc"
		}]
		}
	    }
	}


	#
	# generate the columns we really want to see given the list of removes
	#
	
	set all_columns {}
	foreach column $table_def {
	    lappend all_columns [lindex $column 0]
	}
	set col [list]
	foreach acol $all_columns { 
	    if {[lsearch -exact $remove_column $acol] < 0} { 
		lappend col $acol
	    }
	}

	set new_items_html [ad_table -Taudit {item_id} -Tcolumns $col -Tpre_row_code $rowcode -Torderby $orderby -Tmissing_text "" cal_new_items $sql_query $table_def]

    set new_items_header ""

    if [empty_string_p $new_items_html] {
	append new_items_header "No items"
    } else {
	append new_items_header "Items"
    }

    append new_items_header " added in the "
    if {$new_items_age==1} {
	append new_items_header "last day"
    } else {
	append new_items_header "last $new_items_age days"
    }

    if [empty_string_p $new_items_html] {
	append page_content "
	<ul><li><em>$new_items_header.</em></ul>"
    } else {

	append page_content "
	<b>$new_items_header</b>
	<blockquote>
	$new_items_html
	</blockquote>"
    }
    # We should put in another slider, but for now just do nothing.
    if {[apm_package_enabled_p "education"]} {
	append page_content "
	<blockquote>[edu_new_items_slider]</blockquote>
	"
    }
    return $page_content
}
  

ad_proc cal_groups_list {{} {user_id}} {
    Displays groups that have calendars of which the user is a member.
} { 
    set return_html "
    <table>
    <tr>
    <th align=left valign=bottom>Your Calendars:</th>"

    if {[ad_calendar group_id] == 0} {
	append return_html "
	<th>Group<br>Items</th>
	</tr>
	"
    } else {
	append return_html "
	</tr>
	"
    }
    set return_url [ad_calendar current_view_link]group_id=[ad_calendar group_id]&current_date=[ns_urlencode [ad_calendar current_date]]

    db_foreach cal_get_user_groups "
       select distinct
         cg.group_id,
	 ug.group_name,
	 decode(update_type, 'automatically', 1, 0) as include_p
       from
         cal_groups cg, user_groups ug, user_group_map ugm, cal_user_update_prefs ugp
       where ugm.user_id = :user_id
         and ugp.user_id = ugm.user_id
         and ugm.group_id = cg.group_id
	 and ugp.group_id = cg.group_id
	 and ug.group_id = cg.group_id
       order by group_name" {
	   
	   append return_html "<tr>"
	   if {[ad_calendar group_id] != $group_id} {
	       append return_html "
	       <td><a href=\"[ad_calendar current_view_link]group_id=$group_id\">$group_name</a></td>"
	   } else {
	       append return_html "<td>$group_name</td>"
	       set current_group_name $group_name
	       set current_group_id $group_id
	   }
	   if {[ad_calendar group_id] == 0} {
	       append return_html "<td><a href=\"toggle-group-cal?current_view=[ad_calendar current_view]&[export_url_vars group_id return_url]\">"
	       if {$include_p == 1} {
		   append return_html "
		   hide</a></td>"
	       } else {
		   append return_html "
		   show</a></td>"
	       }
	   }   
       }
       if {[ad_calendar group_id] == 0} {
	   append return_html "
	   <tr><td><i>Personal</i></td></tr>"
       } else {
	   append return_html "
	   <tr><td><a href=\"[ad_calendar current_view_link]group_id=0\"><i>Personal</i></a></td></tr>
	   "
       }
       append return_html "</table>"

       set group_admin_p [db_string cal_group_admin_p "
       select count(group_id)
       from user_group_map
       where user_id = :user_id
       and role = 'administrator'"]
       if {$group_admin_p} {
	   append return_html "<p><li><a href=\"/calendar/group-cals-admin.tcl\">Manage group calendars</a>"
       }
       if {[ad_calendar group_id] == 0} {
	   append return_html "
	   <p><li><a href=\"/calendar/admin/types.tcl?scope=user&[export_url_vars user_id]\">Types for Your Calendar</a>"
       } elseif {[info exists current_group_name] && \
	       [ad_user_group_authorized_admin [ad_calendar logged_in_user_id] $current_group_id]} {
	   append return_html "
	   <p><li><a href=\"/calendar/admin/types.tcl?scope=group&group_id=[ad_calendar group_id]\">Types for $current_group_name</a>"
       }
       append return_html "</ul>"

       return $return_html
}

ad_proc calendar_display_full {} {
    Displays calendar.
} { 
    initialize_calendar_parameters "full"

    set group_id [ad_calendar group_id]
    if {$group_id==0} {
	set add_item_link "
	<li><a href=[ad_calendar add_link]action=item-add&user_id=[ad_calendar logged_in_user_id]&start_date=[ad_calendar current_date]&current_view=[ad_calendar current_view]>Add Personal Item</a>
	"
    } else {
	if [ad_calendar group_admin_p] {
	    set add_item_link "
	    <li><a href=[ad_calendar add_link]action=item-add&start_date=[ad_calendar current_date]&current_view=[ad_calendar current_view]>Add Group Item</a>
	    "
	} else {
	    set add_item_link ""
	}
    }
    
    set page_content "
    <table width=95% border=0>
    <tr>
    <td width=30% valign=top>
    [cal_mini_calendar_widget "" [ad_calendar current_view] [ad_calendar current_date] $group_id]
    <br>
    $add_item_link
    <p>
    "
    if {![apm_package_enabled_p "education"]} {
	append page_content "
	[cal_groups_list [ad_calendar logged_in_user_id]]
	"
    }
    append page_content "
    </td>
    
    <td align=left valign=top>
    "
    
    switch [ad_calendar action] {
	view {
	    switch [ad_calendar current_view] {
		list {
		    append page_content [calendar_display_list_view "full"]
		}
		day {
		    append page_content [calendar_display_day_view "full"]
		}
		week {
		    append page_content [calendar_display_week_view]
		}
		month {
		    append page_content [calendar_display_month_view]
		}
		year {
		    append page_content [calendar_display_year_view]
		}
		default {
		    error "packages/calendar/index.tcl: invalid view"
		}
	    }
	}
	item-add -
	item-edit -
	item-view {
	    append page_content [calendar_display_item_aev]
	}
	item-repeat {
	    append page_content [calendar_display_item_aev "/calendar/item-ae-repeat"]
	}
	item-delete {
  	    ad_page_variables {
  		parent_id
  		{item_id ""}
		repeat_p
		title
		{group_id 0}
		{return_url ""}
		{current_date ""}
  	    }

	    append page_content "
	    <table border=0 cellpadding=2>
	    <form name=\"delete_item\" action=\"/calendar/item-delete-2\" method=\"post\">	    
	    <tr>
	    <td colspan=2>
	    <h2>Are you sure you want to delete \"$title\"?</h2>
	    </td>
	    </tr>
	    [philg_hidden_input parent_id $parent_id]
	    [philg_hidden_input group_id $group_id]
	    [philg_hidden_input return_url $return_url]
	    [philg_hidden_input current_view [ad_calendar current_view]]
	    [philg_hidden_input current_date $current_date]
	    "
	    if $repeat_p {
		append page_content "
		<tr>
	    <td><input type=radio name=item_id value=\"$item_id\" checked>Current instance only<br>
	    <input type=radio name=item_id value=\"\">All occurences
	    </td>
		</tr>
		"
	    }

	    append page_content "
	    <tr>
	    <td>
	    <input type=submit value=\"Delete\">
	    </form>
	    </td>
	    <td align=\"right\">
	    "
	    if {[empty_string_p $return_url]} {
		append page_content "
		<form name=\"cancel\" action=\"\" method=\"post\">
		"
	    } else {
		append page_content "
		<form name=\"cancel\" action=\"$return_url\" method=\"post\">
		"
	    }
	    append page_content "
	    <input type=submit value=\"Cancel\">
	    [philg_hidden_input action item-view]
	    [philg_hidden_input parent_id $parent_id]
	    [philg_hidden_input item_id $item_id]
	    [philg_hidden_input group_id $group_id]
	    [philg_hidden_input return_url $return_url]
	    [philg_hidden_input current_view [ad_calendar current_view]]
	    [philg_hidden_input current_date $current_date]
	    </form>
	    </td>
	    </tr>
	    </table>
	    "
	}
	attachment-add -
	handout-add -
	lecture-notes-add -
	assignment-add {
	    append page_content [calendar_display_attachment_add]
	}
	default {
	    error "packages/calendar/index.tcl: invalid action $action"
	}
    }
    
    append page_content "
    </td>
    </tr>
    </table>
    "
    return $page_content
}



