# packages/calendar/www/admin/type-delete.tcl
ad_page_contract {
    If the type is empty, then it deletes the type

    If the type is not empty, then it gives the choice of
    disabling the type or moving everything to another type

    Number of queries: 3

    @author Philip Greenspun (philg@mit.edu)
    @author Sarah Ahmed (ahmeds@arsdigita.com)
    @creation-date 1998-11-18
    @cvs-id $Id: type-delete.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
    
} {
    type_id:integer
    {scope public}
    {user_id ""}
    {group_id ""}
    {on_what_id ""}
    {on_which_group ""}
}

if {[ad_read_only_p]} {
    ad_return_read_only_maintenance_message
    return
}

ad_scope_error_check

ad_scope_authorize $scope admin group_admin user


# see if there are any calendar entries

set query_num_type_entries "
select count(i.item_id) 
from cal_items i, cal_item_type_map m
where type_id = :type_id
and i.item_id = m.item_id"

set num_type_entries [db_string num_type_entries $query_num_type_entries]

if { $num_type_entries == 0 } {

    # no calendar entries, so just delete
    ad_returnredirect "type-delete-2.tcl?[export_url_scope_vars]&type_id=[ns_urlencode $type_id]"
    return
}

set query_type "select type
from cal_item_types
where type_id=:type_id"

set type [db_string cal_get_type $query_type]

set page_content "
[ad_scope_admin_header "Delete Type $type"]
<h2>Delete </h2>
type  <a href=\"type-one?[export_url_scope_vars]&type_id=[ns_urlencode $type_id]\">$type</a>
<hr>

There are entries in the type $type. 
<p>
Would you like to:
<p>
<A href=\"type-delete-2?[export_url_scope_vars type_id]\">Disable $type</a>

<p>
or move all entries to another type: 
<p>
<ul>
"

set query_other_types "
select type as type_new 
from cal_item_types
where type <> :type 
and [ad_scope_sql]
and enabled_p <> 'f'
"

set counter 0
db_foreach cal_get_other_types $query_other_types {

    incr counter
    append page_content "<li><a href=\"type-change?[export_url_scope_vars type_new type_id]\">$type_new</a>\n
    "
}

if { $counter == 0 } {
    append page_content "No additional types are defined"
}

append page_content "

</ul>

[ad_scope_admin_footer]
"

doc_return 200 text/html $page_content

## END FILE type-delete.tcl



