# packages/calendar/www/admin/type-edit.tcl
ad_page_contract {
    Updates the name of the type

    Number of queries: 2 (includes db_resultrows)
    Number of dml: 1 or 2

    @param type_new The type's new name

    @author Philip Greenspun (philg@mit.edu)
    @author Sarah Ahmed (ahmeds@arsdigita.com)
    @creation-date 1998-11-18
    @cvs-id $Id: type-edit.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
    
} {
    type_id:naturalnum
    type_new
    {scope public}
    {user_id:naturalnum ""}
    {group_id:naturalnum ""}
    {on_what_id:naturalnum ""}
    {on_which_group:naturalnum ""}
}

# Note: if page is accessed through /groups pages then group_id and group_vars_set are already set up in 
#       the environment by the ug_serve_section. group_vars_set contains group related variables (group_id, 
#       group_name, group_short_name, group_admin_email, group_public_url, group_admin_url, group_public_root_url,
#       group_admin_root_url, group_type_url_p, group_context_bar_list and group_navbar_list)

# type_id, type_new
# maybe scope, maybe scope related variables (user_id, group_id, on_which_group, on_what_id)

ad_scope_error_check

ad_scope_authorize $scope admin group_admin user


set exception_count 0
set exception_text ""

if { ![info exists type_new] || [empty_string_p $type_new] } {
    incr exception_count
    append exception_text "<li>Please enter a type."
}


if {$exception_count > 0} { 
    ad_scope_return_complaint $exception_count $exception_text
    return
}


db_1row cal_type "
select type 
from cal_item_types
where type_id = :type_id
and [ad_scope_sql]"


if { $type == $type_new } {
    
    ad_returnredirect "type-one.tcl?[export_url_scope_vars ]&type_id=[ns_urlencode $type_id]"
    return
}


db_transaction { 

    ## Desired effect:  Either the type name will be changed,
    ## or the existing type with that name will be enabled.

    ## Gotta love ghost functionality

    db_dml cal_update_type_name "
    update cal_item_types
    set type = :type_new, enabled_p = 't'
    where type_id = :type_id"
    
} on_error {
    
    # there was some other error with the type
    ad_scope_return_error "Error updating type" "We couldn't update your type. Here is what the database returned:
    <p>
    <blockquote>
    <pre>
    $errmsg
    </pre>
    </blockquote>
    "
    return
}

db_release_unused_handles

ad_returnredirect "type-one.tcl?[export_url_scope_vars]&type_id=[ns_urlencode $type_id]"

## END FILE type-edit.tcl


