# packages/calendar/www/admin/type-new.tcl
ad_page_contract {
    Performs an insert of a new type

    Number of queries: 1
    Number of dml: 1

    @author Philip Greenspun (philg@mit.edu)
    @author Sarah Ahmed (ahmeds@arsdigita.com)
    @creation-date 1998-11-18
    @cvs-id $Id: type-new.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
    
} {
    next_type_id:naturalnum
    type_new
    {scope public}
    {user_id:naturalnum ""}
    {group_id:naturalnum ""}
    {on_what_id:naturalnum ""}
    {on_which_group:naturalnum ""}
}

# Note: if page is accessed through /groups pages then group_id and group_vars_set are already set up in 
#       the environment by the ug_serve_section. group_vars_set contains group related variables (group_id, 
#       group_name, group_short_name, group_admin_email, group_public_url, group_admin_url, group_public_root_url,
#       group_admin_root_url, group_type_url_p, group_context_bar_list and group_navbar_list)

# type_new , type_id
# maybe scope, maybe scope related variables (user_id, group_id, on_which_group, on_what_id)

ad_scope_error_check
ad_scope_authorize $scope admin group_admin user

set exception_count 0
set exception_text ""

if { ![info exists type_new] || [empty_string_p $type_new] } {
    incr exception_count
    append exception_text "<li>Please enter a type."
}

db_1row cal_type_exists "
select count(*) as type_exists_p
from cal_item_types
where type = :type_new
and [ad_scope_sql]
"

if { $type_exists_p } {
    incr exception_count
    append exception_text "<li>Type $type_new already exists. Please enter a new type."
}

if {$exception_count > 0} { 
    ad_scope_return_complaint $exception_count $exception_text
    return
}

db_transaction {    
    # add the new type
    db_dml cal_insert_type "
    insert into cal_item_types
    (type_id, type, [ad_scope_cols_sql]) 
    values
    (:next_type_id, :type_new, [ad_scope_vals_sql])" 
    
} on_error {
    
    # there was some other error with the type
    ad_scope_return_error "Error inserting type" "We couldn't insert your type. Here is what the database returned:
    <p>
    <blockquote>
    <pre>
    $errmsg
    </pre>
    </blockquote>
    "
    return
}

db_release_unused_handles

ad_returnredirect "type-one.tcl?[export_url_scope_vars]&type_id=[ns_urlencode $next_type_id]"
## END FILE type-new.tcl


