# packages/calendar/www/attachment-add-2.tcl

ad_page_contract {
    attaches file to the calendar item

    @param upload_file
    @param url
    @param file_text
    @param version_description
    @param return_url
    @param group_id
    @param current_date
    @param parent_id
    @param item_id
    @param file_title
    @param file_id
    @param version_id
    @param doc_type
    @param text_or_html whether the text is plain text (text) or HTML (html)

    @author (tarik@arsdigita.com)
    @creation-date Mon Jul  3 10:07:22 2000
    @cvs-id $Id: attachment-add-2.tcl,v 1.5 2001/02/01 16:52:17 caroline Exp $
} {
    {upload_file ""}
    {url ""}
    {file_text:allhtml ""}
    {version_description ""}
    {return_url ""}
    {group_id 0}
    {current_date ""}
    parent_id
    item_id
    file_title:notnull
    file_id
    version_id
    {doc_type "calendar-attachment"}
    doc_folder_id:optional,integer
    text_or_html:optional
} -validate {
    exactly_one_attachment_type {
	# exactly one of (file_text, upload_file, url) must be not null
	if {[empty_string_p $file_text] && [empty_string_p $upload_file] && [empty_string_p $url]} {
	    ad_complain "You must either upload a file, enter a URL, or enter the text of your attachment."
	} elseif ![expr ![empty_string_p $file_text] && [empty_string_p $upload_file] && ([empty_string_p $url] || [string compare $url "http://"] == 0) || [empty_string_p $file_text] && ![empty_string_p $upload_file] && ([empty_string_p $url] || [string compare $url "http://"] == 0) || [empty_string_p $file_text] && [empty_string_p $upload_file] && ![empty_string_p $url]] {
	    ad_complain "You may only create an attachment using ONE of the following methods:
	    <ul>
	    <li>Upload a file
	    <li>Enter a URL
	    <li>Enter the text of your attachment
	    </ul>"
	}
    }
    text_option_chosen -requires {exactly_one_attachment_type} {
	if {[info exists file_text] && ![empty_string_p $file_text]} {
	    if {![info exists text_or_html] || [empty_string_p $text_or_html]} {
		ad_complain "You must specify how to format the text."
	    }
	}
    }
} -errors {
    file_title {You must enter a title for the attachment.}
}

if { [string compare $url "http://"] == 0 } {
    set url ""
}

db_1row cal_user_id_group_id_select "
select user_id as cim_user_id, group_id as cim_group_id 
from cal_user_group_item_map 
where item_id = :parent_id"

switch $doc_type { 
    personal {
	set file_parent_id [user_calendar_folder_id $cim_user_id]
    }
    
    default {
	## edu_classes have own categories; no other group does
	set group_type [db_string cal_get_group_type "
	select group_type 
	from user_groups 
	where group_id = :cim_group_id" -default ""]
	
	if { $group_type != "edu_class" } {
	    set file_parent_id [group_calendar_folder_id $cim_group_id]
	} else {
	    set file_parent_id $doc_folder_id
	}
     }
 }

set user_id [ad_verify_and_get_user_id]

if [empty_string_p $return_url] {
    set return_url "?group_id=$group_id&action=item-view&parent_id=$parent_id&item_id=$item_id&current_date=$current_date"
}

# put together due_date, and do error checking
set form [ns_getform]

if {[db_string cal_count_files "
select count(file_id) 
from fs_files 
where file_id = :file_id"] > 0 } {
    # this was a double click
    ad_returnredirect $return_url
    returnparent
}


db_transaction {

    db_dml cal_fs_files_insert "
    insert into fs_files
    (file_id, file_title, owner_id, parent_id, sort_key, depth, group_id, public_p)
    (select :file_id, :file_title, :user_id, :file_parent_id, 1, 0, group_id, 'f'
    from cal_user_group_item_map
    where item_id = :parent_id)
    "
    
    if ![empty_string_p $upload_file] {
	set tmp_filename [ns_queryget upload_file.tmpfile]
        set file_extension [string tolower [file extension $upload_file]]
	# remove the first . from the file extension
	regsub "\." $file_extension "" file_extension
        set guessed_file_type [ns_guesstype $upload_file]
        set n_bytes [file size $tmp_filename]
	
	# strip off the C:\directories... crud and just get the file name
	if ![regexp {([^/]+)$} $upload_file match client_filename] {
	    # couldn't find a match
	    set client_filename $upload_file
	}
	
	db_dml cal_fs_versions_insert_file "
	insert into fs_versions
	(version_id, file_id, version_description, creation_date, author_id, client_file_name, file_type, file_extension, n_bytes, version_content)
	values
	(:version_id, :file_id, :version_description, sysdate, :user_id, :client_filename, :guessed_file_type, :file_extension, :n_bytes, empty_blob())
	returning version_content into :1" -blob_files [list $tmp_filename] 
    } elseif ![empty_string_p $url] {
	db_dml cal_fs_versions_insert_url "
	insert into fs_versions
	(version_id, file_id, version_description, creation_date, author_id, url)
	values
	(:version_id, :file_id, :version_description, sysdate, :user_id, :url)
	"
    } elseif ![empty_string_p $file_text] {

	# Plain text is stored as HTML with <pre> tag.
	set file_extension "html"
	set file_type "text/html"
	switch $text_or_html {
	    text {
#		set file_text "<pre wrap=on>$file_text</pre>"
#We are breaking the rules by modifying the user's input before putting it inot the database. But it sure works better.
		set file_text [ad_text_to_html $file_text]

	    }
	    html {
	    }
	    default {
		error "The text formatting you have specified is invalid: $text_or_html"
	    }
	}

	set n_bytes [string bytelength $file_text]

	set client_filename ""
	append client_filename $version_id "." $file_extension

	db_dml cal_fs_versions_insert_text "
	insert into fs_versions
	(version_id, file_id, version_description, creation_date, author_id, client_file_name, file_type, file_extension, n_bytes, version_content)
	values
	(:version_id, :file_id, :version_description, sysdate, :user_id, :client_filename, :file_type, :file_extension, :n_bytes, empty_blob())
	returning version_content into :1" -blobs [list $file_text] 
    }

    db_exec_plsql cal_grant_permissions_to_user_plsql "begin
    :1 := ad_general_permissions.grant_permission_to_user ( :user_id, 'read', :version_id, 'FS_VERSIONS' );
    :1 := ad_general_permissions.grant_permission_to_user ( :user_id, 'write', :version_id, 'FS_VERSIONS' );
    :1 := ad_general_permissions.grant_permission_to_user ( :user_id, 'comment', :version_id, 'FS_VERSIONS' );
    :1 := ad_general_permissions.grant_permission_to_user ( :user_id, 'administer', :version_id, 'FS_VERSIONS' );
    :1 := ad_general_permissions.grant_permission_to_all_users ( 'read', :version_id, 'FS_VERSIONS' );
    end;"

    if { ![empty_string_p $group_id] && $group_id != 0 } {
	db_exec_plsql cal_fs_group_permission_insert {
	    begin
	    :1 := ad_general_permissions.grant_permission_to_group(:group_id, 'read', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_group(:group_id, 'comment', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_role(:group_id, 'administrator', 'read', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_role(:group_id, 'administrator', 'comment', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_role(:group_id, 'administrator', 'write', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_role(:group_id, 'administrator', 'administer', :version_id, 'FS_VERSIONS');
	    end;
	}

	db_foreach cal_get_administer_role "
	select role from user_group_action_role_map 
	where group_id = :group_id
	  and action = 'Administer Group'
	and role != 'administrator'" {

	    db_exec_plsql fs_group_role_permission_insert {
		begin
		:1 := ad_general_permissions.grant_permission_to_role(:group_id, :role, 'read', :version_id, 'FS_VERSIONS');
		:1 := ad_general_permissions.grant_permission_to_role(:group_id, :role, 'comment', :version_id, 'FS_VERSIONS');
		:1 := ad_general_permissions.grant_permission_to_role(:group_id, :role, 'write', :version_id, 'FS_VERSIONS');
		:1 := ad_general_permissions.grant_permission_to_role(:group_id, :role, 'administer', :version_id, 'FS_VERSIONS');
		end;
	    }
	}
    }


    db_dml cal_item_map_insert "
    insert into cal_item_db_row_map
    (item_id, on_what_id, on_which_table)
    values
    (:item_id, :file_id, 'FS_FILES')
    "

}

fs_order_files

db_release_unused_handles
ad_returnredirect $return_url











