# packages/calendar/www/edit-html-attachment-2.tcl

ad_page_contract {
    processes edit-html-attachment.tcl
    puts the new version into file-storage

    @param file_id
    @param version_id
    @param group_id
    @param upload_file
    @param return_url
    @param version_description
    @param text_or_html whether the attachment is Plain Text (text) or HTML (html)

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date 8/8/2000
    @cvs-id $Id: edit-html-attachment-2.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
} {
    {file_id}
    {version_id}
    {group_id ""}
    {upload_file:allhtml ""}
    {return_url ""}
    {version_description ""}
    text_or_html:notnull
} -errors {
    text_or_html {You must specify whether your attachment is formatted as plain text or HTML.}
}

set user_id [ad_verify_and_get_user_id]

db_1row cal_get_old_version_author "
select version_id as old_version_id,
       author_id as old_author_id
from fs_versions_latest
where file_id = :file_id"

page_validation {
    # double-click protection
    if [db_0or1row cal_get_version "
    select version_id
    from fs_versions
    where file_id = :file_id
      and version_id = :version_id
    "] {
	ad_returnredirect $return_url
    }
    # permission checking

    if {! [fs_check_write_p $user_id $old_version_id $group_id]} {
	error "You can't write into this file"
    }
}

# Plain text is stored as HTML with <pre> tag.
set file_extension "html"
set file_type "text/html"
switch $text_or_html {
    text {
	set upload_file "<pre wrap=on>$upload_file</pre>"
    }
    html {
    }
    default {
	error "The text formatting you have specified is invalid: $text_or_html"
    }
}

set n_bytes [string bytelength $upload_file]

set client_filename ""
append client_filename $version_id "." $file_extension

db_transaction {
    db_dml cal_versions_insert "
    insert into fs_versions
    (version_id, file_id, version_description, creation_date, author_id, client_file_name, file_type, file_extension, n_bytes, version_content)
    values
    (:version_id, :file_id, :version_description, sysdate, :user_id, :client_filename, :file_type, :file_extension, :n_bytes, empty_blob())
    returning version_content into :1" -blobs [list $upload_file] 

    db_dml cal_versions_update "
    update fs_versions 
    set   superseded_by_id = :version_id 
    where file_id = :file_id
    and   version_id <> :version_id"

    # now that the version has been inserted, lets set up the permissions

    # Copy the previous version's permissions, except for rows regarding
    # the current user and the previous version's owner.

    db_exec_plsql cal_grant_permissions "begin
    ad_general_permissions.copy_permissions(:old_version_id, :version_id, 'FS_VERSIONS', :user_id, :old_author_id);
    :1 := ad_general_permissions.grant_permission_to_user(:user_id, 'read', :version_id, 'FS_VERSIONS');
    :1 := ad_general_permissions.grant_permission_to_user(:user_id, 'write', :version_id, 'FS_VERSIONS');
    :1 := ad_general_permissions.grant_permission_to_user(:user_id, 'comment', :version_id, 'FS_VERSIONS');
    :1 := ad_general_permissions.grant_permission_to_user(:user_id, 'administer', :version_id, 'FS_VERSIONS');
    end;"
   
}

ad_returnredirect $return_url