ad_page_contract {
    Lets a user administrate group calendars for user groups of which
    he is a group admin.

    @author Bryan Che (bryanche@arsdigita.com)
    @cvs-id $Id: group-cals-admin.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
} {
}

set user_id [ad_verify_and_get_user_id]

append whole_page "
[ad_header "Manage Group Calendars"]
<h2>Manage Group Calendars</h2>
[ad_context_bar_ws [list index.tcl "Calendar"] "Manage Group Calendars"]
<hr>
"

append whole_page "
<h3>Your Groups' Calendars</h3>
You manage the following user groups that have calendars:
<ul>
"

set yes_cal_count 0
db_foreach cal_sel_grps_w_cals "
select distinct ug.group_id, ug.group_name, ug.short_name, lower(ug.group_name)
from user_groups ug, user_group_map ugm, cal_groups cg
where ug.group_id = ugm.group_id
  and ugm.user_id = :user_id
  and ugm.role = 'administrator'
  and ug.group_id = cg.group_id
order by lower(ug.group_name)
" {
    set header "Delete $group_name's Calendar"
    set message "Are you sure you want to delete $group_name's calendar?
    This will delete all the calendar items people have stored within
    it.
    "

    set yes_url "/calendar/group-cal-delete?[export_url_vars group_id]"
    set no_url "/calendar/group-cals-admin.tcl?[export_url_vars]"

    append whole_page "<li>
    <a href=\"/groups/admin/$short_name\">$group_name</a>
    &nbsp;
    <a href=\"/shared/confirm?[export_url_vars header message yes_url no_url]\">(delete calendar)</a>
    &nbsp;
    <a href=\"/calendar/admin/types.tcl?scope=group&[export_url_vars group_id]\">(add types)</a>. 
    "

    incr yes_cal_count
}

if {$yes_cal_count == 0} {
    append whole_page "<li><i>You do not administrate any user
    groups that have calendars</i>"
}

append whole_page "
</ul>"

append whole_page "
<form method=post action=\"group-cal-create.tcl\">
<h3>Create Group Calendar</h3>
You may create group calendars for user groups that you administrate:
<p>
"

set no_cal_count 0
db_foreach cal_sel_group_no_cal "
select ug.group_id, ug.group_name, lower(ug.group_name)
from user_groups ug, user_group_map ugm
where ug.group_id = ugm.group_id
  and ugm.user_id = :user_id
  and ugm.role = 'administrator'
  and ug.group_id not in
      (select group_id from cal_groups)
order by lower(ug.group_name)
" {
    append whole_page "
    <input type=checkbox name=group_id_list value=$group_id>$group_name<br>"
    incr no_cal_count
}

if {$no_cal_count == 0} {
    append whole_page "<i>You do not administrate any 
    user groups without calendars</i>"
} else {
    append whole_page "
    <p>
    <input type=submit value=\"Create Group Calendars\">
    "
}

append whole_page "
</form>
[ad_footer]"

doc_return 200 text/html $whole_page






