# packages/calendar/www/item-ae-repeat.tcl

# Note: repeat_until grabbed separately
ad_page_contract {
    Inserts or updates a recurring item.  For v1 only new recurrences are 
    supported.
 
    If a new repeat, then updates cal_items and calls
    cal_insert_recurrences.
    
    NOTE: This is not implemented yet, but
    if an update, if the current instance is the first instance, then
    delete cal_repeat_items, otherwise set the repeat_until time to the day
    before.
    Delete all instances after the current instance.  
    Create new cal_item copying
    the old cal_item, point the instance to the new item, create a new 
    cal_repeat_items with the new repeat information, then call 
    cal_insert_recurrences on the new item.

    @param parent_id
    @param item_id
    @param interval_type
    @param nth_interval
    @param days_of_week
    @param pass_through_current_view
    @param pass_through_current_date
    @param group_id
    @param user_id
    @param return_url

    @author (wsmeeks@arsdigita.com)
    @creation-date 2000-07-31
    @cvs-id $Id: item-ae-repeat.tcl,v 1.1.1.1 2001/01/24 18:03:16 tarik Exp $
} {
    parent_id
    item_id
    interval_type
    nth_interval
    {days_of_week:multiple ""}
    pass_through_current_view
    pass_through_current_date
    {group_id "null"}
    {user_id "null"}
    {return_url ""}
} -errors {
    interval_type {You must select an interval type for Repeat Every}
}

set logged_in_user_id [ad_verify_and_get_user_id]
set creator_id $logged_in_user_id
		    
page_validation {
    if {$group_id != "null"} {
	set group_id [validate_integer "Group ID" $group_id]
	# quick hack to get around group_id being set to 0 for no group...
	if {$group_id == 0} {
	    set group_id "null"
	}
    }
    if {$user_id != "null" } {
	set user_id [validate_integer "User ID" $user_id]
    }
    set parent_id [validate_integer "Calendar ID" $parent_id]
    set item_id [validate_integer "Instance ID" $item_id]
    set nth_interval [validate_integer "Nth Interval" $nth_interval]
}

# Get repeat_until date
set repeat_until [lindex [calendar_form_transform_datetime \
	-truncate_p "t" repeat_until] 0]

#make sure repeat_until is valid and limit to future limit
if {[catch {db_1row cal_repeat_select "
select min(a_date) as repeat_check
from (select $repeat_until as a_date from dual
      union
      select add_months(sysdate, 12 * [cal_future_limit]) as a_date from dual)"} errmsg]} {
	  return [ad_return_complaint 1 "<li>You have entered an invalid date $errmsg"]
}

# For v1, just assume we're adding a new repeat
if {[exists_and_not_null parent_id] && 
    [calendar_item_write_access_p $parent_id $group_id]} {
    db_transaction {
	db_dml cal_update_repeat_info "
	UPDATE cal_items
	SET interval_type = :interval_type,
	    every_nth_interval = :nth_interval,
	    days_of_week = :days_of_week,
	    repeat_until = $repeat_until
	WHERE item_id = :parent_id
	"

	db_dml cal_insert_recurrences "
	BEGIN
	cal_insert_recurrences(:parent_id, :user_id, to_date(:repeat_check), 0);
	END;
	"
    } 
} else {
    error "Insufficient priviledges"
}

# Uncomment this section for debugging
#  append page_content "
#      item_id    = $item_id<br>
#      instance_id    = $instance_id <br>
#      interval_type    = $interval_type<br>
#      nth_interval   = $nth_interval<br>
#      days_of_week    = $days_of_week<br>
#      repeat_until    = $repeat_until<br>
#      pass_through_current_view    = $pass_through_current_view<br>
#      pass_through_current_date    = $pass_through_current_date<br>
#      group_id = $group_id<br>
#      user_id = $user_id<br>
#      return_url = $return_url<br>
#  "

#  if {$group_id == "null"} {set group_id ""}

db_release_unused_handles
#  ns_return 200 text/html "
#  [ad_header "Test"]
#  $page_content
#  [ad_footer]
#  "

if { $group_id == "null" } {
    set group_id ""
}

if [empty_string_p $return_url] {
    ns_log notice "no return_url: ?current_view=$pass_through_current_view&current_date=$pass_through_current_date&parent_id=$parent_id&item_id=$item_id&action=item-view&group_id=$group_id"
    ad_returnredirect "?current_view=$pass_through_current_view&current_date=$pass_through_current_date&parent_id=$parent_id&item_id=$item_id&action=item-view&group_id=$group_id"
} else {
    ns_log notice "return_url: $return_url"
    ad_returnredirect $return_url
}

