create sequence edu_grade_sequence;
-- records the grade types and their relative weights. this table will not 
-- capture the qualitative factors, but should take care of the
-- quantitative portion of the final grade
create table edu_grades (
       grade_id		       integer not null primary key,
       grade_name	       varchar(100),
       class_id		       integer not null references user_groups,
       comments		       varchar(4000),
       -- weight is a percentage
       weight		       number check (weight between 0 and 100),
       last_modified           date default sysdate not null,
       last_modifying_user     not null references users,
       modified_ip_address     varchar(20) not null
);

-- we want to audit edu_grades

create table edu_grades_audit (
       grade_id		       integer,
       grade_name	       varchar(100),
       class_id		       integer,
       comments		       varchar(4000),
       -- weight is a percentage
       weight		       number,
       last_modified           date,
       last_modifying_user     integer,
       modified_ip_address     varchar(20),
       delete_p                char(1) default('f') check (delete_p in ('t','f'))
);

-- we create a trigger to keep the audit table current
create or replace trigger edu_grades_audit_trigger
before update or delete on edu_grades
for each row
begin
   insert into edu_grades_audit (
        grade_id,
        grade_name,
	class_id,
	comments,
	weight,
	last_modified,
	last_modifying_user,
	modified_ip_address)
    values (
        :old.grade_id,
        :old.grade_name,
	:old.class_id,
	:old.comments,
	:old.weight,
	:old.last_modified,
	:old.last_modifying_user,
	:old.modified_ip_address);
end;
/
show errors
