-- we want to allow professors to have office hours and
-- for students to be able to automatically sign themselves
-- up as either an individual or as a team.  These items
-- are only used when students can self register.  If they cannot
-- then it is just as easy for a prof to put the event into a class
-- event or under a message of the day.  This could
-- also be used for advisors to allow advisees to sign up for
-- an appointment on registration day

create sequence edu_appointments_appt_id_seq start with 1;
create table edu_appointments (
  	appointment_id 	      integer 
                              constraint edu_appts_appt_id_nn not null
                              constraint edu_appts_appt_id_pk primary key,
	-- who is the meeting with?  If this is office hours,
	-- for instance, the user_id would be the TA or professor
	user_id		      constraint edu_appts_user_id_nn not null 
                              constraint edu_appts_user_id_fk references users,
	-- if the office hours are restricted to a particular group
	-- then we need a group_id (e.g. if the professor teaches
	-- multiple classes he would only want one class to have 
	-- office hours at a given time
	group_id	      constraint edu_appts_group_id_fk references user_groups,	
	-- where is the meeting (office hours)
	place		      varchar(4000),
        -- Date and time.
        start_time            date constraint edu_appts_start_time_nn not null,
        end_time              date constraint edu_appts_end_time_nn not null,
	-- The number of minutes between appointments
	-- if 'increment' is left null or is longer than 
	-- end_time - start_time then there is only one time slot
	-- to fill
	time_increment	      integer,
	-- should students be able to see who has signed up in the other
	-- slots (or should they just see something like "Not Available")
	public_schedule_p     char(1) 
			      constraint edu_appt_public_ck check (public_schedule_p in ('t','f')),
        check (start_time < end_time)
);



-- now, we want a way to keep track of who is signed up
-- for which appointment at which time
-- if the prof wants a lunch break, they just schedule themselves
-- for that time block

create table edu_appointments_scheduled (
	appointment_id	integer 
	 		constraint edu_appt_sched_appt_id_nn not null 
			constraint edu_appt_sched_appt_id_fk references edu_appointments,
	user_id		integer 
                        constraint edu_appt_sched_user_id_fk references users,
	group_id	integer 
			constraint edu_appt_sched_group_id_fk references user_groups,
        -- Date and time.
        start_time      date constraint edu_appt_sched_start_nn not null,
        end_time        date constraint edu_appt_sched_end_nn not null,
	constraint edu_appt_sched_nn_ck check ((user_id is not null and group_id is null) or (user_id is null and group_id is not null))
);


create index edu_appt_schedule_group_idx on edu_appointments_scheduled(appointment_id, group_id);
create index edu_appt_schedule_user_idx on edu_appointments_scheduled(appointment_id, user_id);
