# /packages/education/admin-www/department-add-2.tcl

ad_page_contract {
    this page allows the admin to add a new department to the system
        
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: department-add-2.tcl,v 1.1.1.1 2001/01/24 18:03:19 tarik Exp $
} {
    group_name:notnull
    {department_number [db_null]}
    {external_homepage_url [db_null]}
    {mailing_address [db_null]}
    {phone_number [db_null]}
    {fax_number [db_null]}
    {inquiry_email [db_null]}
    {description [db_null]}
    {mission_statement [db_null]}
} -validate {
    valid_email_p {
	if {![empty_string_p $inquiry_email] && ![philg_email_valid_p $inquiry_email]} {
	    ad_complain {
		The inquiry email address that you typed doesn't look right to us.  Examples of valid email addresses are 
		<ul>
		<li>Alice1234@aol.com
		<li>joe_smith@hp.com
		<li>pierre@inria.fr
		</ul>
	    }
	}
    }
    valid_phone_p {
	if {![empty_string_p $phone_number] && ![edu_phone_number_p $phone_number]} {
	    ad_complain " The phone number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
    valid_fax_p {
	if {![empty_string_p $fax_number] && ![edu_phone_number_p $fax_number]} {
	    ad_complain " The fax number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
} -errors {
    group_name {You must provide a name for the new department.}
}

if {[string compare $external_homepage_url "http://"] == 0} {
    set external_homepage_url [db_null]
}

# so we don't get hit by duplicates if the user double-submits,
# let's generate the group_id here

set group_id [db_string get_group_id "select user_group_sequence.nextval from dual"]


set return_string "
[ad_admin_header "[ad_system_name] Administration - Add a Department"]
<h2>Confirm Department Information</h2>

[ad_context_bar_ws [list "/admin/" "Admin Home"] [list "" "[ad_system_name] Administration"] "Add a Department"]

<hr>
<blockquote>

<form method=post action=\"department-add-3\">

[export_form_vars group_name department_number external_homepage_url mailing_address phone_number fax_number inquiry_email description mission_statement group_id]

<table>

<tr>
<th align=left valign=top>
Department Name
</td>
<td>
$group_name
</td>
</tr>

<tr>
<th align=left valign=top>
Department Number
</td>
<td>
[edu_maybe_display_text $department_number]
</td>
</tr>

<tr>
<th align=left valign=top>
External Homepage URL
</td>
<td>
[edu_maybe_display_text $external_homepage_url]
</td>
</tr>

<tr>
<th align=left valign=top>
Mailing Address
</td>
<td>
[edu_maybe_display_text $mailing_address]
</td>
</tr>


<tr>
<th align=left valign=top>
Phone Number
</td>
<td>
[edu_maybe_display_text $phone_number]
</td>
</tr>

<tr>
<th align=left valign=top>
Fax Number
</td>
<td>
[edu_maybe_display_text $fax_number]
</td>
</tr>

<tr>
<th align=left valign=top>
Inquiry Email Address
</td>
<td>
[edu_maybe_display_text $inquiry_email]
</td>
</tr>


<tr>
<th align=left valign=top>
Description
</td>
<td>
[address_book_display_as_html $description]
</td>
</tr>


<tr>
<th align=left valign=top>
Mission Statement
</td>
<td>
[edu_maybe_display_text [address_book_display_as_html $mission_statement]]
</td>
</tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Create Department\">
</td>
</tr>

</table>

</form>

</blockquote>
[ad_admin_footer]
"

doc_return 200 text/html $return_string
