# /packages/education/admin-www/department-add-3.tcl

ad_page_contract {
    this page allows the admin to add a new department to the system
    this page actually does the insert
        
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: department-add-3.tcl,v 1.1.1.1 2001/01/24 18:03:19 tarik Exp $
} {
    group_id:integer,notnull
    group_name:notnull
    {department_number [db_null]}
    {external_homepage_url [db_null]}
    {mailing_address [db_null]}
    {phone_number [db_null]}
    {fax_number [db_null]}
    {inquiry_email [db_null]}
    {description [db_null]}
    {mission_statement [db_null]}
} -validate {
    valid_email_p {
	if {![empty_string_p $inquiry_email] && ![philg_email_valid_p $inquiry_email]} {
	    ad_complain {
		The inquiry email address that you typed doesn't look right to us.  Examples of valid email addresses are 
		<ul>
		<li>Alice1234@aol.com
		<li>joe_smith@hp.com
		<li>pierre@inria.fr
		</ul>
	    }
	}
    }
    valid_phone_p {
	if {![empty_string_p $phone_number] && ![edu_phone_number_p $phone_number]} {
	    ad_complain " The phone number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
    valid_fax_p {
	if {![empty_string_p $fax_number] && ![edu_phone_number_p $fax_number]} {
	    ad_complain " The fax number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
} -errors {
    group_name {You must provide a name for the new department.}
    group_id {You must provide an identification nubmer for the new department.}
}

# lets make sure this is not a double-click.  If so, just redirect the user

if [db_string check_double_click "select count(group_id) from user_groups where group_id = :group_id"] {
    ad_returnredirect ""
}

if {[string compare $external_homepage_url "http://"] == 0} {
    set external_homepage_url [db_null]
}

# now that all of the input has been check, lets put the information into
# an ns_set

set var_set [ns_set new]

ns_set put $var_set department_number $department_number
ns_set put $var_set external_homepage_url $external_homepage_url
ns_set put $var_set mailing_address $mailing_address
ns_set put $var_set phone_number $phone_number
ns_set put $var_set fax_number $fax_number
ns_set put $var_set inquiry_email $inquiry_email
ns_set put $var_set description $description
ns_set put $var_set mission_statement $mission_statement

if ![ad_user_group_add -approved_p t -existence_public_p f -new_member_policy closed -multi_role_p f -extra_values $var_set -group_id $group_id edu_department $group_name] {
    error "did not create group"
}

db_release_unused_handles

ad_returnredirect ""
