# /packages/education/admin/term-edit-2.tcl

ad_page_contract {
    this page allows the admin to edit information about the given term
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: term-edit-2.tcl,v 1.1.1.1 2001/01/24 18:03:19 tarik Exp $
} {
    term_id:integer,notnull
    term_name:notnull
    short_name
    start_date_array:array,date
    end_date_array:array,date
} -validate {
    date_order -requires {start_date_array end_date_array} {
	if {[db_string check_date_order "select to_date('$start_date_array(date)', 'YYYY-MM-DD') - to_date('$end_date_array(date)','YYYY-MM-DD') from dual"] > 1} {
	    ad_complain "The end date must be after the start date."
	}
    }
    end_in_future -requires {end_date_array} {
	if {[db_string check_end_future "select round(sysdate) - to_date('$end_date_array(date)','YYYY-MM-DD') from dual"] > 1} {
	    ad_complain "The end date must be in the future."
	}
    }
} -errors {
    term_name {You must provide a name for the term.}
}

set start_date $start_date_array(date)
set end_date $end_date_array(date)

if {[empty_string_p $start_date]} {
    set actual_start_date "No Start Date"
} else {
    set actual_start_date [util_AnsiDatetoPrettyDate $start_date]
}

if {[empty_string_p $start_date]} {
    set actual_end_date "Does Not End"
} else {
    set actual_end_date [util_AnsiDatetoPrettyDate $end_date]
}


set return_string "
[ad_admin_header "[ad_system_name] Administration - Edit Term"]
<h2>Edit Term</h2>

[ad_context_bar_ws [list "/admin/" "Admin Home"] [list "" "Education Administration"] "Edit Term"]

<hr>
<blockquote>
Are you sure you wish to edit this term?
<br><br>
<table>

<tr><th align=left>Term Name
<td>$term_name
</tr>

<tr><th align=left>Short Name
<td>$short_name
</tr>

<tr><th align=left>Date term begins: 
<td>$actual_start_date
</tr>

<tr><th align=left>Date term ends:
<td>$actual_end_date
</tr>
</table>

<form method=post action=\"term-edit-3.tcl\">
<input type=submit value=\"Edit Term\">
[export_form_vars term_name short_name start_date end_date term_id]
</form>

</blockquote>
[ad_admin_footer]
"

doc_return 200 text/html $return_string









