# /packages/education/admin-www/term-one.tcl

ad_page_contract {
    this page displays the information about one term

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: term-one.tcl,v 1.2 2001/02/02 21:48:40 tarik Exp $
} {
    term_id:integer,notnull
} -errors {
    term_id {You must provide a valid term_id}
}


if ![db_0or1row get_term_info {
    select term_name,
    start_date,
    end_date,
    short_name
    from edu_terms
    where term_id = :term_id
}] {
    ad_return_complaint 1 "<li>The term id that you provided does not correspond to any term."
    return
}

if {[empty_string_p $start_date]} {
    set actual_start_date "No Start Date Specified"
} else {
    set actual_start_date [util_AnsiDatetoPrettyDate $start_date]
}

if {[empty_string_p $end_date]} {
    set actual_end_date "No End Date Specified"
} else {
    set actual_end_date [util_AnsiDatetoPrettyDate $end_date]
}



set return_string "
[ad_admin_header "[ad_system_name] Administration - Terms"]
<h2>One Term - $term_name</h2>

[ad_context_bar_ws [list "/admin/" "Admin Home"] [list "" "Education Administration"] [list terms.tcl "Terms"] "One Term"]

<hr>
<blockquote>

<li>Term Name: $term_name
<li>Short Name: $short_name
<li>Start Date: $actual_start_date
<li>End Date: $actual_end_date
<br>
(<a href=\"term-edit.tcl?[export_url_vars term_id]\">edit</a>)
<br><br>
<h3>Classes</h3>
<ul>
"

db_foreach get_classes "select class_id, class_name from edu_classes where term_id = :term_id" {
    append return_string "<li><a href=\"/education/util/group-login.tcl?group_id=$class_id&group_type=edu_class&return_url=[ad_urlencode [edu_url]class/one.tcl]\">$class_name</a>
    [ad_space 2] \[ <a href=\"/education/util/group-login.tcl?group_id=$class_id&group_type=edu_class&return_url=[ad_urlencode [edu_url]class/admin/]\">admin page</a> \]"
} if_no_rows {
    append return_string "There are no classes signed up for this term."
}

append return_string "
</ul>
</blockquote>
[ad_admin_footer]
"

doc_return 200 text/html $return_string








