ad_library {
    Procs to produce portals dealing with classes including class members, description, etc.
    Created during a break-up of education-portal-procs.tcl
    
    @author Caroline Meeks (caroline@arsdigita.com)
    @creation-date July 18, 2000
    @cvs-id $Id: class-portal-procs.tcl,v 1.17 2001/02/26 01:52:36 tarik Exp $
}

ad_proc DisplayAdministerUsersLink { {} } {
    Displays a link to a user administration page for a particular class, if the user has permission.

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date Jul 19 2000
} {
    set url [db_null]
    set user_id [ad_verify_and_get_user_id]

    if {[portals_info type]!="group"} {
	return $url
    }

    set section_id [portals_info group_id]
    if [ad_user_group_authorized_admin $user_id $section_id] {
	set target_url [ns_conn url]
	set query [ns_conn query]
	if ![empty_string_p $query] {
	    append target_url ?$query
	}

        append url "<a href=\"/education/class/admin/users/index.tcl?[export_url_vars section_id target_url]\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
    }
    db_release_unused_handles
    return $url
}

ad_proc DisplayClassInfo { {} } {
    Returns description of a class from the edu_classes_info table. 

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date Jul 17 2000
} {
    if {[portals_info type]=="group"} {
	# group portal
	set user_id [ad_verify_and_get_user_id]
	set group_id [portals_info group_id]
	db_1row get_description {
	    select NVL(c.description, s.description) as description
	    from edu_classes c, edu_subjects s
	    where c.class_id=:group_id
	    and s.subject_id=c.subject_id
	}
	set document_html $description
	db_release_unused_handles
	return $document_html
    } else {
	# user portal
	return ""
    }
}

ad_proc DisplayEditClassInfoLink { {} } {
    Displays a link to the edit-class-info page for a particular class, if the user has permission.

    @author Eric J. Cholankeril (ejc@arsdigita.com), befekadu@mit.edu
    @creation-date Jul 17 2000
} {
    set url [db_null]
    set user_id [ad_verify_and_get_user_id]

    if {[portals_info type]=="group"} {
	set group_id [portals_info group_id]
	
	if {[ad_user_group_authorized_admin $user_id $group_id]} {
	    set return_url [ns_conn url]
	    set query [ns_conn query]
	    if ![empty_string_p $query] {
		append return_url ?$query
	    }
	    append url "<a href=\"/education/class/admin/edit-class-info.tcl?[export_url_vars group_id return_url]\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
	}
    }
    db_release_unused_handles
    return $url
}


ad_proc DisplaySyllabusInfo { {} } {
    Returns either the syllabus (if the file is .txt or .html) or a link to the
    file using file-storage
    
    @author Basel Al-Naffouri (basel@arsdigita.com)
    @creation-date Jul 18 2000
} {
    if { [portals_info type] == "group" } {
	#group_portal
	set group_id [portals_info group_id]
	
	set return_url [ns_conn url]
	set query [ns_conn query]
	if ![empty_string_p $query] {
	    append return_url ?$query
	}
	
	if [db_0or1row get_syllabus_info {
	    select fs.file_id as file_id, fs.file_title as file_title, fsvl.file_type  as file_type,fsvl.url as url, 
	    fsvl.client_file_name as client_file_name,fsvl.version_id as version_id, fsvl.n_bytes, fsvl.version_content
	    from fs_files fs,fs_versions_latest fsvl
	    where fs.file_id = (select syllabus_id from edu_class_info where group_id=:group_id)
	    and fs.file_id = fsvl.file_id
	    and deleted_p='f'
	} ] {
	    regsub -all {[^-_.0-9a-zA-Z]+} $client_file_name "_" pretty_file_name
	    
	    if {[empty_string_p $n_bytes]} {
		append result "<a href=$url>View</a>"
	    } elseif {[string compare $file_type text/html]==0 ||  [string compare $file_type text/plain]==0 } {
		append result $version_content
	    } else {
		append result "
		<a href=\"/file-storage/download/$version_id/$pretty_file_name\">Download</a>"
	    }
	    
	} else { 
	    append result "
	    No syllabus uploaded
	    <br><br> "
	}
    } else {
	#user_portal
	set result [db_null]
    }
    db_release_unused_handles
    return $result
}

ad_proc DisplayEditSyllabusLink { {} } {
    Displays a Link to edit the syllabus, if the user has permission.

    @author Eric J. Cholankeril (ejc@arsdigita.com), befekadu@mit.edu
    @creation-date Jul 20 2000
} {
    set url [db_null]

    if { [portals_info type] == "group" } {
	#group_portal
	set user_id [ad_verify_and_get_user_id]
	set group_id [portals_info group_id]
	set edu_class_group_administrator_p [ad_user_group_authorized_admin_or_site_admin $user_id $group_id]
	
	if $edu_class_group_administrator_p {

	    set return_url [ns_conn url]
	    set query [ns_conn query]
	    if ![empty_string_p $query] {
		append return_url ?$query
	    }

	    if [db_0or1row get_syllabus_info {
		select fs.file_id as file_id
		from fs_files fs
		where fs.file_id = (select syllabus_id from edu_class_info where group_id=:group_id)
		and deleted_p='f'
	    }] {
		append url "<a href=\"/file-storage/one-file?[export_url_vars return_url file_id group_id]\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
	    } else { 
		set this_folder [edu_class_attachment_folder_id $group_id syllabus]
		append url "<a href=\"/file-storage/upload-new?[export_url_vars return_url group_id this_folder]&public_p=t&doc_type=syllabus\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
	    }
	}
    }
    db_release_unused_handles
    return $url
}



ad_proc DisplayClassAdministration {} {
    Class administration page
} {
    
    set user_id [ad_verify_and_get_user_id]
    set group_id [portals_info group_id]
    set class_name [portals_info group_name]

    set sql_restriction [db_null]
    
    set return_url [ns_conn url]
    set query [ns_conn query]
    if ![empty_string_p query] {
	append return_url "?$query"
    }

    if {! [ad_user_group_authorized_admin_or_site_admin $user_id $group_id] } {
	return ""
    }

    set role_list [edu_get_class_original_role_pretty_role]
    
    set header_string "$class_name Users"

    set bboard_list [db_null]

    db_foreach get_bboard_topics {
	select topic_id, name, active_p from gc_bboard_topics where group_id = :group_id
    } {
	if { $active_p == "t" } {
	    append bboard_list "<li><a href=\"/threaded-bboard/one-topic.tcl?[export_url_vars topic_id group_id]\">$name</a> - <a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">Administration</a><br>"
	} else {
	    append bboard_list "<li>$name - <a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">Administration</a> (inactive)<br>"
	}
    }

    db_1row get_group_info {
	select existence_public_p, short_name, group_type from user_groups where group_id = :group_id
    }

    set site_wide_admin_html [db_null]
    if [ad_administrator_p] {
	append site_wide_admin_html "
	<li><b>Site Wide Administration</b>
	<ul>
	[AdminTools]
	<li><a href=/education/department/admin>Department Administration</a>
	</ul>
	<br>
	"
    }

    append page_content "
    <br>
    <ul>
     $site_wide_admin_html
     <li><a href=[portals_info customization_url]>Customize This Portal</a><p>
    "

    if { [apm_package_enabled_p "evaluation"] } {
	append page_content "<li><a href=/admin/evaluation?[export_url_vars group_id]> Evaluate Students </a>"
    }

    append class_administration_html "
    <li><b>Class Administration</b>
    <ul>

    <li><a href=\"/education/class/admin/users/index.tcl?section_id=$group_id\">Add/Drop/Manage Students, TA's, CA's, Administrators and Professors</a>
    <li><a href=\"/education/class/admin/properties-edit?class_id=$group_id\">Edit Class Properties</a>
    <li><a href=\"/education/class/admin/edit-enrollment-policy?[export_url_vars group_id return_url]\">View/Change Enrollment Policy</a> - "

    db_1row get_more_group_info {
	select new_member_policy as current_policy,
	group_name
	from user_groups
	where group_id = :group_id
    }

    set new_member_policy_list [list "open" "closed" "wait"]
    
    set count 0
    foreach new_member_policy $new_member_policy_list {
	if $count {
	    append class_administration_html " | "
	}
	if ![string compare $new_member_policy $current_policy] {
	    append class_administration_html "
	    <b>$new_member_policy</b>"
	} else {
	    append class_administration_html "
	    <a href=/education/class/admin/edit-enrollment-policy-2?[export_url_vars new_member_policy group_id return_url]>$new_member_policy</a>"
	}
	incr count
    }

    append class_administration_html "
    </ul>
    "

    append page_content $class_administration_html

    set top_level_group_ids_sql "
    select group_id
    from user_groups
    where parent_group_id= $group_id"

    set parent_domain_id [portals_domain_id_from_domain_name class]

    append page_content "
    <p>
    </ul>
    [edu_subportal_html_links $top_level_group_ids_sql]
    <ul>
    <li><a href=\"/education/subgroup/create?[export_url_vars group_id parent_domain_id]\">Create a new subgroup</a></li>
    <p>
    "

    append page_content "
     <p><li><b>Announcements</b><ul>
    [news_administration_links $group_id]
      <li><a href=\"/[ad_parameter GroupsDirectory ug]/[ad_parameter GroupsAdminDirectory ug]/[ad_urlencode $short_name]/spam-index\">Spam Members of this Group</a>
      </ul><p>"
    append page_content "
       <li><b>Calendar</b><ul>
       <li><a href=\"/calendar/?[export_url_vars group_id]&scope=group&action=item-add\">Add Group Item</a>
       </ul><p>
       "
   append page_content "
     <li><b>Bulletin Boards</b>
      <ul>
       <li><a href=\"/threaded-bboard/admin/bboard-add.tcl?[export_url_vars group_id return_url]\">Add a new Bulletin Board</a><p>
       $bboard_list
      </ul>
    "
   append page_content "
     <br><li><b>FAQs</b>
    [FAQ_administration_links $group_id]
    "
   append page_content "
     <br><li><b>Survey</b>
    [survey_administration_links $group_id]
      </ul>
    <br>
    "

   return $page_content
}
















