# /packages/education/community-procs.tcl

ad_library {
    All tcl procs pertaining to communities go here.

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date July 27, 2000
    @cvs-id $Id: community-procs.tcl,v 1.11 2001/02/15 02:19:07 caroline Exp $
}

ad_proc edu_get_community_original_role_pretty_role { {} } {
    This returns the list of roles and corresponding pretty role and plural pretty role that are used to initialize the roles for a community.
    This procedure should only be called from the procedure that sets up a community.  It prevents us from hardcoding all of this info into TCL.
} {
    return [list [list [edu_get_administrator_role_string] Administrator Administrators] [list member Member Members]]
}

ad_proc edu_get_community_roles_to_actions_map { {} } {
    This returns a role and the corresponding default actions.  This procedure is used to initialize the roles and actions for a new community.
    So, each internal list has the first element of a role and the second element is a list of actions the role should start out with.
} {

    set to_return [list [list [edu_get_administrator_role_string] [list "Administer Group" "Spam Users"]]]
    lappend to_return [list [edu_get_student_role_string] [list]]

    return $to_return
}

ad_proc edu_set_community_roles_and_actions { {} community_id } {
    @param community_id The group id of the community.

    This takes a community id and sets up the community permission options. This should be called when a community is first created.
} {
    set role_list [edu_get_community_original_role_pretty_role]
    set role_action_map [edu_get_community_roles_to_actions_map]
    set action_list [list "Administer Group" "Spam Users"]
    #the first thing we want to do is add all of the roles
    foreach role_sublist $role_list {
	ad_user_group_role_add $community_id [lindex $role_sublist 0]

	# the trigger will have done the insert so now we update
	# the information
	db_dml update_pretty_roles "update edu_role_pretty_role_map
                       set pretty_role = '[lindex $role_sublist 1]',
                           pretty_role_plural = '[lindex $role_sublist 2]'
                       where role = '[lindex $role_sublist 0]'
	               and group_id = :community_id"
    }

    #now, add all of the roles
    foreach action $action_list {
	ad_user_group_action_add $community_id "$action"
    }

    #now, map the roles to the correct actions
    foreach role_action $role_action_map {
	set role [lindex $role_action 0]
	set action_list [lindex $role_action 1]
	foreach action $action_list {
	    ad_user_group_action_role_map $community_id $action $role
	}
    }	

    db_release_unused_handles
}

ad_proc DisplayCommunityAdministration {} {
    Community administration page
} {
    
    set user_id [ad_verify_and_get_user_id]
    set group_id [portals_info group_id]
    set community_name [portals_info portal_name]

    set sql_restriction ""
    
    set return_url [ns_conn url]
    set query [ns_conn query]
    if ![empty_string_p query] {
	append return_url "?$query"
    }
    
    
    set header_string "$community_name Users"

    set short_name [db_string short_name {select short_name from user_groups where group_id = :group_id}]
    set bboard_list [db_null]
    db_foreach get_bboard_topics {
	select topic_id, name, active_p from gc_bboard_topics where group_id = :group_id
    } {
	if { $active_p == "t" } {
	    set toggle_link "<b>active</b> | <a href=\"/threaded-bboard/admin/toggle-active-p.tcl?[export_url_vars topic_id return_url]&active_p=f\">inactive</a>"
	} else {
	    set toggle_link "<a href=\"/threaded-bboard/admin/toggle-active-p.tcl?[export_url_vars topic_id return_url]&active_p=t\">active</a> | <b>inactive</b>"
	}
	append bboard_list "<li><a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">$name</a> - $toggle_link"
    }


    set site_wide_admin_html [db_null]
    if [ad_administrator_p] {
	append site_wide_admin_html "
	<li><a href=/admin/>Site Wide Administration</a>
	<ul>
	<li><a href=/admin/portals>Portal Administration</a>
	</ul>
	<br>
	"
    }

    append page_content "
    <br>
    <ul>
     $site_wide_admin_html
     <li><a href=\"[portals_info customization_url]\">Customize This Portal</a>
    <p>
    <li><b>Membership</b>
    <ul>
    <li><a href=\"/groups/admin/$short_name/members\">Manage Membership</a> - Add/ remove $community_name members 
    <li>Change Enrollment Policy
    "
    
    db_1row get_more_group_info {
	select new_member_policy as current_policy,
	group_name
	from user_groups
	where group_id = :group_id
    }

    set count 0
    db_foreach get_each_member_policy {
	select distinct new_member_policy
	from user_groups
    } {
	if $count {
	    append page_content " | "
	} else {
	    append page_content " - "
	}
	if ![string compare $new_member_policy $current_policy] {
	    append page_content "
	    <b>$new_member_policy</b>"
	} else {
	    append page_content "
	    <a href=/education/class/admin/edit-enrollment-policy-2?[export_url_vars new_member_policy group_id return_url]>$new_member_policy</a>"
	}
	incr count
    }


    set top_level_group_ids_sql "
    select group_id
    from user_groups
    where parent_group_id= $group_id"

    set parent_domain_id [portals_domain_id_from_domain_name community]

    append page_content "
    <li><a href=/manage-users/user-add?group_id=$group_id>Add a new user to [ad_system_name]</a> - This allows you to register new users and give them access to just this community.
    </ul></ul>
    [edu_subportal_html_links $top_level_group_ids_sql]
    <ul>
    <li><a href=\"/education/subgroup/create?[export_url_vars group_id parent_domain_id]\">Create a new subgroup</a></li>
    <p>
    "

    append page_content "
    <li><b>Announcements</b><ul>
    [news_administration_links $group_id]
      <li><a href=\"/[ad_parameter GroupsDirectory ug]/[ad_parameter GroupsAdminDirectory ug]/[ad_urlencode $short_name]/spam-index.tcl\">Spam Members of this Group</a>
      </ul><p>
         <li><b>Calendar</b><ul>
       <li><a href=\"/calendar/?[export_url_vars group_id]&scope=group&action=item-add\">Add Group Item</a>
       </ul><p>
    <li><b>Bulletin Boards</b>
    <ul>
    <li><a href=\"/threaded-bboard/admin/bboard-add.tcl?[export_url_vars group_id return_url]\">Add a new Bulletin Board</a><p>
    $bboard_list
    </ul>
    <p>
    <li><b>Documents</b>
    <ul>
    <li><a href=\"/file-storage/upload-new?[export_url_vars group_id return_url]\">Upload a new File or url</a>
    </ul>
    <br><li><b>FAQs</b>
    [FAQ_administration_links $group_id]

    <br><li><b>Survey</b>
    [survey_administration_links $group_id]
    </ul>
    <br>

    
"
   return $page_content
}

ad_proc -public create_community {
    {-public_p t}
    {-description ""}
    {-approved_p t}
    {-existance_public_p t}
    {-new_member_policy "open"}
    {-add_user_as_admin_p f}
    group_id
    group_name
} {
   @return returns the group_id of the edu_community created.
    @author Caroline Meeks
    @date 02/14/2001
} {
    set user_id [ad_get_user_id]
    # get folder id for the community folder
    db_1row get_seq_nextvals {
	select fs_file_id_seq.nextval as file_id, fs_version_id_seq.nextval as version_id from dual
    }
    
    # the order of this is as follows:
    # 1. stuff all of the edu_community_info variables into an ns_set
    # 2. create the community
    # 3. create the roles for the community
    

	
	# throw all of the community variables into an ns_set so that the ad_user_group_add
	# will take care of putting them into the _info table
	
	set var_set [ns_set new]
	
    ns_set put $var_set public_p $public_p
    ns_set put $var_set description $description

    db_transaction {
        
	if ![ad_user_group_add -approved_p $approved_p -existence_public_p $existance_public_p -new_member_policy $new_member_policy -multi_role_p t -extra_values $var_set -group_id $group_id edu_community $group_name] {
	    error "did not create group"
	}
    
	#create the role and actions for the community
	edu_set_community_roles_and_actions $group_id
	
	if {$add_user_as_admin_p == "t"} {
	    #finally, add the administrator (presumably the user creating the thing) to the community
	    ad_user_group_user_add $user_id [edu_get_administrator_role_string] $group_id
	}

	set depth 0
	set file_title "$group_name Community Folder"

	db_dml insert_into_fs_files {
	    insert into fs_files
	    (file_id, file_title, owner_id, folder_p, sort_key, depth, public_p, group_id)
	    values
	    (:file_id, :file_title, :user_id, 't', 0, :depth, 'f', :group_id)
	}
	
	# now we want to insert a "dummy" version o that we can also create the permission
	# records
    
	db_dml insert_into_fs_versions {
	    insert into fs_versions
	    (version_id, file_id, creation_date, author_id)
	    values
	    (:version_id, :file_id, sysdate, :user_id)
	}
	
	db_with_handle db {
	    ns_ora exec_plsql $db "begin 
	    :1 := ad_general_permissions.grant_permission_to_all_users ( 'read', $version_id, 'FS_VERSIONS' ); 
	    :1 := ad_general_permissions.grant_permission_to_all_users ( 'comment', $version_id, 'FS_VERSIONS' ); 
	    end;"
	}
    
	db_dml update_eci "
	update edu_community_info 
	set root_folder_id = :file_id,
	last_modified = sysdate,
	last_modifying_user = :user_id,
	modified_ip_address = '[ns_conn peeraddr]'                      
	where group_id = :group_id
	"

	db_dml insert_into_cal_groups {
	    insert into cal_groups(group_id) values (:group_id)
	}
    }

    fs_order_files $user_id $group_id $public_p
    
    db_release_unused_handles
    return $group_id
}
