ad_library {
    Modifications to ACS core procedures.

    @creation-date 04 Jan 2001
    @author Tarik Alatovic (tarik@alatovic.com)
    @cvs-id apm-procs.tcl,v 1.16.2.21 2000/08/03 00:23:50 bquinn Exp
}

proc_doc ad_user_group_authorized_admin { user_id group_id } {
    Returns 1 if the user has permission to adminstrate a group. 0 otherwise. This version was modified for education to give parent group admin admin privlages for subgroups. 
} {
    global ad_user_group_authorized_admin_cached
    
    if [info exists ad_user_group_authorized_admin_cached] {
	return $ad_user_group_authorized_admin_cached
    } 
    
    set ad_user_group_authorized_admin_cached [db_exec_plsql ad_user_can_do_action_p "
    begin
    :1 := ad_user_can_do_action_p(v_user_id => :user_id, v_group_id => :group_id, v_action => 'Administer Group');
    end;
    "]
    
    return $ad_user_group_authorized_admin_cached
} 

proc_doc ad_user_group_add { 
    {-approved_p t}
    {-existence_public_p f}
    {-multi_role_p f}
    {-new_member_policy "closed"} 
    {-extra_values ""}
    {-group_id ""}
    {-parent_group_id ""}
    group_type
    group_name
} {
   Fixed a bug for education so that it also does the proper inserts into content_sections.
   Creates a new group. Returns: The groud_id of the group if created
    or it existed already (double click protection); 0 on failure.

    @param group_type: type of group

    @param group_name: pretty name

    @param approved_p (optional): is this an approved group?

    @param existence_public_p (optional): Is the existence of this group public?

    @param new_member_policy (optional): How can members join? (wait, closed, open)

    @param permission_system(optional): What type of permission system (basic, advanced)

    @param extra_values (optional): A ns_set containing 
    extra values that should be stored for this
    group.  These are items that will go in the [set group_type]_info
    tables. The keys of the ns_set contain the column names. The values
    contain the values.

    @param group_id (optional): Group_id. If this is null, one will be created
    @param parent_group_id (optional): Parent_Group_id if this group has a parent group.

} {
    # if no group_id specified, obtain one from the sequence.
    if [empty_string_p $group_id] {
	set group_id [db_nextval user_group_sequence]
    } else {
	# see if it's already there (double-click protection)
	
	set n_rows [db_string user_group_id_exists {
	    select count(*) from user_groups where group_id = :group_id
	}]
	    
	if { $n_rows == 1 } {
	    return $group_id
	}
    }

    db_transaction {
	set short_name [db_string short_name_from_group_name {
	    select short_name_from_group_name(:group_name) from dual
	}]
	    
	set creation_user [ad_get_user_id]
	set creation_ip_address [ns_conn peeraddr]

	db_dml user_group_insert {
	    insert into user_groups
	    (group_id, group_type, group_name, short_name, approved_p, existence_public_p, new_member_policy, multi_role_p, parent_group_id,
	    creation_user, creation_ip_address, registration_date)
	    values (:group_id, :group_type, :group_name, :short_name,
	    :approved_p, :existence_public_p, :new_member_policy, :multi_role_p, :parent_group_id,
	    :creation_user, :creation_ip_address, sysdate)
	}
		
	# insert the extra values
	if { ![empty_string_p $extra_values] } {
	    
	    set bind_vars [ns_set copy $extra_values]
	    ns_set put $bind_vars group_id $group_id
	    db_dml user_group_info_insert "
	    insert into [set group_type]_info ([join [ad_ns_set_keys $bind_vars] ","]) 
	    values ([join [ad_ns_set_keys -colon $bind_vars] ","])
	    " -bind $bind_vars
	    ns_set free $bind_vars
	}
	
	# let's add all the modules to this groups, which are associated with this group type
	db_dml insert_into_cs {
	    insert into content_sections
	    (section_id, scope, section_type, requires_registration_p, visibility, group_id, 
	    section_key, module_key, section_pretty_name, enabled_p)
	    select content_section_id_sequence.nextval, 'group', section_type_from_module_key(module_key), 'f', 'public', :group_id,
	    module_key, module_key, pretty_name_from_module_key(module_key), 't'
	    from user_group_type_modules_map
	    where group_type=:group_type
	}
	

    } on_error {
       ns_log Error "$errmsg in ad-user_groups.tcl - ad_user_group_add insertion into user groups or insertion of extra values"
       db_abort_transaction
    }

    return $group_id
}

# we don't want to encode dot, so we accordingly redefine ad_urlencode
proc_doc ad_urlencode { string } "same as ad_urlencode except that dash and underscore are left unencoded." {
    set encoded_string [ns_urlencode $string]
    regsub -all {%2d} $encoded_string {-} encoded_string
    regsub -all {%5f} $encoded_string {_} encoded_string
    regsub -all {%2e} $encoded_string {.} encoded_string
    return $encoded_string
}


proc_doc ad_footer {{signatory ""} {suppress_curriculum_bar_p 0}} "writes a horizontal rule, a mailto address box (ad_system_owner if not specified as an argument), and then closes the BODY and HTML tags"  {
    global sidegraphic_displayed_p
    if [empty_string_p $signatory] {
	set signatory [ad_system_owner]
    } 
    if { [info exists sidegraphic_displayed_p] && $sidegraphic_displayed_p } {
	# we put in a BR CLEAR=RIGHT so that the signature will clear any side graphic
	# from the ad-sidegraphic.tcl package
	set extra_br "<br clear=right>"
    } else {
	set extra_br ""
    }
    if { [ad_parameter EnabledP curriculum 0] && [ad_parameter StickInFooterP curriculum 0] && !$suppress_curriculum_bar_p} {
	set curriculum_bar "<center>[curriculum_bar]</center>"
    } else {
	set curriculum_bar ""
    }
    if { [llength [info procs ds_link]] == 1 } {
	set ds_link [ds_link]
    } else {
	set ds_link ""
    }
    set education_credit "[ns_adp_parse -file [ad_style_template_root]/ad.adp]"

    return "
$extra_br
$curriculum_bar
<hr>
$education_credit
$ds_link
<a href=\"mailto:$signatory\"><address>$signatory</address></a>
</body>
</html>"
}

proc_doc ad_scope_admin_context_bar args "if scope is not set in the topmost environment then public scope is assumed. if scope=group, it assumes that ug_admin_context_bar_list are set in the topmost environment. returns a Yahoo-style hierarchical contextbar for appropriate scope, starting with links to workspace and admin home.  Suitable for use in pages underneath /admin." {
    if [ad_administrator_p] {
  	set choices [list "<a href=\"[ad_pvt_home]\">Your Workspace</a>" "<a href=\"/admin/\">Admin Home</a>"]
    } else {
  	set choices [list "<a href=\"[ad_pvt_home]\">Your Workspace</a>"]
    }
    set all_args [list]
    
    if { [uplevel [ad_scope_upvar_level] {info exists scope}] } {
  	upvar [ad_scope_upvar_level] scope scope
    } else {
  	set scope public
    }
    
    switch $scope {
  	public {
  	    set all_args $args
  	}
  	group {
  	    upvar [ad_scope_upvar_level] group_vars_set group_vars_set
  	    set group_context_bar_list [ns_set get $group_vars_set group_context_bar_list]
  	    eval "lappend all_args $group_context_bar_list"
  	    foreach arg $args {
  		lappend all_args $arg
  	    }
  	}
  	user {
  	    # this may be later modified if we allow users to customize the display of their pages	    
  	    set all_args $args
  	}
    }
    
    set index 0
    foreach arg $all_args {
  	incr index
  	if { $index == [llength $all_args] } {
  	    lappend choices $arg
  	} else {
  	    lappend choices "<a href=\"[lindex $arg 0]\">[lindex $arg 1]</a>"
  	}
    }
    return [join $choices " : "]
}

# we don't want education pages cached in the proxies
# people behind the firewalls had problems accessing our site
# because web pages were cached
# we need to redefine ns_return, so that it returns pragma:nocache directive

rename ns_return _ad_ns_return

proc ns_return {status type string} {
    ns_write "HTTP/1.0 $status OK
MIME-Version: 1.0
Content-Type: $type
Expires: Mon, 26 Jul 1997 05:00:00 GMT
Last-Modified: [ns_httptime [ns_time]]
Cache-Control: no-cache, must-revalidate
Pragma: no-cache\r\n"

ns_startcontent -type $type
ns_write $string
ns_conn close
}

