ad_library {
 This is the bulk of the tcl procs that are used by the educational module
 @Author: multiple
}

ad_proc edu_url {} {This returns the base url where all of the files are located.} {
    return "/education/"
}

# This redirects guest users that are registered for only one class to that class's portal page.
proc edu_redirect_limited_access_users_to_group_portal {conn args why} {
    set user_id [ad_verify_and_get_user_id]
    
    set guest_p [db_string "check_group_p" "select count(user_id) from user_group_map, user_groups where user_id = :user_id and group_name like 'Limited Access' and user_group_map.group_id = user_groups.group_id"]
    
    if { $guest_p } {
	set other_groups [db_list_of_lists "check_other_groups" "select ug.group_id, domain_name from user_groups ug, portal_domains pd, user_group_map ugm 
	where not (group_name like 'Limited Access') and pd.group_type = ug.group_type 
	and ug.group_id = ugm.group_id 
	and user_id = :user_id
	and ug.group_type in ('edu_class', 'edu_community')"] 

	if { [llength $other_groups] == 1 } {
	    set group_id [lindex [lindex $other_groups 0] 0]
	    set domain_name [lindex [lindex $other_groups 0] 1]
	    
	    ad_returnredirect "[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name $domain_name]]]"
	    return filter_return
	} else {
	    return filter_ok
	}
    } else {
	return filter_ok
    }
}

proc edu_redirect_nonlogged_in_users_to_registration_page {conn args why} {
    set url(1) [lindex [ns_conn urlv] 0]

    if { [empty_string_p $url(1)] } {
	set user_id [ad_verify_and_get_user_id]
	if { $user_id==0 } {
	    # if user is not logged in, redirect him to the registration page
	    ad_returnredirect /register/
	} else {
	    # if user is logged in, redirect him to his home page
	    ad_returnredirect "[portals_get_portal_property base_url [portals_get_portal_id user $user_id [portals_domain_id_from_domain_name users]]]"
	}
	return filter_return
    }

    set url(1) [lindex [ns_conn urlv] 0]
    if { [string compare $url(1) register]==0 } {
	# we want to allow non-logged in users to register
	return filter_ok
    }

    if { [ad_verify_and_get_user_id]==0 } {
        ad_returnredirect /register/
	return filter_return
    } else {
	return filter_ok
    }
}

proc edu_redirect_group_index_page_to_portal_page {conn args why} {
    set urlc [ns_conn urlc]

    if { $urlc==2 } {
	set url2 [lindex [ns_conn urlv] 1]
    } elseif { $urlc==3 } {
	set url2 [lindex [ns_conn urlv] 1]
	set url3 [lindex [ns_conn urlv] 2]
	if [string compare index [string range $url3 0 4]]!=0 {
	    # not a group index page, so return TCL_OK
	    return filter_ok
	}
    } else {
	return filter_ok
    }

    if ![db_0or1row portal_domain_for_group_exists_p "
    select ug.group_id, pd.domain_id
    from user_groups ug, portal_domains pd
    where ug.group_type=pd.group_type
    and ug.short_name=:url2"] {
	# not a group index page, so return TCL_OK
	return filter_ok
    }

    # at this point we know that group index page is being served, so we will
    # redirect to corresponding portal
    
    ad_returnredirect [portals_get_portal_property base_url [portals_get_portal_id group $group_id $domain_id]]
    return filter_return
}

ad_proc edu_term_select_widget { select_name { default "" } } {Returns a selection box that lists all of the available terms that run are current or in the future.} {
    set widget_value "<select name=\"$select_name\">\n"
    if { $default == "" } {
        append widget_value "<option value=\"\" SELECTED>Choose a Term</option>\n"
    }

    db_foreach "term_select" "select term_name, term_id from edu_terms where end_date > sysdate or end_date is null order by end_date" {
	if { $default == $term_id } {
            append widget_value "<option value=\"$term_id\" SELECTED>$term_name</option>\n" 
	} else {            
            append widget_value "<option value=\"$term_id\">$term_name</option>\n"
	}
    }
    db_release_unused_handles

    append widget_value "</select>\n"
    return $widget_value
}

# the following two procs are used to automatically set up the roles
# and actions for a class when it is created

###################################
#                                 #
#       Begin Role Procs          #
#                                 #
###################################

# the next set of three procs are here so that we do not have to hard code
# ta, professor, or student into the code anywhere.  This will allow us to easily
# change the roles if we so desire.

ad_proc edu_get_ta_role_string {} {This returns the string used for the TEACHING ASSISTANT role.  It prevents us from having to hard code Teaching Assistant into the code all over the place.} {
    return ta
}

ad_proc edu_get_ca_role_string {} {This returns the string used for the COURSE ASSISTANT role.  It prevents us from having to hard code Course Assistant into the code all over the place.} {
    return ca
}

ad_proc edu_get_admin_role_string {} {This returns the string used for the ADMINISTRATOR role.  It prevents us from having to hard code Administrator into the code all over the place.} {
    return administrator
}

ad_proc edu_get_professor_role_string {} {This returns the string used for the PROFESSOR role.  It prevents us from having to hard code Professor into the code all over the place.} {
    return professor
}


ad_proc edu_get_student_role_string {} {This returns the string used for the STUDENT role.  It prevents us from having to hard code Studnet into the code all over the place.} {
    return student
}

ad_proc edu_get_dropped_role_string {} {This returns the string used for the Dropped role.  It prevents us from having to hard code Dropped into the code all over the place.} {
    return dropped
}

ad_proc edu_get_class_original_role_pretty_role {} {This returns the list of roles and corresponding pretty role and plural pretty role that are used to initialize the roles for a class.  This procedure should only be called from the procedure that sets up a class.  It is a proc only so that is is next to the other place role are hardcoded into TCL} {
    return [list [list [edu_get_professor_role_string] Professor Professors] [list [edu_get_ta_role_string] "Teaching Assistant" "Teaching Assistants"] [list [edu_get_ca_role_string] "Course Assistant" "Course Assistants"]  [list [edu_get_student_role_string] Student Students] [list [edu_get_dropped_role_string] Dropped Dropped] [list [edu_get_admin_role_string] "Course Administrator" "Course Administrators"]]
}


ad_proc edu_get_class_roles_to_actions_map {} {This returns a role and the corresponding default actions.  This procedure is used to initialize the roles and actions for a new class.  So, each internal list has the first element of a role and the second element is a list of actions the role should start out with.} {

    set to_return [list [list [edu_get_professor_role_string] [list "Administer Group" "Spam Students"]]]
    lappend to_return [list [edu_get_ta_role_string] [list "Administer Group" "Spam Students"]]
    lappend to_return [list [edu_get_ca_role_string] [list "Administer Group" "Spam Students"]]
    lappend to_return [list [edu_get_admin_role_string] [list "Administer Group" "Spam Students"]]
    lappend to_return [list [edu_get_student_role_string] [list "Spam Users" "Spam Students"]]
    lappend to_return [list [edu_get_dropped_role_string] [list]]

    return $to_return
}

ad_proc edu_set_class_roles_and_actions { class_id } {This takes a class id and a database handle and sets up the class permission options.  This should be called when a class is first created and we want to set up all of the permissions.} {

    set roles [edu_get_class_original_role_pretty_role]
    set role_action_map [edu_get_class_roles_to_actions_map]
    set action_list [list "Administer Group" "Spam Students"]

    #the first thing we want to do is add all of the roles
    foreach role $roles {
	ad_user_group_role_add $class_id [lindex $role 0]
	set role_name [lindex $role 0]
	set pretty_role [lindex $role 1]
	set pretty_role_plural [lindex $role 2]
	# the trigger will have done the insert so now we update
	# the information
	db_dml "edu_pretty_role_map_update" "
	update edu_role_pretty_role_map
	set pretty_role = :pretty_role,
	pretty_role_plural = :pretty_role_plural
	where role = :role_name
	and group_id = :class_id"
    }

    #now, add all of the roles
    foreach action $action_list {
	ad_user_group_action_add $class_id "$action"
    }

    #now, map the roles to the correct actions
    foreach role_action $role_action_map {
	set role [lindex $role_action 0]
	set action_list [lindex $role_action 1]
	foreach action $action_list {
	    ad_user_group_action_role_map $class_id $action $role
	}
    }
    db_release_unused_handles
    return
}

ad_proc edu_group_user_role_select_widget { select_name group_id {user_id ""}} {This returns a select box that allows an administrator to select a role for a user.} {
    
    if {[empty_string_p $user_id]} {
	set default ""
    } else {
	set default [db_string "select lower(role) from user_group_map where group_id = :group_id and user_id = :user_id" -default ""]
    }

    set widget_value "<select name=\"$select_name\">\n"
    if { $default == "" } {
        append widget_value "<option value=\"\" SELECTED>Choose a Role</option>\n"
    }

    db_foreach "edu_role_select" "
    select roles.role, pretty_role
    from user_group_roles roles,
    edu_role_pretty_role_map map
    where roles.group_id = :group_id 
    and lower(roles.role) = lower(map.role)
    and roles.group_id = map.group_id
    order by sort_key" {
	if { [string compare $default [string tolower $role]] == 0 } {
            append widget_value "<option value=\"$role\" SELECTED>$pretty_role</option>\n" 
	} else {            
            append widget_value "<option value=\"$role\">$pretty_role</option>\n"
	}
    } if_no_rows {
	set role_list [db_string "group_role_select" "select role from user_group_roles where group_id = :group_id"]

	if {[llength $role_list] == 0} {
	    # we just want to have the list of admin and member
	    set role_list [list administrator member]
	}

	foreach role $role_list {
	    if { [string compare $default $role] == 0 } {
		append widget_value "<option value=\"$role\" SELECTED>[capitalize $role]</option>\n" 
	    } else {            
		append widget_value "<option value=\"$role\">[capitalize $role]</option>\n"
	    }
	}
    }
    db_release_unused_handles

    append widget_value "</select>\n"
    return $widget_value
}

##############################
#                            #
# End role management procs  #
#                            #
##############################

ad_proc edu_empty_row {} {returns an empty table row} {
    return "<tr><td>&nbsp;</td></tr>"
}

ad_proc edu_phone_number_p { number_to_check } {This makes sure that the number passed in has only numbers, -, (, and ).  It returns 1 if the number is valid, 0 otherwise.} {
    return [regexp {[0-9\-\(\)]} $number_to_check]
}

ad_proc edu_textarea { name { default ""} {cols 60} {rows 10}} {outputs a standard textarea of cols=60 rows=10 for varchar(4000).} {
    return "<textarea cols=$cols rows=$rows wrap name=$name>$default</textarea>"
}

ad_proc edu_maybe_display_text { text_to_display } {Takes in text and returns the text if it is not the empty string.  It is is the empty string, it returns the word 'None'} {
    if {[empty_string_p $text_to_display]} {
	return "None"
    } else {
	return $text_to_display
    }
}

##################################################
#                                                #
#                                                #
#     BEGIN THE SECURITY PROCS                   #
#                                                #
#                                                #
##################################################

ad_proc edu_display_not_authorized_message { } {This displays a generic not authorized message for all of the security functions.} {

    set signatory [ad_system_owner]
 
    doc_return 200 text/html "
    [ad_header "Authorization Failed"]
    <h3>Authorization Failed</h3>
    in <a href=/>[ad_system_name]</a>
    <hr>
    <p>You are not authorized to use this section of [ad_system_name].  Please contact <a href=\"mailto:$signatory\"><i>$signatory</i></a> if you have any questions.
    </p>
    [ad_footer]
    "
    return
}

ad_proc edu_user_security_check {} {determines if the user's requested page should be displayed -- under /education/class. this is different from admin page security. Returns {user_id group_id group_name}} {
    set user_id [ad_verify_and_get_user_id]
    
    if { [string compare $user_id "0"] == 0 } {
	ad_returnredirect "/register/index.tcl?return_url=[ad_urlencode [ns_conn url]?[ns_conn query]]"
	return 0
    }

    set class_id [ad_get_client_property education edu_class]

    # we want to get the group name and make sure that the id was the correct type
    set group_name [db_string "group_name_select" "select group_name from user_groups where group_id = :class_id and group_type = 'edu_class'" -default ""]
    
    if {[empty_string_p $class_id] || [empty_string_p $group_name]} {
	ad_returnredirect "/education/util/group-select.tcl?group_type=edu_class&return_url=[ad_urlencode [ns_conn url]?[ns_conn query]]"
	# blow out of 2 levels
	return -code return
    } else {
	# check if the class is public, if so just display the page
	# otherwise check if the user is a member of the class with
	# role != dropped
	if {[db_string "class_public_p_select" "select public_p from edu_class_info where group_id=:class_id"]=="t"} {
	    return [list $user_id $class_id "$group_name"]
	} elseif {[db_string "count_user_role_select" "select count(*) from user_group_map where user_id=:user_id and group_id=:class_id and role!='dropped'"]>0} {
		return [list $user_id $class_id "$group_name"]
	} else {
	    edu_display_not_authorized_message
	    # blow out of 2 levels
	    return -code return
	} 
    }
}

ad_proc edu_group_security_check { group_type {action ""} {error_page 1}} {This returns a list containing, in order, the user_id, the group_id, and the group_name.  Group type should be something like edu_class or edu_department.  This checks to see if the user is logged in as a member of any groups of the given group type.  
<p>
If the user is logged in under the correct group type, it returns the above mentioned list.  If the user is not logged in as a member of a group of the correct type then the user is automatically redirected to group_select.tcl.
<p>
If the user is logged in under the correct group_type then this checks to make sure that the user has permission to perform the passed in action.  If the user does not have the correct permission, this calls edu_display_not_authorized_message and then forces the calling environment to return.
the last argument error_page=1 means that if the user is unauthorized,
redirect to an error page. if error_page=0 then return 0 for unauthorized
user} { 

    set user_id [ad_verify_and_get_user_id]

    if { [string compare $user_id "0"] == 0 } {
	ad_returnredirect "/register/index.tcl?return_url=[ad_urlencode [ns_conn url]?[ns_conn query]]"
	return -code return
    }

    set group_id [ad_get_client_property education $group_type]

    if {![empty_string_p $group_id]} {
	# we want to get the group name and make sure that the id was the correct type
	set group_name [db_string "group_name_from_group_type_select" "select group_name from user_groups where group_id = :group_id and group_type = :group_type" -default ""]
    }

    if {[empty_string_p $group_id] || [empty_string_p $group_name]} {
	append return_url [ns_conn url]
	set query_data [ns_conn query]
	if ![empty_string_p $query_data] {
	    append return_url ?$query_data
	}
	ad_returnredirect "/education/util/group-select.tcl?[export_url_vars group_type return_url]"
	# blow out of 2 levels
	return -code return
    } else {
	if {![ad_permission_p "" "" $action $user_id $group_id]} {
	    if {$error_page} {
		edu_display_not_authorized_message
		# blow out of 2 levels
		return -code return
	    } else {
		return 0
	    }
	} else {
	    return [list $user_id $group_id "$group_name"]
	}
    }
}

ad_proc edu_subject_admin_security_check { subject_id } {This returns the user_id.  It determines if the user is allowed to see the subject admin pages by seeing if they have admin in a department that has the subject.
<p>
If the user is not logged in they are redirected to the log in page.
<p>
If the user is not logged in as a member of a group, they are redirected to group-select.tcl and asked to select a group.
<p>
If they are logged in as a group, the security check is performed.  If the user passes, the user_id is returned to the calling environment.  If the user fails the security check, a standard UNAUTHORIZED message is displayed and the procedure forces the calling environment to return. } {

    # this should be altered if departments go to a multi-roled system 
    # (e.g. prof, staff, students)

    set user_id [ad_verify_and_get_user_id]

    if { [string compare $user_id "0"] == 0 } {
	ad_returnredirect "/register/index.tcl?return_url=[ad_urlencode [ns_conn url]?[ns_conn query]]"
	return -code return
    }

    if {[ad_administrator_p $user_id]} {
	return $user_id
    } 

    # the user is not a site wide admin
    
    set department_id [ad_get_client_property education edu_department]

    if {[empty_string_p $department_id]} {
	ad_returnredirect "/education/util/group-select.tcl?type=edu_department&return_url=[ad_urlencode [ns_conn url]?[ns_conn query]]"
	# blow out of 2 levels
	return -code return
    } else {
	# now, we see if the user is an admin for a department that offers this
	# subject.  If not, we bounce them to group_select or display an error
	# depending on which is appropriate.

	set valid_p [db_string "subject_admin_count_select" "select count(map.subject_id) 
                 from edu_subjects, 
                      edu_subject_department_map map,
                      user_group_map ugmap
                where edu_subjects.subject_id = map.subject_id
                  and map.subject_id = :subject_id
                  and ugmap.user_id = :user_id
                  and ugmap.group_id = map.department_id"] 

	if { $valid_p == 0 } {
	    edu_display_not_authorized_message
	    # blow out of 2 levels
	    return -code return
	} else {
	    return $user_id
	}
    }
}

# stolen from andrew's code for 6.916
ad_proc edu_random_member_blurb { class_id } "Returns a random class member's photograph and a little bio" {

    set users_with_photos_list  [db_list "user_id_list_select" "
    select u.user_id
    from users_active u, user_group_map ugm, general_portraits gp
    where u.user_id=ugm.user_id
    and ugm.group_id=:class_id
    and gp.on_which_table(+)='USERS'
    and gp.on_what_id(+)=u.user_id
    and gp.portrait is not null"]
    # and u.user_id != [ad_get_user_id]"]

    if { [llength $users_with_photos_list] == 0 } {
	return ""
    }

    # get the lucky user
    set random_num [randomRange [expr [llength $users_with_photos_list] -1] ]
    set portrait_user_id [lindex $users_with_photos_list $random_num]

    if { ![db_0or1row "user_info_select" "
    select u.first_names || ' ' || u.last_name as name,
    ugm.role, pretty_role
    from users u,
    user_group_map ugm,
    edu_role_pretty_role_map m
    where u.user_id = ugm.user_id
    and u.user_id = $portrait_user_id
    and ugm.group_id = $class_id
    and m.group_id=$class_id
    and m.role=ugm.role
    and rownum < 2"] } {
	return ""
    }
    
    # **** this should really be smart and look for the actual thumbnail
    # but it isn't and just has the browser smash it down to a fixed width
 
    set string_to_return "
<a href=\"/shared/portrait.tcl?user_id=$portrait_user_id\"><img width=125 src=\"/shared/portrait-bits.tcl?user_id=$portrait_user_id\"></a>
<p>
<a href=/shared/community-member.tcl?user_id=$portrait_user_id>$name</a>,<br>$pretty_role
"

    return $string_to_return
}

ad_proc edu_class_attachment_folder_id { group_id which } {
    returns folder_id where attachments for a class are stored
    which specifies the type of attachment (lecture-notes, handouts, assignments)
} {
    switch $which {
	lecture-notes {
	    return [db_string "lecture_notes_folder_id_select" "select lecture_notes_folder_id from edu_class_info where group_id=:group_id"]
	}
	handouts {
	    return [db_string "handouts_folder_id_select" "select handouts_folder_id from edu_class_info where group_id=:group_id"]
	}
	assignments {
	    return [db_string "assignments_folder_id_select" "select assignments_folder_id from edu_class_info where group_id=:group_id"]
	}
	readings  {
	    return [db_string "assignments_folder_id_select" "select readings_folder_id from edu_class_info where group_id=:group_id"]
	}
	syllabus {
	    return ""
	}
	default {
	    error "Unrecognized folder value. Possible values are lecture-notes, handouts, and assignments"
	}
    }    
}

ad_proc edu_calendar_attachment_folder_widget {group_id} {
    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date 1/17/2001

    Returns select box with options for different kinds of calendar attachments.
    These options are every folder 
} {
    append select_box "
    <select name=doc_folder_id>"

    db_foreach get_folder_names {
	select fsf.file_title, fsf.file_id
	from fs_files fsf, edu_class_info eci
	where fsf.folder_p = 't'
	and fsf.deleted_p = 'f'
	and fsf.parent_id = eci.root_folder_id
	and eci.group_id = :group_id
	and fsf.group_id = :group_id
	order by fsf.file_title
    } {
	append select_box "
	<option value=$file_id>$file_title</option>"
    }

    append select_box "
    </select>"

    return $select_box
}

ad_proc -private edu_display_attachments_in_table { {} table_def group_id doctype {n_past_days ""}} {
    Displays attachments in table.

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date Summer 2000
} {

    switch $doctype {
	all {
	    set folder_query_bit ""
	}
	lecture-notes {
	    set folder_query_bit "and eci.lecture_notes_folder_id=fs.parent_id"
	}
	handouts {
	    set folder_query_bit "and eci.handouts_folder_id=fs.parent_id"
	}
	assignments {
	    set folder_query_bit "and eci.assignments_folder_id=fs.parent_id"
	}
	projects {
	    set folder_query_bit "and eci.projects_folder_id=fs.parent_id"
	}
	default {
	    error "Unrecognized folder value $which. Possible values are lecture-notes, handouts, assignments, and readings"
	}
    }

    set user_id [ad_verify_and_get_user_id]

    # need to set orderby
    ad_page_contract {
	@ Author: ejc@arsdigita.com
    } {
	{orderby ""}
    }

    if { [empty_string_p $n_past_days] } {
	set n_past_days_clause ""
    } else {
	set n_past_days_clause "and fsvl.creation_date >= sysdate - $n_past_days"
    }

    # if group, select just documents for that group, otherwise user, so select all documents from user's classes and communities
    if {$group_id != 0} {
	set group_clause "
	where ug.group_id = $group_id
	and ug.approved_p='t'
	"
    } else {
	set group_clause ", user_group_map ugm
	where ug.group_id = ugm.group_id
	and ug.approved_p='t'
	and user_id = $user_id"
    }

    set sql_query "
    select file_id, file_title, version_id, version_description as description, client_file_name, n_bytes, url,
           ci.item_id, ci.title as cal_item_title, ci.start_date, group_name, short_name, group_type,
           combine_type_names(ci.item_id, '<br>') as category_list,
           to_char(ci.start_date, 'MM/DD/YYYY') as pretty_start_date
    from cal_items ci, 
         (select fs.file_id, 
                 fs.file_title as file_title,
                 fsvl.version_id,
                 fsvl.client_file_name,
                 fsvl.n_bytes,
                 fsvl.version_description,
                 fsvl.url,
                 cdrm.item_id,
                 ug.group_name,
                 ug.short_name,
                 ug.group_type
          from fs_files fs, fs_versions_latest fsvl, edu_class_info eci, cal_item_db_row_map cdrm, user_groups ug
          $group_clause
          and fs.file_id=fsvl.file_id
          and eci.group_id=ug.group_id
          and fs.group_id=ug.group_id
          and fs.folder_p='f'
          $n_past_days_clause
          and cdrm.on_which_table(+)='FS_FILES'
          and fs.file_id= cdrm.on_what_id(+)
          $folder_query_bit
          and (ad_general_permissions.user_has_row_permission_p ( $user_id, 'read', fsvl.version_id, 'fs_versions' ) = 't'
               or fs.owner_id = $user_id)
          and fs.deleted_p='f') files
    where ci.item_id(+)=files.item_id [ad_order_by_from_sort_spec $orderby $table_def]
    "

    set row_code {[
    if {![info exists url] || [empty_string_p $url]} {
	regsub -all {[^-_.0-9a-zA-Z]+} $client_file_name "_" pretty_file_name
	set url "/file-storage/download/$version_id/$pretty_file_name"
    }
	set garbage ""
    
    ]}

    set table "[ad_table -Textra_vars {group_id} -Tpre_row_code $row_code -Tmissing_text {} -Torderby $orderby "class_files_select" $sql_query $table_def]"
    return $table
}

ad_proc edu_user_has_permission_p {{} portal_id permission} {
    Permission procedure for class and community portals.
    Checks whether logged in user has a right to view or administer the portal page identified by portal_id.

    @author tarik@arsdigita.com
    @date november 2000
    
    @param portal_id
    @param permission is either view or administer
    @return 1 if user has indicated permission, otherwise returns 0.

    @see portals_default_user_has_permission_p
    @see portals_register_permission_proc
} {
    set logged_in_user_id [ad_verify_and_get_user_id]
    set portal_type [portals_get_portal_property type $portal_id]
    
    switch $portal_type {
	default_portal {
	    switch $permission {
		view - administer {
		    # only site-wide administrators can manage default portals	
		    if [ad_administrator_p $logged_in_user_id] {
			return 1
		    } else {
			return 0
		    }
		}
		default {
		    error "edu_user_has_permission_p: $permission is invalid permission."
		}
	    }
	}
	group {
	    set group_id [portals_get_portal_property group_id $portal_id]
	    if {[ad_user_group_authorized_admin $logged_in_user_id $group_id]} {
		return 1
	    }
	    switch $permission {
		view {
		    return [ad_user_group_member $group_id $logged_in_user_id]
		}
		administer {
		    #check admin privalage before the switch
		    return 0
		}
		default {
		    error "edu_user_has_permission_p: $permission is invalid permission."
		}
	    }
	}
	user {
	    set portal_user_id [portals_get_portal_property user_id $portal_id]
	    switch $permission {
		view - administer {
		    if {$portal_user_id == $logged_in_user_id} {
			return 1
		    } else {
			return 0
		    }
		}
		default {
		    error "edu_user_has_permission_p: $permission is invalid permission."
		}
	    }
	}
    }
}
 
ad_proc edu_document_pretty_name {{} doc_type} {
    Given the document type, it returns pretty name for the document.
    There are three different types of documents: lecture-notes, handouts, and assignments.
} {
    switch $doc_type {
	lecture-notes {
	    set pretty_name "Lecture Notes"
	}
	handouts {
	    set pretty_name "Handout"
	}
	assignments {
	    set pretty_name "Assignment"
	}
	readings {
	    set pretty_name "Reading"
	}
	syllabus {
	    set pretty_name "Syllabus"
	}
	default {
	    error "Unknown type of document"
	}
    }
    return $pretty_name
}

ad_proc edu_document_pretty_plural_name {{} doc_type} {
    Given the document type, it returns pretty plural name for the document.
    There are three different types of documents: lecture-notes, handouts, and assignments.
} {
    switch $doc_type {
	lecture-notes {
	    set pretty_name "Lecture Notes"
	}
	handouts {
	    set pretty_name "Handouts"
	}
	assignments {
	    set pretty_name "Assignments"
	}
	readings {
	    set pretty_name "Readings"
	}
	default {
	    error "Unknown type of document"
	}
    }
}

ad_proc edu_display_class_info {class_id} {
    returns the vital course info: description, prereqs, credit hours, link to syllabus, etc. Returns results in a table
} {
  if { ![db_0or1row "term_info_select" "
    term_id,
    c.subject_id,
    start_date,
    end_date,
    nvl(c.description, s.description) as description,
    where_and_when,
    syllabus_id,
    version_id,
    file_extension,
    exams_p,
    final_exam_p,
    credit_hours, 
    prerequisites
    from edu_current_classes c,
    (select * from fs_versions_latest 
    where ad_general_permissions.user_has_row_permission_p([ad_verify_and_get_user_id], 'read', version_id, 'FS_VERSIONS') = 't') ver,
    edu_subjects s
    where class_id = :class_id
    and syllabus_id = file_id(+)
    and c.subject_id = s.subject_id(+)"] } {
	return ""
    }

    set class_info_text "
    <table>
    <tr>
    <th valign=top align=left>
    Description:
    </td>
    <td valign=top>
    [edu_maybe_display_text $description]
    </td>
    </tr>
    "
    
    if {![empty_string_p $credit_hours]} {
	append class_info_text "
	<tr>
	<th valign=top align=left nowrap>
	Credit Hours:
	</td>
	<td valign=top>
	$credit_hours
	</td>
	</tr>
	"
    }
    
    # if there is a syllabus, show a link here
    
    if {![empty_string_p $syllabus_id]} {
	set syllabus_text "
	<a href=\"/file-storage/download/$version_id/Syllabus.$file_extension\">Syllabus</a>"
    } else {
	set syllabus_text ""
    }
    
    if {![empty_string_p $prerequisites]} {
	append class_info_text "
	<tr>
	<th valign=top align=left>
	Prerequisites:
	</td>
	<td valign=top>
	$prerequisites
	</td>
	</tr>
	"
    }
    
    append class_info_text "
    <tr><td></td><td><b>$syllabus_text</td></tr>
    </table>"

    return $class_info_text
}


##########
#
# Display the roles for a class...
# (usually professors and assistants)
# Hans C. Masing (hmasing@arsdigita.com)
# July 13, 2000
#
# Each entry looks something like this:
#
# Professor Tarik Alatovic
# Tel: (800) 555-1212 
# Email: tarik@arsdigita.com 
#
##########
# modified by ejc@arsdigita.com - 7/19/2000
# fixed a couple of bugs, also modified function to take a list of roles, rather than one role
################
#modified by basel@arsdigita.com - 7/20/2000
#changed name, and moved proc

ad_proc edu_display_group_roles { list_of_roles } {
    displays information for all the users who have a particular role in a group.
    for example, if this function is called with the list containing "professor" and "ta," it returns a list of all the professors and TAs for that class.
} {
    set user_id [ad_verify_and_get_user_id]

    ad_page_contract {
	@Author: hmasing, ejc, basel
    } {
	{orderby "last_name"}
    }

    if {[portals_info type]=="group"} {
	# group portal
	set group_id [portals_info group_id]
    } else {
	# user portal
	error "edu_display_group_roles: group roles can be only used within group portlets"
    }

    set html ""

    if ![empty_string_p $user_id] {	
	foreach role $list_of_roles {
	    set table_def {
		{first_names {First name} {} {<td><a href=\"/shared/community-member?[export_url_vars user_id]\">$first_names</a></td>} }
		{last_name {Last name} {} {<td><a href=\"/shared/community-member?[export_url_vars user_id]\">$last_name</a></td>} }
		{email {Email} {} {<td><a href=\"mailto:$email\">$email</a></td>} }
	    }
	    
	    set sql_query "
            select INITCAP(ugm.role) as role_cap,
	           u.first_names, u.last_name, u.email, u.user_id
            from   users u, user_group_map ugm, user_groups ug
            where  ugm.group_id = :group_id
            and    ugm.role = :role
            and    ugm.group_id = ug.group_id
            and    ugm.user_id = u.user_id [ad_order_by_from_sort_spec $orderby $table_def]"

	    set bind_vars [ns_set create]
	    
	    ns_set put $bind_vars group_id $group_id
	    ns_set put $bind_vars role $role
	    
	    set table [ad_table -Torderby $orderby -Tmissing_text "<em>There are no persons with that role.</em>" -bind $bind_vars "user_class_roles_select" $sql_query $table_def]

	    if [db_0or1row select_pretty_role_for_edu_class_roles "select pretty_role_plural from edu_role_pretty_role_map where role = :role and group_id = :group_id"] {
		append html "
		<b>$pretty_role_plural</b>"
	    } 
	    
	    append html "	    
	    <blockquote>$table</blockquote>"
	}
    }

    return $html
}

ad_proc edu_display_class_members { } {
    Display the class info portlet.  Invokes edu_display_group_roles and 
    adds a link at the bottom. (edu_display_group_roles is very generic so 
    I didn't want to modify it.)
} {
    set html [edu_display_group_roles [list professor ta ca]]

    set group_id [portals_info group_id]

    append html "<p><ul>
    <a href=\"/education/class/display-student-list?group_id=$group_id\">Show Student List</a><p>"

    return $html
}

ad_proc edu_display_group_administrators { } {
    Display the group administrators portlet.
} {
    return [edu_display_group_roles [list administrator]]
}

ad_proc edu_display_class_students { } {
    Displys a list of students, and then gives a link to add a student if user is an administrator, calls edu_display_group_roles 
} {
    set user_id [ad_verify_and_get_user_id]
    
    if {[portals_info type]=="group"} {
	# group portal
	set group_id [portals_info group_id]
		    
	## if not a site-wide admin, and
	## either not a member of the group
	## dropped or self-enrolled, cannot
	## see this list
	if { ![ad_administrator_p $user_id] } {
	    if { ![ad_user_group_member $group_id $user_id] } { 
		return "PORTAL_NO_ACCESS"
	    } else {
		set role [db_string "role_select" "select lower(role) from user_group_map where user_id = :user_id and group_id = :group_id" -default ""]
		
		if { [string compare $role administrator] != 0 && [string compare $role member] != 0 && [string compare $role professor] != 0 && [string compare $role student] != 0 && [string compare $role ta] != 0 } {
		    return "PORTAL_NO_ACCESS"
		}
	    }
	}
	
	set return_url [ns_conn url]
	set query [ns_conn query]
	
	if ![empty_string_p query] {
	    append return_url ?query
	}
	
	set html [edu_display_group_roles [list student]]
	if [ad_user_group_authorized_admin $user_id $group_id] {
	    append html "<blockquote><br><a href=/education/class/admin/users/add.tcl?[export_url_vars group_id return_url]&role=student>add student</a></blockquote>"
	}
	return $html
    } else {
	#user portal
	return ""
    }
}

#############--- ROLE PROCS ---############
# defined here so that names of roles can be changed easily

ad_proc edu_get_administrator_role_string { {} } {
    This returns the string used for the ADMINISTRATOR role.  It prevents us from having to hard code Administrator into the code all over the place.
} {
    return administrator
}

ad_proc edu_get_member_role_string { {} } {
    This returns the string used for the MEMBER role.  It prevents us from having to hard code Member into the code all over the place.
} {
    return member
}

ad_proc -public edu_user_has_limited_access_p {user_id} {
    @return return 1 if user identified be user_id is a member of limited access group.
            otherwise, it returns 0.
    @param user_id
    @author Tarik Alatovic
    @date 01/25/2001
} {
    return [db_0or1row user_has_limited_access_p "
    select 1
    from user_group_map ugm, user_groups ug 
    where user_id = :user_id 
    and short_name='limited_access'
    and ug.group_id = ugm.group_id"]
}

ad_proc -public edu_subportal_html_links {{ -show_only_user_subportals_p 0} top_level_group_ids_sql} {
    @return html segment that hierarchically lists links to subportals of portals specified in top_level_portal_id_list
    @param top_level_group_ids_sql sql segment that defines top level groups for subportal links
    @param show_only_user_subportals_p if show_only_user_subportals_p is 1, then subportals of groups that logged-in-user is not a member of are not shown. otherwise, all subportals are shown.
    @author Tarik Alatovic
    @date 01/25/2001
} {
    set cur_group_type ""
    set cur_hierarchy_level 0

    set user_id [ad_verify_and_get_user_id]
    if $show_only_user_subportals_p { 
	set limitation_sql "
	where ug.group_id in (select ugm.group_id 
                              from user_group_map ugm, portals p2
                              where ugm.user_id = :user_id
                              and ugm.group_id= p2.group_id)
	and ug.approved_p='t'
	and ug.active_p='t'
	"
    } else {
	set limitation_sql ""
    }

    append html_content "<ul>"

    db_foreach get_subgroup_info "
    select /* +INDEX(USER_GROUPS USER_GROUP_HIERARCHY_INDEX)*/ 
           ug.group_id, 
           ug.group_type,
           ug.group_name,
           (select ugt.pretty_plural
            from user_group_types ugt
	    where ug.group_type= ugt.group_type) as pretty_plural,
           level as hierarchy_level,
           (select portal.get_base_url(p.portal_id)
            from portals p
            where p.group_id=ug.group_id) as base_url,
           ad_user_can_do_action_p(:user_id, ug.group_id, 'Administer Group') as admin_p
    from user_groups ug
    $limitation_sql
    start with ug.group_id in ($top_level_group_ids_sql)
    connect by prior ug.group_id = ug.parent_group_id
    " {
	if { [string compare $group_type $cur_group_type]!=0 && $hierarchy_level==1 } {
	    if { ![empty_string_p $cur_group_type] } {
		for { set i 0 } { $i < $cur_hierarchy_level } { incr i } {
		    append html_content "
		    </ul>"
		}
	    }
	    
	    append html_content "
	    <br>
	    <li><b>$pretty_plural</b>
	    <ul>
	    "
	    set cur_group_type $group_type
	} else {
	    if { $cur_hierarchy_level > 0 } {
		if { $hierarchy_level > $cur_hierarchy_level } {
		    append html_content "
		    <ul>
		    "
		} elseif { $hierarchy_level < $cur_hierarchy_level } {
		    append html_content "
		    </ul>
		    "
		}
	    }
	}
	
	append html_content "
	<li><a href=\"$base_url/\">$group_name</a>"
	
	if $admin_p {
	    append html_content " - \[<a href=\"$base_url/control-panel/\">Admin</a>\]"
	}
	
	append html_content "</li>"
	
	set cur_hierarchy_level $hierarchy_level

    }

    if { ![empty_string_p $cur_group_type] || $cur_hierarchy_level > 0 } {
	for { set i 0 } { $i < $cur_hierarchy_level } { incr i } {
	    append html_content "
	    </ul>"
	}
    }

    append html_content "</ul>"

    return $html_content
}


ad_proc -public edu_display_subgroups_in_a_group {group_id user_id} {
    @author Befekadu Ayenew
    @date 02/01/2001
} {
    set html_content "<ul>"
    set counter 0
    db_foreach subgroups_select "
    select ug.group_name, ug.group_id subgroup_id, 
    ad_user_can_do_action_p(:user_id, ug.group_id, 'Administer Group') as admin_p 
    from user_groups ug, user_group_map map 
    where parent_group_id = :group_id 
    and ug.group_id = map.group_id 
    and ug.approved_p='t'
    and ug.active_p='t'
    and map.user_id = :user_id order by lower(ug.group_name)" {	
	append html_content "<li><a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $subgroup_id [portals_domain_id_from_domain_name subgroup]]]/\">$group_name</a>"
	if { $admin_p } {
	    append html_content " - \[<a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $subgroup_id [portals_domain_id_from_domain_name subgroup]]]/control-panel\">Admin</a>\]"
	}
	incr counter
    }

    set subgroups_exist_p [db_string subgroup_count "select count(group_name) from user_groups where parent_group_id = :group_id and new_member_policy in ('open', 'wait')"]

    append html_content "</ul>"
    return [list [expr $counter + $subgroups_exist_p] $html_content]
}

