# /packages/education/subgroup-procs.tcl

ad_library {
    All tcl procs pertaining to communities go here.

    @creation-date January 22, 2000
    @cvs-id $Id: subgroup-procs.tcl,v 1.11 2001/02/26 01:52:36 tarik Exp $
}

ad_proc edu_get_subgroup_original_role_pretty_role { {} } {
    This returns the list of roles and corresponding pretty role and plural pretty role that are used to initialize the roles for a subgroup.
    This procedure should only be called from the procedure that sets up a subgroup.  It prevents us from hardcoding all of this info into TCL.
} {
    return [list [list [edu_get_administrator_role_string] Administrator Administrators] [list [edu_get_member_role_string] Member Members]]
}

ad_proc edu_get_subgroup_roles_to_actions_map { {} } {
    This returns a role and the corresponding default actions.  This procedure is used to initialize the roles and actions for a new subgroup.
    So, each internal list has the first element of a role and the second element is a list of actions the role should start out with.
} {

    set to_return [list [list [edu_get_administrator_role_string] [list "Administer Group" "Spam Users"]]]
    lappend to_return [list [edu_get_member_role_string] [list]]

    return $to_return
}

ad_proc edu_set_subgroup_roles_and_actions { {} subgroup_id } {
    @param subgroup_id The group id of the subgroup.

    This takes a subgroup id and sets up the subgroup permission options. This should be called when a subgroup is first created.
} {
    set role_list [edu_get_subgroup_original_role_pretty_role]
    set role_action_map [edu_get_subgroup_roles_to_actions_map]
    set action_list [list "Administer Group" "Spam Users"]
    #the first thing we want to do is add all of the roles
    foreach role_sublist $role_list {
	ad_user_group_role_add $subgroup_id [lindex $role_sublist 0]

	# the trigger will have done the insert so now we update
	# the information
	db_dml update_pretty_roles "update edu_role_pretty_role_map
                       set pretty_role = '[lindex $role_sublist 1]',
                           pretty_role_plural = '[lindex $role_sublist 2]'
                       where role = '[lindex $role_sublist 0]'
	               and group_id = :subgroup_id"
    }

    #now, add all of the roles
    foreach action $action_list {
	ad_user_group_action_add $subgroup_id "$action"
    }

    #now, map the roles to the correct actions
    foreach role_action $role_action_map {
	set role [lindex $role_action 0]
	set action_list [lindex $role_action 1]
	foreach action $action_list {
	    ad_user_group_action_role_map $subgroup_id $action $role
	}
    }	
}

ad_proc DisplaySubGroupAdministration {} {
    SubGroup administration page
} {
    
    set user_id [ad_verify_and_get_user_id]
    set group_id [portals_info group_id]
    set group_name [portals_info group_name]

    set sql_restriction [db_null]
    
    set return_url [ns_conn url]
    set query [ns_conn query]
    if ![empty_string_p query] {
	append return_url "?$query"
    }

    if {! [ad_user_group_authorized_admin_or_site_admin $user_id $group_id] } {
	return ""
    }

    set role_list [edu_get_community_original_role_pretty_role]
    
    set header_string "$group_name Users"

    set bboard_list [db_null]

    db_foreach get_bboard_topics {
	select topic_id, name, active_p from gc_bboard_topics where group_id = :group_id
    } {
	if { $active_p == "t" } {
	    append bboard_list "<li><a href=\"/threaded-bboard/one-topic.tcl?[export_url_vars topic_id group_id]\">$name</a> - <a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">Administration</a><br>"
	} else {
	    append bboard_list "<li>$name - <a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">Administration</a> (inactive)<br>"
	}
    }

    db_1row get_group_info {
	select existence_public_p, short_name, group_type from user_groups where group_id = :group_id
    }

    set site_wide_admin_html [db_null]
    if [ad_administrator_p] {
	append site_wide_admin_html "
	<li><b>Site Wide Administration</b>
	<ul>
	[AdminTools]
	<li><a href=/education/department/admin>Department Administration</a>
	</ul>
	<br>
	"
    }

    append page_content "
    <br>
    <ul>
     $site_wide_admin_html
     <li><a href=[portals_info customization_url]>Customize This Portal</a><p>

    <li><b>SubGroup Administration</b>
    <ul>

    <li><a href=\"/education/subgroup/manage-users?group_id=$group_id\">Manage Membership</a>
    <li><a href=\"/education/class/admin/edit-enrollment-policy?[export_url_vars group_id return_url]\">View/Change Enrollment Policy</a> - "

    db_1row get_more_group_info {
	select new_member_policy as current_policy,
	group_name
	from user_groups
	where group_id = :group_id
    }

    set new_member_policy_list [list "open" "closed" "wait"]
    
    set count 0
    foreach new_member_policy $new_member_policy_list {
	if $count {
	    append group_administration_html " | "
	}
	if ![string compare $new_member_policy $current_policy] {
	    append group_administration_html "
	    <b>$new_member_policy</b>"
	} else {
	    append group_administration_html "
	    <a href=/education/class/admin/edit-enrollment-policy-2?[export_url_vars new_member_policy group_id return_url]>$new_member_policy</a>"
	}
	incr count
    }

    append page_content "$group_administration_html </ul>"

    append page_content "<p><li><b>Announcements</b><ul>
    [news_administration_links $group_id]
      <li><a href=\"/[ad_parameter GroupsDirectory ug]/[ad_parameter GroupsAdminDirectory ug]/[ad_urlencode $short_name]/spam-index\">Spam Members of this Group</a>
      </ul><p>
       <li><b>Calendar</b><ul>
       <li><a href=\"/calendar/?[export_url_vars group_id]&scope=group&action=item-add\">Add Group Item</a>
       </ul><p>
       "
   append page_content "
     <li><b>Bulletin Boards</b>
      <ul>
       <li><a href=\"/threaded-bboard/admin/bboard-add.tcl?[export_url_vars group_id return_url]\">Add a new Bulletin Board</a><p>
       $bboard_list
      </ul>
    "
   append page_content "
     <br><li><b>FAQs</b>
        [FAQ_administration_links $group_id]
    <br><li><b>Survey</b>
    [survey_administration_links $group_id]
    </ul>
    <br>
    "

   return $page_content
}

ad_proc parent_group_link {group_id} {
    Returns the parent group name wrapped in a url
} {
    db_1row parent_info {select ugp.group_name as parent_name, portal.get_base_url(portal_id) as parent_url
    from user_groups ug, user_groups ugp, portals
    where ug.group_id = :group_id
    and ugp.group_id = ug.parent_group_id
    and portals.group_id = ugp.group_id}
    return "<a href=$parent_url>$parent_name</a>"
}


ad_proc -public DisplaySubgroupCreateLink { {} } {
    Displays a link to the create.tcl page for a subgroups, if the user has permission.

    @author Befekadu Ayenew (befekadu@mit.edu)
    @creation-date Feb 01 2001
} {
    set user_id [ad_verify_and_get_user_id]
    
    set url ""
    if {[portals_info type]=="group"} {	
	set group_id [portals_info group_id]	
	if {[ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {
	    ns_log Notice "group_id $group_id

	    select group_type from user_groups where group_id = $group_id"

	    set group_type [db_string select_group_type "select group_type from user_groups where group_id = $group_id"]
	    regexp edu_(.*) $group_type match type

	    set parent_domain_id [portals_domain_id_from_domain_name $type]
	    
	    append url "<a href=\"/education/subgroup/create?[export_url_vars group_id parent_domain_id]\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
	}
    }
    db_release_unused_handles
    return $url
}



