# /packages/education/www/class/admin/edit-enrollment-policy.tcl

ad_page_contract {
    Allows a class admin / professor to change the enrollment policy between "open," "wait," and "closed."

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date August 2, 2000
    @cvs-id $Id: edit-enrollment-policy.tcl,v 1.1.1.1 2001/01/24 18:03:21 tarik Exp $
} {
    group_id:integer,notnull
    return_url:notnull
} -validate {
    accessible_p -requires {group_id} {
	if {![ad_administrator_p] && ![ad_user_group_authorized_admin [ad_verify_and_get_user_id] $group_id]} {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    group_id {Valid Class ID not specified}
    return_url {Return URL not specified}
}

db_1row get_group_info {
    select new_member_policy as current_policy,
    group_name
    from user_groups
    where group_id = :group_id
}

append doc "
[ad_header "View/Change Enrollment Policy"]
<h2>View/Change Enrollment Policy</h2>
<hr>

<blockquote>
<center>
The current enrollment policy for $group_name is \"<b>$current_policy</b>.\"
<br><br>
Change policy to <br>
"

set count 0
db_foreach get_new_member_policies {
    select distinct new_member_policy
    from user_groups
} {
    if $count {
	append doc " | "
    }
    if ![string compare $new_member_policy $current_policy] {
	append doc "
	<b>$new_member_policy</b>"
    } else {
	append doc "
	\[<a href=edit-enrollment-policy-2?[export_url_vars new_member_policy group_id return_url]>$new_member_policy</a>\]"
    }
    incr count
}

append doc "
</center>
<br><br>
<em>
Open - Any user can join the group.
<br>Wait - A user may request membership, but must be approved by the group administrator.
<br>Closed - The group is closed to new users.
</em>
</blockquote>
[ad_footer]"

doc_return 200 text/html $doc