#
# /www/education/class/admin/office-hours-add.tcl
#
# This page allows profs and TAs to add office hours for a 
# particular day so that students can automatically sign up
# for a time slot
# 
# by randyg@arsdigita.com, aileen@mit.edu, January 2000
#

# this page will loop back on itself as long as the profossor
# keeps adding breaks.  

ad_page_variables {
    place
    start_time_hour
    start_time_minute
    start_time_ampm
    end_time_hour
    end_time_minute
    end_time_ampm
    increment
    public_schedule_p
    {appointment_date ""}
    {start_break_time_hour ""}
    {start_break_time_minute ""}
    {start_break_time_ampm ""}
    {end_break_time_hour ""}
    {end_break_time_minute ""}
    {end_break_time_ampm ""}
    {break_times_list [list]}
    return_url
    return_url_string
}

# this also takes in the times for the begin and end of 
# the office hours as well as the begin and end of any
# break.

set db [ns_db gethandle]

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

set id_list [edu_group_security_check $db edu_class "View Admin Pages"]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]


# appointment_date is only not null when a break is being scheduled
# and the appointment has already been set
if {[empty_string_p $appointment_date]} {
    set appointment_date [validate_ad_dateentrywidget Date appointment_date [ns_conn form]]
}


set exception_count 0
set exception_text ""

if {![edu_check_times $start_time_hour $start_time_minute $start_time_ampm $end_time_hour $end_time_minute $end_time_ampm]} {
    incr exception_count
    append exception_text "<li>The start time must come before the ending time."
}

if {![edu_check_times $start_break_time_hour $start_break_time_minute $start_break_time_ampm $end_break_time_hour $end_break_time_minute $end_break_time_ampm]} {
    incr exception_count
    append exception_text "<li>The break must start before it ends."
}

if {!([empty_string_p $start_break_time_hour] || [empty_string_p $start_break_time_minute] || [empty_string_p $start_break_time_ampm] || [empty_string_p $end_break_time_hour] || [empty_string_p $end_break_time_minute] || [empty_string_p $end_break_time_ampm])} {
    lappend break_times_list [list [list $start_break_time_hour $start_break_time_minute $start_break_time_ampm] [list $end_break_time_hour $end_break_time_minute $end_break_time_ampm]]
} 


if {$exception_count > 0} {
    ad_return_complaint $exception_count $exception_text
    return
}


set html "
[ad_header "Office Hours for $class_name @ [ad_system_name]"]

<h2>Add Office Hours</h2>

[ad_context_bar_ws_or_index [list "../one.tcl" "$class_name Home"] [list "" "Administration"] "Add Office Hours"]

<hr>
<blockquote>

<table>
<tr>
<th align=right>
Location:
</td>
<td>
$place
</td>
</tr>

<tr>
<th align=right>
Date:
</td>
<td>
[util_AnsiDatetoPrettyDate $appointment_date]
</td>
</tr>

<tr>
<th align=right>
Start Time:
</td>
<td>
${start_time_hour}:${start_time_minute} $start_time_ampm
</td>
</tr>

<tr>
<th align=right>
End Time:
</td>
<td>
${end_time_hour}:${end_time_minute} $end_time_ampm
</td>
</tr>

<tr>
<th align=right>
How long would you like each 
<br>
appointment to last?
</td>
<td>
[lindex [split $increment "|"] 1]
</td>
</tr>

<tr>
<th align=right>
Do you want to allow the class 
<br>
to see the names of people signed 
<br>
up for a given time slot?
</td>
<td>
[ad_html_pretty_boolean $public_schedule_p]
</td>
</tr>
"

set count 0
foreach break_time $break_times_list {
    if {$count == 0} {
	append html "<tr><td colspan=2 align=left>
	[ad_space]<p> Scheduled Breaks: <ul>"
    }
    incr count
    set start_time [lindex $break_time 0]
    set end_time [lindex $break_time 1]
    append html "<li>[lindex $start_time 0]:[lindex $start_time 1] [lindex $start_time 2] to
    [lindex $end_time 0]:[lindex $end_time 1] [lindex $end_time 2]"
}

if {$count > 0} {
    append html "</ul></td></tr>"
}

append html "
<tr>
<td colspan=2 align=center>
<input type=submit value=\"Add Office Hours\">
</td>
</tr>
</table>

<form method=post action=\"office-hours-add-2.tcl\">
<p>[ad_space]<p>
<b>Or, Add a break:</b>
<blockquote>
<table>
<tr>
<td>
Start Break:
</td>
<td>
[edu_time_select_widget start_break_time $start_time_hour $start_time_minute $start_time_ampm]
</td>
</tr>

<tr>
<td>
End Break:
</td>
<td>
[edu_time_select_widget end_break_time $end_time_hour $end_time_minute $end_time_ampm]
</td>
</tr>
</table>

[export_form_vars place appointment_date start_time_ampm start_time_hour start_time_minute end_time_hour end_time_ampm end_time_minute increment public_schedule_p break_times_list return_url return_url_string]
<input type=submit value=\"Add Break\">
</form>

<form method=post action=\"office-hours-add-3.tcl\">

[export_form_vars place appointment_date start_time_ampm start_time_hour start_time_minute end_time_hour end_time_ampm end_time_minute increment public_schedule_p break_times_list return_url return_url_string]

<input type=submit value=\"Finished\">
</form>

</blockquote>

</blockquote>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $html
