#
# /www/education/class/admin/office-hours-add-3.tcl
#
# This page allows profs and TAs to add office hours for a 
# particular day so that students can automatically sign up
# for a time slot
# 
# by randyg@arsdigita.com, aileen@mit.edu, January 2000
#

# this page will loop back on itself as long as the profossor
# keeps adding breaks.  

ad_page_variables {
    place
    start_time_hour
    start_time_minute
    start_time_ampm
    end_time_hour
    end_time_minute
    end_time_ampm
    increment
    public_schedule_p
    appointment_date
    break_times_list
    return_url
    return_url_string
}

# this also takes in the times for the begin and end of 
# the office hours as well as the begin and end of any
# break.

set db [ns_db gethandle]

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

set id_list [edu_group_security_check $db edu_class "View Admin Pages"]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]



set html "
[ad_header "Office Hours for $class_name @ [ad_system_name]"]

<h2>Confirm Office Hours</h2>

[ad_context_bar_ws_or_index [list "../one.tcl" "$class_name Home"] [list "" "Administration"] "Confirm Office Hours"]

<hr>
<blockquote>

<table>
<tr>
<th align=right>
Location:
</td>
<td>
$place
</td>
</tr>

<tr>
<th align=right>
Date:
</td>
<td>
[util_AnsiDatetoPrettyDate $appointment_date]
</td>
</tr>

<tr>
<th align=right>
Start Time:
</td>
<td>
${start_time_hour}:${start_time_minute} $start_time_ampm
</td>
</tr>

<tr>
<th align=right>
End Time:
</td>
<td>
${end_time_hour}:${end_time_minute} $end_time_ampm
</td>
</tr>

<tr>
<th align=right>
How long would you like each 
<br>
appointment to last?
</td>
<td>
[lindex [split $increment "|"] 1]
</td>
</tr>

<tr>
<th align=right>
Do you want to allow the class 
<br>
to see the names of people signed 
<br>
up for a given time slot?
</td>
<td>
[ad_html_pretty_boolean $public_schedule_p]
</td>
</tr>
"

set count 0
foreach break_time $break_times_list {
    if {$count == 0} {
	append html "<tr><td colspan=2 align=left>
	[ad_space]<p> Scheduled Breaks: <ul>"
    }
    incr count
    set start_time [lindex $break_time 0]
    set end_time [lindex $break_time 1]
    append html "<li>[lindex $start_time 0]:[lindex $start_time 1] [lindex $start_time 2] to
    [lindex $end_time 0]:[lindex $end_time 1] [lindex $end_time 2]"
}

if {$count > 0} {
    append html "</ul></td></tr>"
}


set appointment_id [database_to_tcl_string $db "select edu_appointments_appt_id_seq.nextval from dual"]


append html "
<tr>
<td colspan=2 align=center>
<form method=post action=\"office-hours-add-4.tcl\">

[export_form_vars place appointment_date start_time_ampm start_time_hour start_time_minute end_time_hour end_time_ampm end_time_minute increment public_schedule_p break_times_list appointment_id return_url return_url_string]

<input type=submit value=\"Add Office Hours\">
</td>
</tr>
</table>
</form>

</blockquote>

[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $html
