#
# /www/education/class/admin/office-hours-add-4.tcl
#
# this page enters the office hours into the table
# and it then shows a confirmation page with a link to
# edit them
# 
# by randyg@arsdigita.com, aileen@mit.edu, January 2000
#

# this page will loop back on itself as long as the profossor
# keeps adding breaks.  

ad_page_variables {
    place
    appointment_date
    appointment_id
    start_time_hour
    start_time_minute
    start_time_ampm
    end_time_hour
    end_time_minute
    end_time_ampm
    increment
    public_schedule_p
    break_times_list
    return_url
    return_url_string
}


set db [ns_db gethandle]

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

set id_list [edu_group_security_check $db edu_class "View Admin Pages"]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

# the input has already been validated by previous pages so there
# is no reason to do it again.

set list_before_sort $break_times_list
# we want to sort the breaks by start time.  Since we will probably 
# only have 2 or
# three (or less) breaks, we are going to use bubble sort


if {[llength $break_times_list] > 1} {
    # we sort by the start time
    set list_length [llength $break_times_list]
    set count 0
    while {$count < $list_length} {
	set list_index 0

	while {$list_index < $list_length - 1} {
	    set start_time_one [lindex [lindex $break_times_list $list_index] 0]
	    set start_time_two [lindex [lindex $break_times_list [expr $list_index + 1]] 0]
	    set not_switch_p [edu_check_times [lindex $start_time_one 0] [lindex $start_time_one 1] [lindex $start_time_one 2] [lindex $start_time_two 0] [lindex $start_time_two 1] [lindex $start_time_two 2]]
	    
	    if {$not_switch_p} {
		# then we want to break out of the inner loop
		break
	    } else {
		# lets switch the elements in the list and then loop
		set new_list [list]
		set break_list_count 0
		foreach break_time $break_times_list {
		    if {$break_list_count == $list_index} {
			lappend new_list [lindex $break_times_list [expr $break_list_count + 1]]
		    } elseif {$break_list_count == $list_index + 1} {
			lappend new_list [lindex $break_times_list [expr $break_list_count - 1]]
		    } else {
			lappend new_list $break_time
		    }
		    incr break_list_count
		}
		set break_times_list $new_list
	    }
	    incr list_index
	}
	incr count
    }
}


set html "
[ad_header "Office Hours for $class_name @ [ad_system_name]"]
<h2>Office Hours Added</h2>
[ad_context_bar_ws_or_index [list "../one.tcl" "$class_name Home"] [list "" "Administration"] "Office Hours Added"]

<hr>
<blockquote>

The office hours have been added.  You can now return to <a href=\"$return_url\">$return_url_string</a>.
<table>
<tr>
<th align=left>
Location:
</td>
<td>
$place
</td>
</tr>

<tr>
<th align=left>
Do you want to allow the class 
<br>
to see the names of people signed 
<br>
up for a given time slot?
</td>
<td>
[ad_html_pretty_boolean $public_schedule_p]
</td>
</tr>
</table>


<table border=1>
<tr>
<td colspan=2 align=left>
Date:
[util_AnsiDatetoPrettyDate $appointment_date]
</td>
</tr>

<tr>
<td colspan=2 align=left>
From ${start_time_hour}:${start_time_minute} $start_time_ampm
To ${end_time_hour}:${end_time_minute} $end_time_ampm
in increments of [lindex [split $increment "|"] 1]
</td>
</tr>
"


# now, we display the table with all of the times.

set increment_time [lindex [split $increment "|"] 0]
set display_hour $start_time_hour
set display_minute $start_time_minute
set display_ampm $start_time_ampm
set break_list_index 0
set toggle_ampm t
set message ""
set bgcolor white

set break_list_for_insert [list]
set new_break_interval [list]

while {[edu_check_times $display_hour $display_minute $display_ampm $end_time_hour $end_time_minute $end_time_ampm]} {

    # if the person is on break, then make the background grey
    set break_time [lindex $break_times_list $break_list_index]
    set break_time_start [lindex $break_time 0]
    set break_time_end [lindex $break_time 1]

    # if the start time of the break is before the current time and the
    # end time is after the current time then grey out the line
    if {$break_list_index < [llength $break_times_list] && [edu_check_times [lindex $break_time_start 0] [lindex $break_time_start 1] [lindex $break_time_start 2] $display_hour $display_minute $display_ampm t] && [edu_check_times $display_hour $display_minute $display_ampm [lindex $break_time_end 0] [lindex $break_time_end 1] [lindex $break_time_end 2] f]} {
	# the time about to be displayed and the beginning of the break
	# are the same time so lets grey out the area
	set bgcolor cccccc
	set message "Break"
	if {[llength $new_break_interval] == 0} {
	    lappend new_break_interval $break_time_start
	}
    } else {
	if {![empty_string_p $message]} {
	    incr break_list_index 
	    
	    # we have to do this to catch the base case where
	    # the next time overlaps with the first time
	    set old_break_time_end $break_time_end
	    set break_time [lindex $break_times_list $break_list_index]
	    set break_time_start [lindex $break_time 0]
	    set break_time_end [lindex $break_time 1]
	    if {!($break_list_index < [llength $break_times_list] && [edu_check_times [lindex $break_time_start 0] [lindex $break_time_start 1] [lindex $break_time_start 2] $display_hour $display_minute $display_ampm t] && [edu_check_times $display_hour $display_minute $display_ampm [lindex $break_time_end 0] [lindex $break_time_end 1] [lindex $break_time_end 2] f])} {
		set bgcolor white
		set message ""
		lappend new_break_interval $old_break_time_end
		lappend break_list_for_insert $new_break_interval
		set new_break_interval [list]
	    }
	}
    }

    append html "
    <tr><td align=left width=10% bgcolor=$bgcolor>
    "

    if {$display_hour < 10} {
	append html "[ad_space 2]${display_hour}:${display_minute} $display_ampm"
    } else {
	append html "${display_hour}:${display_minute} $display_ampm"
    }

    append html "
    </td>
    <td width=90% bgcolor=$bgcolor>
    [ad_space]$message
    </td>
    </tr>
    "

    # now, lets increment the time
    set display_minute [expr $display_minute + $increment_time]
    if {$display_minute >= 60} {
	# by default, the expr / drops the remainder
	set hours_to_add [expr $display_minute / 60]
	set display_minute [expr $display_minute % 60]
	if {$display_minute < 10} {
	    set display_minute 0${display_minute}
	}
	set display_hour [expr $display_hour + $hours_to_add]
    } 
    if {$display_hour >= 12} {
	if {[string compare $toggle_ampm t] == 0} {
	    # we want to toggle the am/pm
	    if {[string compare [string tolower $display_ampm] am] == 0} {
		set display_ampm PM
	    } else {
		set display_ampm AM
	    }
	}
	if {$display_hour > 12 } {
	    set display_hour [expr $display_hour % 12]
	    set toggle_ampm t
	} else {
	    set toggle_ampm f
	} 
    }	
}


append html "
</table>

</blockquote>
[ad_footer]
"

# lets insert the information into the database

if {[database_to_tcl_string $db "select count(appointment_id) from edu_appointments where appointment_id = $appointment_id"] == 0} {

    # lets do all of the inserts now
 
    ns_db dml $db "insert into edu_appointments (
    appointment_id,
    user_id,		
    group_id,	
    place,		
    start_time,      
    end_time,        
    time_increment,	
    public_schedule_p)
    values (
    $appointment_id,
    $user_id,		
    $class_id,	
    '$QQplace',		
    to_date('$appointment_date ${start_time_hour}:${start_time_minute} $start_time_ampm', 'YYYY-MM-DD HH:MI AM'),
    to_date('$appointment_date ${end_time_hour}:${end_time_minute} $end_time_ampm', 'YYYY-MM-DD HH:MI AM'),
    '[lindex [split $increment "|"] 0]',	
    '$public_schedule_p')"


    foreach break_list $break_list_for_insert {
	set start_time [lindex $break_list 0]
	set end_time [lindex $break_list 1]

	ns_db dml $db "insert into edu_appointments_scheduled (
	appointment_id,
	user_id,
        start_time,
        end_time)
	values (
	$appointment_id,
	$user_id,
	to_date('$appointment_date [lindex $start_time 0]:[lindex $start_time 1] [lindex $start_time 2]', 'YYYY-MM-DD HH:MI AM'),
	to_date('$appointment_date [lindex $end_time 0]:[lindex $end_time 1] [lindex $end_time 2]', 'YYYY-MM-DD HH:MI AM')
	)"

    }
}



# finally, lets display the confirmation page

ns_db releasehandle $db

ns_return 200 text/html $html

