#
# /www/education/class/admin/office-hours-add.tcl
#
# This page allows profs and TAs to add office hours for a 
# particular day so that students can automatically sign up
# for a time slot
# 
# by randyg@arsdigita.com, aileen@mit.edu, January 2000
#

ad_page_variables {
    {default_date ""}
    {return_url "/pvt/home.tcl"}
    {return_url_string "your workspace"}
}

set db [ns_db gethandle]

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

set id_list [edu_group_security_check $db edu_class "View Admin Pages"]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

if {$default_date == ""} {
    set date_default [database_to_tcl_string $db "select sysdate + 2 from dual"]
}

set html "
[ad_header "Office Hours for $class_name @ [ad_system_name]"]

<h2>Add Office Hours</h2>

[ad_context_bar_ws_or_index [list "../one.tcl" "$class_name Home"] [list "" "Administration"] "Add Office Hours"]

<hr>
<blockquote>

<form method=post action=\"office-hours-add-2.tcl\">
[export_form_vars return_url return_url_string]
<table>
<tr>
<th align=right>
Location:
</td>
<td>
[edu_textarea place "" 40 4]
</td>
</tr>

<tr>
<th align=right>
Date:
</td>
<td>
[ad_dateentrywidget appointment_date $default_date]
</td>
</tr>

<tr>
<th align=right>
Start Time:
</td>
<td>
[edu_time_select_widget start_time 9 00 am]
</td>
</tr>

<tr>
<th align=right>
End Time:
</td>
<td>
[edu_time_select_widget end_time 5 00 pm]
</td>
</tr>

<tr>
<th align=right>
How long would you like each 
<br>
appointment to last?
</td>
<td>
<select name=increment>
"

set increment_list [list [list 5 "5 Minutes"] [list 10 "10 Minutes"] [list 15 "15 Minutes"] [list 20 "20 Minutes"] [list 30 "30 Minutes"] [list 45 "45 Minutes"] [list 60 "1 Hour"] [list 75 "1 Hour, 15 Minutes"] [list 90 "1 Hour, 30 Minutes"] [list 105 "1 Hour, 45 Minutes"] [list 120 "2 Hours"] [list 150 "2 Hours, 30 Minutes"] [list 180 "3 Hours"]]

foreach increment $increment_list {
    # we make the value the value for the database joined with the string
    # we want to show on the confirmation page so that we only need to keep
    # the list current on this page (instead of both pages)
    append html "<option value=\"[join $increment "|"]\">[lindex $increment 1] \n"
}


append html "
</select>
</td>
</tr>

<tr>
<th align=right>
Do you want to allow the class 
<br>
to see the names of people signed 
<br>
up for a given time slot?
</td>
<td>
<input type=radio name=public_schedule_p value=t checked> Yes
[ad_space 2]
<input type=radio name=public_schedule_p value=f> No
</td>
</tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Continue\">
</td>
</tr>
</table>
</form>

</blockquote>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $html
