# /packages/education/www/class/admin/properties-edit-2.tcl

ad_page_contract {
    This page displays the confirmation page so that the class admin can review
    the changes about to be made

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: properties-edit-2.tcl,v 1.1.1.1 2001/01/24 18:03:22 tarik Exp $
} {
    class_id:integer,notnull
    class_name:notnull
    short_name:notnull
    {term_id ""}
    {where_and_when ""}
    start_date_array:array,date
    end_date_array:array,date
    {public_p t}
    {grades_p t}
    {exams_p t}
    {final_exam_p t}
    {teams_p f}
    {description:allhtml ""}
    {pretty_role_ta "Teaching Assistant"}
    {pretty_role_ca "Course Assistant"}
    {pretty_role_professor Professor}
    {pretty_role_student Student}
    {pretty_role_dropped Dropped}
    {pretty_role_plural_ta "Teaching Assistants"}
    {pretty_role_plural_ca "Course Assistants"}
    {pretty_role_plural_professor Professors}
    {pretty_role_plural_student Students}
    {pretty_role_plural_dropped Dropped}
} -validate {
    accessible_p -requires {class_id} {
	if {![ad_administrator_p] && ![ad_user_group_authorized_admin [ad_verify_and_get_user_id] $class_id]} {
	    ad_complain "You do not have permission to access this page"
	}
    }
    date_order -requires {start_date_array end_date_array} {
	if {[db_string check_date_order "select to_date('$start_date_array(date)', 'YYYY-MM-DD') - to_date('$end_date_array(date)','YYYY-MM-DD') from dual"] > 1} {
	    ad_complain "The end date must be after the start date."
	}
    }
    end_in_future -requires {end_date_array} {
	if {[db_string check_end_future "select round(sysdate) - to_date('$end_date_array(date)','YYYY-MM-DD') from dual"] > 1} {
	    ad_complain "The end date must be in the future."
	}
    }
    valid_short_name -requires {short_name} {
	set temp_short_name [ad_urlencode $short_name]
	if [db_string check_valid_short_name {
	    select count(short_name) from user_groups
	    where short_name = :temp_short_name
	    and group_type = 'edu_class'
	    and group_id != :class_id
	}] {
	    ad_complain "That short name has already been chosen.  Please choose another."
	}
    }
} -errors {
    class_id {You must provide a class ID.}
    class_name {You must provide a title for the class.}
    class_short_name {You must specify a short name/URL.}
}

# using temp_short_name because I don't want to ad_urlencode over and over again and thus change the value (e.g. percent signs are encoded as percent something)
set temp_short_name [ad_urlencode $short_name]
set start_date $start_date_array(date)
set end_date $end_date_array(date)
set old_class_name [db_string get_class_name "select class_name from edu_classes where class_id = :class_id"]
set user_id [ad_verify_and_get_user_id]
set group_id $class_id

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

#set id_list [edu_group_security_check $db edu_class "Edit Class Properties"]
#set user_id [lindex $id_list 0]
#set class_id [lindex $id_list 1]
#set old_class_name [lindex $id_list 2]

set variables_to_check [list [list grades_p "Grades"] [list exams_p "Exams"] [list final_exam_p "Final Exam"] [list term_id "Term"] [list teams_p Teams]]

foreach var $variables_to_check {
    if {![info exists [lindex $var 0]] || [empty_string_p [set [lindex $var 0]]]} {
	incr exception_count
	append exception_text "<li>You forgot to provide a value for the [lindex $var 1]"
    }
}

set return_string "

[ad_header "Class Administration @ [ad_system_name]"]

<h2>Edit Class Properties for $old_class_name</h2>

[ad_context_bar_ws_or_index [list "../one.tcl" "$old_class_name"] [list "index.tcl?class_id=$class_id" Administration] "Edit Properties"]


<hr>
<blockquote>
<table>
<form method=post action=\"properties-edit-3\">

<tr><th align=right>Class Title
</th>
<td colspan=2>$class_name
</td>
</tr>

<tr><th align=right>Short Name (URL)</th>
<td colspan=2>
[ad_parameter SystemURL]/[ad_urlencode [portals_get_domain_property url_root [portals_domain_id_from_domain_name class]]]/$temp_short_name/
</td>
</tr>

<tr><th align=right>Term 
</thn>
<td colspan=2>
[db_string get_term_name "select term_name from edu_terms where term_id = :term_id"]
</td>
</tr>

<tr><th valign=top align=right>When/Where </th>
<td colspan=2>$where_and_when</td>
</tr>

<tr><th align=right valign=top>Class Description
</th>
"

if {[empty_string_p $description]} {
    append return_string "<td colspan=2 valign=top>None"
} else {
    append return_string "<td colspan=2 valign=top>$description"
}

append return_string "
</td>
</tr>
<tr>
<th align=right>Class Roles</th>
<td align=center><em>Singular</em></td>
<td align=center><em>Plural</em></td>
</tr>
"

db_foreach get_roles "select role, pretty_role, pretty_role_plural from edu_role_pretty_role_map where group_id=:class_id and role != 'administrator' order by sort_key" {
    append return_string "
    <tr>
    <td align=right><em>[capitalize $role]</em></td>
    <td align=center>
    [set pretty_role_[string tolower [join $role "_"]]]
    </td>
    <td align=center>
    [set pretty_role_plural_[string tolower [join $role "_"]]]
    </td>
    </tr>
    "
}
    

append return_string "
<tr><th align=right>Start displaying<br>web page 
</th>
<td colspan=2 valign=top>[util_AnsiDatetoPrettyDate $start_date]
</td>
</tr>

<tr><th align=right>Stop displaying<br>web page 
</th>
<td colspan=2 valign=top>[util_AnsiDatetoPrettyDate $end_date]
</td>
</tr>
<tr>
<td colspan=2 align=center>
<br>
[export_form_vars start_date end_date class_id class_name short_name term_id where_and_when public_p grades_p exams_p final_exam_p teams_p description pretty_role_ta pretty_role_professor pretty_role_ca pretty_role_student pretty_role_dropped pretty_role_plural_ta pretty_role_plural_ca pretty_role_plural_professor pretty_role_plural_student pretty_role_plural_dropped]

<input type=submit value=\"Edit Class Properties\"></td>

</form>
</td>
</tr>
</table>



</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string
