# /packages/education/www/class/admin/properties-edit-3.tcl

ad_page_contract {
    This page actually updates the class_info table to reflect the changes in the
    properties of the class

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: properties-edit-3.tcl,v 1.1.1.1 2001/01/24 18:03:22 tarik Exp $
} {
    class_id:integer,notnull
    class_name:notnull
    short_name:notnull
    {term_id ""}
    {where_and_when ""}
    {start_date ""}
    {end_date ""}
    {public_p t}
    {grades_p t}
    {exams_p t}
    {final_exam_p t}
    {teams_p f}
    {description:allhtml ""} 
    pretty_role_ca
    pretty_role_ta
    pretty_role_professor
    pretty_role_student    
    pretty_role_dropped
    pretty_role_plural_ta
    pretty_role_plural_ca
    pretty_role_plural_professor
    pretty_role_plural_student
    pretty_role_plural_dropped
} -validate {
    accessible_p -requires {class_id} {
	if {![ad_administrator_p] && ![ad_user_group_authorized_admin [ad_verify_and_get_user_id] $class_id]} {
	    ad_complain "You do not have permission to access this page"
	}
    }
    valid_short_name -requires {short_name} {
	set temp_short_name [ad_urlencode $short_name]
	if [db_string check_valid_short_name {
	    select count(short_name) from user_groups
	    where short_name = :temp_short_name
	    and group_type = 'edu_class'
	    and group_id != :class_id
	}] {
	    ad_complain "That short name has already been chosen.  Please choose another."
	}
    }
} -errors {
    class_id {You must provide a class ID.}
    class_name {You must provide a title for the class.}
    class_short_name {You must specify a short name/URL.}
}

set user_id [ad_verify_and_get_user_id]

# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

#set id_list [edu_group_security_check $db edu_class "Edit Class Properties"]
#set user_id [lindex $id_list 0]
#set class_id [lindex $id_list 1]

db_transaction {
    # we don't want to insert the url-encoded version of short_name, because all of our pages already encode before redirecting (see below)
    db_dml update_ug "update user_groups set group_name = :class_name, short_name = :short_name where group_id = :class_id"

    db_dml update_eci "update edu_class_info
    set start_date  = :start_date,
                       end_date = :end_date,
	               term_id = :term_id,
	               description = :description,
	               where_and_when = :where_and_when,
	               public_p = :public_p,
	               grades_p = :grades_p,
	               teams_p = :teams_p,
	               exams_p = :exams_p,
	               final_exam_p = :final_exam_p,
      	               last_modified = sysdate,
                       last_modifying_user = :user_id,
                       modified_ip_address = '[ns_conn peeraddr]'                       
                 where group_id = :class_id"

    set role_list [db_list get_roles "select role from user_group_roles where role != 'administrator' and group_id=:class_id"]

    foreach role $role_list {
	db_dml update_role_map "update edu_role_pretty_role_map 
	set pretty_role=[ns_dbquotevalue [set [string tolower pretty_role_[join $role "_"]]]], 
	pretty_role_plural =  [ns_dbquotevalue [set pretty_role_plural_[string tolower [join $role "_"]]]] 
	where group_id=:class_id 
	and lower(role)=lower(:role)"
    }
}

# whether or not the transaction failed,
# we still want to redirect back to the correct portal page
set short_name [db_string get_short_name "select short_name from user_groups where group_id = :class_id"]

db_release_unused_handles

ad_returnredirect "[portals_get_portal_property base_url [portals_get_portal_id group $class_id [portals_domain_id_from_domain_name class]]]/"

