# /packages/education/www/class/admin/properties-edit.tcl
ad_page_contract { 
    This page displays the form so that the class admin can edit the properties of
    the class

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: properties-edit.tcl,v 1.2 2001/01/26 01:37:12 caroline Exp $
} {
    class_id:integer,notnull
} -validate {
    accessible_p -requires {class_id} {
	if {![ad_administrator_p] && ![ad_user_group_authorized_admin [ad_verify_and_get_user_id] $class_id]} {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    class_id {You must provide a class ID.}
}


# gets the class_id.  If the user is not an admin of the class, it
# displays the appropriate error message and returns so that this code
# does not have to check the class_id to make sure it is valid

#set id_list [edu_group_security_check $db edu_class "Edit Class Properties"]
#set user_id [lindex $id_list 0]
#set class_id [lindex $id_list 1]
#set class_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]
# the portals navigation looks for group_id to be set.
set group_id $class_id


if ![db_0or1row get_class_info "select start_date,
	class_id,
	class_name,
        class_short_name as short_name,
	term_id,
	start_date,
	end_date,
	description,
	where_and_when,
	syllabus_id,
	lecture_notes_folder_id,
	handouts_folder_id,
	assignments_folder_id,
	public_p,
	grades_p,
	teams_p,
	exams_p,
	final_exam_p
   from edu_classes
  where class_id = :class_id"] {

    # this should never happen.
    ad_return_complaint 1 "<li>The group you are logged in as is not a class.  Please log out and log back in."
    return
}


#note there is no context bar here anymore because this is now accessed through the control panel in portals.
set return_string "
[ad_header "Edit Class Properties"]

<h2>Edit Class Properties</h2>

<hr>
<blockquote>

<form method=post action=\"properties-edit-2.tcl\">

<table>
<tr><th align=right>Class Title</th>
<td colspan=2><input type=text size=60 name=class_name maxlength=100 value=\"$class_name\"></td>
</tr>

<tr><th align=right>Short name (URL):</th>

<td>
<input type=text name=short_name value=\"$short_name\" size=20 maxlength=100></td>
<td>Used in personal calendars etc. 
Must be unique and may not contain spaces or special charaters like: /\,~@. (- is ok)
</td>
</tr>

<tr><th align=right>Term</th>
<td colspan=2>
[edu_term_select_widget term_id $term_id]
</td>
</tr>

<tr><th valign=top align=right>Class Description
<p>
<br><i>(must use html)</i></th>
<td colspan=2>[edu_textarea description "$description"]</td>
</tr>

<tr>
<th align=right>Class Roles</th>
<td align=center><em>Singular</em></td>
<td align=center><em>Plural</em></td>
</tr>

"

db_foreach get_roles "select role, pretty_role, pretty_role_plural from edu_role_pretty_role_map where group_id=:class_id and role != 'administrator' order by sort_key" {
    append return_string "
    <tr>
    <td align=right><em>[capitalize $role]</em></td>
    <td>
    <input type=text name=pretty_role_[string tolower [join $role "_"]] value=\"$pretty_role\" size=30>
    </td>
    <td>
    <input type=text name=pretty_role_plural_[string tolower [join $role "_"]] value=\"$pretty_role_plural\" size=30>
    </td>
    </tr>
    "
}
    

append return_string "
</table>

<table>
<tr><th align=right>Date to Start Displaying Class Web Page </th>
<td>[ad_dateentrywidget start_date_array $start_date]</td>
</tr>

<tr><th align=right>Date to Stop Displaying Class Web Page </th>
<td>[ad_dateentrywidget end_date_array $end_date]</td>
</tr>
</td></tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Continue\">
</td>
</tr>
</table>

[export_form_vars class_id]
</form>

</blockquote>
[ad_footer]
"


doc_return 200 text/html $return_string


