# /packages/education/www/class/admin/users/index.tcl

ad_page_contract {
    This file lists all of the users for a given class (group) and 
    divides them by role.  In addition, it allows the caller to show
    only people with "emails beginning with" or "last name beginning with"
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: index.tcl,v 1.3 2001/02/02 21:48:43 tarik Exp $
} {
    {target_url "one.tcl"}
    {type ""}
    {target_url_params ""}
    section_id:integer,notnull
    {orderby ""}
} -validate {
    accessible_p -requires {section_id} {
	if ![ad_user_group_authorized_admin_or_site_admin [ad_verify_and_get_user_id] $section_id] {
	    ad_complain "You are not allowed to access this page."
	}	
    }
} -errors {
    section_id {Class ID not specified.}
}

#This is a list of all the users in a given company and provides
#links to different functions regarding those users

set user_id [ad_verify_and_get_user_id]

db_1row get_class_info "select group_name as class_name, group_id as section_id from user_groups where group_id = :section_id"

set sql_restriction ""

set return_url [ns_conn url]
set query [ns_conn query]
if ![empty_string_p query] {
    append return_url "?$query"
}

set group_id $section_id

set role_list [edu_get_class_original_role_pretty_role]

if {[string compare $type section_leader] == 0} {
    set header_string "Select a Section Instructor"
    set add_person_string ""
} else {
    set header_string "$class_name Users"
    set add_person_string "\[<a href=add.tcl?role=professor&[export_url_vars group_id return_url]>Add a Professor</a>\] | 
\[<a href=add.tcl?role=ta&[export_url_vars group_id return_url]>Add a Teaching Assistant</a>\] | \[<a href=add.tcl?role=ca&[export_url_vars group_id return_url]>Add a Course Assistant</a>\] | 
\[<a href=add.tcl?role=student&[export_url_vars group_id return_url]>Add a Student</a>\] | \[<a href=add.tcl?role=administrator&[export_url_vars group_id return_url]>Add a Course Administrator</a>\]"
}

set return_string "
[ad_header "$class_name @ [ad_system_name]"]


<h2>$header_string</h2>

<hr>
<blockquote>
"

#-------------------------------------
#----   threshold stuff commented out by ejc@arsdigita.com 7-26-2000
#set threshold 75

#see if there are more than $threshold users
#if so, give search options
#if not, list all of the users



# if {[db_string "select count(distinct user_id) from user_group_map where group_id = $section_id"] < $threshold } {
#-------------------------------------

    # if there is a target url, make all users go to the same url
    # otherwise, have them go to one.tcl

    # ---------------------------------
    # screw the target url
    # always have them go to one.tcl
    # ejc@arsdigita.com 7-25-2000
    # ---------------------------------


# note: it is okay to use $section_id instead of :section_id below because we have a query above that selects for section_id
# moreover, this wouldn't work otherwise

    set spam_links f
    set variable_name user_id
    set sql_restriction ""

    if {[string compare $type section_leader] == 0} {
	    if {![empty_string_p $section_id]} {
		set sql_restriction "and user_group_map.user_id not in (select user_id from user_group_map where group_id = $section_id and lower(role) = 'administrator')"
	    }
	    set variable_name instructor_id
	    set spam_links f
    }

    foreach role_sublist $role_list {
	set role [lindex $role_sublist 0]
	set pretty_role [lindex $role_sublist 1]
	set pretty_role_plural [lindex $role_sublist 2]
	set counter 0
	append return_string "<b>$pretty_role_plural</b>  "

	
	if [string compare $role "dropped"] {
	    append return_string "\[<a href=add.tcl?role=$role&[export_url_vars group_id return_url]>Add a $pretty_role</a>\]<p>"
	} else {
	    append return_string "<p>"
	}
	
	set table_def {
	    {last_name {Last Name} {} {<td><a href=\"/shared/community-member?user_id=$user_id\">$last_name</a></td>}}
	    {first_names {First Name} {} {<td><a href=\"/shared/community-member?user_id=$user_id\">$first_names</a></td>}}
	    {email {Email} {} {<td><a href=\"mailto:$email\">$email</a></td>}}
	    {manage {} {} {[upvar section_id section_id] [upvar return_url return_url] <td>\[<a href=\"one.tcl?class_id=$section_id&[export_url_vars return_url user_id]\">manage</a>\]</td>}}
	    {remove {} {} {<td>\[<a href=\"remove?class_id=$section_id&[export_url_vars user_id return_url]\">remove</a>\]</td>}}
	}

	set query "select distinct users.user_id, 
                       first_names, 
                       last_name,
	               email
                  from users, 
                       user_group_map    
                 where user_group_map.group_id = $section_id
                       and users.user_id = user_group_map.user_id 
                       and lower(role) = lower('$role')
	               $sql_restriction [ad_order_by_from_sort_spec $orderby $table_def]"

	append return_string "
	[ad_table -Torderby $orderby -Tmissing_text {(<em>none</em>)} table_$role $query $table_def]"

	if {[string compare $spam_links t] == 0} {
	    append return_string "<br>\[<a href=\"../spam.tcl?who_to_spam=[ad_urlencode [list $role]]\">Spam the $pretty_role_plural</a>\]<br>"
	}

	append return_string "<p>"

	#if [string compare $role "dropped"] {
	#    append return_string "<br>\[<a href=add.tcl?role=$role&[export_url_vars group_id return_url]>Add a $pretty_role</a>\]<br>"
	#}
    }

#-------------------------------------
#----   threshold stuff commented out by ejc@arsdigita.com 7-26-2000

#} else {
#
#    set url_string [export_url_vars type section_id target_url target_url_params header_string]
#
#    append return_string "
#    <li>Browse by last name : 
#    <a href=\"list.tcl?begin=A&end=H&lastletter=G&browse_type=lastname&$url_string\">A - G</a> |
#    <a href=\"list.tcl?begin=H&end=N&lastletter=M&browse_type=lastname&$url_string\">H - M</a> |
#    <a href=\"list.tcl?begin=N&end=T&lastletter=S&browse_type=lastname&$url_string\">N - S</a> |
#    <a href=\"list.tcl?begin=T&end=z&lastletter=Z&browse_type=lastname&$url_string\">T - Z</a> 
#    <br><br>
#    <li>Browse by email address : 
#    <a href=\"list.tcl?begin=A&end=H&lastletter=G&browse_type=email&$url_string\">A - G</a> |
#    <a href=\"list.tcl?begin=H&end=N&lastletter=M&browse_type=email&$url_string\">H - M</a> |
#    <a href=\"list.tcl?begin=N&end=T&lastletter=S&browse_type=email&$url_string\">N - S</a> |
#    <a href=\"list.tcl?begin=T&end=z&lastletter=Z&browse_type=email&$url_string\">T - Z</a> 
#    <br><br>
#    <li><a href=\"list.tcl?begin=A&end=z&lastletter=Z&browse_type=all&$url_string\">Browse All Users</a>
#    <Br>
#    <br>
#    <form method=post action=\"search.tcl\">
#    [export_form_vars type section_id target_url target_url_params header_string]
#    <li>Search:
#    <br>
#    <table>
#    <tr>
#    <td align=right>
#    By last name: 
#    </td>
#    <td><input type=text name=last_name>
#    </td>
#    <tr>
#    <td align=right>
#    By email: 
#    </td>
#    <td>
#    <input type=text name=email>
#    </td>
#    </tr>
#    <tr>
#    <td colspan=2><input type=submit value=\"Search\">
#    </td>
#    </tr>
#    </table>
#    </form>
#    "
#}

#-----------------------------------

append return_string "
<br>
\[<a href=\"/manage-users/user-add?group_id=$group_id\">Add a New User to the System</a>\]

</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string


