# /packages/education/www/class/admin/users/one.tcl

ad_page_contract {
    This page displays information about the users.  If the user had a role
    of 'student' for the given group then it redirects to student-info.tcl

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: one.tcl,v 1.1.1.1 2001/01/24 18:03:23 tarik Exp $
} {
    user_id:integer,notnull
    class_id:integer,notnull
    {return_url:optional "index?section_id=$class_id"}
} -validate {
    accessible_p -requires {class_id} {
	if ![ad_user_group_authorized_admin [ad_verify_and_get_user_id] $class_id] {
	    error "You are not authorized to see this page."
	}
    }
} -errors {
    user_id {Valid user ID not specified.}
    class_id {Valid class ID not specified.}
}

set class_name [db_string get_class_name "select group_name from user_groups where group_id = :class_id"]

# get user info
db_1row get_user_info {
    select first_names, 
    last_name, 
    email, 
    role
    from users u, 
    user_group_map ugm,
    general_portraits gp
    where u.user_id = :user_id 
    and ugm.user_id = :user_id
    and ugm.group_id = :class_id
    and gp.on_which_table(+) = 'USERS'
    and gp.on_what_id(+) = u.user_id
}
    
set return_string "
[ad_header "$class_name @ [ad_system_name]"]

<h2>$first_names $last_name ([capitalize $role])</h2>

[ad_context_bar [list "index?section_id=$class_id" Users] "One User"]


<hr>
<blockquote>


<b>Email:</b>
<a href=\"mailto:$email\">$email</a>
<br><br>
"

#--------------commented out by ejc@arsdigita.com 7-26-2000

#db_foreach "select field_name, field_value from user_group_member_field_map m
#where m.user_id=$user_id 
#and m.group_id=$class_id" {

#    if {![empty_string_p $field_value]} {
#	append return_string "
#	<tr><th align=right>$field_name:</th>
#	<td>$field_value</td>
#	</tr>"    
#    }
#}
 

#append return_string "
#</table>


#</td>
#<td>
#"

#if {![empty_string_p $portrait_thumbnail]} {
#    append return_string "
#    <a href=\"/shared/portrait.tcl?user_id=$user_id\"><img width=125 src=\"/shared/portrait-thumbnail-bits.tcl?user_id=$user_id\"></a>"
#} elseif {![empty_string_p $portrait]} {
#    append return_string "
#    <a href=\"/shared/portrait.tcl?user_id=$user_id\"><img width=125 src=\"/shared/portrait-bits.tcl?user_id=$user_id\"></a>"
#}

#append return_string "
#</td>
#</tr>
#</table>

#"

#--------------evaluations

#db_with_handle db {set temp [ad_permission_p $db "" "" "Evaluate" $user_id $class_id]}

#if {$temp} {

#    append return_string "
#    <h3>Evaluations given by $first_names</h3>
#    
#    <ul>
#    "

    # lets first get all of the assignment and exam evaluations

#    set count 0

#    db_foreach "select first_names || ' ' || last_name as student_name,
#    grade,
#    assignment_name,
#    edu_assignments.assignment_id,
#    users.user_id as student_id,
#    evaluation_type
#    from edu_student_evaluations eval,
#    users,
#    edu_assignments
#    where grader_id = $user_id
#    and eval.class_id = $class_id
#    and student_id = users.user_id
#    and eval.task_id = edu_assignments.assignment_id(+)
#    order by evaluation_date" {
#
#	incr count
#	append return_string "<li><a href=\"student-info.tcl?student_id=$student_id\">$student_name</a>, $grade on "
#	
#	if {[empty_string_p $assignment_name]} {
#	    append return_string "$evaluation_type"
#	} else {
#	    append return_string "<a href=\"../assignment-info.tcl?assignment_id=$assignment_id\">$assignment_name</a>"
#	}
#    }
#    
#    
#    # now lets see if they have given any team evaluations
#
#    db_foreach "select team_name,
#    grade,
#    assignment_name,
#    edu_assignments.assignment_id,
#    edu_teams.team_id,
#    evaluation_type
#    from edu_student_evaluations eval,
#    edu_assignments,
#    edu_teams
#    where grader_id = $user_id
#    and edu_teams.class_id = $class_id
#    and eval.team_id = edu_teams.team_id
#    and eval.task_id = edu_assignments.assignment_id(+)
#    order by evaluation_date" {
#
#	incr count
#	
#	append return_string "<li><a href=\"../teams/one.tcl?team_id=$team_id\">$team_name</a>, $grade on "
#	
#	if {[empty_string_p $assignment_name]} {
#	    append return_string "$evaluation_type"
#	} else {
#	    append return_string "<a href=\"../assignment-info.tcl?assignment_id=$assignment_id\">$assignment_name</a>"
#	}
#    }
#    
#    
#    if {$count == 0} {
#	append return_string "No Evaluations given"
#    }
#
#    append return_string "
#    </ul>
#    "
#}


#set n_spams_sent [db_string "select count(spam_id) from group_spam_history where sender_id = $user_id and group_id in (select unique group_id from user_groups where parent_group_id = $class_id)"]

#if {$n_spams_sent > 0} {
#    append return_string "
#    <p>
#    <li>$first_names has sent <a href=\"../spam-history.tcl?user_id=$user_id\">$n_spams_sent spams</a>"
#}

#append return_string "<h3>This user is a member of the following groups</h3>
#<ul>"

#set old_group_type ""
#set count 0

#db_foreach "select ug.short_name, ug.group_name, ug.group_type, ugt.pretty_plural
#from user_groups ug, user_group_map m, user_group_types ugt
#where ug.group_id=m.group_id
#and ug.group_type=ugt.group_type
#and m.user_id=$user_id
#and existence_public_p='t'
#and approved_p='t'
#order by upper(ug.group_type)" {

#    if {$old_group_type!=$group_type} {
#	if {$count} {
#	    append return_string "</ul>"
#	}
#	set old_group_type $group_type
#	append return_string "
#	<b><li>$pretty_plural</b>
#	<ul>"
#    }
#    
#    append return_string "
#    <li>$group_name
#    "
#
#    incr count
#}
#
#if {$count} {
#    append return_string "</ul>"
#}
#append return_string " 
#</ul>
#<br>"

if {![string compare "student" $role] || ![string compare "dropped" $role]} {
    append return_string "
    <b>Change Role for $first_names $last_name:</b>
    <form method=post action=change-role>
    <select name=new_role>"

    if {![string compare "student" $role]} {
	append return_string "
	<option selected value=student>Student
	<option value=dropped>Dropped"
    } elseif ![string compare "dropped" $role] {
	append return_string "
	<option value=student>Student
	<option selected value=dropped>Dropped"
    }

    append return_string "
    </select>
    [export_form_vars user_id class_id]
    <input type=submit value=Submit>
    </form><br>"
}


append return_string "
<a href=\"remove?[export_url_vars user_id class_id return_url]\">Remove $first_names $last_name from $class_name</a>
<br>
</blockquote>

[ad_footer]
"

doc_return 200 text/html $return_string
