# /www/education/class/appointment-cancel.tcl
#
# allows a student to cancel their appointment
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: appointment-cancel-3.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

ad_page_variables {
    appointment_id
    start_time_hour
    start_time_minute
    start_time_ampm
    appt_start_date
}


set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set class_exists [database_to_tcl_string $db "select count(*) from edu_current_classes where class_id=$class_id"]

if {!$class_exists} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
}

# lets make sure the person has an appointment to cancel
# appointment for the given appointment_id

set selection [ns_db 0or1row $db "
    select place,
           to_char(appts.start_time, 'Day Month DD, YYYY') as start_date,
           users.first_names || ' ' || users.last_name as appt_user_name,
           to_char(sched.start_time, 'HH:MI AM') as start_time,
           to_char(sched.start_time + time_increment / (24*60), 'HH:MI AM') as end_time
      from edu_appointments appts,
           users,
           edu_appointments_scheduled sched 
     where appts.appointment_id = sched.appointment_id
       and appts.appointment_id = $appointment_id
       and appts.user_id = users.user_id
       and to_date('$appt_start_date $start_time_hour $start_time_minute $start_time_ampm', 'YYYY-MM-DD HH MI AM') = sched.start_time
       and (sched.user_id = $user_id
            or ad_group_member_p($user_id, sched.group_id) = 't')"]


if {$selection == ""} {
    ad_return_complaint 1 "<li>You do not have an appointment for this time."
    return
} else {
    set_variables_after_query
    regexp {^0?(.*)} $start_time match start_time
    regexp {^0?(.*)} $start_time match end_time
}


set return_string "
[ad_header "Classes @ [ad_system_name]"]

<h2>Cancel Appointment</h2>

<p>
[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Cancel Appointment"]

<hr>
<blockquote>

<form action=\"appointment-cancel-2.tcl\" method=post>
[export_form_vars appointment_id start_time_hour start_time_minute start_time_ampm appt_start_date]

Are you sure you wish to cancel your appointment with $appt_user_name?
<p>
<table>
<tr>
<th align=left>Location</td>
<td>$place</td>
</tr>

<tr>
<th align=left>On</td>
<td>$start_date</td>
<tr>

<tr>
<th align=left>From</td>
<td>$start_time</td>
<tr>

<tr>
<th align=left>Until</td>
<td>$end_time</td>
</tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Cancel Appointment\">
</td>
</tr>
</table>
</form>

</blockquote>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $return_string
