# /www/education/class/appointment-sign-up-2.tcl
#
# confirms that a student really wants to sign up for 
# an appointment
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: appointment-sign-up-2.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

ad_page_variables {
    appointment_id
    display_hour
    display_minute 
    display_ampm 
    appt_start_date
}


set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set class_exists [database_to_tcl_string $db "select count(*) from edu_current_classes where class_id=$class_id"]

if {!$class_exists} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
}


# lets make sure that the slot is still open and that the
# person has permission to make the appointment

set selection [ns_db 0or1row $db "
    select place,
           to_char(start_time, 'Day Month DD, YYYY') as start_date,
           first_names || ' ' || last_name as appt_user_name,
           to_char(to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60), 'HH') as end_hour,
           to_char(to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60), 'MI') as end_minute,
           to_char(to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60), 'AM') as end_ampm
      from edu_appointments appts,
           users
     where users.user_id = appts.user_id
       and appts.appointment_id = $appointment_id
       and (appts.group_id is null 
            or ad_group_member_p($user_id, appts.group_id) = 't')
       and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') >= appts.start_time
       and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) <= appts.end_time
       and not exists (select 1 from edu_appointments_scheduled sc
                       where sc.appointment_id = $appointment_id
                       and ((to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') >= sc.start_time
                            and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') < sc.end_time)
                          or (to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) > sc.start_time
                              and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) <= sc.end_time)))"]


if {$selection == ""} {
    ns_db releasehandle $db
    ad_return_complaint 1 "<li>The time that you have requested is no longer available."
    return
} else {
    set_variables_after_query
}

regexp {0?(.*)} $end_hour match end_hour
set end_time "${end_hour}:${end_minute} $end_ampm"

set return_string "
[ad_header "Classes @ [ad_system_name]"]

<h2>Schedule Appointment</h2>

[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Schedule Appointment"]

<hr>
<blockquote>

<form action=\"appointment-sign-up-3.tcl\" method=post>
[export_form_vars appointment_id display_hour display_minute display_ampm appt_start_date start_date end_time appt_user_name place]

Are you sure you wish to schedule an appointment with $appt_user_name?
<p>
<table>
<tr>
<th align=left>Location</td>
<td>$place</td>
</tr>

<tr>
<th align=left>On</td>
<td>$start_date</td>
<tr>

<tr>
<th align=left>From</td>
<td>${display_hour}:${display_minute} $display_ampm</td>
<tr>

<tr>
<th align=left>Until</td>
<td>$end_time</td>
</tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Schedule Appointment\">
</td>
</tr>
</table>
</form>

</blockquote>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $return_string


















