# /www/education/class/appointment-sign-up-3.tcl
#
# inserts the appointment into the database
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: appointment-sign-up-3.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

ad_page_variables {
    appointment_id
    display_hour
    display_minute 
    display_ampm 
    appt_start_date
    start_date
    end_time
    appt_user_name
    place
}


set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set class_exists [database_to_tcl_string $db "select count(*) from edu_current_classes where class_id=$class_id"]

if {!$class_exists} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
}


# lets go ahead and insert the appointment into the database.
# we do an "insert...select" so that we can make sure that the
# time is still available (for the case that they spent a long
# time on the confirmation page) and to make sure that they 
# are authorized for the slot (and did not get it through URL hacking).


ns_db dml $db "insert into edu_appointments_scheduled (
  appointment_id,
  user_id,
  start_time,
  end_time)
select distinct
  $appointment_id,
  $user_id,
  to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM'),
  to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60)
  from edu_appointments_scheduled sc,
       edu_appointments appts
 where appts.appointment_id = $appointment_id
   and appts.appointment_id = sc.appointment_id
   and (appts.group_id is null 
        or ad_group_member_p($user_id, appts.group_id) = 't')
   and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') >= appts.start_time
   and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) <= appts.end_time
   and not exists (select 1 from edu_appointments_scheduled sc
                   where sc.appointment_id = $appointment_id
                   and ((to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') >= sc.start_time
                         and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') < sc.end_time)
                     or (to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) > sc.start_time
                          and to_date('$appt_start_date $display_hour $display_minute $display_ampm', 'YYYY-MM-DD HH MI AM') + time_increment/(24*60) <= sc.end_time)))"


set rows_inserted [ns_ora resultrows $db]

ns_db releasehandle $db

if {$rows_inserted == 0} {
    ad_return_complaint 1 "<li>The appointment time that you have selected has been taken by someone else.  Please hit the back button twice and reload to see which slots are still available."
    return
}


set return_string "
[ad_header "Classes @ [ad_system_name]"]

<h2>Appointment Scheduled on $start_date</h2>

[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Schedule Appointment"]

<hr>
<blockquote>

You are now scheduled to meet with $appt_user_name.  You can now return to <a href=\"/pvt/home.tcl\">your workspace</a>.
<p>
<table>
<tr>
<th align=left>Location</td>
<td>$place</td>
</tr>

<tr>
<th align=left>Date</td>
<td>[util_AnsiDatetoPrettyDate $appt_start_date]</td>
</tr>

<tr>
<th align=left>On</td>
<td>$start_date</td>
<tr>

<tr>
<th align=left>From</td>
<td>${display_hour}:${display_minute} $display_ampm</td>
<tr>

<tr>
<th align=left>Until</td>
<td>$end_time</td>
</tr>

<tr>
<td colspan=2 align=center>
<input type=submit value=\"Schedule Appointment\">
</td>
</tr>
</table>
</form>

</blockquote>
[ad_footer]
"


ns_return 200 text/html $return_string


















