# /www/education/class/appointment-sign-up.tcl
#
# allows a student to sign up for an appointment
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: appointment-sign-up.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

ad_page_variables {
    appointment_id
}


set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set class_exists [database_to_tcl_string $db "select count(*) from edu_current_classes where class_id=$class_id"]

if {!$class_exists} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
}

# lets make sure that the person has permission to make an
# appointment for the given appointment_id

set selection [ns_db select $db "
    select appts.appointment_id,
           place,
           to_char(appts.start_time, 'Day Month DD, YYYY') as start_date,
           to_char(appts.start_time, 'HH') as appt_start_hour,
           to_char(appts.start_time, 'MI') as appt_start_minute,
           to_char(appts.start_time, 'AM') as appt_start_ampm,
           to_char(appts.end_time, 'HH') as appt_end_hour,
           to_char(appts.end_time, 'MI') as appt_end_minute,
           to_char(appts.end_time, 'AM') as appt_end_ampm,
           to_char(sched.start_time, 'HH MI AM') as sched_start_time,
           to_char(sched.end_time, 'HH MI AM') as sched_end_time,
           time_increment,
           sched.user_id as visitor_user_id,
           sched.group_id as visitor_group_id,
           sched.user_name as visitor_name,
           public_schedule_p,
           appts.start_time as appt_start_date,
           appts.user_id as appt_user_id,
           users.first_names || ' ' || users.last_name as appt_user_name
      from edu_appointments appts,
           users,
           (select first_names || ' ' || last_name as user_name,
                   start_time, end_time, group_id,
                   appointment_id, sched.user_id
              from users,
                   edu_appointments_scheduled sched 
             where sched.user_id = users.user_id(+)) sched
     where appts.appointment_id = sched.appointment_id(+)
       and appts.appointment_id = $appointment_id
       and appts.user_id = users.user_id
       and (appts.group_id is null 
            or ad_group_member_p($user_id, appts.group_id) = 't')
  order by sched.start_time"]


set scheduled_times [list]
while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    lappend scheduled_times [list $sched_start_time $sched_end_time $visitor_user_id $visitor_group_id $visitor_name]
}


if {[llength $scheduled_times] == 0} {
    ad_return_complaint 1 "<li>There are no appointment slots corresponding to what you are requesting."
    return
}

set return_string "
[ad_header "Classes @ [ad_system_name]"]

<h2>Schedule Appointment</h2>
 on $start_date with $appt_user_name
<p>
[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Schedule Appointment"]

<hr>
<blockquote>
"


if {[llength $scheduled_times] > 0} {
    regexp {0?(.*)} $appt_start_hour match appt_start_hour
    regexp {0?(.*)} $appt_end_hour match appt_end_hour
    
    append html "
    <h3>Select a Time:</h3>
    <blockquote>
    <table>
    <tr>
    <th align=left>
    Location:
    </td>
    <td>
    $place
    </td>
    </tr>
    </table>
    
    <table border=1>

    <tr>
    <td colspan=2 align=left>
    From ${appt_start_hour}:${appt_start_minute} $appt_start_ampm
    To ${appt_end_hour}:${appt_end_minute} $appt_end_ampm
    </td>
    </tr>
    "
    
    set display_hour $appt_start_hour
    set display_minute $appt_start_minute
    set display_ampm $appt_start_ampm
    set sched_list_index 0
    set bgcolor white
    set toggle_ampm t
    set scheduled_p f
    

    while {[edu_check_times $display_hour $display_minute $display_ampm $appt_end_hour $appt_end_minute $appt_end_ampm]} {
	set message "<a href=\"appointment-sign-up-2.tcl?[export_url_vars appointment_id display_hour display_minute display_ampm appt_start_date]\">Sign Up</a>"
	
	# If the time is scheduled then display that fact
	set sched_time [lindex $scheduled_times $sched_list_index]
	set sched_time_start [lindex $sched_time 0]
	set sched_time_end [lindex $sched_time 1]

	set display_end_time [edu_increment_time $display_hour $display_minute $display_ampm $time_increment $toggle_ampm]
	set display_end_hour [lindex $display_end_time 0]
	set display_end_minute [lindex $display_end_time 1]
	set display_end_ampm [lindex $display_end_time 2]
	
	# does the item start before the display end and end after
	# the display start
	set start_before_display_end [edu_check_times [lindex $sched_time_start 0] [lindex $sched_time_start 1] [lindex $sched_time_start 2] $display_end_hour $display_end_minute $display_end_ampm f]

	set end_after_display_start [edu_check_times $display_hour $display_minute $display_ampm [lindex $sched_time_end 0] [lindex $sched_time_end 1] [lindex $sched_time_end 2] f]

	if {$sched_list_index < [llength $scheduled_times] && $start_before_display_end && $end_after_display_start} {
	    # the time about to be displayed and the beginning of the sched
	    # are the same time so lets grey out the area
	    
	    set sched_item [lindex $scheduled_times $sched_list_index]
	    if {[string compare [lindex $sched_item 2] $appt_user_id] == 0} {
		set message "Break"
		set bgcolor cccccc
	    } else {
		set bgcolor white
		if {[string compare [lindex $sched_item 2] $user_id] == 0} {
		    set message "You (<a href=\"appointment-cancel.tcl?appointment_id=$appointment_id&start_time_hour=[lindex $sched_time_start 0]&start_time_minute=[lindex $sched_time_start 1]&start_time_ampm=[lindex $sched_time_start 2]&appt_start_date=$appt_start_date\">cancel appointment</a>)"
		} elseif {[string compare $public_schedule_p t] == 0} {
		    set message "[lindex $sched_item 4]"
		} else {
		    set message "Scheduled"
		}
	    }
	    set scheduled_p t
	} else {
	    if {[string compare $scheduled_p t] == 0} {
		incr sched_list_index 
		set bgcolor white
		set scheduled_p f
		continue
	    }
	}
	

	append html "
	<tr><td align=left width=10% bgcolor=$bgcolor>
	"
	
	if {$display_hour < 10} {
	    append html "[ad_space 2]${display_hour}:${display_minute} $display_ampm"
	} else {
	    append html "${display_hour}:${display_minute} $display_ampm"
	}
	
	append html "
	</td>
	<td width=90% bgcolor=$bgcolor>
	[ad_space]$message
	</td>
	</tr>
	"
	
	# now, lets increment the time
	set new_time [edu_increment_time $display_hour $display_minute $display_ampm $time_increment $toggle_ampm]
	set display_hour [lindex $new_time 0]
	set display_minute [lindex $new_time 1]
	set display_ampm [lindex $new_time 2]
	set toggle_ampm [lindex $new_time 3]
    }
}



if {[llength $scheduled_times] > 0} {
    append html "</table></blockquote>"
}

append return_string "
$html
</blockquote>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $return_string









