# /www/education/class/assignments-display.tcl
#
# displays the class assignments
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: assignments-display.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set assignments_folder_id [database_to_tcl_string_or_null $db "select assignments_folder_id from edu_classes where class_id=$class_id"]

set header "

[ad_header "Classes @ [ad_system_name]"]

<h2>Assignments</h2>

[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Assignments"]

<hr>"

#################################
#                               #
#  Begin displaying assignments #
#                               #
#################################


set assignment_text "<table cellpadding=2>"

set user_has_turn_in_permission_p [ad_permission_p $db "" "" "Submit Tasks" $user_id $class_id]

# get all of the assignments.  If there are solutions, get those.
# if the student has uploaded their answers, get those as well

set selection [ns_db select $db "select edu_assignments.assignment_name, 
            edu_assignments.assignment_id, 
            edu_assignments.due_date, 
            pset.version_id, 
            pset.file_extension,
            pset.url,
            sol.url as sol_url,
            sol.file_extension as sol_file_extension,
            sol.version_id as sol_version_id,
            answers.url as ans_url,
            answers.file_extension as ans_file_extension,
            answers.file_title as ans_filename,
            answers.version_id as ans_version_id,
            edu_assignments.electronic_submission_p
       from edu_assignments,
            edu_assignments edu_assignments1,
            (select * from fs_versions_latest 
              where ad_general_permissions.user_has_row_permission_p($user_id, 'read', version_id, 'FS_VERSIONS') = 't') pset,
            (select file_extension, url, version_id, task_id 
                    from fs_versions_latest ver,
                         edu_task_solutions solutions
                   where ver.file_id = solutions.file_id
                     and ad_general_permissions.user_has_row_permission_p($user_id, 'read', version_id, 'FS_VERSIONS') = 't') sol,
            (select file_extension, file_title, url, version_id, task_id
                    from fs_versions_latest ver,
                         edu_student_answers ans,
                         fs_files
                   where ver.file_id = ans.file_id 
                     and fs_files.file_id = ver.file_id
                     and ad_general_permissions.user_has_row_permission_p($user_id, 'read', version_id, 'FS_VERSIONS') = 't'
                     and student_id = $user_id) answers
      where edu_assignments.class_id = $class_id 
        and edu_assignments.file_id = pset.file_id(+)
        and edu_assignments1.assignment_id = edu_assignments.assignment_id
        and edu_assignments1.assignment_id = answers.task_id(+)
        and edu_assignments.assignment_id = sol.task_id(+)
     order by due_date"]


set count 0
set assignment_info ""

while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    incr count

    if {![empty_string_p $url]} {
	append assignment_info "<tr><td><a href=\"$url\">$assignment_name</a></td>"
    } elseif {![empty_string_p $version_id]} {
	append assignment_info "<tr><td><a href=\"/file-storage/download/[join $assignment_name "_"].$file_extension?version_id=$version_id\">$assignment_name</a></td>"
    } else {
	append assignment_info "<td>$assignment_name</td>"
    }
    
    append assignment_info "
    <td><a href=\"task-info.tcl?task_id=$assignment_id\">Details</a></td>
    "


    set submit_solutions_text "Submit Solutions"

    if {[string compare $electronic_submission_p t] == 0} {
	set submit_solutions_text "Submit/Update Answers"

	if {![empty_string_p $ans_url]} {
	    append assignment_info "<td><a href=\"$ans_url\">Your Answers</a></td>"
	} elseif {![empty_string_p $ans_version_id]} {
	    append assignment_info "<td><a href=\"/file-storage/download/$ans_filename.$ans_file_extension?version_id=$ans_version_id\">Your Answers</a></td>"
	} else {
 	    append assignment_info "<td>[ad_space]</td>"
	}
    } else {
	append assignment_info "<td>[ad_space]</td>"
    }

    if {[empty_string_p $sol_url] && [empty_string_p $sol_version_id]} {
	append assignment_info "<td>Due: [util_AnsiDatetoPrettyDate $due_date]</td> \n"
	if {[string compare $electronic_submission_p t] == 0 && $user_has_turn_in_permission_p} {
	    append assignment_info "<td><a href=\"task-turn-in.tcl?task_id=$assignment_id&task_type=assignment\">$submit_solutions_text</a></td>"
	} else {
	    append assignment_info "<td>[ad_space]</td>"
	}
    } elseif {![empty_string_p $sol_url]} {
	append assignment_info "<Td colspan=2 align=left><a href=\"$sol_url\">Solutions</a></td>"
    } elseif {![empty_string_p $sol_version_id]} {
	append assignment_info "<td colspan=2 align=left><a href=\"/file-storage/download/$assignment_name-solutions.$sol_file_extension?version_id=$sol_version_id\">Solutions</a></td>"
    } 
    append assignment_info "</tr>"
}

if {$count == 0} {
    append assignment_text "None</table>"
} else {
    append assignment_text "$assignment_info</table>"
}

ns_db releasehandle $db

ns_return 200 text/html "
$header
$assignment_text
[ad_footer]
"