# /www/education/class/info-display.tcl
#
# displays the class description, syllabus, etc.
#
# aileen@mit.edu, randyg@mit.edu
#
# March 2000
#
# $Id: info-display.tcl,v 1.1.1.1 2001/01/24 18:03:20 tarik Exp $

set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set class_exists [database_to_tcl_string $db "select count(*) from edu_current_classes where class_id=$class_id"]

if {!$class_exists} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
}

set header "

[ad_header "Classes @ [ad_system_name]"]

<h2>Course Info</h2>

[ad_context_bar_ws [list "" Classes] [list one.tcl "$class_name"] "Course Info"]

<hr>
[edu_display_class_info $db $class_id]
"

#
#
# get information about the instructors
#
#



# get all instructors and things like their office hours (in field_values)
set selection [ns_db select $db "select 
          fm.sort_key,
          role_map.role,
          pretty_role,
          pretty_role_plural,
          first_names || ' ' || last_name as user_name,
          users.user_id, 
          email,
          url,
          fm.field_name, 
          fm.field_value
     from users,
          user_group_map map,
          edu_role_pretty_role_map role_map,
          (select fm.field_name, 
                   fm.field_value,
                   tmf.sort_key,
                   fm.user_id
              from user_group_type_member_fields tmf,
                   user_group_member_field_map fm
             where group_type = 'edu_class'
               and fm.group_id = $class_id
               and tmf.field_name = fm.field_name order by sort_key) fm
     where users.user_id = map.user_id
       and (lower(map.role) = lower('[edu_get_professor_role_string]') 
            or lower(map.role) = lower('[edu_get_ta_role_string]'))
       and map.group_id = $class_id
       and map.user_id=fm.user_id(+)
       and lower(role_map.role) = lower(map.role)
       and role_map.group_id = map.group_id
  order by role_map.sort_key, map.role, last_name, first_names, fm.sort_key"]


# we use old_user_id here because the above query can potentially
# return more than one row for each user.  For instance, for a prof,
# it will return one row for the office location, phone number, and
# office hours.  Since we only want to display the name once, we only
# add the text once.

set teacher_text ""
set old_user_id ""

while {[ns_db getrow $db $selection]} {
    set_variables_after_query

    if {$old_user_id!=$user_id} {
	if {$old_user_id!=""} {
	    append teacher_text "</ul>"
	}
	
	if {![empty_string_p $url]} {
	    set user_name "<a href=\"$url\">$user_name</a>"
	}
	append teacher_text "<li>$pretty_role - $user_name (<a href=mailto:$email>$email</a>) \n"
	set old_user_id $user_id
	append teacher_text "<ul>"
    }

    # this is kind of clumsy, so we prob do want to separate the 
    # staff info from the regular class member info by creating a separate
    # edu_class_staff group type
    if {$sort_key==3 || $sort_key==4 || $sort_key==5} {
	append teacher_text "<li><b>$field_name</b>: [edu_maybe_display_text $field_value] \n"
    }
}

if {![empty_string_p $teacher_text]} {
    set course_staff_text "
    <h3>Course Staff</h3>
    <ul>
    $teacher_text
    </ul>
    </ul>
    "
} else {
    set course_staff_text ""
}



set selection [ns_db select $db "select title, 
                              edu_textbooks.textbook_id 
                         from edu_textbooks, 
                              edu_classes_to_textbooks_map map 
                        where edu_textbooks.textbook_id = map.textbook_id 
                          and map.class_id = $class_id 
                        order by title"]

set textbook_text ""

while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    append textbook_text "<li><a href=\"textbook-info.tcl?textbook_id=$textbook_id\">$title</a> \n"
}


if {![empty_string_p $textbook_text]} {
    append textbook_text_to_show "
    <h3>Textbooks</h3>
    <ul>
    $textbook_text
    </ul>
    "
} else {
    set textbook_text_to_show ""
}


#
# Now we want to give the student the chance to sign
# up for office hours if there are office hours available
#

set selection [ns_db select $db "
    select appointment_id,
           first_names || ' ' || last_name as user_name,
           start_time
      from users,
           edu_appointments appt
     where appt.user_id = users.user_id
       and group_id = $class_id
       and not appt.user_id = $user_id
       and start_time > sysdate - 1
   order by start_time, lower(last_name)"]

set count_appointments 0
while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    if {$count_appointments == 0} {
	set appointment_text "
	<h3>Schedule an Appointment with</h3>
	<ul>
	"
    }
    incr count_appointments
    append appointment_text "
    <li><a href=\"appointment-sign-up.tcl?appointment_id=$appointment_id\">$user_name</a> ([util_AnsiDatetoPrettyDate $start_time])\n
    "
}

if {[info exists appointment_text]} {
    append appointment_text "</ul>"
} else {
    set appointment_text ""
}


set selection [ns_db select $db "
select grade_name, comments, weight, grade_id
from edu_grades where class_id=$class_id"]
set count 0

while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    if {$count == 0} {
	set grades_text "
	<h3>Grade Policy</h3>
	<ul>
	"
    }
    append grades_text "
    <li>$grade_name - $comments ($weight\%)"
    incr count
}    

if {!$count} {
    set grades_text ""
} else {
    append grades_text "</ul>"
}

ns_db releasehandle $db

ns_return 200 text/html "
$header
$course_staff_text
$appointment_text
$grades_text
$textbook_text_to_show
[ad_footer]
"




















