#
# /www/education/class/one.tcl (as in one class)
#
# by randyg@arsdigita.com, aileen@arsdigita.com, January 2000
#
# this displays information about one class
#

set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set selection [ns_db 0or1row $db "select 
               term_id,
               c.subject_id,
               start_date,
               end_date,
               nvl(c.description, s.description) as description,
               public_p,
               grades_p,
               teams_p,
               exams_p,
               final_exam_p
          from edu_current_classes c,
               edu_subjects s
         where class_id = $class_id
           and c.subject_id = s.subject_id(+)"]


if {$selection == ""} {
    ad_return_complaint 1 "<li> The class you have requested either does not exist or is not longer available to the public."
    return
} else {
    set_variables_after_query
}


set selection [ns_db select $db "
select title, news_item_id 
from news_items news, users, newsgroups ng
where users.second_to_last_visit < creation_date
and release_date <= sysdate
and expiration_date > sysdate
and news.approval_state = 'approved'
and news.newsgroup_id = ng.newsgroup_id
and ng.group_id=$class_id
and users.user_id=$user_id
order by release_date"]

set news_items ""
set count 0

while {[ns_db getrow $db $selection]} {
    set_variables_after_query

    if {!$count} {
	set news_items "<table width=100% border=0 cellpadding=2><tr><th bgcolor=#ffffc6><h3>News</h3>"
    }

    append news_items "<li><a href=/news/item.tcl?news_item_id=$news_item_id>$title</a>\n"
    incr count
}


if {$count} {
    append news_items "</th></tr></table>"
}

set past_news [database_to_tcl_string $db "
select count(*) 
from news_items news, newsgroups ng
where expiration_date < sysdate
and news.approval_state = 'approved'
and news.newsgroup_id = ng.newsgroup_id
and ng.group_id=$class_id"]

set projects_count [database_to_tcl_string $db "select count(*) from edu_projects where class_id=$class_id"]
set teams_count [database_to_tcl_string $db "select count(team_id) from edu_teams where class_id=$class_id"]

################################################
#                                              #
#  Begin displaying collaboration items        #
#                                              #
################################################

set chat_room_id [database_to_tcl_string_or_null $db "select chat_room_id from chat_rooms where group_id=$class_id"]

# select the bboard topic that is accessible to students in the class
set bboard_cnt [database_to_tcl_string $db "
select count(*) 
from bboard_topics t,
     edu_role_pretty_role_map m1, edu_role_pretty_role_map m2 
where t.group_id=$class_id 
and t.role=m1.role
and m1.priority>=m2.priority
and m2.role='student'"]

# get the tasks due this week
set selection [ns_db select $db "
select * from edu_student_tasks 
where due_date <= sysdate+7
and due_date > sysdate-7
and class_id=$class_id
and active_p='t'
order by task_type, due_date"]

set old_task_type ""
set rhs_text ""

while {[ns_db getrow $db $selection]} {
    set_variables_after_query

    if {$old_task_type!=$task_type} {
	if {$old_task_type!=""} {
	    append rhs_text "</ul>"
	}

	append rhs_text "<h3>[capitalize $task_type]</h3>
	<ul>" 

	set old_task_type $task_type
    }

    append rhs_text "
    <li><a href=task-info.tcl?task_id=$task_id>$task_name - $due_date</a>"

}

if {$old_task_type!=""} {
    append rhs_text "</ul>"
}

set lecture_notes_folder_id [database_to_tcl_string_or_null $db "select lecture_notes_folder_id from edu_classes where class_id=$class_id"]

set selection [ns_db select $db "select handout_id, 
         edu_handouts.file_id, 
         distribution_date, 
         handout_name,
         url,
         version_id
    from edu_handouts,
         fs_versions_latest ver
   where lower(handout_type) = lower('lecture_notes') 
     and class_id = $class_id 
     and ver.file_id = edu_handouts.file_id
     and distribution_date > sysdate-7
     and distribution_date <= sysdate+7
     and ad_general_permissions.user_has_row_permission_p($user_id, 'read', version_id, 'FS_VERSIONS') = 't'
order by distribution_date"]

set count 0

while {[ns_db getrow $db $selection]} {
    set_variables_after_query
    
    if {!$count} {
	append rhs_text "<h3>Lecture Notes</h3>
	<ul>"
    }
    
    if {![empty_string_p $url]} {
	append rhs_text "<li><a href=\"$url\">$handout_name</a>"
    } elseif {![empty_string_p $version_id]} {
	append rhs_text "<li><a href=\"/file-storage/download/[join $handout_name "_"].$file_extension?version_id=$version_id\">$handout_name</a>"
    } else {
	append rhs_text "<li>$handout_name"
    }
    
    append rhs_text "
    - Distributed: 
    [util_AnsiDatetoPrettyDate $distribution_date]"

    incr count
}

if {$count} {
    append rhs_text "</ul>"
}

if {$rhs_text==""} {
    append rhs_text [edu_display_class_info $db $class_id]
}

append rhs_text "<p>[edu_random_member_blurb $db $class_id]"

ns_db releasehandle $db

ns_return 200 text/html "

[ad_header "Classes @ [ad_system_name]"]

<style>
A:link {color:maroon}
A:visited {color:maroon }
A:hover {color:maroon }
A:active {color:maroon }
</style>

<table width=\"100%\" border=0 cellspacing=0 cellpadding=0 bgcolor=\"#FFFFFF\">
 <tr>
  <td colspan=3>
   <table width=100% border=0 cellpadding=2>
    <tr align=left> 
     <td colspan=5 valign=\"top\"><font face=\"Trebuchet MS, Arial, Helvetica\" size=3><b> <font size=5>$class_name</font></b></font></td>
    </tr>
    <tr> 
     <td colspan=5><font face=\"Trebuchet MS, Arial, Helvetica\" size=3><b><img src=\"/graphics/kdot.gif\" width=100% height=1></b></font></td>
    </tr>
    <tr>
     <td colspan=5 valign=middle align=left><font face=\"Trebuchet MS, Arial, Helvetica\" size=2>[ec_decode $past_news 0 "" "<a href=/news/index.tcl?scope=group&group_id=$class_id&archive_p=1>News</a> | "][ec_decode $description "" "" "<a href=info-display.tcl>Course Info</a> | "]<a href=assignments-display.tcl>Assignments</a> | [ec_decode $exams_p "t" "<a href=exams-display.tcl>Exams</a> | " ""]<a href=handouts-display.tcl>Handouts</a> | <a href=lecture-notes-display.tcl>Lecture Notes</a> | [ec_decode $projects_count 0 "" "<a href=projects-display.tcl>Projects</a> | "][ec_decode $teams_count 0 "" "<a href=teams-view.tcl>Teams</a> | "]<a href=students-view.tcl>Students</a>[ec_decode $bboard_cnt 0 "" " | <a href=/bboard/index.tcl?group_id=$class_id>Q&A Forum</a>"][ec_decode $chat_room_id "" "" " | <a href=/chat/enter-room.tcl?chat_room_id=$chat_room_id>Chat Room</a>"]</font></td>
    </tr>
    <tr> 
     <td colspan=5 valign=top align=left><font face=\"Trebuchet MS, Arial, Helvetica\"><b><img src=\"/graphics/kdot.gif\" width=100% height=1></b></font></td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td colspan=2 valign=top>$news_items<p>$rhs_text</td>
 </tr>
</table>
[ad_footer]
"





