#
# /www/education/class/projects/instances/index.tcl
#
# by aegrumet@arsdigita.com, March 3, 2000
#
# this page displays project assignments and allows self-assignment
# if the appropriate flag is set
#

ad_page_variables {
    project_id
}

set db [ns_db gethandle]

set id_list [edu_group_security_check $db edu_class "Manage Users"]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set exception_count 0
set exception_text ""

if {[empty_string_p $project_id]} {
    ad_return_complaint 1 "<li>You must provide a project identification number"
    return
} else {
    set project_info_list [database_to_tcl_list_list $db "select project_name,
       decode(self_assignable_p,'t',1,'f',0)
from edu_projects
where project_id = $project_id"]
    if ![llength $project_info_list] {
	ad_return_complaint 1 "There are no projects in this class corresponding to the provided identification number.  This is an error in our code.  Please contact <a href=mailto:[ad_system_owner]>[ad_system_owner]</a>."
	return
    } else {
	set project_name [lindex [lindex $project_info_list 0] 0]
	set self_assignable_p [lindex [lindex $project_info_list 0] 1]
    }
}

# We found the project.

# Let's keep a list of what instances the student is assigned to.
set student_assignments [list]
set assignment_text {}

# Get a list of project instances
set instance_list [database_to_tcl_list_list $db "select project_instance_id,
       project_instance_name
from edu_project_instances
where project_id = $project_id
  and active_p = 't'"]

# Loop through the list and construct the main table
set main_table "
<table width=100%>
<tr>
 <th align=left>Title</th>
 <th>Students</th>
</tr>
"

set n_instances 0
foreach instance $instance_list {
    set project_instance_id [lindex $instance 0]
    set project_instance_name [lindex $instance 1]
    incr n_instances   

    if [expr ($n_instances+1) % 2] {
	set bgcolor "#FFFFFF"
    } else {
	set bgcolor "#EEEEEE"
    }

    append main_table "
<tr bgcolor=$bgcolor>
  <td align=left><a href=\"project.adp?[export_url_vars project_instance_id]\">$project_instance_name</a></td>
<td align=center>"

    set instance_student_text {}
    set instance_student_count 0

    # Query for students assigned to the instance.
    set selection [ns_db select $db "select user_id as assigned_user_id,
       (first_names || ' ' || last_name) as full_name,
       email,
       0 as team_id,
       '' as team_name
from users,
     edu_project_user_map
where project_instance_id = $project_instance_id
  and team_id is null
  and user_id = student_id
union
select users.user_id as assigned_user_id,
       (first_names || ' ' || last_name) as full_name,
       email,
       edu_teams.team_id,
       edu_teams.team_name
from users,
     user_group_map,
     edu_project_user_map,
     edu_teams
where project_instance_id = $project_instance_id
  and student_id is null
  and edu_teams.team_id = group_id
  and edu_teams.team_id = edu_project_user_map.team_id
  and user_group_map.user_id = users.user_id"]

    while { [ns_db getrow $db $selection] } {
	incr instance_student_count

	set_variables_after_query
	if { $user_id == $assigned_user_id } {
	    lappend student_assignments \
		    [list $project_instance_name $project_instance_id]
	    append instance_student_text "you "
	    if $self_assignable_p {
		append instance_student_text "(<a href=\"remove.tcl?[export_url_vars project_instance_id]\">remove</a>)"
	    }
	    append instance_student_text "<br>"
	} else {
	    append instance_student_text "
<a href=\"mailto:$email\">$full_name</a><br>"
        }
    }

    if ![empty_string_p $instance_student_text] {
	append main_table $instance_student_text
    } else {
	append main_table {&nbsp;}
    }

    append main_table "
</td></tr>"
}

if $n_instances {
    append main_table "
</table>"
    # Look for instances this student is assigned to.
    if [llength $student_assignments] {
	set assignment_text "
<blockquote>
You are assigned to the following projects:
<ul>"
	foreach assignment $student_assignments {
            set project_instance_name [lindex $assignment 0]
            set project_instance_id [lindex $assignment 1]
	    append assignment_text "
<li><a href=\"project.adp?[export_url_vars project_instance_id]\">$project_instance_name</a>"
        }
    append assignment_text "
</ul>
</blockquote>
<br>
<br>"
    }
} else {
    set main_table "There were no project instances in our database.\n"
}

set page_html "
[ad_header "One Project @ [ad_system_name]"]

<h2>$project_name Assignments</h2>

[ad_context_bar_ws_or_index [list "../../one.tcl?class_id=$class_id" "$class_name Home"] [list "../" "All Projects"] [list ../one.tcl?[export_url_vars project_id] "One Project"] Assignments]

<hr>

$assignment_text

$main_table

<p>
[ad_footer]
"

ns_db releasehandle $db

ns_return 200 text/html $page_html






