#
# education/class//students-view.tcl
#
# by randyg@arsdigita.com, aileen@mit.edu, March 2000
#
# lists all students in the class
#
# $Id: students-view.tcl,v 1.1.1.1 2001/01/24 18:03:21 tarik Exp $


ad_page_variables {
    {order_by "last_name"}
    {order_toggle ""}
    {view_type all}
    {section_id ""}
    {project_instance_name ""}
}

set db [ns_db gethandle]

set id_list [edu_user_security_check $db]
set user_id [lindex $id_list 0]
set class_id [lindex $id_list 1]
set class_name [lindex $id_list 2]

set student_roles [database_to_tcl_list_list $db "select pretty_role, pretty_role_plural from edu_role_pretty_role_map where lower(role) = lower('[edu_get_student_role_string]') and group_id = $class_id"]

set student_roles [lindex $student_roles 0]

set student_pretty_role [lindex $student_roles 0]
set student_pretty_role_plural [lindex $student_roles 1]

set exception_count 0
set exception_text ""

if {[string compare $view_type section] == 0} {
    if {[empty_string_p $section_id]} {
	incr exception_count
	append exception_text "<li>In order to restrict by section, you must provide a section identification number."
    } else {
	# lets make sure the section provided is part of this class
	set section_name [database_to_tcl_string_or_null $db "select section_name from edu_sections where section_id = $section_id and class_id = $class_id"]
	if {[empty_string_p $section_name]} {
	    incr exception_count
	    append exception_text "<li>The section identification number you have provided is not a section of $class_name"
	} else {
	    # this means that section name was defined above
	    set title "All $student_pretty_role_plural"
	    set sub_title "in $class_name not in $section_name"
	    set header "View All $student_pretty_role_plural not in $section_name"
	    set sql_restriction "and map.user_id not in (select user_id from user_group_map where group_id = $section_id)"
	}
    }
} elseif {[string compare $view_type project] == 0} {
    set title "Select a $student_pretty_role"
    set header "Select a $student_pretty_role for a project"
    set sql_restriction ""
    if {![empty_string_p $project_instance_name]} {
	set sub_title "for $project_instance_name"
    } else {
	set sub_title ""
    }
} else {
    # this is the base case where we want to show all students
    set title "All $student_pretty_role_plural"
    set header "View All $student_pretty_role_plural"
    set sql_restriction ""
}


if {$exception_count > 0} {
    ad_return_complaint $exception_count $exception_text
    return
}

# see if the class has sections/teams
set section_count [database_to_tcl_string $db "select count(*) from edu_sections where class_id=$class_id"]
set team_count [database_to_tcl_string $db "select count(*) from edu_teams where class_id=$class_id"]

set return_string "
[ad_header "$header"]

<h2>$title</h2>
"

if {[info exists sub_title] && ![empty_string_p $sub_title]} {
    append return_string "<p>$sub_title<p>"
}

append return_string "
[ad_context_bar_ws_or_index [list "" "All Classes"] [list "one.tcl" "$class_name Home"] "$student_pretty_role_plural"]

<hr>
<blockquote>
"

set export_string [export_url_vars view_type section_id]

# order_by: last_name, email, section, team - section and team exist conditionally
# order_toggle: "" = ascending, desc = descending
# on order_toggle=desc: all ordering links are defaults
# on order_toggle="": the ordering link for the order_by item has order_toggle changed to desc
set sql_order_by "$order_by $order_toggle"

if {$order_toggle==""} {
    set order_toggle "desc"
} else {
    set order_toggle ""
}

set last_name_url "students-view.tcl?$export_string&order_by=last_name"
set email_url "students-view.tcl?$export_string&order_by=email"
set section_name_url "students-view.tcl?$export_string&order_by=section_name"
set team_name_url "students-view.tcl?$export_string&order_by=team_name"

append [set order_by]_url "&order_toggle=$order_toggle"

set header "
<td><b><a href=$last_name_url>Name</a></td>
<td><b><a href=$email_url>Email</a></td>
[ec_decode $section_count 0 "" "<td><b><a href=$section_name_url>Section</a></td>"]
[ec_decode $team_count 0 "" "<td><b><a href=$team_name_url>Team</a></td>"]
"

append header "<td><b>Portrait</td>"

set sql_select "
select distinct map.user_id as student_id, last_name, first_names,
email, role [ec_decode $section_count 0 "" ", section_name"] [ec_decode $team_count 0 "" ", team_name"]"

set sql_from "
from user_group_map map, users [ec_decode $section_count 0 "" ", (select user_id, section_id, section_name from edu_sections s, user_group_map sm where sm.group_id=s.section_id and s.class_id=$class_id) sections"] [ec_decode $team_count 0 "" ", (select user_id, team_id, team_name from edu_teams t, user_group_map tm where tm.group_id=t.team_id and t.class_id=$class_id) teams"]
"

set sql_criteria "
where users.user_id = map.user_id
and lower(map.role) = lower('[edu_get_student_role_string]')
$sql_restriction
and map.group_id = $class_id
[ec_decode $section_count 0 "" "and map.user_id=sections.user_id(+)"]
[ec_decode $team_count 0 "" "and map.user_id=teams.user_id(+)"]
order by $sql_order_by"

set sql_string "$sql_select $sql_from $sql_criteria"

set selection [ns_db select $db $sql_string]

set count 0
set section_name ""
set team_name ""

while {[ns_db getrow $db $selection]} {
    set_variables_after_query

    if {!$count} {
	append return_string "
	<table cellpadding=2>
	<tr>
	$header
	<td>[ad_space 1]</td>
	</tr>
	"
    }

    append return_string "
    <tr>
    <td>$last_name, $first_names</td>
    <td><a href=mailto:$email>$email</a></td>
    [ec_decode $section_count 0 "" "<td>$section_name</td>"]
    [ec_decode $team_count 0 "" "<td>$team_name</td>"]
    <td><a href=/shared/portrait.tcl?user_id=$student_id>portrait</a></td>
    <td>[ad_space 1]
    "
    
    append return_string "</td></tr>"
   
    incr count
}

if {$count} {
    append return_string "
    </table>"
} else {
    append return_string "
    <p>There are currently no $student_pretty_role_plural registered in the system</p>"
}

append return_string "
</blockquote>
[ad_footer]"



ns_db releasehandle $db

ns_return 200 text/html $return_string



