# /packages/education/www/community/request-community-3.tcl

ad_page_contract {
    Adds community to user_groups with approved_p = 'f'
    The portal and file system stuff don't get created until the community is approved by a site-wide admin.

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date July 26, 2000
    @cvs-id $Id: request-community-3.tcl,v 1.2 2001/02/15 02:18:53 caroline Exp $
} {
    group_name:notnull
    community_group_id:integer,notnull
    {public_p t}
    {description ""}
} -errors {
    group_name {You must name your community.}
    community_group_id {Group ID not provided.}
}

set user_id [ad_verify_and_get_user_id]

#lets check and make sure that it is not a double click
if {[db_string check_if_group_id_exists {
    select count(group_id) from user_groups where group_id = :community_group_id
}] > 0} {
    ns_returnredirect "index.tcl?group_id=$community_group_id"
    return
}

# send the email first, just in case there's an error - we don't want to insert into user_groups and then not send an email

# get all pertinent information about user to put in body of email message
db_1row get_user_info {
    select first_names, last_name, email
    from users
    where user_id = :user_id
}

set to [ad_parameter CommunityOwner "" [ad_parameter SystemOwner]]
set from [spam_system_default_from_address]
set subject "Request for a new community"
set body "
$first_names $last_name ($email) has requested to form a new community.
Community Name: $group_name
Description: $description
Public? [util_PrettyBoolean $public_p]
Visit this link if you wish to approve the new community:
[ad_parameter SystemURL]/education/community/approve-community?group_id=$community_group_id"

if {[catch {ns_sendmail $to $from $subject $body} errmsg]} {
    ad_complain "The request was not sent, because of an error.  Please try again."
}

create_community -approved_p f -public_p $public_p -new_member_policy open -description $description $community_group_id $group_name

append doc "
[ad_header "Request Sent"]
<h2>Request Sent</h2>
[ad_context_bar_ws [list "/education/manage-memberships.tcl" "Add/Drop Memberships"] "Request Sent"]
<hr>
<blockquote>
Your request for a new community has been sent.<p>
Please check back later to see if your request has been approved.  Do not repeat your request.
</blockquote>
[ad_footer]"

doc_return 200 text/html $doc
