# /packages/education/www/department/admin/department-edit-3.tcl

ad_page_contract {
    This page allows the user to edit information about a department.

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: department-edit-3.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    group_name:notnull
    {department_number [db_null]}
    {external_homepage_url [db_null]}
    {mailing_address [db_null]}
    {phone_number [db_null]}
    {fax_number [db_null]}
    {inquiry_email [db_null]}
    {description [db_null]}
    {mission_statement [db_null]}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    valid_email_p {
	if {![empty_string_p $inquiry_email] && ![philg_email_valid_p $inquiry_email]} {
	    ad_complain {
		The inquiry email address that you typed doesn't look right to us.  Examples of valid email addresses are 
		<ul>
		<li>Alice1234@aol.com
		<li>joe_smith@hp.com
		<li>pierre@inria.fr
		</ul>
	    }
	}
    }
    valid_phone_p {
	if {![empty_string_p $phone_number] && ![edu_phone_number_p $phone_number]} {
	    ad_complain " The phone number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
    valid_fax_p {
	if {![empty_string_p $fax_number] && ![edu_phone_number_p $fax_number]} {
	    ad_complain " The fax number you have entered is not in the correct form.  It must be of the form XXX-XXX-XXXX "
	}
    }
} -errors {
    group_name {You must provide a name for the new department.}
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]

if {[string compare $external_homepage_url "http://"] == 0} {
    set external_homepage_url [db_null]
}

db_transaction {
    db_dml update_eci {
	update edu_department_info 
	set department_number = :department_number,
	external_homepage_url = :external_homepage_url,
	mailing_address = :mailing_address,
	phone_number = :phone_number,
	fax_number = :fax_number,
	inquiry_email = :inquiry_email,
	description = :description,
	mission_statement = :mission_statement,
	last_modified = sysdate,
	last_modifying_user = :user_id,
	modified_ip_address = '[ns_conn peeraddr]'
	where group_id = :department_id
    }
    db_dml update_ug {
	update user_groups
	set group_name=:group_name
	where group_id = :department_id
    }
}

db_release_unused_handles

ns_returnredirect "one?[export_url_vars department_id]"
