# /packages/education/www/department/admin/index.tcl

ad_page_contract {
    This page displays the information for the department the person
    is logged in as.
 
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: one.tcl,v 1.2 2001/02/02 21:48:45 tarik Exp $
} {
    department_id:integer,notnull
    {orderby "subject_number,subject_name"}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
}

# set the user and group information
#db_with_handle db {
#    set id_list [edu_group_security_check $db edu_department]
#}
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]

db_1row get_dept_info {
    select department_number, external_homepage_url, department_name
    from edu_departments
    where department_id = :department_id
}

set title "$department_name [ad_decode $department_number "" "" ($department_number)] Administration"

append doc "
[ad_header $title]
<h2>$title</h2>
[ad_context_bar_ws [list "" "Departments"] "Department Administration"]
<br><br>
"

if [empty_string_p $external_homepage_url] {
    set links [ad_navbar [list "department-edit?[export_url_vars department_id]" "Edit Department Properties"]]
} else {
    set links [ad_navbar [list $external_homepage_url "Department Home Page"] [list "department-edit?[export_url_vars department_id]" "Edit Department Properties"]]
}

append doc "
$links
<blockquote>
"

# let's list the subjects and classes in the department 

#db_1row get_num_subjects_n_classes {
#    select count(unique(map.subject_id)) as n_subjects, 
#    count(class_id) as n_classes 
#    from edu_classes, 
#    edu_subject_department_map map 
#    where map.subject_id = edu_classes.subject_id(+) 
#    and map.department_id = :department_id
#}

# we want to list the subjects

# it is okay to use $department_id here instead of the bind variable, because the query above would have caught any error
# besides, it doesn't work otherwise

set table_def {
    {subject_number {Subject Number} {} {
	<td align=center>
	$subject_number
	[if ![string compare $grad_p t] {
	    subst "G"
	}] </td>
	}
    }
    {subject_name {Name} {} {<td><a href=[edu_url]subject/admin/index.tcl?[export_url_vars subject_id]>$subject_name</a></td>}}
    {edit {} {} {<td><a href=subject-edit?[export_url_vars subject_id department_id]>edit</a></td>}}
    {remove {} {} {<td><a href=subject-unlink?[export_url_vars subject_id department_id]>remove</a></td>}}
}


set sql "
select subject_name, 
map.subject_number, 
map.subject_id,
map.grad_p
from edu_subjects, edu_subject_department_map map 
where map.subject_id = edu_subjects.subject_id 
and map.department_id = $department_id 
[ad_order_by_from_sort_spec $orderby $table_def]
"

set table [ad_table -Tmissing_text "" -Textra_vars {department_id} -Torderby $orderby subject_table $sql $table_def]

if [empty_string_p $table] {
    append doc "
    <h3>There are currently no subjects in this department.</h3>
    "
} else {
    append doc "
    <h3>Subjects in $department_name</h3>
    <blockquote>
    $table
    </blockquote>"
}

append doc "
<ul>
<li><a href=\"subject-add?[export_url_vars department_id]\">Add a New Subject</a>
<li><a href=\"subject-add-existing?[export_url_vars department_id]\">Add a Subject From Another Department</a>
</ul>
</blockquote>"

# unused code
# we only want to list the subjects in a department
# the classes are listed on the appropriate subject page

#  set class_text "
#  <h3>Classes</h3>
#  <ul>

#  "

#  if {$n_classes == 0} {
#      append class_text "Currently, there are no classes in this department.</ul>"
#  } elseif {$n_classes < $class_threshhold} {
#      # we want to list the subjects
#      set selection [ns_db select $db "select class_name, 
#              class_id 
#         from edu_classes, 
#              edu_subjects, 
#              edu_subject_department_map map 
#        where map.subject_id = edu_classes.subject_id
#          and map.department_id = $department_id
#          and edu_subjects.subject_id = map.subject_id"]

#      set return_url "[edu_url]class/admin/"

#      while {[ns_db getrow $db $selection]} {
#  	set_variables_after_query

#  	append class_text "<li> $class_name [ad_space 2] 
#  	\[<a href=\"/education/util/group-login.tcl?group_id=$class_id&group_type=edu_class&return_url=[ad_urlencode [edu_url]class/one.tcl]\">home page</a> 
#  	| <a href=\"/education/util/group-login.tcl?group_id=$class_id&group_type=edu_class&[export_url_vars return_url]\">admin page</a>\]"
#      }

#      append class_text "</ul>"

#  }

#append doc "
#<p>
#<a href=\"users?[export_url_vars department_id]\">User Management</a>
#"

append doc "
</blockquote>
[ad_footer]
"

doc_return 200 text/html $doc