# /packages/education/www/department/admin/subject-add-2.tcl

ad_page_contract {
    This allows an admin to add a subject to the department.
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-add-2.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    subject_name:notnull
    {description [db_null]}
    {credit_hours [db_null]}
    {prerequisites [db_null]}
    {professors_in_charge [db_null]}
    {subject_number [db_null]}
    {grad_p f}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    subject_name {You must provide a name for the new subject.}
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]

# so we don't get hit by duplicates if the user double-submits,
# let's generate the subject_id here

if ![db_0or1row get_info {
    select edu_subject_id_sequence.nextval as subject_id,
    department_name
    from edu_departments
    where department_id = :department_id
}] {
    ad_complain "invalid department id"
}

doc_return 200 text/html "

[ad_header "Add a Subject"]
<h2>Confirm Subject Information</h2>

[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Add a Subject"]

<hr>
<blockquote>

<table>

<tr>
<th align=left valign=top>
Subject Name:
</td>
<td>
$subject_name
</td>
</tr>

<tr>
<th align=left valign=top>
Description:
</td>
<td>
[address_book_display_as_html $description]
</td>
</tr>

<tr>
<th align=left valign=top>
Credit Hours:
</td>
<td>
$credit_hours
</td>
</tr>

<tr>
<th align=left valign=top>
Prerequisites:
</td>
<td>
[address_book_display_as_html $prerequisites]
</td>
</tr>

<tr>
<th align=left valign=top>
Professors in Charge:
</td>
<td>
$professors_in_charge
</td>
</tr>

<tr>
<th align=left valign=top>
Subject Number:
</td>
<td>
$subject_number
</td>
</tr>

<tr>
<td align=left valign=top>
<b>Is this a Graduate Class?</b>
</td>
<td align=left>
[util_PrettyBoolean $grad_p]
</td>
</tr>

<tr>
<th align=center valign=top colspan=2>

<form method=post action=subject-add-3>

[export_form_vars department_id subject_name description credit_hours prerequisites professors_in_charge subject_number grad_p subject_id]

<br>
<input type=submit value=\"Create Subject\">
</form>

</td>
</tr>

</table>

</blockquote>
[ad_footer]
"