# /packages/education/www/department/admin/subject-add-3.tcl

ad_page_contract {
    This allows an admin to add a subject to the department.
    This page does the actual insert.
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-add-3.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    subject_name:notnull
    subject_id:integer,notnull
    {description [db_null]}
    {credit_hours [db_null]}
    {prerequisites [db_null]}
    {professors_in_charge [db_null]}
    {subject_number [db_null]}
    {grad_p f}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    subject_name {You must provide a name for the new subject.}
    subject_id {You must provide an identification number for the new subject.}
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]

set user_id [ad_verify_and_get_user_id]

set addr [ns_conn peeraddr]

if [catch {
    db_transaction {
	db_dml insert_subject {
	    insert into edu_subjects (
	    subject_id,
	    subject_name,
	    description,
	    credit_hours,
	    prerequisites,
	    professors_in_charge,
	    last_modified,
	    last_modifying_user,
	    modified_ip_address)
	    values (
	    :subject_id,
	    :subject_name,
	    :description,
	    :credit_hours,
	    :prerequisites,
	    :professors_in_charge,
	    sysdate,
	    :user_id,
	    :addr)
	}
	
	db_dml insert_dept {
	    insert into edu_subject_department_map (
	    subject_id,
	    subject_number,
	    grad_p,
	    department_id)
	    values (
	    :subject_id,
	    :subject_number,
	    :grad_p,
	    :department_id)
	}
    }
} errmsg] {
    # something went wrong.  
    
    if {[db_string check_if_subject_exists "select count(subject_id) from edu_subjects where subject_id = :subject_id"] > 0 } {
	# mapping was already in the tables
	ad_returnredirect "?[export_url_vars department_id]"
    } else {
	ad_return_error "database choked" "The database choked on your insert:
	<blockquote>
	<pre>
	$errmsg
	</pre>
	</blockquote>
	You can back up, edit your data, and try again"
    }
    return
}

# insert went OK

db_release_unused_handles

ad_returnredirect "one?[export_url_vars department_id]"
