# /packages/education/www/department/admin/subject-add-existing-3.tcl

ad_page_contract {
    This page confirms the information for adding an existing subject.
       
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-add-existing-3.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    subject_id:integer,notnull
    {subject_number [db_null]}
    {grad_p f}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    subject_id_already_mapped_to_dept_p {
	if [db_string check_if_subject_exists {
	    select count(department_id)
	    from edu_subject_department_map
	    where subject_id = :subject_id
	    and department_id = :department_id
	}] {
	    ad_complain "The subject you are trying to add already exists in this department."
	}
    }
} -errors {
    subject_id {You must include a subject identification number.}
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

db_1row get_info {
    select subject_name, department_name
    from edu_subjects, edu_departments
    where subject_id = :subject_id
    and department_id = :department_id
}

doc_return 200 text/html "

[ad_header "Add an Existing Subject @ [ad_system_name]"]
<h2>Add an Existing Subject</h2>


[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Add a Subject"]


<hr>
<blockquote>

Are you sure you wish to add $subject_name to the department $department_name?

<form method=post action=\"subject-add-existing-4\">

[export_form_vars subject_id subject_number grad_p department_id]

<b>Subject Name:</b> [ad_space] $subject_name

<p>

<b>Subject Number:</b> [ad_space] [edu_maybe_display_text $subject_number]

<p>

<b>Is this a Graduate Class?</b> [ad_space] [util_PrettyBoolean $grad_p]

<p>

<input type=submit name=button value=\"Add Subject\">
</form>


</blockquote>
[ad_footer]
"














