# /packages/education/www/department/admin/subject-add-existing.tcl

ad_page_contract {
    This page allows the admin to add an existing subject to the department.
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-add-existing.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set department_name [db_string get_dept_name "select department_name from edu_departments where department_id = :department_id"]

set threshold 40
set display_text "Click on a subject to add<p>"

append return_string "
[ad_header "Add an Existing Subject @ [ad_system_name]"]
<h2>Add an Existing Subject</h2>


[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Add a Subject"]


<hr>
<blockquote>
"

# get the number of subjects that are not already in the department

set n_subject [db_string get_num_sub {
    select count(subject_id)
    from edu_subjects
    where subject_id not in
     (select subject_id from edu_subject_department_map where department_id = :department_id)
}]


# if there are < $threshold subjects we list all of the possible subjects
# else, we provide both a broswe by subject name and a search functionality

if { $n_subject < $threshold } {
    # display all of the subjects
    append return_string "$display_text<ul>"
    
    db_foreach get_subject_info {
	select subject_id, subject_name
	from edu_subjects
	where subject_id not in
	  (select subject_id from edu_subject_department_map where department_id = :department_id) order by lower(subject_name)
    } {
	append return_string "
	<li><a href=\"subject-add-existing-2?[export_url_vars subject_id department_id]\">$subject_name</a> <br> \n"
    }

    append return_string "</ul>"

} else {

    # there are a lot of subjects so we want to let them browse or search
    
    set subjects_in_department_p f
    set export_vars [export_url_vars target_url subjects_in_department_p display_text department_id]

    append return_string "
    <li>Find subject by subject name : 
    <a href=subject-list?begin=A&end=H&lastletter=G&$export_vars>A - G</a> |
    <a href=subject-list?begin=H&end=N&lastletter=M&$export_vars>H - M</a> |
    <a href=subject-list?begin=N&end=T&lastletter=S&$export_vars>N - S</a> |
    <a href=subject-list?begin=T&end=z&lastletter=Z&$export_vars>T - Z</a> 
    <br><br>
    <li><a href=subject-list?begin=A&end=z&lastletter=Z&$export_vars>Show all subjects</a>
    "
}

# commented out search capability --ejc@arsdigita.com 8/16/2000
#    <Br>

#    <form method=get action=\"subject-search\">
#    [export_form_vars target_url subjects_in_department_p display_text]
    
#    <li>Search through all subjects:
#    <table>
#    <tr><td align=right>by Subject Name</td>
#    <td><input type=text maxlength=100 size=30 name=subject_name><BR></td>
#    </td>
#    <tr>
#    <td colspan=2>
#    <center><input type=submit value=\"Search For a Subject\"></center>
#    </td>
#    </table>
#    </form>



append return_string "
</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string
