# /packages/education/www/department/admin/subject-edit.tcl

ad_page_contract {
    This page allows the admin to change the subject number and 
    graduate status of the class
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-edit.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    subject_id:integer,notnull
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    subject_id {You must include a subject identification number.}
}

# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]

if ![db_0or1row get_info {
    select subject_name, 
    subject_number, 
    grad_p,
    department_name
    from edu_subjects sub, 
    edu_subject_department_map map,
    edu_departments dep
    where sub.subject_id = map.subject_id 
    and map.department_id = :department_id 
    and sub.subject_id = :subject_id
    and dep.department_id = :department_id
}] {
    # the department is not mapped to this subject
    ad_return_complaint 1 "<li>The subject you have requested does not belong to this department."
    return
}


set return_string "

[ad_header "Edit an Existing Subject @ [ad_system_name]"]
<h2>Edit Subject Number</h2>


[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Edit Subject Properties"]


<hr>
<blockquote>
<form method=post action=\"subject-edit-2\">
<b>Subject Name:</b> [ad_space 1] $subject_name

<p>

<b>Subject Number:</b> [ad_space 1] <input type=text size=15 maxlength=20 value=\"$subject_number\" name=subject_number>

<br><br>

<b>Is this a Graduate Class?</b> [ad_space 1]
"

if {![string compare $grad_p t]} {
    append return_string "
    <input type=radio name=grad_p value=t checked> Yes
    <input type=radio name=grad_p value=f> No
    "
} else {
    append return_string "
    <input type=radio name=grad_p value=t> Yes
    <input type=radio name=grad_p value=f checked> No
    "
}

append return_string "
[export_form_vars subject_id department_id] 
<p>
<input type=submit value=\"Continue\">
</form>

</blockquote>
[ad_footer]
"

db_release_unused_handles

doc_return 200 text/html $return_string













