# /packages/education/www/department/admin/subject-list.tcl

ad_page_contract {
    This page shows the list of subjects in the class that meet
    the passed in conditions.
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-list.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    begin:notnull
    end:notnull
    lastletter:notnull
    {subjects_in_department_p t}
    {target_url ""}
    {display_text ""}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    begin {You must have a starting letter}
    end {You must have a stopping letter}
    lastletter {You must provide a last letter}
}


# set the user and group information
#set id_list [edu_group_security_check $db edu_department]
#set user_id [lindex $id_list 0]
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

set user_id [ad_verify_and_get_user_id]
set department_name [db_string get_dept_name "select department_name from edu_departments where department_id = :department_id"]

if { [string compare [string tolower $begin] a] == 0) && [string compare [string tolower $end] z] == 0 } {
    set header "All Subjects"
    set sql_suffix ""
} else {
    set header "Subject Names $begin through $lastletter"
    set sql_suffix "where upper('$begin') < upper(subject_name)
               and upper('$end') > upper(subject_name)"
}

set return_string "
[ad_header "Department Administration @ [ad_system_name]"]

<h2> $header </h2>


[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Subject List"]

<hr>
<blockquote>

"

set sql_tables [db_null]

if {[empty_string_p $sql_suffix]} {
    set sql_prefix "where"
} else {
    set sql_prefix "and"
}


if {[string compare $subjects_in_department_p f] == 0} { 
   append sql_suffix "$sql_prefix subject_id not in (select subject_id from edu_subject_department_map where department_id = :department_id)"
} else {
    append sql_tables ", edu_subject_department_map map "
    append sql_suffix "$sql_prefix map.subject_id = edu_subjects.subject_id and map.department_id = :department_id"
}


set text_to_output ""
    
db_foreach get_subject_info {
    select edu_subjects.subject_id, 
    subject_name 
    from edu_subjects 
    $sql_tables
    $sql_suffix
    order by lower(subject_name)
} {
    if {![empty_string_p $target_url]} {
	append text_to_output "
	<li><a href=\"$target_url?[export_url_vars subject_id department_id]\">$subject_name</a> <br> \n"
    } else {
	append text_to_output "
	<li> $subject_number $subject_name [ad_space]
	\[ <a href=\"/subject/one?[export_url_vars subject_id]\">home page</a> 
	| <a href=\"/subject/admin/index?[export_url_vars subject_id]\">admin page</a> 
	| <a href=\"subject-remove?[export_url_vars subject_id department_id]\">remove</a> \]"
    }
}


if {[empty_string_p $display_text_to_output]} {
    append return_string "There are no subjects that meet your criteria."
} else {
    append return_string "
    $text
    $text_to_output
    "
}
    
append return_string "
</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string












