# /packages/education/www/department/subject-unlink.tcl

ad_page_contract {
    This page asks for confirmation before unlinking a subject from a dept.
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: subject-unlink.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    department_id:integer,notnull
    subject_id:integer,notnull
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    subject_id_not_mapped_to_dept_p {
	if ![db_string check_if_subject_exists {
	    select count(department_id)
	    from edu_subject_department_map
	    where subject_id = :subject_id
	    and department_id = :department_id
	}] {
	    ad_complain "The subject you are trying to delete does not belong to the department $department_name."
	}
    }
} -errors {
    subject_id {You must include a subject identification number.}
}

# set the user and group information
#db_with_handle db {
#    set id_list [edu_group_security_check $db edu_department]
#}
#set department_id [lindex $id_list 1]
#set department_name [lindex $id_list 2]

db_1row get_info {
    select subject_name, department_name
    from edu_subjects, edu_departments
    where subject_id = :subject_id
    and department_id = :department_id
}

doc_return 200 text/html "

[ad_header "Department Administration @ [ad_system_name]"]

<h2>Remove $subject_name</h2>

[ad_context_bar_ws [list "" "Department Administration"] [list "one?[export_url_vars department_id]" "$department_name"] "Remove Subject"]

<hr>
<blockquote>

Are you sure you want to remove $subject_name from the department of $department_name?  

<table align=center>
<tr>

<td>
<form method=post action=\"subject-unlink-2\">
[export_form_vars subject_id department_id]
<input type=submit name=button value=\"Yes, remove the subject\">
</form>
</td>

<td>
<form method=post action=one>
[export_form_vars department_id]
<input type=submit value=\"No, don't remove it\">
</form>
</td>

</tr>
</table>

</blockquote>
[ad_footer]
"




