# /packages/education/www/manage-memberships.tcl

ad_page_contract {
    Allows user to join a group, request membership in a group if approval is required, or drop his/her membership.
    Examples of groups: classes, communities
    @param orderby Optional orderby variable, for ordering columns in tables.

    @author eric j. cholankeril (ejc@arsdigita.com), modified by befekadu@mit.edu to include subgroup scoping
    @creation-date July 19, 2000
    @cvs-id $Id: manage-memberships.tcl,v 1.3 2001/02/01 20:53:24 bef Exp $
} {
    {orderby:optional "group_name"}
    group_id:optional
}

set user_id [ad_maybe_redirect_for_registration]

if { [edu_user_has_limited_access_p $user_id] } {
    ad_returnredirect "/"
}

set return_url [ns_conn url]
set query [ns_conn query]
if ![empty_string_p $query] {
    append return_url "?$query"
}

# IF group_id exists return only the subgroups in that group


set current_memberships_html ""
set subgroup_p 0

if { [info exists group_id] } {

    set parent_group_id $group_id
    set subgroup_p 1
    
    set sublist [db_list get_group_type_info "
    select pretty_name, pretty_plural
    from user_group_types
    where group_type = 'edu_subgroup'
    order by pretty_plural"]
     
    set pretty_name [lindex $sublist 0]
    set pretty_plural [lindex $sublist 1]

    set table_def {
	{group_name {Subgroup} {} {<td valign=top> <a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name subgroup]]]/\">$group_name</a> </td>} }
	{role {Role} {} {<td align=center valign=top> $role </td>} }
	{drop {} {} {<td valign=top> \[<a href=\"/education/drop-confirm?[export_url_vars group_id return_url]\">drop</a>\] </td>} }
    }
	
    set sql "    
    select distinct ug.group_name, ug.short_name,
    ug.group_id, role
    from user_groups ug, user_group_map ugm
    where upper(ug.group_type) = 'EDU_SUBGROUP'
    and ugm.group_id = ug.group_id
    and ug.approved_p = 't'
    and ugm.user_id = $user_id and ug.parent_group_id = $group_id
    [ad_order_by_from_sort_spec $orderby $table_def]"
    
    set rowcode {}
    set remove_column [list]
    
    # generate the columns we really want to see given the list of removes
    
    set all_columns {}
    foreach column $table_def {
	lappend all_columns [lindex $column 0]
    }
    
    set col [list]
    foreach acol $all_columns { 
	if {[lsearch -exact $remove_column $acol] < 0} { 
	    lappend col $acol
	}
    }

    set table [ad_table -Taudit {group_id} -Tpre_row_code $rowcode -Tcolumns $col -Textra_vars {return_url parent_group_id} -Torderby $orderby get_class_membership_table $sql $table_def]

    if {![regexp {No data found} $table]} {
	append current_memberships_html "
	<b>$pretty_plural</b>
	$table
	<br>"
    }

    # get the subgroups they're not members of
    
    set table_def {
	{group_name {Subgroup} {} {<td valign=top>[
	if {[ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {
	    return "<a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name subgroup]]]\">$group_name</a>"
	} else {
	    return "$group_name"
	}] </td>} 
    }
    {join_request {Action} {new_member_policy $order} {
	<td align=center valign=top>
	[if {![string compare $new_member_policy "open"] || [ad_administrator_p]} {
	    return "\[<a href=\"join?[export_url_vars group_id return_url]\">join</a>\]"
	} elseif ![string compare $new_member_policy "wait"] {
	    return "\[<a href=\"request-membership?[export_url_vars parent_group_id group_id return_url]\">request membership</a>\]"
	}]
	    </td>} 
	}
    }
    
    set sql "
    select distinct ug.group_name, ug.short_name, ug.group_id, 
    ug.new_member_policy, lower(ug.existence_public_p) as existence_public_p
    from user_groups ug 
    where upper(ug.group_type) = 'EDU_SUBGROUP'
    and upper(ug.new_member_policy) != 'CLOSED'
    and ug.parent_group_id=$group_id
    and lower(ug.approved_p) = 't'
    and not exists (select 1 from user_group_map ugm
                             where ugm.group_id = ug.group_id
    and user_id = $user_id) [ad_order_by_from_sort_spec $orderby $table_def]"
    
    set rowcode {}
    set remove_column [list]
    
    set all_columns {}
    foreach column $table_def {
	lappend all_columns [lindex $column 0]
    }
    set col [list]

    foreach acol $all_columns { 
	if {[lsearch -exact $remove_column $acol] < 0} { 
	    lappend col $acol
	}
    }
    
    set table2 [ad_table -Taudit {group_id} -Textra_vars {user_id return_url parent_group_id} -Tpre_row_code $rowcode -Tcolumns $col -Torderby $orderby get_non_member_classes_table $sql $table_def]


    if {![regexp {No data found} $table2]} {
	append join_group_html "
	<b>$pretty_plural</b>
	$table2
	<br>"
    }

} else {
    

# --- PUT ALL GROUP TYPES TO CHECK IN THIS LIST ---
set list_of_group_types_to_check "('edu_class', 'edu_community')"

# get all the information about group types once, since we use it twice
set list_of_pretty_group_types [db_list_of_lists get_group_type_info "
                                    select group_type, pretty_name, pretty_plural
                                    from user_group_types
                                    where group_type in $list_of_group_types_to_check
                                    order by pretty_plural"]

# for each group type, display all the groups the user is a member of,
# with links to the portal for that group

foreach sublist $list_of_pretty_group_types {
    
    set group_type [lindex $sublist 0]
    set pretty_name [lindex $sublist 1]
    set pretty_plural [lindex $sublist 2]

    if ![string compare $group_type "edu_class"] {	
    
	# if the type is "edu_class", select department, term, enrollment policy
	# so we can display this information in the table

	set table_def {
	    {group_name {Class} {} {<td valign=top> <a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name class]]]/\">$group_name</a> </td>} }
	    {term_name {Term} {term_start_date $order} {<td align=center valign=top> $term_name </td>} }
	    {role {Role} {} {<td align=center valign=top> $role </td>} }
	    {drop {} {} {<td valign=top> \[<a href=\"/education/drop-confirm?[export_url_vars group_id return_url]\">drop</a>\] </td>} }
	}
	
	set sql "
	select distinct ug.group_name, ug.short_name, term_name, 
                et.start_date as term_start_date, ug.group_id, role
  	from edu_class_info eci, edu_terms et, user_groups ug, user_group_map ugm
	where upper(ug.group_type) = 'EDU_CLASS'
	and ugm.group_id = ug.group_id
	and eci.group_id = ug.group_id
	and et.term_id = eci.term_id
	and ug.approved_p = 't'
	and ugm.user_id = $user_id
	[ad_order_by_from_sort_spec $orderby $table_def]"

	set rowcode {}
	set remove_column [list]
#  	switch [ad_sort_primary_key $orderby] {
#  	    department_name {
#  		lappend remove_column department_name
#  		set rowcode {[
#  		if {![ad_table_same department_name]} {
#  		    ad_table_span [
#  		    switch $department_name {
#  			[db_null] {subst {<b>No Department</b>}}
#  			default {subst {<b>$department_name</b>}}
#  		    }] "bgcolor=cccccc"
#  		    }
#  		    ]
#  		}
#  	    }
#  	}
	    
	# generate the columns we really want to see given the list of removes
	
	set all_columns {}
	foreach column $table_def {
	    lappend all_columns [lindex $column 0]
	}
	set col [list]
	foreach acol $all_columns { 
	    if {[lsearch -exact $remove_column $acol] < 0} { 
		lappend col $acol
	    }
	}
	
	set table [ad_table -Taudit {group_id} -Tpre_row_code $rowcode -Tcolumns $col -Textra_vars {return_url} -Torderby $orderby get_class_membership_table $sql $table_def]
	
    } else {

	# this is some other kind of group, not classes
	
	set table_def {
	    {group_name {Group Name} {} {<td> <a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name community]]]/\">$group_name</a> </td>} }
	    {role {Role} {} {<td align=center valign=top> $role </td>} }
	    {drop {} {} {<td> \[<a href=\"/education/drop-confirm?[export_url_vars group_id return_url]\">drop</a>\] </td>} }
	}

	set sql "
	select distinct group_name, short_name, ug.group_id, role
	from user_group_map ugm, user_groups ug
	where ug.group_type = '[DoubleApos $group_type]'
	and ugm.group_id = ug.group_id
	and lower(ug.approved_p) = 't'
	and ugm.user_id = $user_id [ad_order_by_from_sort_spec $orderby $table_def]"

	set table [ad_table -Taudit {group_id} -Textra_vars {return_url} -Torderby $orderby get_group_membership_table $sql $table_def]
    }

    if {![regexp {No data found} $table]} {
	append current_memberships_html "
	<b>$pretty_plural</b>
	$table
	<br>"
    }
}


# for each group type, list the groups the user might want to join

foreach sublist $list_of_pretty_group_types {

    set group_type [lindex $sublist 0]
    set pretty_name [lindex $sublist 1]
    set pretty_plural [lindex $sublist 2]

    if ![string compare $group_type "edu_class"] {
	# if the type is "edu_class", select department(s), term, enrollment policy
	# so we can display this information in the table
	
	set table_def {
	    {group_name {Class} {} {<td valign=top>[
	                            if {[ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {
					return "<a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name class]]]\">$group_name</a>"
				    } else {
					return "$group_name"
				    }] </td>} }
	    {term_name {Term} {term_start_date $order} {<td align=center valign=top> $term_name </td>} }
	    {join_request {Action} {new_member_policy $order} {
		<td align=center valign=top>
		[if {![string compare $new_member_policy "open"] || [ad_administrator_p]} {
		    return "\[<a href=\"join?[export_url_vars group_id return_url]\">join</a>\]"
		} elseif ![string compare $new_member_policy "wait"] {
		    return "\[<a href=\"request-membership?[export_url_vars group_id return_url]\">request membership</a>\]"
		}]
		</td>} }
	    }

	set sql "
	select distinct ug.group_name, ug.short_name, ug.group_id, term_name, et.start_date as term_start_date,
                        ug.new_member_policy, lower(ug.existence_public_p) as existence_public_p
	from edu_class_info eci, edu_terms et,
             user_groups ug, user_group_map ugm
	where upper(ug.group_type) = 'EDU_CLASS'
	and upper(ug.new_member_policy) != 'CLOSED'
	and ugm.group_id = ug.group_id
	and eci.group_id = ug.group_id
	and et.term_id = eci.term_id
	and lower(ug.approved_p) = 't'
	and not exists (select 1 from user_group_map ugm
                             where ugm.group_id = ug.group_id
                             and user_id = $user_id) [ad_order_by_from_sort_spec $orderby $table_def]"

	set rowcode {}
	set remove_column [list]
#  	switch [ad_sort_primary_key $orderby] {
#  	    department_name {
#  		lappend remove_column department_name
#  		set rowcode {[
#  		if {![ad_table_same department_name]} {
#  		    ad_table_span [switch $department_name {
#  			[db_null] {subst {<b>No Department</b>}}
#  			default {subst {<b>$department_name</b>}}
#  		    }] "bgcolor=cccccc"
#  		    }
#  		    ]
#  		}
#  	    }
#  	}
	
	# generate the columns we really want to see given the list of removes
	
	set all_columns {}
	foreach column $table_def {
	    lappend all_columns [lindex $column 0]
	}
	set col [list]
	foreach acol $all_columns { 
	    if {[lsearch -exact $remove_column $acol] < 0} { 
		lappend col $acol
	    }
	}
	
	set table [ad_table -Taudit {group_id} -Textra_vars {user_id return_url} -Tpre_row_code $rowcode -Tcolumns $col -Torderby $orderby get_non_member_classes_table $sql $table_def]
		
    } else {
	# this is some kind of group other than class
	# select just the basics
	
	set table_def {
	    {group_name {Group Name} {} {<td> [
	    if [ad_user_group_authorized_admin_or_site_admin $user_id $group_id] {
		return "<a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name community]]]/\">$group_name</a>"
	    } else {
		return "$group_name"
	    }
	       </td>} }
	       {join_request {Action} {new_member_policy $order} {<td align=center> [
	       if ![string compare $new_member_policy "open"] {
		   return "\[<a href=\"join?[export_url_vars group_id return_url]\">join</a>\]"
	      } elseif ![string compare $new_member_policy "wait"] {
		  return "\[<a href=\"request-membership?[export_url_vars group_id return_url]\">request membership</a>\]"
	      }
	       </td>} }
	 }
	 
	 set sql "
	 select distinct group_name, short_name, group_id, new_member_policy, lower(existence_public_p) as existence_public_p
	 from user_groups ug
	 where group_type = '[DoubleApos $group_type]'
	 and upper(new_member_policy) != 'CLOSED'
	 and lower(ug.approved_p) = 't'
	 and not exists (select 1 from user_group_map ugm
	 where ugm.group_id = ug.group_id
	 and user_id = $user_id) [ad_order_by_from_sort_spec $orderby $table_def]"
	 
	 set table [ad_table -Taudit {group_id} -Textra_vars {return_url user_id} -Torderby $orderby get_non_member_group_table $sql $table_def]
     }
     
     if {![regexp {No data found} $table]} {
	 append join_group_html "
	 <b>$pretty_plural</b>
	 $table
	 <br>"
     }
 }
}



if { [info exists current_memberships_html] && ![empty_string_p $current_memberships_html] || [info exists join_group_html] && ![empty_string_p $join_group_html] } { 
    append doc "
    [ad_header "Add/Drop Memberships"]
    <h2>Add/Drop Memberships</h2>
    <hr>"
} else {
    append doc "
    [ad_header "Add/Drop Memberships"]
    <h3>This group currently has no open subgroups</h3>"
}

if {[info exists current_memberships_html] && ![empty_string_p $current_memberships_html]} {
    append doc "
    <h3>Your current memberships</h3>
    $current_memberships_html"
}

if {[info exists join_group_html] && ![empty_string_p $join_group_html]} {
    if {[info exists current_memberships_html] && ![empty_string_p $current_memberships_html]} {
	append doc "
	<br>
	<hr>"
    }

    if $subgroup_p {
	append doc "<h3>Join a subgroup</h3>
	$join_group_html"
    } else {
	append doc "<h3>Join a group</h3>
	$join_group_html"
    }
    
}

append doc "<p>
<a href=\"/education/community/request-community\">Request a new community</a>
[ad_footer]
"

doc_return 200 text/html $doc



