# /packages/education/www/request-membership.tcl

ad_page_contract {
    Processes request for membership in a group by emailing all the group admins (e.g. professors)
    
    @author eric j. cholankeril (ejc@arsdigita.com)
    @creation-date July 24, 2000
    @cvs-id $Id: request-membership.tcl,v 1.4 2001/02/13 23:37:26 tarik Exp $
} {
    parent_group_id:optional
    group_id:notnull
    {return_url:optional "/education/manage-memberships"}
}

set user_id [ad_verify_and_get_user_id]

#this was added for subgroups
set group_has_administrator_p [db_string administrator_select "select count(role) from user_group_action_role_map where action = 'Administer Group' and group_id = $group_id"]


#= upper('[edu_get_administrator_role_string]')
#or upper(role) = upper('[edu_get_professor_role_string]'))"]

set group_name [db_string select_group_name "select group_name from user_groups where group_id = :group_id"]

if {$group_has_administrator_p == 0 && [info exists parent_group_id] } {
     set sql_query "select first_names, last_name, email
    from users u, user_group_map ugm, user_groups ug
    where ugm.group_id = :parent_group_id
    and ug.group_id = :parent_group_id
    and u.user_id = ugm.user_id
    and role in (select role from user_group_action_role_map where action = 'Administer Group' and group_id = :parent_group_id)
    "
} elseif {$group_has_administrator_p == 0 && ![info exists parent_group_id] } {
    set site_wide_needs_notification 1
} else {
    # select all appropriate people to email
    # currently set to all users of type "administrator" or "professor" for that group
    set sql_query "
    select first_names, last_name, email, group_name
    from users u, user_group_map ugm, user_groups ug
    where ugm.group_id = :group_id
    and ug.group_id = :group_id
    and u.user_id = ugm.user_id
    and role in (select role from user_group_action_role_map where action = 'Administer Group' and group_id = :group_id)
    "
}

set counter 0
if { [info exists site_wide_needs_notification] } {
    append to "[ad_system_owner]"
    append sent_to_list "
    <li>[ad_system_owner]"
} else {
    db_foreach get_topeople_info $sql_query {
	append to "$email,"
	append sent_to_list "
	<li>$first_names $last_name (<a href=\"mailto:$email\">$email</a>)"
	append sent_to_list2 "
	$first_names $last_name ($email)"
	incr counter
    }
}

# get all pertinent information about user to put in body of email message
db_1row get_user_info {
    select first_names, last_name, email
    from users
    where user_id = :user_id
}


if { [info exists parent_group_id] } {
    set approval_link "[ad_parameter SystemURL]/education/subgroup/manage-users-2?join_id=$user_id&group_id=$group_id"
} else {
    set approval_link "[ad_parameter SystemURL]/education/class/admin/users/add-2?user_id_from_search=$user_id&role=student&group_id=$group_id"
}


set from [spam_system_default_from_address]
set subject "Request to Join $group_name"
set body "
$first_names $last_name ($email) has requested to join $group_name.
Visit this link if you wish to add him/her to the group: $approval_link"

if { $counter > 1} {
    append body "

This email has been sent to the following people:
$sent_to_list2
"
} 

page_validation {
    if {![info exists sent_to_list] || [empty_string_p $sent_to_list]} {
	error "There was a problem with your request. No one currently administers that group."
    } elseif {[catch {ns_sendmail $to $from $subject $body} errmsg]} {
	error "The request was not sent, because of an error.  Please try again."
    }
}

set doc "
[ad_header "Request Sent"]
<h2>Request Sent</h2>
[ad_context_bar_ws [list $return_url "Add/Drop Memberships"] "Request Sent"]
<hr>
Your request to be added to $group_name was sent to the following individuals:
<ul>
$sent_to_list
</ul>
Please check back later to see if your request has been approved.
[ad_footer]
"

doc_return 200 text/html $doc


