ad_page_contract {
    Creates a subgroup, with values passed in from create-2.tcl

    @author Tarik Alatovic (tarik@alatovic.com)
    @creation-date Janurary 22, 2000
    @cvs-id $Id: create-2.tcl,v 1.9 2001/02/06 08:28:27 tarik Exp $
} {
    group_id:integer,notnull
    parent_domain_id:integer,notnull
    subgroup_group_id:integer,notnull
    group_name:notnull
} -validate {
    accessible_p {
	set user_id [ad_get_user_id]
	if ![ad_user_group_authorized_admin $user_id $group_id] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    group_name {You must select a name for a subgroup.}
}

set user_id [ad_verify_and_get_user_id]

# let's check and make sure that it is not a double click
if [db_0or1row check_if_subgroup_group_id_exists {
    select group_id as old_id from user_groups
    where group_id = :subgroup_group_id
}] {
    ad_returnredirect "manage-users?group_id=$subgroup_group_id"
    return
}

db_transaction {
    # get folder id for the subgroup folder
    db_1row get_seq_nextvals "select fs_file_id_seq.nextval as file_id, fs_version_id_seq.nextval as version_id from dual"

    if ![ad_user_group_add -approved_p t -existence_public_p t -new_member_policy closed -multi_role_p t -group_id $subgroup_group_id -parent_group_id $group_id "edu_subgroup" $group_name] {
	error "did not create group"
    }
 
    # create the role and actions for the subgroup
    edu_set_subgroup_roles_and_actions $subgroup_group_id
    
    set depth 0
    set file_title "$group_name Subgroup Folder"
    
    # we want to set the parent folder for the subgroup to be the root folder for its containing group
    if ![set parent_folder_id [portals_fs_group_root_folder $group_id]] {
	db_dml insert_into_fs_files {
	    insert into fs_files
	    (file_id, file_title, owner_id, folder_p, sort_key, depth, public_p, group_id)
	    values
	    (:file_id, :file_title, :user_id, 't', 0, :depth, 'f', :subgroup_group_id)
	}
    } else {
    	db_dml insert_into_fs_files {
	    insert into fs_files
	    (file_id, file_title, owner_id, parent_id, folder_p, sort_key, depth, public_p, group_id)
	    values
	    (:file_id, :file_title, :user_id, :parent_folder_id, 't', 0, :depth, 'f', :subgroup_group_id)
	}
    }
    
    # now we want to insert a "dummy" version o that we can also create the permission records
    db_dml insert_into_fs_versions {
	insert into fs_versions
	(version_id, file_id, creation_date, author_id)
	values
	(:version_id, :file_id, sysdate, :user_id)
    }
    
    db_exec_plsql grant_file_storage_permissions {
	begin 
	:1 := ad_general_permissions.grant_permission_to_all_users ( 'read', :version_id, 'FS_VERSIONS' ); 
	:1 := ad_general_permissions.grant_permission_to_all_users ( 'comment', :version_id, 'FS_VERSIONS' ); 
	end;
    }
	
    db_dml insert_into_cal_groups {
	insert into cal_groups(group_id) values (:subgroup_group_id)
    }
    
    db_dml insert_into_edu_subgroup_info {
	insert into edu_subgroup_info(group_id, root_folder_id) values (:subgroup_group_id, :file_id)
    }
}

fs_order_files $user_id $subgroup_group_id

ad_returnredirect "manage-users?group_id=$subgroup_group_id"




