# /education/subgroup/subgroup-users-add.tcl

ad_page_contract {
    @author caroline@arsdigita.com
    @creation-date January 23, 2001
    @cvs-id view.tcl,v 3.5.2.6.2.4 2000/09/22 01:36:26 kevin Exp
} {
    group_id:notnull
    {orderby ""}
}



db_1row group_info {select ug1.group_name as subgroup_name, ug2.group_id as parent_group_id, ug2.group_name as parent_group_name
	from user_groups ug1, user_groups ug2
        where ug2.group_id = ug1.parent_group_id
and ug1.group_id = :group_id}

set user_id [ad_verify_and_get_user_id]
 
#this page can be used by parent group admin or subgroup admin

if { ![ad_user_group_authorized_admin $user_id $group_id] || ![ad_user_group_authorized_admin $user_id $parent_group_id]} {
	ns_returnforbidden
}

append whole_page "[ad_header "Manage Members of $subgroup_name"]

<h2>Manage members of $subgroup_name</h2>

<hr>

<p>
<h3>Current Memebers of $subgroup_name:</h3>
"

#assumes that subgroups use the same roles as communities.

set return_url "/education/subgroup/manage-users?group_id=$group_id"

set role_list [edu_get_community_original_role_pretty_role]

foreach role_sublist $role_list {
    set role [lindex $role_sublist 0]
    set pretty_role [lindex $role_sublist 1]
    set pretty_role_plural [lindex $role_sublist 2]
    set counter 0
    append whole_page "<h3>$pretty_role_plural</h3>"

    set table_def {
	{last_name {Last Name} {} {<td><a href=\"/shared/community-member?user_id=$user_id\">$last_name</a></td>}}
	{first_names {First Name} {} {<td><a href=\"/shared/community-member?user_id=$user_id\">$first_names</a></td>}}
	{email {Email} {} {<td><a href=\"mailto:$email\">$email</a></td>}}
	{remove {} {} {<td>\[<a href=\"/education/class/admin/users/remove?class_id=$group_id&[export_url_vars user_id return_url]\">remove</a>\]</td>}}
    }
    
    set query "select distinct users.user_id, 
                       first_names, 
                       last_name,
	               email
                  from users, 
                       user_group_map    
                 where user_group_map.group_id = :group_id
                       and users.user_id = user_group_map.user_id 
                       and lower(role) = lower('$role')
	               [ad_order_by_from_sort_spec $orderby $table_def]"


    set bind_vars [ns_set create]
    ns_set put $bind_vars group_id $group_id
    append whole_page "
    [ad_table -Torderby $orderby -Tmissing_text {(<em>none</em>)} -Textra_vars {group_id return_url} -bind $bind_vars table_$role $query $table_def]"

}


# we print out all the users all of the time

append whole_page "
<p>
<hr>
<h3>Add New Members</h3>
<form action=\"manage-users-2\" method=\"post\">
<blockquote>The following people are members of $parent_group_name and are not yet members of $subgroup_name.  Check the first box to add them as a regular member and the second box to give that person adminstrative rights in the subgroup.</blockquote>
<p>
[export_form_vars group_id]
<table cellpadding=3>
<tr>
<th>Member</th><th>Administrator</th><th>Name</th>
</tr>
"

set query "
select distinct users.user_id, first_names, last_name, email 
from users, user_group_map ugm
where ugm.user_id = users.user_id
and ugm.group_id = :parent_group_id
and ugm.user_id not in (select user_id from user_group_map 
                        where group_id = :group_id)
order by upper(last_name),
         upper(first_names)"

if { [catch {

    set count 0
    db_foreach users_in_parent_group $query {
	incr count

	append whole_page "
<tr>
<td><center><input type=checkbox name=join_ids.$user_id value=\"No\"></center></td>
<td><center><input type=checkbox name=admin_ids.$user_id value=\"No\"></center></td>
<td> <a href=\"/shared/community-member?user_id=$user_id\">$first_names $last_name</a> (<a href=mailto:$email>$email</a>)</td>"
    }
    append whole_page "<tr><td colspan=3><center><input type=\"submit\" value=\"Add users to $subgroup_name\" name=\"add\"> </center></td></tr>
    </table></form>"

} err_msg] } {
    ad_return_error "Database Error" "We got the following error trying to run this query:
$err_msg<p><pre>$query</pre>\n"
    return
}


if { $count == 0 } {
    append whole_page "no users found meeting these criteria"
}

append whole_page "
[ad_footer]
"



doc_return  200 text/html $whole_page







