# /www/education/subject/admin/class-add-2.tcl

ad_page_contract {
    this is the confirmation page for the addition of a subject.    

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: class-add-2.tcl,v 1.2 2001/02/02 19:53:16 tarik Exp $
} {
    subject_id:integer,notnull
    instructor_id:integer,notnull
    group_name:notnull
    term_id:integer,notnull
    {where_and_when [db_null]}
    {public_p t}
    {grades_p t}
    {exams_p t}
    {final_exam_p t}
    {description [db_null]}
    {teams_p f}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    subject_id {You must include the subject identification number.}
    group_name {You must name your class.}
    term_id {Please select a term or specify \"no term\"}
}

set user_id [ad_verify_and_get_user_id]

#db_with_handle db {set user_id [edu_subject_admin_security_check $db $subject_id]}

# now that we know we have valid input, we display the confirmation page
set instructor_name [db_string get_instr_name "select first_names || ' ' || last_name from users where user_id=:instructor_id"]

set class_id [db_string get_class_id "select user_group_sequence.nextval from dual"]

set subject_name [db_string get_subj_name "select subject_name from edu_subjects where subject_id = :subject_id"]
set term_string [db_string get_term+name "select term_name from edu_terms where term_id = :term_id"]

db_release_unused_handles

if {[empty_string_p $description]} {
    set pretty_description "None"
} else {
    set pretty_description "$description"
}

set title "Add a $subject_name Class"
set navbar "[ad_context_bar_ws [list "../" "Subjects"] [list "index.tcl?subject_id=$subject_id" "Subject Administration"] "Add a Class"]"

append doc "
[ad_header $title]
<h2>$title</h2>
$navbar
<hr>

<blockquote>
<table>
<tr><th align=left>Instructor</th>
<td>$instructor_name</td>
</tr>

<tr><th align=left>Class Title</th>
<td>$group_name</td>
</tr>

<tr><th align=left>Term</th>
<td>
$term_string</td>
</tr>

<tr><th align=left valign=top>Class Description</th>
<td align=top>$pretty_description</td>
</tr>

<tr><th colspan=2 align=left>Will the class web page and documents be open to the public?</th></tr>
<tr><td></td>
<td valign=top>[util_PrettyBoolean $public_p]</td>
</tr>"

set currently_unused_html "




<tr><th align=left>Do students recieve grades?
<td valign=top>[util_PrettyBoolean $grades_p]
</td>
</tr>

<tr><th align=left>Will the class have teams?
<td valign=top>[util_PrettyBoolean $teams_p]
</td>
</tr>

<tr><th align=left>Will the class have exams?
<td valign=top>[util_PrettyBoolean $exams_p]
</td>
</tr>

<tr><th align=left>Will the class have a final exam?
<td valign=top>[util_PrettyBoolean $final_exam_p]
</td>
</tr>
"



append doc "
</td>
</tr>

<tr>
<td colspan=2 align=left><em>Use the back button on your browser if any of this information is incorrect.</em></td></tr>

<td colspan=2 align=center>
<br>
<form method=post action=\"class-add-3\">
[export_form_vars group_name term_id where_and_when public_p grades_p exams_p final_exam_p description subject_id instructor_id teams_p class_id]

<input type=submit value=\"Create a New Class\"></td>

</form>
</td>
</tr>
</table>



</blockquote>
[ad_footer]
"

doc_return 200 text/html $doc
