ad_page_contract {
    this page inserts the class into the database as a member of
    this subject

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: class-add-3.tcl,v 1.2 2001/02/02 19:53:16 tarik Exp $
} {
    subject_id:integer,notnull
    instructor_id:integer,notnull
    group_name:notnull
    term_id:integer,notnull
    class_id:integer,notnull
    {where_and_when [db_null]}
    {public_p t}
    {grades_p t}
    {exams_p t}
    {final_exam_p t}
    {description [db_null]}
    {teams_p f}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
} -errors {
    subject_id {You must include the subject identification number.}
    group_name {You must name your class.}
    term_id {Please select a term or specify \"no term\"}
    class_id {You must specify a class ID.}
}

set user_id [ad_verify_and_get_user_id]


#db_with_handle db {set user_id [edu_subject_admin_security_check $db $subject_id]}

#lets check and make sure that it is not a double click
if {[db_string check_double_click "select count(group_id) from user_groups where group_id = :class_id"] > 0} {
    ad_returnredirect "index.tcl?subject_id=$subject_id"
    return
}



set term_name [db_string get_term_name "select term_name from edu_terms where term_id = :term_id"]


# we want to add a folder in the file system for the class and
# within that folder we want to create a problem sets, lecture notes,
# and handouts folder



# we get IDs for class_folder, assignments_folder, lecture_notes_folder, 
# handouts_folder and exams_folder...these are file_id and version_id and
# we build a list to do the inserts

# the class folder name has to be first because it is the parent of the rest
# of the folders

# we also build the sql update clause at the same time...the folder_name_list
# is a list of lists corresponding to the folder name and a list of related columns

set folder_name_list [list [list "$group_name Class Folder - $term_name"] [list "Assignments" assignments_folder_id] [list "Lecture Notes" lecture_notes_folder_id] [list "Handouts" handouts_folder_id] [list "Exams" exams_folder_id] [list "Projects" projects_folder_id]]

set folder_id_list [list]
set sql_update_statement [list]
set folder_count 0

while {[llength $folder_id_list] < [llength $folder_name_list]} {
    set id_list [db_list_of_lists get_fs_nextvals "select fs_file_id_seq.nextval as a, fs_version_id_seq.nextval as b from dual"]
    lappend folder_id_list "[list [lindex [lindex $folder_name_list $folder_count] 0] [lindex [lindex $id_list 0] 0] [lindex [lindex $id_list 0] 1]]"

    if {[llength [lindex $folder_name_list $folder_count]] > 1} {
	lappend sql_update_statement "[lindex [lindex $folder_name_list $folder_count] 1] = [lindex [lindex $id_list 0] 0]"
    }

    incr folder_count
}

# the order of this is as follows:
# 1. stuff all of the edu_class_info variables into an ns_set
# 2. create the class
# 3. create the roles for the class
# 4. create the four folders for the class
# 5. place pointers to the folders into the edu_class_info table
# we have to create the folders after we create the class because the
# folders reference the class and doing it the other way around would
# cause an error.


db_transaction {
    # throw all of the class variables into an ns_set so that the ad_user_group_add
    # will take care of putting them into the _info table
    
    set var_set [ns_set new]
    
    ns_set put $var_set term_id $term_id
    ns_set put $var_set where_and_when $where_and_when
    ns_set put $var_set public_p $public_p
    ns_set put $var_set grades_p $grades_p
    ns_set put $var_set exams_p $exams_p
    ns_set put $var_set final_exam_p $final_exam_p
    ns_set put $var_set description $description
    ns_set put $var_set teams_p $teams_p
    ns_set put $var_set subject_id $subject_id
    
    if ![ad_user_group_add -approved_p t -existence_public_p t -new_member_policy open -multi_role_p t -extra_values $var_set -group_id $class_id edu_class $group_name] {
	error "did not create group"
    }
    
    #create the role and actions for the class
    edu_set_class_roles_and_actions $class_id
    
    #finally, add the instructor to the class
    ad_user_group_user_add $instructor_id [edu_get_professor_role_string] $class_id 
    
    set depth 0
    set parent_id ""
    
    foreach folder $folder_id_list {
	set file_title [lindex $folder 0]
	set file_id [lindex $folder 1]
	set version_id [lindex $folder 2]

	db_dml insert_into_fs_files {
	    insert into fs_files
	    (file_id, file_title, owner_id, parent_id, folder_p, sort_key, depth, public_p, group_id)
	    values
	    (:file_id, :file_title, :user_id, :parent_id, 't',0, :depth, 'f', :class_id)
	}
	  
	# this if statement makes the first folder inserted the parent of all of
	# the rest of the folders.
	if {[empty_string_p $parent_id]} {
	    set parent_id [lindex $folder 1]
	    set depth 1
	}
	
	# now we want to insert a "dummy" version o that we can also create the permission
	# records
	
	db_dml insert_into_fs_versions "insert into fs_versions
	(version_id, file_id, creation_date, author_id)
	values
	(:version_id, :file_id, sysdate, :user_id)"

	db_with_handle db {
	    ns_ora exec_plsql $db "begin 
	    :1 := ad_general_permissions.grant_permission_to_all_users ( 'read', [lindex $folder 2], 'FS_VERSIONS' ); 
	    :1 := ad_general_permissions.grant_permission_to_all_users ( 'comment', [lindex $folder 2], 'FS_VERSIONS' ); 
	    end;"
	}
	
    }

ns_log Notice "EJC:[join $sql_update_statement ","]"

    db_dml update_eci "update edu_class_info 
    set [join $sql_update_statement ","],
    root_folder_id=:parent_id,
    last_modified = sysdate,
    last_modifying_user = :user_id,
    modified_ip_address = '[ns_conn peeraddr]'                      
    where group_id = :class_id"
    
    db_dml insert_into_cal_groups "
    insert into cal_groups(group_id) values (:class_id)
    "

fs_order_files $user_id $class_id $public_p
}

ad_returnredirect "[portals_get_portal_property base_url [portals_get_portal_id group $class_id [portals_domain_id_from_domain_name class]]]/"




