# /packages/education/www/subject/admin/department-add-2.tcl

ad_page_contract {
    this page allows the user to add more departments to the given subject
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: department-add-2.tcl,v 1.1.1.1 2001/01/24 18:03:26 tarik Exp $
} {
    subject_id:integer,notnull
    subject_name:notnull
    department_id:array
    grad_p:array
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    valid_subject_id_p -requires {subject_id} {
	if ![db_0or1row check_valid_subject_id "select subject_name from edu_subjects where subject_id = :subject_id"] {
	    ad_complain "The subject identification number you have entered is not valid."
	}
    }
} -errors {
    subject_id {You must provide a subject identification number.}
    subject_name {You must provide a subject name.}
}

# expecting subject_id, and sparse arrays of grad_p_${department_id}
# and department_id_${department_id} and subject_name

#set user_id [edu_subject_admin_security_check $db $subject_id]

set user_id [ad_verify_and_get_user_id]

# lets loop through and get a list of department_id's that now have subject_names
# we just grab all department_ids instead of doing the same query as the previous
# page because there is only a small number of departments so it is quicker to
# loop through them then to join 3 tables in a big select.

set department_ids [db_list_of_lists get_dept_info "select department_id, department_name from edu_departments order by lower(department_name)"]

set department_list [list]
foreach department_info $department_ids {
    set new_department_id [lindex $department_info 0]
    set department_name [lindex $department_info 1]
    if {[info exists department_id($new_department_id)] && ![empty_string_p [set department_id($new_department_id)]]} {
	
	# here we make a list to pass to the next page.  This consists of,
	# in order, the department_id, subject_number, department_name, and
	# grad_p for the subject

	lappend department_list [list $new_department_id "$department_id($new_department_id)" "$department_name" $grad_p($new_department_id)]
    }
}


# if they did not select anything then redirect them back to the subject page

if {[llength $department_list] == 0} {
    ad_returnredirect "index.tcl?subject_id=$subject_id"
    return
}


set return_string "
[ad_header "[ad_system_name] Administration - Subjects"]

<h2>Add $subject_name to a Department</h2>

[ad_context_bar_ws [list "../" "Subjects"] [list "index.tcl?subject_id=$subject_id" "$subject_name Administration"] "Edit Subject"]

<hr>
<blockquote>

<form method=post action=\"department-add-3.tcl\">

[export_form_vars department_list subject_id]

Are you sure you wish to add $subject_name to the following departments?
<ul>
"

foreach department $department_list {
    append return_string "
    <li>[lindex $department 2]
    <ul>
    <li>Subject Number: [lindex $department 1] 
    <li>Grad? [util_PrettyBoolean [lindex $department 3]]
    </ul>
    "

}

append return_string "
</ul>
<br>
<input type=submit value=\"Add Department\">
</form>
</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string
