# /packages/education/www/subject/admin/department-add.tcl

ad_page_contract {
    this page allows the user to add more departments to the given subject
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: department-add.tcl,v 1.1.1.1 2001/01/24 18:03:26 tarik Exp $
} {
    subject_id:integer,notnull
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    valid_subject_id_p -requires {subject_id} {
	if ![db_0or1row check_valid_subject_id "select subject_name from edu_subjects where subject_id = :subject_id"] {
	    ad_complain "The subject identification number you have entered is not valid."
	}
    }
} -errors {
    subject_id {You must provide a subject identification number.}
}

#set user_id [edu_subject_admin_security_check $db $subject_id]

set user_id [ad_verify_and_get_user_id]

# if the person is a site-wide admin, give them the option to add any 
# department in the system that does not already have the class
# else,
# give the person the option to add this subject to a department if they
# are the admin of the department and the subject is not already in
# the given deparmtment
# else,
# supply an error message

set n_other_departments 0

if { [ad_administrator_p] } {
    set sql "select department_name, 
    department_id 
    from edu_departments 
    where department_id not in (select department_id 
    from edu_subject_department_map map 
    where map.department_id = edu_departments.department_id 
    and subject_id = :subject_id)
    order by lower(department_name)"

} else {
    # we want to select the departments that the person is a member of 
    set sql "select dept.department_id,
    dept.department_name
    from user_group_map map,
    edu_departments dept
    where map.group_id = dept.department_id
    and map.user_id = $user_id
    and dept.department_id not in (select
    sdmap.department_id
    from edu_subject_department_map sdmap
    where sdmap.subject_id = :subject_id)
    order by lower(department_name)"
}

set n_departments 0


set html "

[ad_header "[ad_system_name] Administration - Subjects"]
<h2>Add $subject_name to a Department</h2>

[ad_context_bar_ws [list "../" "Subjects"] [list "index.tcl?subject_id=$subject_id" "$subject_name Administration"] "Edit Subject"]

<hr>
<blockquote>

To add a department, enter in the course number.

<form method=post action=\"department-add-2.tcl\">
<table>
<tr>
<th align=left>Department Name<br><Br></td>
<td valign=top align=center><b>Department<br>Number</b></td>
<td valign=top align=center><b>Is this a Graduate<br>Subject?</b></td>
</tr>
"

db_foreach main_query $sql {
    incr n_departments
    append html "
    <tr>
    <td align=left>$department_name
    </td>
    <td align=center>
    <input type=text size=10 name=department_id.${department_id} maxlength=20>
    </td>
    <td align=center>
    <input type=radio name=grad_p.${department_id} value=t> Yes
    <input type=radio name=grad_p.${department_id} value=f checked> No
    </td>
    </tr>"
} if_no_rows {
    ad_return_complaint 1 "<li> There are no departments available for this class."
    return
}


set return_string "
$html
<tr>
<td colspan=2 align=center>
<input type=submit value=\"Continue\">
</td>
</tr>
</table>

[export_form_vars subject_id subject_name]

</form>
</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string









