# /packages/education/www/subject/admin/index.tcl

ad_page_contract {
    This page is the front page seen by the person running the subject
    
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: index.tcl,v 1.1.1.1 2001/01/24 18:03:26 tarik Exp $
} {
    subject_id:integer,notnull
    {orderby "term_name,group_name,class_short_name"}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    valid_subject_id_p -requires {subject_id} {
	if ![db_0or1row check_valid_id "select subject_name, description, credit_hours, prerequisites, professors_in_charge from edu_subjects where subject_id = :subject_id"] {
	    ad_complain "The subject identification number you have entered is not valid."
	}
    }
} -errors {
    subject_id {You must provide a subject identification number.}
}

set user_id [ad_verify_and_get_user_id]
db_1row get_info "select subject_name, description, credit_hours, prerequisites, professors_in_charge from edu_subjects where subject_id = :subject_id"

# if they are a site wide admin we want to give them all possible links
set site_wide_admin_p [ad_administrator_p]

set return_string "
[ad_header "Subject Administration @ [ad_system_name]"]

<h2>$subject_name</h2>

[ad_context_bar_ws [list "../" "Subjects"] "Subject Administration"]

<hr>
<blockquote>
"


# show ALL classes that are not deleted (i.e. member policy not 'closed')

set table_def {
    {group_name {Class Name} {} {<td><a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name class]]]/\">$class_name</a></td>} }
    {class_short_name {Short Name} {} {<td><a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $group_id [portals_domain_id_from_domain_name class]]]/\">$class_short_name</a></td>} }
    {term_name  {Term}       {t.start_date $order} c}
    {action     {}           {} {<td>\[<a href=\"remove-class?[export_url_vars group_id subject_id]\">remove</a>\]</td>} }
}


# it is okay to use $subject_id here instead of the bind variable, because the query above would have caught any error
# besides, it doesn't work otherwise
set sql "
    select class_name,
    class_id as group_id,
    class_short_name,
    term_name
    from edu_terms t, 
    edu_classes cl,
    user_groups ug
    where ug.group_id=class_id
    and cl.subject_id=$subject_id
    and cl.term_id=t.term_id
    and ug.new_member_policy <> 'closed'
    [ad_order_by_from_sort_spec $orderby $table_def]
"

set class_table [ad_table -Textra_vars {subject_id} -Torderby $orderby -Tmissing_text "" classes_table $sql $table_def]

if [empty_string_p $class_table] {
    append return_string "<h3>No classes are currently being offered in this subject.</h3>"
} else {
    append return_string "
    <h3>Classes offered in this subject:</h3>
    <blockquote>
    $class_table
    </blockquote>"
}

set target_url "/education/subject/admin/class-add"

set browse_type "select_instructor"

append return_string "
<ul><li><a href=\"users.tcl?[export_url_vars target_url subject_id browse_type]\">Add a class in this subject</a></ul>
<a href=\"edit.tcl?subject_id=$subject_id\">Edit subject properties</a>
<br><br>
"

# we are doing the view on the fly so that we can tell if the person is
# an admin for the given deparment so we know whether or not to show the
# link

set n_departments 0

set table_def {
    {subject_number {Subject Number} {} {
	<td>
	$subject_number
	[if ![string compare $grad_p t] {
	    subst "G"
	}] </td>
	}
    }
    {department_name {Department} {} {<td><a href=\"/education/department/admin/one?[export_url_vars department_id]\">$department_name</a></td>}}
}

set sql "
    select map.department_id, 
    department_name, 
    subject_number,
    grad_p,
    count(admin_list.group_id) as department_admin_p
    from edu_subject_department_map map, 
    edu_departments dept,
    (select group_id 
    from user_group_map 
    where user_id = $user_id 
    and role = 'administrator') admin_list
    where dept.department_id = map.department_id 
    and map.subject_id = $subject_id
    and map.department_id = admin_list.group_id(+)
    group by map.department_id, 
    department_name, 
    subject_number, 
    grad_p
    [ad_order_by_from_sort_spec $orderby $table_def]
"

set dept_table [ad_table -Tmissing_text "" -Torderby $orderby department_table $sql $table_def]

if [empty_string_p $dept_table] {
    append return_string "<em>This subject is not currently affiliated with any department.</em>"
} else { 
    append return_string "
    <h3>Departments affiliated with this subject:</h3>
    <blockquote>
    $dept_table
    </blockquote>
    "
}


# if the person is a site-wide admin, give them the option to add a 
# department if there are still departments that do not have this subject
# else,
# give the person the option to add this subject to a department if they

# are the admin of the department and the subject is not already in
# the given deparmtment
# else,
# don't give a link to add a department

set n_other_departments 0

if { $site_wide_admin_p == 1 } {
    set n_other_departments [db_string count_depts "select count(department_id) from edu_departments"]
} else {
    # we want to select the departments that the person is admin for 
    # but are not currently affiliated with the subject
    set n_other_departments [db_string count_other_depts "select count(dept.department_id)
                                from user_group_map map,
                                     edu_departments dept
                               where map.group_id = dept.department_id
                                 and map.user_id = :user_id
                                 and dept.department_id not in (select
                                           sdmap.department_id
                                           from edu_subject_department_map sdmap
                                          where sdmap.subject_id = :subject_id)
                            order by lower(department_name)"]
}

if {$n_departments < $n_other_departments} {
    append return_string "
    <ul><li><a href=\"department-add.tcl?[export_url_vars subject_id subject_name]\">Add this subject to another department</a></ul>
    "
}


append return_string "
</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string
