# /www/education/subject/admin/user-search.tcl


ad_page_contract {
    this page allows the person to select a user to lead a class
 
    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: user-search.tcl,v 1.2 2001/02/02 21:48:46 tarik Exp $
} {
    subject_id:integer,notnull
    email
    last_name
    {target_url class-add.tcl}
    {param_list ""}
    {browse_type ""}
} -validate {
    accessible_p {
	if ![ad_administrator_p] {
	    ad_complain "You do not have permission to access this page"
	}
    }
    email_or_last_name {
	if { [empty_string_p $email] && [empty_string_p $last_name] } {
	    ad_complain "You need to search for a customer by either Last Name or Email\n"
	}
    }
} -errors {
    subject_id {You must provide a subject identification number.}
}

# param_list should be any variables that need to be passed on
# to the next page.  These variables should have already been
# url encoded.  So, the calling page should have a line that looks like
# set param_list [ad_urlencode var1 var2 ...] and then
# [export_url_vars $param_list]

if {[string compare [string tolower $browse_type] select_instructor] == 0} {
    set begin_header "Select an Instructor/Moderator for the Class"
    set nav_bar_value "Select Instructor"
    set instructions "To select a user as the instructor, please click on their name."
    } else {
    set begin_header "Site Wide Users Search Results"
    set nav_bar_value "Site Wide Users"
    set instructions "To view information about a user, simply click on their name."
}


#lets strip the leading and trailing spaces off of the last_name and email
if {[info exists last_name]} {
    set bb last_name
    regexp {[ ]*(.*[^ ])} $last_name match last_name
}

if {[info exists email]} {
    regexp {[ ]*(.*[^ ])} $email match email
    set aa '$email'
}


set return_string "
[ad_header "Add a Class @ [ad_system_name]"]
<h2> $begin_header </h2>
$title
<br>
<br>

[ad_context_bar_ws [list "../" "Subjects"] [list "index.tcl?subject_id=$subject_id" "Subject Administration"] "Add a Class"]

<hr>
"

set text ""
set counter 0


### search by last_name and email
if { ![empty_string_p $last_name] && ![empty_string_p $email] } {
    set query_string "select distinct users.user_id, first_names, last_name, email from users, user_group_map
    where upper(last_name) like '%[DoubleApos [string toupper $last_name]]%'
    and upper(email) like '%[DoubleApos [string toupper $email]]%'
    and user_group_map.user_id = users.user_id
    order by lower(last_name), first_names"
    set title "Users whose last name contains '$last_name' and email contains '$email'"
}

## search by email
if { [empty_string_p $last_name] && ![empty_string_p $email] } {
    set query_string "select distinct users.user_id, first_names, last_name, email from users, user_group_map 
    where upper(email) like '%[DoubleApos [string toupper $email]]%'
    and user_group_map.user_id = users.user_id
    order by lower(last_name), first_names"
    set title "Users whose email contains '$email'"
}

## search by last_name
if { ![empty_string_p $last_name] && [empty_string_p $email] } {
    set query_string "select distinct users.user_id, first_names, last_name, email from users, user_group_map 
    where upper(last_name) like '%[DoubleApos [string toupper $last_name]]%'
    and user_group_map.user_id = users.user_id
    order by lower(last_name), first_names"
    set title "Users whose last name contains '$last_name'"
}

db_foreach main_query $query_string {
    incr counter
    append text "<li><a href=\"$target_url?user_id=$user_id&$param_list\">$last_name, $first_names ($email)</a>\n"
}


if { $counter > 0 } {

    append return_string "
    $title:
    <ul>
    $text
    <br><br>
    </ul>
    $instructions
    "
} else {
    append return_string "We found no matches to your query for $title, please check your information again\n"
}


append return_string "
<br>
[ad_footer]
"

doc_return 200 text/html $return_string





