# /packages/education/www/subject/one.tcl

ad_page_contract {
    this page shows information about the requested subject

    @author Randy Graebner (randyg@arsdigita.com)
    @author Aileen Tang (aileen@mit.edu)
    @creation-date January 2000
    @cvs-id $Id: one.tcl,v 1.1.1.1 2001/01/24 18:03:25 tarik Exp $
} {
    subject_id:integer,notnull
} -errors {
    subject_id {You must include a subject identification number.}
}

set site_wide_admin_p [ad_administrator_p]

if ![db_0or1row get_s_info "select subject_name, description, credit_hours, prerequisites, professors_in_charge from edu_subjects where subject_id = :subject_id"] {
    ad_complain "The subject identification number you have entered is not valid."
}

set return_string "

[ad_header "[ad_system_name] - Add a Subject"]
<h2>$subject_name</h2>

[ad_context_bar_ws [list "" "Subjects"] "One Subject"]

<hr>
<blockquote>

<table>

<tr>
<th align=left valign=top>
Subject Name:
</td>
<td>
$subject_name
"

if $site_wide_admin_p {
    append return_string "
    \[<a href=\"admin/index?[export_url_vars subject_id]\">manage</a>\]
    "
}

append return_string "
</td>
</tr>

<tr>
<th align=left valign=top>
Description:
</td>
<td>
[address_book_display_as_html $description]
</td>
</tr>

<tr>
<th align=left valign=top>
Credit Hours:
</td>
<td>
$credit_hours
</td>
</tr>

<tr>
<th align=left valign=top>
Prerequisites:
</td>
<td>
[address_book_display_as_html $prerequisites]
</td>
</tr>

<tr>
<th align=left valign=top>
Professors in Charge:
</td>
<td>
$professors_in_charge
</td>
</tr>

</table>

<h3>Departments</h3>
<ul>
"

db_foreach get_d_info {
    select map.department_id, 
    department_name, 
    subject_number 
    from edu_subject_department_map map, 
    edu_departments 
    where edu_departments.department_id = map.department_id 
    and map.subject_id = :subject_id
} {    
    # if site wide admin show link to dept admin page
    if $site_wide_admin_p {
	append return_string "<li><a href=\"../department/admin/one.tcl?[export_url_vars department_id]\">$department_name</a>; $subject_number"
    } else {
	append return_string "<li>$department_name; $subject_number \n"
    }
} if_no_rows {
    append return_string "<li>This subject is not currently affiliated with any department."
}
    
append return_string "
</ul>
<h3>Classes</h3>
<ul>
"

db_foreach get_c_info "select class_name, class_id, term_name, class_short_name
from edu_terms t, edu_classes c
where c.subject_id=:subject_id
and c.term_id=t.term_id
order by
t.start_date" {
    append return_string "
    <li><a href=\"[portals_get_portal_property base_url [portals_get_portal_id group $class_id [portals_domain_id_from_domain_name class]]]/\">$class_name ($term_name)</a>"
}

append return_string "
</ul>

</blockquote>
[ad_footer]
"

doc_return 200 text/html $return_string




