# /file-storage/file-delete-2.tcl
ad_page_contract {
    marks a file deleted (but does not actually remove anything 
    from the database); if a folder, marks the entire subtree deleted
    
    @author aure@arsdigita.com
    @creation-date July 1999
    @cvs-id file-delete-2.tcl,v 3.8.2.2 2000/07/21 22:05:16 mdetting Exp

    modified by randyg@arsdigita, January, 2000 to use the general permissions module
} {
    {file_id}
    {group_id ""}
    {source ""}
    {return_url}
} -validate {
    permission_to_delete_p -requires {file_id} {
	set user_id [ad_maybe_redirect_for_registration]

	set version_id [db_string unused "
	select version_id from fs_versions_latest where file_id = :file_id"]

	if {![portals_fs_check_edit_p $user_id $version_id]} {
	    ad_complain "You are not allowed to delete this file\n"
	}
    }
    not_allowed_to_delete_root_folder_p -requires {file_id} {
	if [db_0or1row get_group_id "select group_id as file_group_id from fs_files where file_id = :file_id"] {
	    if ![empty_string_p $file_group_id] {
		set root_folder [portals_fs_group_root_folder $file_group_id]
		if {$root_folder && $root_folder == $file_id} {
		    ad_complain "You are not allowed to delete the root folder"
		}
	    }
	}
    }
} -errors {
    file_id {You did not provide a file_id}
}

set user_id [ad_maybe_redirect_for_registration]

# Determine if we are working in a Group, or our personal space
# this is based if no group_id was sent - then we are in
# our personal area - otherwise the group defined by group_id

# is this a folder ? Get all its children
set folder_p [db_string unused "
    select folder_p from fs_files where file_id=:file_id"]

db_transaction {

if {$folder_p=="t"} {

    set children_query "
        select file_id
        from   fs_files
        connect by prior file_id = parent_id
        start with file_id = :file_id"

    # note that the "children" list includes the top-level folder
    set children_list [db_list unused $children_query]
    
    set sql_faux_delete "
        update fs_files
        set    deleted_p = 't'
        where  file_id in ( [join $children_list ", "] ) "
    
    
} else {
    set sql_faux_delete "
        update fs_files
        set    deleted_p = 't'
        where  file_id = $file_id"
}

db_dml unused $sql_faux_delete

fs_order_files

}

ad_returnredirect $return_url
