# /packages/file-storage/www/upload-new-2.tcl
 
ad_page_contract {
    insert both a file and a version into the database

    ADDED 8/20: the ability to upload a url. We take either
    a url or a file, but not both. We look for an URL first.

    @author aure@arsdigita.com
    @creation-date July 1999
    @cvs-id upload-new-2.tcl,v 3.11.2.9 2000/10/26 19:54:29 kevin Exp

    modified by randyg@arsdigita.com, January 2000 
    to use the general permissions system
    modified by ejc@arsdigita.com, January 2001 for portals-specific functionality,
    specifically the granting of read permissions to all members of a group
    
    files, urls and folders all have at least one record in fs_vesion so that the
    permissions will work properly.  In addition, this leaves itself open to the
    options of placing permissions on the folders
} {
    file_id:integer
    file_title:trim,notnull
    {group_id ""}
    parent_id:integer
    {public_p "f"}
    {return_url}
    {upload_file ""}
    {url ""}
    {version_id:integer}
    {version_description:string_length(max|500) ""}
    {doc_type ""}
} -validate {
    if_group_must_be_admin_to_upload {
	if {[info exists group_id] && ![empty_string_p $group_id] && ![ad_user_group_authorized_admin_or_site_admin [ad_verify_and_get_user_id] $group_id]} {
	    ad_complain "You are not allowed to upload files for this group\n"
	}
    }
    syllabus_for_classes_only {
	if {[info exists doc_type] && ![string compare $doc_type syllabus] && ![db_0or1row check_class_p "select group_name from user_groups where group_id = :group_id and group_type = 'edu_class'"]} {
	    ad_complain "Syllabus is not allowed for this type of group."
	}
    }
} -errors {
    parent_id {You must provide a location for the file.}
} 

set user_id [ad_maybe_redirect_for_registration]

# check the user input first

set exception_text ""
set exception_count 0

# check if the url starts with http:// or https:// or ftp://
if { ![empty_string_p $url] && ![regexp -nocase {^(http://|https://|ftp://)} $url] } {
    append exception_text "<li>The URL must start with http://, https:// or ftp://\n"
    incr exception_count
}

if ![string compare $url http://] {
    set url ""
}

if {[empty_string_p $url] && (![info exists upload_file] || [empty_string_p $upload_file])} {
    append exception_text "<li>You need to upload a file or enter a URL\n"
    incr exception_count
}

if {![empty_string_p $url] && ![empty_string_p $upload_file]} {
    append exception_text "<li>You can not both add a url and upload a file"
    incr exception_count
}

if {$public_p == "t" && ![ad_parameter PublicDocumentTreeP fs]} {
    append exception_text "<li> [ad_system_name] does not support a public directory tree. \n"
    incr exception_count
} 

if ![empty_string_p $group_id] {

	#modified by ejc@arsdigita.com so that only admins can upload (validation, above)
	# old code:
#    if { ![ad_user_group_member $group_id $user_id] && ![ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {
#	append exception_text "<li>You are not a member of this group.\n"
#	incr exception_count
#    }

} else {
    set group_id ""
}

if { $doc_type=="syllabus" && ![empty_string_p [db_string check_if_there_is_syllabus "select fs.file_id as file_id
from fs_files fs
where fs.file_id = (select syllabus_id from edu_class_info where group_id=:group_id)
and deleted_p='f'" -default ""] ] } {
    append exception_text "<li> you already have uploaded a syllabus.\n"
    incr exception_count
}

if { $exception_count > 0 } {
    ad_return_complaint $exception_count $exception_text
    return 0
}

if {$doc_type == "syllabus"} {
    set parent_id [db_string get_parent_id "select root_folder_id from edu_class_info where group_id=:group_id"]
}

if { [empty_string_p $url] } {
    # We are processing a file, not a URL.
    # get the file from the user.
    # number_of_bytes is the upper-limit
    set max_n_bytes [ad_parameter MaxNumberOfBytes fs]
    
    set tmp_filename [ns_queryget upload_file.tmpfile]

    if { ![empty_string_p $max_n_bytes] && ([file size $tmp_filename] > $max_n_bytes) } {
	ad_return_complaint 1 "Your file is larger than the maximum permissible upload size:  [util_commify_number $max_n_bytes] bytes"
	return 0
    }

    set file_extension [string tolower [file extension $upload_file]]
    # remove the first . from the file extension
    regsub "\." $file_extension "" file_extension

    set guessed_file_type [ns_guesstype $upload_file]

    set n_bytes [file size $tmp_filename]

    # strip off the C:\directories... crud and just get the file name
    if ![regexp {([^//\\]+)$} $upload_file match client_filename] {
        # couldn't find a match
        set client_filename $upload_file
    }

    set version_insert "
    insert into fs_versions (
        version_id, 
        file_id, 
        version_description, 
        creation_date, 
        author_id, 
        client_file_name, 
        file_type, 
        file_extension, 
        n_bytes, 
        version_content)
    values (
        :version_id, 
        :file_id, 
        :version_description, 
        sysdate, 
        :user_id, 
        :client_filename,
        :guessed_file_type, 
        :file_extension, 
        :n_bytes, 
        empty_blob())
    returning version_content into :1" 
} else {
    # We are processing a url, not a file.
    set version_insert "
	insert into fs_versions
	(version_id, file_id, version_description, creation_date, author_id, url)
	values
	(:version_id, :file_id, :version_description, sysdate, :user_id, :url)"
}

db_transaction {
    db_dml file_insert {
	insert into fs_files (
			      file_id, 
			      file_title, 
			      owner_id, 
			      parent_id, 
			      sort_key, 
			      depth, 
			      group_id, 
			      public_p)
	values (
		:file_id, 
		:file_title,
		:user_id, 
		:parent_id,
		0,
		0, 
		:group_id, 
		:public_p)
    }
	   
    if { [empty_string_p $url] } {
	db_dml version_insert $version_insert -blob_files [list $tmp_filename]
    } else {
	db_dml version_insert $version_insert
    }
    #if this is a syllabus, then set syllabus_id in edu_class_info to this file

    if { $doc_type == "syllabus" } {
	
	db_dml updating_syllabus_id "update edu_class_info set syllabus_id=:file_id where group_id=:group_id"
    }
    # now that the version has been inserted, let's set up the permissions

    if { [string compare $public_p t] == 0 } {
	db_exec_plsql fs_public_permission_insert {
	    begin
	    :1 := ad_general_permissions.grant_permission_to_all_users
	    ('read', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_all_users
	    ('write', :version_id, 'FS_VERSIONS');
	    :1 := ad_general_permissions.grant_permission_to_all_users
	    ('comment', :version_id, 'FS_VERSIONS');
	    end;
	} 
    }
    
    db_exec_plsql fs_user_permission_insert {
	begin
	:1 := ad_general_permissions.grant_permission_to_user
	(:user_id, 'read', :version_id, 'FS_VERSIONS');
	:1 := ad_general_permissions.grant_permission_to_user
	(:user_id, 'write', :version_id, 'FS_VERSIONS');
	:1 := ad_general_permissions.grant_permission_to_user
	(:user_id, 'comment', :version_id, 'FS_VERSIONS');
	:1 := ad_general_permissions.grant_permission_to_user
	(:user_id, 'administer', :version_id, 'FS_VERSIONS');
	end;
    }

    if {[info exists group_id] && ![empty_string_p $group_id]} {
	db_exec_plsql fs_group_permission_insert {
	    begin
	    :1 := ad_general_permissions.grant_permission_to_group
	    (:group_id, 'read', :version_id, 'FS_VERSIONS');
	    end;
	}
    }

    fs_order_files
} on_error {
    # insert failed; let's see if it was because of duplicate submission

    if { [db_string num_duplicates "select count(*) from fs_files where file_id = $file_id"] == 0 } {
	
	ns_log Error "/file-storage/create-folder-2.tcl choked:  $errmsg"
	
	ad_return_error "Insert Failed" "The Database did not like what 
	        you typed.  This is probably a bug in our code.  Here's what 
	        the database said:
	        <blockquote>
	        <pre>$errmsg</pre>
	        </blockquote>"
	ad_script_abort
    } else {
	ad_returnredirect $return_url
	return
    }
}
	
ad_returnredirect $return_url
