# /packages/file-storage/www/upload-new.tcl

ad_page_contract {
    Serve the user a form to upload a new file or URL

    @author aure@arsdigita.com
    @creation-date July 1999
    @cvs_id upload-new.tcl,v 3.6.6.5 2000/09/22 01:37:49 kevin Exp

    modified by randyg@arsdigita.com, January 2000 to use the general permisisons system
    modified by ejc@arsdigita.com Jan 2001 for portals-specific functionality
} {
    return_url
    {group_id ""}
    {public_p ""}
    {doc_type ""}
    {this_folder ""}
} -validate {
    if_group_must_be_admin_to_upload {
	if {[info exists group_id] && ![empty_string_p $group_id] && ![ad_user_group_authorized_admin_or_site_admin [ad_verify_and_get_user_id] $group_id]} {
	    ad_complain "You are not allowed to upload files for this group\n"
	}
    }
    syllabus_for_classes_only {
	if {![empty_string_p $group_id] && ![string compare $doc_type syllabus] && ![string compare edu_class_info [db_string get_group_type "select group_type from user_groups where group_id = :group_id"]]} {
	    ad_complain "Syllabus is not allowed for this type of group."
	}
    }
}

set user_id [ad_maybe_redirect_for_registration]

set title "Upload New File/URL"

# Determine if we are uploading to a Group, the public area, or personal area

# if public_p = 't', we are uploading to the public area
# if  a group_id was sent - then we are uploading to a group defined
#           by group_id
# otherwise, to our personal area

set exception_text ""
set exception_count 0

if {$public_p == "t" && ![ad_parameter PublicDocumentTreeP fs]} {
    incr exception_count
    append exception_text "
        [ad_system_name] does not support a public directory tree."
}

if { ![empty_string_p $group_id]} {

    set group_name [db_string group_name_get {
	select group_name 
	from   user_groups 
        where  group_id = :group_id } ]

    # we are in the group tree

	#modified by ejc@arsdigita.com so that only admins can upload (validation, above)
	# old code:
	# if { ![ad_user_group_member $group_id $user_id] && ![ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {
	#    append exception_text "
	#    <li>You are not a member of group <cite>$group_name</cite>\n"
	#    
	#    incr exception_count

#    } else {

	set navbar [ad_context_bar_ws \
		[list "" [ad_parameter SystemName fs]] \
		[list $return_url "$group_name document tree"] \
		$title]

 #   }

    set public_p "f"

} elseif { $public_p == "t" } {
 
    # we are in the public tree

    set navbar [ad_context_bar_ws [list "" [ad_parameter SystemName fs]] $title]
    set group_id ""

} else  {

    # we are in the personal tree

    set navbar [ad_context_bar_ws [list "" [ad_parameter SystemName fs]]\
	                          [list "private-one-person" "Personal document tree"]\
				  $title]
    set group_id ""
    set public_p "f"
}

if { $exception_count > 0 } {
    ad_return_complaint $exception_count $exception_text
    return 0
}

# get the next sequence values for double click protection

set file_id    [db_string unused "
    select fs_file_id_seq.nextval from dual"]
set version_id [db_string unused "
    select fs_version_id_seq.nextval from dual"]

if {$doc_type == "syllabus"} {
    set parent_id [portals_fs_group_root_folder $group_id]
}

set page_content "
[ad_header $title]

<h2>$title</h2>

<hr align=left>

<form enctype=multipart/form-data method=POST action=upload-new-2>

[export_form_vars file_id version_id return_url group_id public_p doc_type]

<table border=0>
<tr>
<td align=right>URL: </td>
<td><input type=input name=url size=40 value=\"http://\"></td>
</tr>

<tr>
<td align=right><EM>or</EM> filename: </td>
<td><input type=file name=upload_file size=20></td>
</tr>

<tr>
<td>&nbsp;</td>
<td><font size=-1>Use the \"Browse...\" button to locate your file, 
    then click \"Open\". </font></td>
</tr>"

if { $doc_type != "syllabus" } {
    append page_content "
    <tr>
    <td align=right> Title: </td>
    <td><input size=30 name=file_title></td>
    </tr>
    
    <tr>
    <td valign=top align=right> Description: </td>
    <td colspan=2><textarea rows=5 cols=50 name=version_description wrap></textarea></td>
    </tr>
    
    <tr>
    <td align=right>Location:</td>
    <td>[portals_fs_folder_def_selection $user_id $group_id $public_p $this_folder $this_folder]</td>
    </tr>
    "
} else {
    append page_content "
    <input type=hidden name=file_title value=syllabus>
    <input type=hidden name=version_description value=syllabus>
    <input type=hidden name=parent_id value=$parent_id>"
}

append page_content "
<tr>
<td>&nbsp;</td>
<td>&nbsp;</td>
</tr>

<tr>
<td></td>
<td><input type=submit value=\"Submit and Upload\">
</td>
</tr>

</table>

</form>

[ad_footer [fs_system_owner]]"

# serve the page

doc_return  200 text/html $page_content

