# /file-storage/url-edit.tcl

ad_page_contract {
    allows the user to edit information about an URL

    @author Mark Dettinger <dettinger@arsdigita.com>
    @creation-date May 2000
    @cvs-id url-edit.tcl,v 1.1.2.2 2000/09/22 01:37:49 kevin Exp
} {
    {return_url}
    {file_id:integer}
    {group_id:integer ""}
} -validate {
    permission_to_edit_p -requires {file_id} {
	set user_id [ad_maybe_redirect_for_registration]

	set version_id [db_string unused "
	select version_id from fs_versions_latest where file_id = :file_id" -default ""]

	if { [empty_string_p $version_id]} {
	    ad_complain "The file you have requested does not exist."
	} elseif {![portals_fs_check_edit_p $user_id $version_id]} {
	    ad_complain "You are not allowed to edit this file\n"
	}
    }
} -errors {
    file_id {You did not provide a URL.}
}


set title "Edit Properties"

db_1row file_lsit {
    select fsf.file_title,
           decode ( fsf.folder_p, 't', 'Folder', 'File') as object_type,
           fsvl.file_type,
           ad_general_permissions.user_has_row_permission_p ( :user_id, 'read', fsvl.version_id, 'FS_VERSIONS' ) as public_read_p,
           fsf.public_p
    from   fs_files fsf,
           fs_versions_latest fsvl
    where  fsf.file_id = :file_id
    and    fsf.file_id = fsvl.file_id
}

if ![empty_string_p $group_id] {
    set group_name [db_string get_group_name "
    select group_name 
    from   user_groups 
    where  group_id=$group_id"]
    
    set navbar [ad_context_bar_ws [list "" [ad_parameter SystemName fs]]\
	                          [list "private-one-group?group_id=$group_id" $group_name]\
				  [list $return_url "One File"]\
				  $title]
} else {
    set navbar [ad_context_bar_ws [list "" [ad_parameter SystemName fs]]\
	                          [list $return_url "One File"]\
				  $title]
}

set page_content "[ad_header $title]

<h2>$title</h2>

$navbar

<hr align=left>
<blockquote>
<form method=POST action=url-edit-2>

[export_form_vars file_id version_id return_url group_id object_type]

<table>
<tr>
<td align=right>URL Title: </td>
<td><input size=30 name=file_title value=\"$file_title\"></td>
</tr>"

append page_content "

<tr>
<td align=right>Location:</td>
<td>[fs_folder_selection $user_id $group_id $public_p $file_id]</td>
</tr>

<tr>
<td></td>
<td><input type=submit value=\"Update\">
</td>
</tr>
</table>

</form>
"

set object_name "$file_title"
set on_what_id $version_id
set on_which_table FS_VERSIONS

append page_content "
<ul>
<li><a href=\"/gp/administer-permissions?[export_url_vars return_url object_name on_what_id on_which_table]\">Edit Permissions</a>
</ul>


<h3>Severe actions</h3>

<ul>
<li><a href=url-delete?[export_url_vars group_id file_id return_url object_type]>Delete this URL</a>

</ul>
</blockquote>
[ad_footer [fs_system_owner]]"

# serve the page

doc_return  200 text/html $page_content

