# /packages/news/news-procs.tcl

ad_library {
    functions for the /news

    @author lin@arsdigita.com
    @creation-date 12-14-00
}

# ad_register_proc * /news news_redirect

ad_proc news_redirect { conn context } {

    Redirect to Enhanced News

} {

    ad_page_contract {} {
    }

    set url_file index
    set url [ns_conn url]
    regexp {news\/(.+)} $url match url_file
    ad_returnredirect "/news/$url_file"
    return
}

proc_doc news_decode { var_p } {Returns "yes" if pass in "t"; returns "no" if pass in "f" } {
    if { $var_p == "t" } {
	set ret "yes"
    } else {
	set ret "no"
    }
    return $ret
}


proc_doc news_get_admins { newsgroup_id } { Return a list of user_id of admins of the newsgroup} {
    # get admingroup_id
    db_1row ag_id "select
    admingroup_id, scope
    from newsgroups
    where newsgroup_id = :newsgroup_id"

    if { [empty_string_p $admingroup_id] } {
	if { $scope == "group" } {
	    set sql "select distinct( ugm.user_id ) 
	    from user_group_map ugm, newsgroups ng
	    where ng.newsgroup_id = :newsgroup_id
	    and ugm.group_id = ng.group_id
	    and ad_user_can_do_action_p(ugm.user_id, ugm.group_id, 'Administer Group')=1"
	} else {
	    return [list]
	}
    } else {
	set sql "select distinct( user_id )
	from user_group_map ugm, newsgroups ng
	where ugm.group_id = ng.admingroup_id
	  and ng.newsgroup_id = :newsgroup_id"
    }

    set admin_list [db_list admin_select $sql]
    return $admin_list
}

proc_doc news_is_admin_p { user_id news_group_id} { Check if the user is a
site-wide administrator or an
admin for the newsgroup (can either be a member of the admin group, or the 
admin (role) of the newsgroup if admin_group_id is null). If yes, then 1 is 
returned. Otherwise, 0 is returned.} {
    # if site-wide admin, returns 1
    if [ad_user_group_authorized_admin_or_site_admin $user_id $news_group_id] {
        return 1
    }

    set admin_list [news_get_admins $news_group_id]

    if { [lsearch $admin_list $user_id] != -1 } {
	return 1
    } else {
	return 0
    }
}

proc_doc news_get_user_priviledge { user_id {newsgroup_id 0} } { Returns the 
priviledge the user has to the newsgroup. Possible values are "Post" 
"Suggest" and "View", "". If no newsgroup_id is passed, then the highest
priviledge to all newsgroups are returned. } {
    # if site-wide admin, returns "Post"
    if [ad_administrator_p $user_id] {
        return "Post"
    }

    if { $newsgroup_id != 0 } {
	set clause " and newsgroup_id = $newsgroup_id"
    } else {
	set clause ""
    }

    set priviledge ""
    db_foreach check_priviledge "
    select scope, approval_policy, newsgroup_id, group_id
    from newsgroups
    where enabled_p = 't'
    $clause" {
	
	if { [ad_user_group_member $group_id $user_id]
	|| $scope == "public"
	|| $scope == "all_users"
	|| ($scope == "registered_users" && $user_id >0)
        } {
	    
	    if { $approval_policy == "open" ||
	    [news_is_admin_p $user_id $newsgroup_id] } {
		set priviledge "Post"
		break
	    }
	    if { $approval_policy == "wait" } {
		set priviledge "Suggest"
	    } else {
		if [empty_string_p $priviledge] {
		    set priviledge "View"
		}
	    }
	}
    }
    
    return $priviledge
}

proc_doc news_newsgroup_id_list { user_id {group_id 0}} { Returns the list of newsgroup_ids for the appropriate news items for this user and group. If the user_id exists (i.e. non zero) then the list includes the registered_users. If group_id is set, then the newsgroup for the group is added (if it exists). if only the user_id is passed in, then return all newsgroup_id for the group she belongs.} {

    # Build the newsgroup clause
    set scope_clause_list [list "scope = 'all_users'"]
    lappend scope_clause_list "scope = 'public'"
    
    if { $user_id != 0 } {
	lappend scope_clause_list "scope = 'registered_users'"
    }

    if { $group_id > 0 } {
	lappend scope_clause_list "(scope = 'group' and group_id = :group_id)"
    } else {
	if { $user_id > 0 } {
	    set group_id_list [db_list group_id_select "select group_id 
                         from user_group_map
	                 where user_id = :user_id"]
	    set str "(scope = 'group' and ( 1=0 "
	    foreach one_group_id $group_id_list {
		append str " or group_id = $one_group_id "
	    }
	    append str ") )"
	    lappend scope_clause_list $str
	}
    }

    return [db_list newsgroup_ids_by_scope \
	    "select newsgroup_id from newsgroups where 
             enabled_p = 't'
             and [join $scope_clause_list " or "]"]
}


proc_doc news_newsgroup_id_list_view { user_id } { Returns the list of 
newsgroup_ids the user has view priviledge of. } {
    set ng_id_list [list]

    db_foreach each_newsgroup "
    select newsgroup_id from newsgroups
    where enabled_p = 't'" {
        if {[news_get_user_priviledge $user_id $newsgroup_id] != ""} {
            lappend ng_id_list $newsgroup_id
        }
    }

    return $ng_id_list
}

proc_doc news_newsgroup_id_list_post { user_id } { Returns the list of newsgroup_ids to which this user can post or suggest items to.} {

    set ng_id_list [list]

    db_foreach each_newsgroup "select newsgroup_id from newsgroups
    where enabled_p = 't'" {
	set p [news_get_user_priviledge $user_id $newsgroup_id]
	if { ![empty_string_p $p] && ($p != "View") } {
	    lappend ng_id_list $newsgroup_id
	}
    }

    return $ng_id_list                   
}

proc_doc news_newsgroup_id_list_admin { user_id } { Returns the list of
newsgroup_ids the user administers. If the user is a site wide admin, then
all enabled newsgroup_ids are returned.  } {
    if [ad_administrator_p $user_id] {
        return [db_list ng_id_list "
        select newsgroup_id
        from newsgroups
        where enabled_p ='t'"]
    }

    set newsgroup_id_list [list]
    db_foreach admin_check "
    select newsgroup_id
    from newsgroups
    where enabled_p = 't' " {
	if [news_is_admin_p $user_id $newsgroup_id] {
	    lappend newsgroup_id_list $newsgroup_id
	}
    }
 
    return $newsgroup_id_list
}

proc_doc news_header { title {newsgroup_id 0} } { Returns the header for the specified newsgroup. If no newsgroup_id is passed in, then return the default header \[ad_header\] } {

    set header [ad_header $title]
    
    return $header
}

proc_doc news_footer { {newsgroup_id 0} } { Returns the footer for the specified newsgroup. If no newsgroup_id is passed in, then return the default footer \[ad_footer\] } {
    set footer [ad_footer]
    
    return $footer
}

proc_doc news_ap_display { ap newsgroup_id return_url} { This proc is for 
internal use only in an ad_table on admin index page} {
    
    set admin_list [news_get_admins $newsgroup_id]
#    This section disabled because a site-wide-admin or parent group admin could alwasy post and/or people could later be added to the adminstration group. caroline@arsdigita.com for education.
   #  if { [llength $admin_list] == 0 } {
#  	# no admin, so only open is allowed
#  	# set approval policy to open if it's not
#  	if { $ap != "open" } {
#  	    db_transaction {
#  		db_dml set_ap_open "update newsgroups
#  		set approval_policy = 'open'
#  		where newsgroup_id = :newsgroup_id"
#  	    }
#  	}
#	return "<b>open</b> *"
#    } else {
	set open_link_str "<a href=/news/admin/toggle?proc=news_ap_update&newsgroup_id=$newsgroup_id&policy=open&return_url=$return_url>open</a>"
	set wait_link_str "<a href=/news/admin/toggle?proc=news_ap_update&newsgroup_id=$newsgroup_id&policy=wait&return_url=$return_url>wait</a>"
	set closed_link_str "<a href=/news/admin/toggle?proc=news_ap_update&newsgroup_id=$newsgroup_id&policy=closed&return_url=$return_url>closed</a>"
#    }

    switch $ap {
	"open" {
	    set ret "<b>open</b> | $wait_link_str | $closed_link_str"
	}
	"wait" {
	    set ret "$open_link_str | <b>wait</b> | $closed_link_str"
	}
	"closed" {
	    set ret "$open_link_str | $wait_link_str | <b>closed</b>"
	}
    }
    return $ret
}

proc_doc news_get_latest { {num_items 1} {list_p 0} {newsgroup_id 0} } { 
Returns a number of latest news items for the specified newsgroup. If no
newsgroup_id is passed in, then get the lastest regardless of newsgroups. 
if list_p is 1, then return the headers only in a list. Otherwise, return
the content as well. } {
    
    if { $num_items < 1} {
	return
    }

    set user_id [ad_get_user_id]
    # default newsgroup_id to public
    if { $newsgroup_id == 0 } {
	set newsgroup_clause " and newsgroup_id in (
	[join [news_newsgroup_id_list_view $user_id] ","])"
    } else {
	set newsgroup_clause " and newsgroup_id = :newsgroup_id"
    }

    # get the approved, already release, latest press releases
    
    set sql "select title, subtitle, news_item_id,
    body, html_p, release_date
    from news_items 
    where release_date <= sysdate
    and expiration_date > sysdate
    and approval_state = 'approved'
    $newsgroup_clause
    order by release_date desc"
	
    set count 0
    set latest_str ""
    db_foreach getnews $sql {
	if { $list_p } {
	    append latest_str "
	    <li>[util_AnsiDatetoPrettyDate $release_date]:
	    <a href=/news/item?news_item_id=$news_item_id>$title</a>"
	} else {
	    append latest_str "
	    <h3>$title</h3>
	    <blockquote><b>$subtitle</b></blockquote>
	    [util_maybe_convert_to_html $body $html_p]
	    "
	}

	incr count
	if {$count == $num_items} {
	    break
	}
    }
    return $latest_str
}


ns_share ad_new_stuff_module_list

if { ![info exists ad_new_stuff_module_list] || [lsearch -glob $ad_new_stuff_module_list "News*"] == -1 } {
    lappend ad_new_stuff_module_list [list "News" news_new_stuff]
}

# added two additional arguments and a parameter to this proc
#  - include_comments_p - if set to 0, we skip the comments regardless of the type. This
#    is good for adding news to user workspaces
#  - DefaultNumberOfStoriesToDisplay .ini Parameter: Specified the maximum number of stories
#    to display. An active site can have a lot of news in a month! Use this parameter to
#    say "Only display the 10 most recent news items"
#  - include_date_p: Prepends the news item with it's release date
# brucek: added group_id argument to filter group-specific news
#         how_many to override the ini parameter

proc news_new_stuff {since_when only_from_new_users_p purpose { include_date_p 0 } { include_comments_p 1 } { group_id 0 } { how_many 0 }} {

    ns_log Notice "Inside news_new_stuff: since_when $since_when"
    # Get the user_id for finding which newsgroups this user can see.
    set user_id [ad_get_user_id]

    if { $only_from_new_users_p == "t" } {
	set users_table "users_new"
    } else {
	set users_table "users"
    }
    # What is the maximum number of rows to return?
    # the how_many proc argument has precedence over the value in the ini file
    if { $how_many > 0 } {
	set max_stories_to_display $how_many
    } else {
	set max_stories_to_display [ad_parameter DefaultNumberOfStoriesToDisplay news -1]
    }

    # Create a clause for returning the postings for relavent groups
    # Don't have to bind this here because news_newsgroup_id_list binds group_id, if used,
    #  so that all the values in this clause are already from the database
    set newsgroup_clause "(newsgroup_id = [join [news_newsgroup_id_list $user_id $group_id] " or newsgroup_id = "])"
    

    if { $purpose == "site_admin" } {
	set query "select news.title, news.news_item_id, news.approval_state, 
 expired_p(news.expiration_date) as expired_p, 
 to_char(news.release_date,'Mon DD, YYYY') as release_date_pretty
from news_items news, $users_table ut
where creation_date > :since_when
and $newsgroup_clause
and news.creation_user = ut.user_id
order by creation_date desc"
    } else {
	# only showed the approved and released stuff
	set query "select news.title, news.news_item_id, news.approval_state, 
 expired_p(news.expiration_date) as expired_p, 
 to_char(news.release_date,'Mon DD, YYYY') as release_date_pretty
from news_items news, $users_table ut
where creation_date > :since_when
and $newsgroup_clause
and news.approval_state = 'approved'
and release_date < sysdate
and news.creation_user = ut.user_id
order by release_date desc, creation_date desc"
    }
    ns_log Notice "$query"
    set result_items ""
    set counter 0
    db_foreach news_info $query {
	switch $purpose {
	    web_display {
		append result_items "<li>[util_decode $include_date_p 1 "$release_date_pretty: " ""]<a href=\"/news/item?news_item_id=$news_item_id\">$title</a>\n" }
	    site_admin { 
		append result_items "<li>[util_decode $include_date_p 1 "$release_date_pretty: " ""]<a href=\"/admin/news/item?news_item_id=$news_item_id\">$title</a>"
		if { ![string match $approval_state "approved"] } {
		    append result_items "&nbsp; <font color=red>not approved</font>"
		}
		append result_items "\n"
	    }
	    email_summary {
		append result_items "[util_decode $include_date_p 1 "$release_date_pretty: " ""]$title
  -- [ad_url]/news/item.tcl?news_item_id=$news_item_id
"
            }
	}
	incr counter
	if { $max_stories_to_display > 0 && $counter >= $max_stories_to_display } {
	    break
	}
    }
    if { ! $include_comments_p } {
	return $result_items
    } 
    # we have the result_items or not
    if { $purpose == "email_summary" } {
	set tentative_result $result_items
    } elseif { ![empty_string_p $result_items] } {
	set tentative_result $result_items
    } else {
	set tentative_result ""
    }
    # now let's move into the comments on news territory (we don't do
    # this in a separate new-stuff proc because we want to keep it 
    # together with the new news)
    if { $purpose == "email_summary" } {
	# the email followers aren't going to be interested in comments
	return $tentative_result
    }
    if { $purpose == "site_admin" } {
	set where_clause_for_approval ""
    } else {
	set where_clause_for_approval "and gc.approved_p = 't'"
    }
    set comment_query "
select 
  gc.comment_id, 
  gc.on_which_table, 
  gc.html_p as comment_html_p,
  dbms_lob.substr(gc.content,100,1) as content_intro, 
  gc.on_what_id,
  users.user_id as comment_user_id, 
  gc.comment_date,
  first_names || ' ' || last_name as commenter_name, 
  gc.approved_p,
  news.title, 
  news.news_item_id 
from general_comments gc, $users_table users, news_items news
where users.user_id = gc.user_id 
and gc.on_which_table = 'news_items'
and gc.on_what_id = news.news_item_id
$where_clause_for_approval
and comment_date > :since_when
order by gc.comment_date desc"

    set result_items ""
    db_foreach news_comment_query $comment_query {
	if { $comment_html_p == "t" } {
	    regsub {<[^>]*$} $content_intro "" content_intro
	}

	switch $purpose {
	    web_display {
		append result_items "<li>comment from <a href=\"/shared/community-member?user_id=$comment_user_id\">$commenter_name</a> on <a href=\"/news/item?news_item_id=$news_item_id\">$title</a>:
<blockquote>
$content_intro ...
</blockquote>
"
            }
	    site_admin { 
		append result_items "<li>comment from <a href=\"/users/one?user_id=$comment_user_id\">$commenter_name</a> on <a href=\"/admin/news/item?news_item_id=$news_item_id\">$title</a>:
<blockquote>
$content_intro ...
</blockquote>
"
	    }
	}
    }
    if ![empty_string_p $result_items] {
	append tentative_result "\n<h4>comments on news items</h4>\n\n$result_items"
    }
    if ![empty_string_p $tentative_result] {
	return "<ul>\n\n$tentative_result\n</ul>"
    } else {
	return ""
    }
}

##################################################################
#
# interface to the ad-user-contributions-summary.tcl system

ns_share ad_user_contributions_summary_proc_list

if { ![info exists ad_user_contributions_summary_proc_list] || [util_search_list_of_lists $ad_user_contributions_summary_proc_list "/news postings" 0] == -1 } {
    if { [ad_parameter EnabledP user-contributions 0] == 1 } {
        lappend ad_user_contributions_summary_proc_list [list "/news postings" news_user_contributions 0]
    }
}

proc_doc news_user_contributions {user_id purpose} {Returns list items, one for each news posting} {


    if { $purpose == "site_admin" } {
	set restriction_clause ""
    } else {
	set restriction_clause "\nand n.approval_state = 'approved'"
    }

    set sql "
    select n.news_item_id, n.title, n.approval_state, n.release_date, ng.scope, 
           ng.group_id, ug.group_name, ug.short_name,
           decode(ng.scope, 'all_users', 1, 'registered_users', 1, 'public', 1, 'group', 4, 5)
             as scope_ordering
    from news_items n, newsgroups ng, user_groups ug 
    where n.creation_user = :user_id $restriction_clause
    and n.newsgroup_id = ng.newsgroup_id
    and ng.group_id=ug.group_id(+)
    order by scope_ordering, ng.group_id, n.release_date"

    set items ""
    set last_group_id ""
    set item_counter 0
    db_foreach user_contributions $sql {

	switch $scope {
	    public {
		if { $item_counter==0 } {
		    append items "<h4>Public News Postings</h4>"		    
		    set root_url "/news"
		    set admin_root_url "/news/admin"
		}
	    }
	    group {
		if { $last_group_id!=$group_id } {
		    append items "<h4>$group_name News Postings</h4>"
		    
		    if { [db_0or1row section_key_from_group_id "
		    select section_key
		    from content_sections
		    where scope='group' and group_id=:group_id
		    and module_key='news'"] } {

			set root_url "[ug_url]/[ad_urlencode $short_name]/[ad_urlencode $section_key]"
			set admin_root_url "[ug_admin_url]/[ad_urlencode $short_name]/[ad_urlencode $section_key]"
		    } else {
			set root_url "/news"
			set admin_root_url "/news/admin"
		    }
		}
	    } 
	}

	if { $purpose == "site_admin" } {
	    append items "<li>[util_AnsiDatetoPrettyDate $release_date]: <a href=\"$admin_root_url/item?[export_url_vars news_item_id]\">$title</a>\n"
	    if { ![string match $approval_state "approved"] } {
		append items "&nbsp; <font color=red>not approved</font>"
	    }
	} else {
	    append items "<li>[util_AnsiDatetoPrettyDate $release_date]: <a href=\"$root_url/item?[export_url_vars news_item_id]\">$title</a>\n"
	}
	set last_group_id $group_id
	incr item_counter
    }

    if [empty_string_p $items] {
	return [list]
    } else {
	return [list 0 "News Postings" "<ul>\n\n$items\n\n</ul>"]
    }

}

proc_doc news_admin_authorize { news_item_id } "given news_item_id, this 
procedure will check whether the user can administer this news item. if news 
doesn't exist page is served to the user informing him that the news item 
doesn't exist. if successfull it will return user_id of the administrator." {
    
    set sql "
    select news_item_id, scope, group_id, news_items.newsgroup_id
    from news_items, newsgroups
    where news_item_id=:news_item_id
    and news_items.newsgroup_id = newsgroups.newsgroup_id"

    if { ![db_0or1row news_info $sql] } {
	# news item doesn't exist
	uplevel {
	    doc_return  200 text/html "
	    [ad_scope_admin_header "News Item Does not Exist"]
	    [ad_scope_admin_page_title "News Item Does not Exist"]
	    [ad_scope_admin_context_bar [list index?[export_url_scope_vars]  "News Admin"] "No News Item"]
	    <hr>
	    <blockquote>
	    Requested News Item does not exist.
	    </blockquote>
	    [ad_scope_admin_footer]
	    "
	}
	ad_script_abort
    }

    set user_id [ad_verify_and_get_user_id]

    if [news_is_admin_p $user_id $newsgroup_id] {
	return $user_id
    } else {
	ad_return_warning "Not authorized" "You are not authorized to see t\his page"
	ad_script_abort
    }
}


ad_proc -public news_administration_links {group_id} { 
    @creation-date January 2001
    @author caroline@arsdigita.com
    @Provides a links to adminster and add items to the newsgroup for a particlar group.
} {
    if { [db_string newgroup_exists {select count(*) from newsgroups where group_id = :group_id}] } {

	return "    <li><a href=\"/news/admin/index?[export_url_vars group_id]&scope=group\">Manage Announcements</a>
      <li><a href=\"/news/post-new?[export_url_vars group_id]&scope=group\">Add an Annoucement</a>"
	
    } else {
	#news isn't turned on just give back nothing
	return ""
    }   
}













