-- /packages/enhanced-news/enhanced-news.sql
--
-- A package to manage news postings/viewings
--

-- A table to describe newsgroups
create sequence newsgroup_id_sequence start with 1;

create table newsgroups (
        newsgroup_id    integer 
	                constraint ng_newsgroup_id_pk primary key,
        -- if scope=all_users, this is the news for all newsgroups
        -- is scope=registered_users, this is the news for all registered users
        -- if scope=public, this is the news for the main newsgroup
        -- if scope=group, this is news associated with a group
        scope           varchar(20) not null,
        group_id        integer
	                constraint ng_group_id_fk references user_groups,
	approval_policy varchar(20) default 'closed' 
	                constraint ng_approval_policy_nn not null
		   	constraint ng_approval_policy_ck 
	                check ( approval_policy in ('open', 'wait','closed')),
	-- group id of the admin group for this newsgroup
	-- if null, the administrators (role) of this group will be admins
	admingroup_id	integer
			constraint ng_admingroup_id_fk
			references user_groups,
	enabled_p	varchar(1) default 'f' 
                        constraint ng_enabled_p_ck 
                        check(enabled_p in ('t', 'f')),
	-- if 't', then when a member suggests an item, admin group
	-- members will be notified via e-mail
	notify_admin_p 	varchar(1) default 'f'
                        constraint ng_notify_admin_p_ck
                        check(notify_admin_p in ('t', 'f')),
	constraint ng_scope_ck
        check ((scope='group' and group_id is not null) or
        (scope='public') or
        (scope='all_users') or
        (scope='registered_users'))
);

insert into newsgroups
        (newsgroup_id, scope)
        values
        (newsgroup_id_sequence.nextval, 'public');

insert into newsgroups
        (newsgroup_id, scope)
        values
        (newsgroup_id_sequence.nextval, 'registered_users');

insert into newsgroups
        (newsgroup_id, scope)
        values
        (newsgroup_id_sequence.nextval, 'all_users');


create sequence news_item_id_sequence start with 100000;

create table news_items (
        news_item_id    integer primary key,
        newsgroup_id    integer
			constraint ni_newsgroup_id_fk
			references newsgroups not null,
        title           varchar(200) 
	               	constraint ni_title_nn not null,
	subtitle       varchar(200),
        body            clob not null,
        -- is the body in HTML or plain text (the default)
        html_p          char(1) default 'f' 
			constraint ni_html_p_ck
			check(html_p in ('t','f')),
        approval_state  varchar(15) default 'unexamined' 
			constraint ni_approval_state_ck
	check(approval_state in ('unexamined','approved', 'disapproved')),
        approval_date   date,
        approval_user   integer
			constraint ni_approval_user_fk
			references users(user_id),
        approval_ip_address     varchar(50),
        release_date   	date 
			constraint ni_release_date_nn not null,
        expiration_date date 
			constraint ni_expiration_date_nn not null,
        creation_date   date 
			constraint ni_creation_date_nn not null,
        creation_user   integer
			constraint ni_creation_user_nn not null 
			constraint ni_creation_user_fk 
			references users(user_id),
        creation_ip_address     varchar(50) 
			constraint ni_creation_ip_nn not null
);


--author caroline@arsdigita.com
--When you enable a module though the admin/ug pages this will create the newgroup.
--Note we don't have a delete trigger as there maybe content already in the newsgroup
--and we wouldn't want to delete it by accident.

Create or replace trigger news_ng_create_on_cs_add_tr
after insert on content_sections 
for each row
DECLARE
	v_newsgroup_exists_p	integer;
BEGIN

	IF :new.module_key = 'news' THEN
		IF :new.scope = 'group' THEN	
			select count(group_id) into v_newsgroup_exists_p
			from newsgroups
			where group_id = :new.group_id;

			IF v_newsgroup_exists_p < 1 THEN
				insert into newsgroups
				(newsgroup_id, scope, group_id)
				values (newsgroup_id_sequence.nextval, 'group', :new.group_id);
			END IF;
		END IF;
	END IF;
END;
/
show errors




