# /packages/news/www/admin/admingroup-ae.tcl

ad_page_contract {
    Add/Edit the admin group for a newsgroup

    @author lin@arsdigita.com
    @creation-date 2000-12-19
} {
    {admin_group ""}
    {newsgroup_id}
    {return_url ""}
}

if { $admin_group == "Group Admins" } {
    set function Add
} else {
    set function Edit
}

set user_id [ad_get_user_id]

# only admin can use this page
if { ![news_is_admin_p $user_id $newsgroup_id] } {
    ad_return_error "Error" "Sorry, but you are not authorized."
    return
}


set count [db_0or1row newsgroup_name "select
    nvl(group_name, scope) as newsgroup_name,
    admingroup_id, ng.group_id,
    nvl((select short_name from user_groups
     where group_id = ng.admingroup_id), '') as admin_short_name
    from user_groups ug, newsgroups ng
    where ug.group_id(+) = ng.group_id 
      and ng.newsgroup_id = :newsgroup_id"]

if { $count == 0 } {
    ad_return_error "Error" "the newsgroup_id passed along is not valid"
}

if { ![empty_string_p $admingroup_id] } {
    set sql "select first_names, last_name, email, u.user_id
             from users u, user_group_map ugm
             where u.user_id = ugm.user_id
             and ugm.group_id = :admingroup_id "
    set admin_str "This newsgroup currently has an admin group, which has
    the following members:<ul>"

    set count 0
    db_foreach admin_members $sql {
	append admin_str "<li>
	<a href=/shared/community-member?user_id=$user_id>$first_names 
	$last_name</a> (<a href=mailto:$email>$email</a>)"
	incr count
    }
    
    if { $count == 0 } {
	set admin_str "This newsgroup currently has NO admins."
    } else {
	append admin_str "</ul>"
    } 
    
    append admin_str "
    <p>
    You can choose a different admin group by entering the short name in
    the box. Or, you can leave it blank, in which case, the administrators 
    (role) of the newsgroup will do the news admin work.
    </p>"
    
} else {
    set sql "select first_names, last_name, email, u.user_id
             from users u, user_group_map ugm
             where u.user_id = ugm.user_id
             and ugm.group_id = :group_id
             and lower(ugm.role) = 'administrator' "

    set admin_str "This newsgroup currently does NOT have an admin group.
    The following administrators (role) of the group 
    are responsible for the news admin work:<ul>"
    set count 0
    db_foreach admin_members $sql {
	append admin_str "<li>
	<a href=/shared/community-member?user_id=$user_id>$first_names 
	$last_name</a> (<a href=mailto:$email>$email</a>)"
	incr count
    }
    
    if { $count == 0 } {
	set admin_str "This newsgroup currently has NO admins."
    } else {
	append admin_str "</ul>"
    }

    append admin_str "
    If you add an admin group, then the members of the admin group will
    be responsible for the news admin work."
}

if { $function == "add" } {
    set page_title "Add an Admin Group"
} else {
    set page_title "Edit an Admin Group"
}

set context_bar [ad_admin_context_bar [list "/admin/news" "AdministerNews"] $page_title]

set page_content "
[ad_header $page_title]
<h2>$page_title</h2>
$context_bar

<blockquote>
<h3>$newsgroup_name</h3>

<p>
$admin_str
</p>

<form action=admingroup-ae-2 method=post>
[export_form_vars newsgroup_id newsgroup_name return_url]
<table>
<tr>
<th align=right>Admin Group Short Name:</th>
<td><input type=text size=30 name=admin_short_name value=\"$admin_short_name\"></td>
</tr>
</table>
<center>
<input type=submit value=$function>
</center>
</form>
</blockquote>

[ad_footer]
"
doc_return  200 text/html $page_content


