# /packages/news/www/admin/expired.tcl
#

ad_page_contract {
    expired news items page

    @author lin@arsdigita.com
    @creation-date March 8, 2000
} {
    {orderby "num"}
}

set user_id [ad_get_user_id]

# Get a list of newsgroup ids this user administers
set newsgroup_id_list [news_newsgroup_id_list_admin $user_id]

if { [llength $newsgroup_id_list] == 0 } {
    ad_return_error "Not an Administer" "Sorry, but there is no
    newsgroup to be administered by you."
    return
}

set newsgroup_clause "and ng.newsgroup_id in (
[join $newsgroup_id_list ","]) "

set return_url "/news/admin/expired"

set query "
select news_item_id, i.title, release_date, i.body, i.html_p, 
nvl(group_name, scope) as scope,
nvl(ng.group_id, '') as group_id, approval_state
from news_items i, newsgroups ng, user_groups ug
where sysdate >= expiration_date
and ug.group_id(+) = ng.group_id
and i.newsgroup_id = ng.newsgroup_id
$newsgroup_clause
order by scope desc, release_date desc"

set counter 0
set news_html ""
set old_scope ""
db_foreach news_item_get $query {
    switch $scope {
        "public" {
            set scope_str "Public Press Releases"
        }
        "registered_users" {
            set scope_str "Registered Users News"
        }
        "all_users" {
            set scope_str "All Users News"
        }
        default {
            set scope_str "$scope News"
        }
    }

    if { [empty_string_p $old_scope] } {
	append news_html "
	<h3><a name=$scope>$scope_str:</a></h3>
	<ul>"
	set old_scope $scope
    }

    if {$scope != $old_scope} {
        append news_html "</ul>
	<a href=#top>Top</a>
	<h3><a name=$scope>$scope_str:</a></h3>
	<ul>"
        set old_scope $scope
    }
    incr counter
    append news_html "<li>[util_AnsiDatetoPrettyDate $release_date]:
    <a href=\"item?[export_url_vars news_item_id]\">$title</a>"

    if { $approval_state == "approved" } {
	append news_html "&nbsp;&nbsp;
	\[<a href=\"post-edit?[export_url_vars news_item_id return_url]\"> Edit</a>\]"
    } elseif {$approval_state == "disapproved"} {
        append news_html "&nbsp;&nbsp;
        <font size=-1 color=red>(Rejected)</font>
        \[<a href=\"post-edit?[export_url_vars news_item_id return_url]\"> Edit</a>\]"
    } else {
	append news_html "&nbsp;&nbsp;
	<font size=-1 color=red>(Pending)</font>
	\[<a href=\"post-edit?[export_url_vars news_item_id return_url]\"> Edit</a>\]
	"
    }
}

if { [empty_string_p $old_scope] } {
    # no item
    append news_html "
    There is no items.
    "
} else {
    append news_html "
    </ul>
    <p>
    <a href=#top>Top</a>
    </p>"
}

append news_html </ul>

set table_def {
    {scope "News Group"
    {scope}
    {<td><a href=#$scope>$scope</a></td>}}
    {num "Total # Expired Items"
    {num desc}
    {}}
}

# query 
set sql "select min(nvl(ug.group_name, scope)) as scope,
                count(news_item_id) as num,
                ng.newsgroup_id
         from newsgroups ng, news_items ni, user_groups ug
         where ng.newsgroup_id = ni.newsgroup_id
           and ng.group_id = ug.group_id(+)
           and ni.expiration_date <= sysdate
           $newsgroup_clause
           group by ng.newsgroup_id
           [ad_order_by_from_sort_spec $orderby $table_def]"

set page_title "Administer Expired Items"
set context_bar [ad_context_bar_ws [list "/news/admin" "Administer News"] "Expired News"]

set page_content "
[ad_header $page_title]
<a name=top></a>
<h2>$page_title</h2>
$context_bar
<hr>

<blockquote>
<h3>Summary of Expired Items</h3>
<p>
(Including approved, pending and rejected news items)
</p>

[ad_table \
        -Tband_colors {{} {\"\#cccccc\"}} \
        -Ttable_extra_html { cellpadding=3 } \
        rep_index_table $sql $table_def ]

<p>
<b>Tip</b>
<p>
To make an expired item live again, click on the <i>Edit</i> link and change
the expiration date to a future date. If the item is in <i>Rejected</i>
or <i>Pending</i> 
state, then go to the <a href=/news/admin>admin page</a> and approve
it.
</p>

$news_html


</blockquote>

[ad_footer]
"
doc_return  200 text/html $page_content












