# /packages/news/www/admin/index.tcl
#

ad_page_contract {
    News package main sub-site admin page

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
} {
    {orderby "num"}
    {orderby2 "scope"}
    {group_id:integer "0"}
}

set user_id [ad_get_user_id]

#set up the page header because group_id might get changed

set page_title "Administer News"
set context_bar [ad_context_bar_ws [list "/news" "News"] "Administer News"]

set page_content "
[ad_header $page_title]
<h2>$page_title</h2>
$context_bar
<hr>"


if {!$group_id} {
    # Get a list of newsgroup ids this user administers.  If a group_id is supplied then just give that newsgroup.
    set newsgroup_id_list [news_newsgroup_id_list_admin $user_id]   
} else {
    set newsgroup_id_list [db_list newgroups_for_one_group {select newsgroup_id as newsgroup_id_list from newsgroups where group_id = :group_id}]
}

if { [llength $newsgroup_id_list] == 0 } {
    ad_return_error "Not an Administer" "Sorry, but there is no
    newsgroup being administered by you."
    return
}

set newsgroup_clause "and ng.newsgroup_id in (
[join $newsgroup_id_list ","]) "

set query "
select news_item_id, title, release_date, i.body, i.html_p, 
nvl(group_name, scope) as scope,
nvl(ng.group_id, '') as group_id, approval_state
from news_items i, newsgroups ng, user_groups ug
where sysdate < expiration_date
and ug.group_id(+) = ng.group_id
and i.newsgroup_id = ng.newsgroup_id
$newsgroup_clause
order by scope, release_date desc"

set counter 0
set news_html "<ul>"
set old_scope ""
db_foreach news_item_get $query {
    switch $scope {
        "public" {
            set scope_str "Public Press Releases"
        }
        "registered_users" {
            set scope_str "Registered Users News"
        }
        "all_users" {
            set scope_str "All Users News"
        }
        default {
            set scope_str "$scope News"
        }
    }

    if {$scope != $old_scope} {
        append news_html "</ul>
	<a href=#top>Top</a>
	<h3><a name=$scope>$scope_str:</a></h3>
	<ul>"
        set old_scope $scope
    }
    incr counter
    append news_html "<li>[util_AnsiDatetoPrettyDate $release_date]:
    <a href=\"item?[export_url_vars news_item_id scope]\">$title</a>"

    if { $approval_state == "approved" } {
	append news_html "&nbsp;&nbsp;
	\[<a href=\"post-edit?[export_url_vars news_item_id]\"> Edit</a>
	| <a href=\"toggle-approved-p?[export_url_vars news_item_id]\">Revoke</a>\]"
    } elseif { $approval_state == "disapproved"} {
	append news_html "&nbsp;&nbsp;
        <font size=-1 color=red>(Rejected)</font>
        \[<a href=\"post-edit?[export_url_vars news_item_id]\"> Edit</a>
        | <a href=\"toggle-approved-p?[export_url_vars news_item_id]\">Approve</a>\]"
    } else {
	append news_html "&nbsp;&nbsp;
	<font size=-1 color=red>(Pending)</font>
	\[<a href=\"post-edit?[export_url_vars news_item_id]\"> Edit</a>
	| <a href=\"toggle-approved-p?[export_url_vars news_item_id]\">Approve</a>\]
	"
    }
}

if { [empty_string_p $old_scope] } {
    # no item
    append news_html "
    There is no items.
    "
} else {
    append news_html "
    </ul>
    <p>
    <a href=#top>Top</a>
    </p>"
}

# news waiting for approval

set sql "select nvl(ug.group_name, scope) as scope,
         news_item_id, release_date, title
         from newsgroups ng, news_items ni, user_groups ug
         where ng.newsgroup_id = ni.newsgroup_id
           and ng.group_id = ug.group_id(+)
           and ni.approval_state = 'unexamined'
           and ni.expiration_date > sysdate
           $newsgroup_clause
         order by scope desc, release_date desc"

set unexamined_str "<ul>"
set count 0
db_foreach unexamined_select $sql {
    append unexamined_str "<li>[util_AnsiDatetoPrettyDate $release_date]:
    <a href=\"item?[export_url_vars news_item_id scope]\">$title</a>
    <br>($scope) &nbsp;&nbsp;
    \[<a href=\"post-edit?[export_url_vars news_item_id]\"> Edit</a>
    | <a href=\"toggle-approved-p?[export_url_vars news_item_id]\">Approve</a>
    | <a href=\"reject?[export_url_vars news_item_id]\">Reject</a>\] 
    <br>&nbsp;"
    incr count
}

if {$count == 0} {
    append unexamined_str "<li>None"
}
append unexamined_str "</ul>"

set return_url "/news/admin/index"

set table_def {
    {scope "News Group"
    {scope}
    {<td><a href=?group_id=$group_id&scope=group>$scope</a></td>}}
    {num "Total #<br>Current Items"
    {num desc}
    {}}
    {approval_policy "Approval Policy"
    {approval_policy}
    {<td>[news_ap_display $approval_policy $newsgroup_id $return_url]
    </td>}}
    {notify_admin_p "Notify Admin on New Items?"
    {notify_admin_p}
    {<td align=center>[news_decode $notify_admin_p]
    (<a href=toggle?proc=news_na_toggle&[export_url_vars newsgroup_id return_url]>
     toggle</a>)</td>}}
    {"" "Action"
    {""}
    {<td><a href=/news/post-new?[export_url_vars return_url group_id scope newsgroup_id]>Add an Item</a></td>}}
}

# query 
set sql "select min(nvl(ug.group_name, scope)) as scope,
                count(*) as num, 
                ng.newsgroup_id, ug.group_id,
                min(ng.approval_policy) as approval_policy,
                min(ng.enabled_p) as enabled_p, 
                min(ng.notify_admin_p) as notify_admin_p,
                min(ng.admingroup_id) as admingroup_id,
                '$return_url' as return_url
         from newsgroups ng, news_items ni, user_groups ug
         where ng.newsgroup_id = ni.newsgroup_id(+)
           and ng.group_id = ug.group_id(+)
           and ni.expiration_date > sysdate
           $newsgroup_clause
           group by ng.newsgroup_id, ug.group_id
           [ad_order_by_from_sort_spec $orderby $table_def]"


set bind_vars [ns_set create]
ns_set put $bind_vars group_id $group_id


set table_def2 {
    {scope "News Group"
    {scope}
    {<td><a href=#$scope>$scope</a></td>}}
    {num "Total #<br>Current Items"
    {num desc}
    {}}
    {approval_policy "Approval Policy"
    {approval_policy}
    {<td>[news_ap_display $approval_policy $newsgroup_id $return_url]
    </td>}}
    {notify_admin_p "Notify Admin on New Items?"
    {notify_admin_p}
    {<td align=center>[news_decode $notify_admin_p]
    (<a href=toggle?proc=news_na_toggle&[export_url_vars newsgroup_id return_url]>
     toggle</a>)</td>}}
    {"" "Action"
    {""}
    {<td><a href=/news/post-new?[export_url_vars return_url group_id scope newsgroup_id]>Add an Item</a></td>}}
}

# query 
set sql2 "select nvl(ug.group_name, scope) as scope,
                0 as num, 
                ng.newsgroup_id,
                ug.group_id,
                approval_policy,
                enabled_p, 
                notify_admin_p,
                admingroup_id,
                '$return_url' as return_url
         from newsgroups ng, user_groups ug
         where ng.newsgroup_id not in ( select distinct newsgroup_id from  news_items
                                        where expiration_date > sysdate )
           and ng.group_id = ug.group_id(+)
           $newsgroup_clause
           [ad_order_by_from_sort_spec $orderby2 $table_def2]"




append page_content "
<blockquote>
<table width=90%>
<tr><td align=left>
<h3>Summary</h3> 
</td><td align=right>
<a href=/doc/news>Help</a> | <a href=expired>Expired News</a>
</td></tr>
</table>
<h4>Newsgroups with posts</h4>
[ad_table \
        -Tband_colors {{} {\"\#cccccc\"}} \
        -Ttable_extra_html { cellpadding=3 } \
        rep_index_table $sql $table_def ]

<h4>Newsgroups without posts</h4>

[ad_table \
        -Tband_colors {{} {\"\#cccccc\"}} \
        -Ttable_extra_html { cellpadding=3 } \
        rep_index_table $sql2 $table_def2 ]

<h3>Items Waiting for Approval</h3>
$unexamined_str

<p>
<b>Tip</b>
<p>
To take off an active item,
click on the <i>Edit</i> link and change
the expiration date to a past date. Or click on the <i>Revoke</i> link
to disapprove it.
</p>

<p>
$news_html

<p>
<a href=expired>Expired News</a>
</p>

</blockquote>

[ad_footer]
"
doc_return  200 text/html $page_content












