# /packages/news/www/admin/item.tcl
#

ad_page_contract {
    admin a news item page

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
    @cvs-id item.tcl,v 3.4.2.9 2000/09/22 01:38:58 kevin Exp

    Note: if page is accessed through /groups pages then group_id and 
    group_vars_set are already set up in the environment by the 
    ug_serve_section. group_vars_set contains group related variables
    (group_id, group_name, group_short_name, group_admin_email, 
    group_public_url, group_admin_url, group_public_root_url,
    group_admin_root_url, group_type_url_p, group_context_bar_list and
    group_navbar_list)
} {
    news_item_id:integer,notnull
    scope
}

set user_id [ad_get_user_id]

set return_url "[ns_conn url]?[export_url_vars scope news_item_id]"

db_0or1row news_item_get "
select n.title, n.body, n.html_p, n.approval_state, n.release_date, 
       n.expiration_date, n.creation_user, n.creation_date,
       first_names, last_name, subtitle, email, user_id as creation_user_id,
       n.newsgroup_id
from news_items n, users u
where news_item_id = :news_item_id
and u.user_id = n.creation_user"


# only admin can view this page
if { ![news_is_admin_p $user_id $newsgroup_id] } {
    ad_return_error "Error" "Sorry, but you are not authorized."
    return
}

db_release_unused_handles


if { ![info exists title] || [empty_string_p $title] } {
    ad_return_error "Can't find news item" "Can't find news item $news_item_id"
    return
}


set page_content "
[ad_header "$title"]
<h2>Administer One Item</h2>
[ad_context_bar_ws [list "/news/admin" "Administer News"] "Admin One Item"]

<hr>
<blockquote>

<h3>Information</h3>
<ul>
<li>Scope: $scope
<li>Status:  
"

if { [string match $approval_state "approved"] } {
    append page_content "Approved (<a href=\"toggle-approved-p?[export_url_vars news_item_id return_url]\">Revoke</a>)"
} else {
    append page_content "<font color=red>Pending</font> (<a href=\"toggle-approved-p?[export_url_vars news_item_id return_url]\">Approve</a>)"
}

append page_content "
<li>Release Date: [util_AnsiDatetoPrettyDate $release_date]
<li>Expires: [util_AnsiDatetoPrettyDate $expiration_date]
<li>Submitted by: <a href=\"/shared/community-member?user_id=$creation_user_id\">$first_names $last_name</a> (<a href=mailto:$email>$email</a>)
<li>Submitted on: [util_AnsiDatetoPrettyDate $creation_date]
</ul>

<blockquote>
<form action=post-edit method=get>
[export_form_vars news_item_id return_url]
<input type=submit name=submit value=\"Edit\">
</form>
</blockquote>

<h3>Title</h3>
<blockquote>
$title
</blockquote>

<h3>Subtitle</h3>
<blockquote>
$subtitle
</blockquote>

<h3>Body</h3>

<blockquote>
[util_maybe_convert_to_html $body $html_p]
</blockquote>

</blockquote>
[ad_footer]
"

# [ad_general_comments_list $news_item_id news_items $title news]

doc_return  200 text/html $page_content
