# /packages/news/www/admin/post-edit-2.tcl
#

ad_page_contract {
    process the edit form for the news item

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
    @cvs-id post-edit-2.tcl,v 3.4.2.10 2000/08/16 20:50:33 luke Exp
} {
    newsgroup_id
    news_item_id:integer,notnull
    title:html,notnull
    subtitle:html
    body:allhtml,notnull
    releasedate:array,date
    expirationdate:array,date
    html_p:notnull
    return_url
}

set user_id [ad_get_user_id]


# only admin can view this page
if { ![news_is_admin_p $user_id $newsgroup_id] } {
    ad_return_error "Error" "Sorry, but you are not authorized."
    return
}

# set release_date in "YYYY-MM-DD" format
set release_date $releasedate(year)
append release_date "-$releasedate(month)"
append release_date "-$releasedate(day)"

# set expiration_date in "YYYY-MM-DD" format
set expiration_date $expirationdate(year)
append expiration_date "-$expirationdate(month)"
append expiration_date "-$expirationdate(day)"


set exception_count 0
set exception_text ""

# Check the expiration_date is later than the release_date
db_1row julian_select "select
  to_char(to_date('$release_date', 'YYYY-MM-DD'),'J') as j_release_date,
  to_char(to_date('$expiration_date', 'YYYY-MM-DD'),'J') as j_expiration_date
  from dual"

if { $j_expiration_date < $j_release_date } {
    incr exception_count
    append exception_text "<li>Please make sure the expiration date is later th\an the release date."
}

if { $exception_count > 0 } {
    ad_return_complaint $exception_count $exception_text
    return
}

set update_sql "update news_items
   set title = :title, 
       subtitle = :subtitle,
       body = empty_clob(), 
       html_p = :html_p,
       release_date= :release_date,
       expiration_date = :expiration_date,
       newsgroup_id = :newsgroup_id
where news_item_id = :news_item_id 
returning body into :1"

db_transaction {

    db_dml news_item_update $update_sql -clobs [list $body] 

}

db_release_unused_handles

ad_returnredirect $return_url





