# /packages/news/www/index.tcl

ad_page_contract {
    main page to the news package

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
 
} {
    {archive_p 0}
    {group_id:optional,integer 0}
    {scope "public"}
}


set user_id [ad_get_user_id]

if { $archive_p } {
    set page_title "News (Expired)"
} else {
    set page_title "News"
}

set user_id [ad_scope_authorize $scope all group_member none]

if {$group_id} {
    set newsgroup_clause "g.group_id = :group_id"
} else {
    # Create a clause for returning the postings for relevant and enabled groups
    set newsgroup_clause "g.newsgroup_id in ( [join [news_newsgroup_id_list_view $user_id] ","])"
}

if { !$archive_p } {
    set page_title "Active News"
    set context_bar [ad_context_bar_ws "News"]
    set query "
    select news_item_id, title, release_date, i.body, i.html_p, 
           nvl(group_name, scope) as scope
    from news_items i, newsgroups g, user_groups ug
    where sysdate between trunc(release_date) and trunc(expiration_date)
    and g.group_id = ug.group_id(+)
    and i.newsgroup_id = g.newsgroup_id
    and $newsgroup_clause
    and approval_state = 'approved'
    order by scope, release_date desc, news_item_id desc"
} else {
    set page_title "Expired News"
    set context_bar [ad_context_bar_ws [list "" "News"] "Expired News"]
    set query "
    select news_item_id, title, release_date, i.body, i.html_p, 
           nvl(group_name, scope) as scope
    from news_items i, newsgroups g, user_groups ug
    where sysdate > expiration_date
    and g.group_id = ug.group_id(+)
    and i.newsgroup_id = g.newsgroup_id
    and $newsgroup_clause
    and approval_state = 'approved'
    order by scope, release_date desc, news_item_id desc"
}


set counter 0
set news_html "<ul>"
set old_scope ""
db_foreach news_item_get $query {
    set show_release_date 1
    switch $scope {
	"public" {
	    set show_release_date 0
	    set scope_str "Public Press Releases"
	}
	"registered_users" {
	    set scope_str "Registered Users News"
	}
	"all_users" {
	    set scope_str "All Users News"
	}
	default {
	    set scope_str "$scope News"
	}
    }

    if {$scope != $old_scope} {
	append news_html "</ul><h3>$scope_str:</h3><ul>"
	set old_scope $scope
    }
    incr counter 
#      append news_html "   <li>[util_AnsiDatetoPrettyDate $release_date]: "
    append news_html "   <li>$release_date]: "
    append news_html "<a href=\"item?[export_url_vars news_item_id show_release_date]\">$title</a>\n"
}

db_release_unused_handles


if { $counter == 0 } {
    append news_html "<li>no items found"
}
append news_html "</ul>"

set return_url "/news/?archive_p=$archive_p"

# construct an admin_str to be displayed at top right corner

# check if the user is a site-wide admin or an admin for ANY newsgroup
set is_admin_p [ad_administrator_p $user_id]
if !$is_admin_p {
    db_foreach newsgroup_id_sel "select newsgroup_id
    from newsgroups
    where enabled_p = 't' " {
	if [news_is_admin_p $user_id $newsgroup_id ] {
	    set is_admin_p 1
	    break
	}
    }
}

if { $archive_p } {
    set admin_str "<a href=/doc/news>Help</a>"
} else {
    set admin_str "<a href=/doc/news>Help</a> | <a href=\"?archive_p=1\">Expired news</a>"
}

if { $is_admin_p } {
    set admin_str "<a href=\"post-new?[export_url_vars approval_policy return_url]\">Post an item</a> | 
                   <a href=\"admin\">Administer News</a>
    | <a href=/doc/news>Help</a>" 
} else { 
    set priviledge [news_get_user_priviledge $user_id]
    if {![empty_string_p $priviledge] && $priviledge != "View"} {
	set admin_str "<a href=\"post-new?[export_url_vars return_url]\"
	>$priviledge an item</a>
	| <a href=/doc/news>Help</a>"  
    }
}


# construct the page
set page_content "
[news_header $page_title]
<h2>$page_title</h2>
$context_bar
<hr>

<blockquote>
<table width=90%>
<tr>
<td align-left>
<h2>$page_title</h2>
</td>
<td align=right>
$admin_str
</td>
</tr>
</table>
$news_html

"

if { !$archive_p } {
    append page_content "
<p>If you're looking for an old news article, check
<a href=\"?archive_p=1\">the expired news</a>.</p>"
} 

append page_content "
</blockquote>

[news_footer]"


doc_return 200 text/html $page_content



