# /package/news/item.tcl

ad_page_contract {
    news item page
    
    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
} { 
    news_item_id:integer,notnull
    {show_release_date 1}
}

set user_id [ad_get_user_id]
db_1row ng_id "
select ni.newsgroup_id, ng.group_id
from news_items ni, newsgroups ng
where ni.news_item_id = :news_item_id
and ni.newsgroup_id=ng.newsgroup_id"

# check if user had "View" priviledge of the newsgroup
if { [news_get_user_priviledge $user_id $newsgroup_id] == "" } {
    db_release_unused_handles
    ad_return_error "Error" "Sorry, you are not authorized to view this page."
    return
}    

db_0or1row news_item_get "
select title, subtitle,
       body, 
       html_p, 
       n.approval_state, 
       release_date, 
       expiration_date,
       creation_user, 
       (expiration_date-sysdate) as expired_p,
       first_names, 
       last_name
from   news_items n, users u

where  news_item_id = :news_item_id
and    u.user_id    = n.creation_user"

if { ![exists_and_not_null title] && ![exists_and_not_null body] } {
    db_release_unused_handles
    ad_return_error "Can't find news item" "Can't find news item $news_item_id"
    return
}

db_release_unused_handles

# check if expired
if { $expired_p <= 0 } {
    set expired_str "<font color=red>(Expired)</font>"
} else {
    set expired_str ""
}

if {$show_release_date} {
    set release_str "<p align=right>
    <i>Released on: [util_AnsiDatetoPrettyDate $release_date] $expired_str</i>
    </p>"
} else {
    set release_str "<p align=right><i>$expired_str</i></p>"
}

set page_body "
<blockquote>
<h2>$title</h2>
<blockquote><b>$subtitle</b></blockquote>
$release_str
[util_maybe_convert_to_html $body $html_p]
</blockquote>


[ad_general_comments_list $news_item_id news_items $title news]
"

set context_bar [ad_context_bar_ws [list "" "News"] "One News Item"]

set scope [db_string scope "
select nvl(group_name, scope) 
from newsgroups ng, user_groups ug
where ug.group_id(+) = ng.group_id
and newsgroup_id = :newsgroup_id"]

set page_title "$scope News"

set page_content "
[news_header $page_title $newsgroup_id]
<h2>$page_title</h2>
$context_bar
<hr>

$page_body

[news_footer]
"

doc_return  200 text/html $page_content








