# /packages/news/www/post-new-2.tcl
#

ad_page_contract {
    display confirmation page for new news item

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
} {
    newsgroup_id:integer,notnull
    group_id:integer,optional
    return_url:optional
    name:optional
    title:html,notnull
    subtitle:html
    body:allhtml,notnull
    releasedate:array,date
    expirationdate:array,date
    {html_p "f"}
}

# Check priviledge
set user_id [ad_get_user_id]
set priviledge [news_get_user_priviledge $user_id $newsgroup_id]

if {[empty_string_p $priviledge] || $priviledge == "View"} {
    db_release_unused_handle
    ad_return_error "Insufficent Priviledge" "Sorry but you are not
    authorized to view this page."
    return
}

# set release_date in "YYYY-MM-DD" format
set release_date $releasedate(year)
append release_date "-$releasedate(month)"
append release_date "-$releasedate(day)"

# set expiration_date in "YYYY-MM-DD" format
set expiration_date $expirationdate(year)
append expiration_date "-$expirationdate(month)"
append expiration_date "-$expirationdate(day)"


set exception_count 0
set exception_text ""

# Check the expiration_date is later than the release_date
db_1row julian_select "select
  to_char(to_date('$release_date', 'YYYY-MM-DD'),'J') as j_release_date,
  to_char(to_date('$expiration_date', 'YYYY-MM-DD'),'J') as j_expiration_date
  from dual"

if { $j_expiration_date < $j_release_date } {
    incr exception_count
    append exception_text "<li>Please make sure the expiration date is later than the release date."
}

if { $exception_count > 0 } {
    ad_return_complaint $exception_count $exception_text
    return
}

set news_item_id [db_nextval news_item_id_sequence]

set scope [db_string scope_select "select 
         distinct(nvl(group_name, scope)) as scope
         from newsgroups ng, user_groups ug
         where ng.group_id = ug.group_id(+)
           and newsgroup_id = :newsgroup_id"]

db_release_unused_handles


set page_content "
[ad_header "Confirm"]
<h2>Confirm</h2>
[ad_context_bar_ws [list "/news" "Press Releases"] "Confirm"]
<hr>

<blockquote>

<h3>A new item for newsgroup: $scope</h3>

<blockquote>
<b>Title: $title</b><br>
<b>Subtitle: $subtitle</b>
<p>
<b>Full Story:</b>
<p>
[util_maybe_convert_to_html $body $html_p]
</blockquote>
"

if { [info exists html_p] && $html_p == "t" } {
    append page_content "
    <p>
    <b>Note</b>:
    if the story has lost all of its paragraph breaks then you
    probably should have selected \"Plain Text\" rather than HTML.  Use
    your browser's Back button to return to the submission form.
    "
} else {
    append page_content "
    <p>
    <b>Note</b>: 
    if the story has a bunch of visible HTML tags then you probably
    should have selected \"HTML\" rather than \"Plain Text\".  Use your
    browser's Back button to return to the submission form.  " 
}

append page_content "

<h3>Dates</h3>

<ul>
<li>will be released on [util_AnsiDatetoPrettyDate $release_date]
<li>will expire on [util_AnsiDatetoPrettyDate $expiration_date]
</ul>

<form method=post action=\"post-new-3\">
[export_form_vars news_item_id title subtitle body html_p release_date expiration_date scope newsgroup_id return_url priviledge group_id]
<center>
<input type=submit value=\"Confirm\">
</center>
</form>

[ad_scope_footer]"



doc_return  200 text/html $page_content


