# /packages/packages/news/post-new-3.tcl
#

ad_page_contract {
    process the input form for the new news item (after the confirm page)

    @author jkoontz@arsdigita.com
    @author lin@arsdigita.com
    @creation-date March 8, 2000
} {
    scope
    newsgroup_id:integer
    release_date
    expiration_date
    html_p
    news_item_id:integer,notnull
    title:html,notnull
    subtitle:html
    body:allhtml,notnull
    return_url
    priviledge
    group_id:optional,integer
}

set user_id [ad_get_user_id]
if { $user_id == 0 } {
	set db_user_id [db_string system_user "select user_id from users
        where email='system'"]
} else {
	set db_user_id $user_id
}

set creation_ip_address [ns_conn peeraddr]

if { $priviledge == "Post" } {
    set approval_state "approved"
    set approval_user $db_user_id
    set approval_ip_address $creation_ip_address

    set status_str "Your submission will be published on [util_AnsiDatetoPrettyDate $release_date]."
    set notify_admin_p "f"
} elseif { $priviledge == "Suggest" } {
    set approval_state "unexamined"
    set approval_user [db_null]
    set approval_ip_address [db_null]

    set status_str "Your submission will be reviewed by the News administrator. Upon approval, it will be published on [util_AnsiDatetoPrettyDate $release_date]."

    set notify_admin_p [db_string notify_admin_check " 
    select notify_admin_p
    from newsgroups
    where newsgroup_id = :newsgroup_id"]

} else {
    db_release_unused_handles
    ad_return_error "Error" "Sorry, you are not authorized to view this page."
    return
}

set insert_sql "insert into news_items
        ( news_item_id
        , newsgroup_id
        , title
        , subtitle
        , body
        , html_p
        , approval_state
        , approval_date
        , approval_user
        , approval_ip_address
        , release_date
        , expiration_date
        , creation_date
        , creation_user
        , creation_ip_address
        )
        values (:news_item_id
        , :newsgroup_id
        , :title
        , :subtitle
        , empty_clob()
        , :html_p
        , :approval_state
        , sysdate
        , :approval_user
        , :approval_ip_address
        , to_date(:release_date)
        , to_date(:expiration_date)
        , sysdate
        , :db_user_id
        , :creation_ip_address
        )
        returning body into :1"

if [catch {db_dml item_insert_with_clob "$insert_sql" -clobs [list $body]} errmsg] {
    # check double click
    if { ![db_string count_select "select count(*) from news_items
    where news_item_id = :news_item_id"] } {
	ns_log Error "/news/post-new-3 choked:  $errmsg"
	ad_return_error "Insert Failed" "Here's what the database said:
	<blockquote>
	<pre>
	$errmsg
	</pre>
	</blockquote>"
	return
    }
}

set page_content "
[ad_header "Thank you"]
<h2>Thank you for posting</h2>
[ad_context_bar_ws [list "/news/" "News"] "Thank you for submission"]

<hr>
<blockquote>
<h2>Thank you</h2>
$status_str
"

if { ![empty_string_p $return_url] } {
    append page_content "
    <p>
    Return to <a href=$return_url>where you were</a>.
    "
} else {
    append page_content "
    <p>
    Return to <a href=/news>News</a> main page.
    "
}

append page_content "
</blockquote>
[ad_footer]
"

doc_return  200 text/html $page_content

# send email to admin if necessary
if { $approval_state != "approved" && $notify_admin_p == "t" } {

    db_0or1row userinfo "
    select first_names || ' ' || last_name as user_name, 
    email as user_email
    from users
    where user_id = :user_id"

    if [empty_string_p $user_name] {
	set user_name "unregistered"
    } else {
	set user_name "$user_name ($user_email)"
    }

    set newsgroup_name [db_string ng_name_sel "
    select nvl(group_name, scope) as newsgroup_name
    from newsgroups ng, user_groups ug
    where ng.group_id = ug.group_id(+)
    and ng.newsgroup_id = :newsgroup_id"]

    set email_title "A news item has been submitted to newsgroup 
    $newsgroup_name"

    set email_msg "
    Hi,

    User $user_name has submitted an item to newsgroup
    $newsgroup_name. Please visit page:

    [ad_parameter SystemUrl]/news/admin to evaluate and approve/reject it.

    Thanks.

    -- News Wizard
    "

    # Get admin list of the newsgroup
    set admin_list [news_get_admins $newsgroup_id]
    
    foreach admin_id $admin_list {
	db_1row admin_info "select email
	from users where user_id = :admin_id"

	if [catch {ns_sendmail $email "[ad_system_owner]" \
                $email_title $email_msg} errmsg ] {
            ns_log Notice $errmsg
        }

    }
	
}

