# /packages/education/fs-procs.tcl
#
# Procs to produce portals dealing with documents stored in file-storage.
# Created during a break-up of education-portal-procs.tcl
#
# Caroline@arsdigita.com, July 18, 2000
# Tarik Alatovic <tarik@alatovic.com>
#
# $Id: portals-file-storage-procs.tcl,v 1.25 2001/02/06 08:28:27 tarik Exp $

ad_library {
    Procs to produce portals dealing with documents stored in file-storage.

    @creation-date July 2000
    @author basel@arsdigita.com
    @author Caroline Meeks (caroline@arsdigita.com)
    @author Ian Baker (ibaker@arsdigita.com)
    @cvs-id $Id: portals-file-storage-procs.tcl,v 1.25 2001/02/06 08:28:27 tarik Exp $
}

ad_proc portals_fs_check_edit_p {user_id version_id {group_id ""}} {Returns 1 if the user has permission to edit the version of the file; 0 otherwise} {

    return [portals_fs_check_write_p $user_id $version_id $group_id]

}

proc_doc portals_fs_check_read_p {user_id version_id {group_id ""}} {Returns 1 if the user can read the version of the file; 0 otherwise.} {
    # see if the user is the owner.  If not, see if the user has permission
    if {[db_string read_permission_check "select count(fs_files.file_id) 
                                          from fs_files, fs_versions_latest 
                                          where fs_files.file_id = fs_versions_latest.file_id 
                                          and fs_files.owner_id = :user_id and version_id = :version_id"] > 0} {
	return 1
    } else {
	return [ad_user_has_permission_p $user_id "read" $version_id "FS_VERSIONS"]
    }
}

ad_proc portals_fs_check_write_p {user_id version_id {group_id ""}} {Returns 1 if the user can write the file; 0 otherwise.} {

    db_1row file_info_get \
        "select fsf.file_id, NVL(group_id, 0) as group_id
         from fs_versions_latest fsvl, fs_files fsf
         where version_id = :version_id
         and fsf.file_id = fsvl.file_id"

    # see if the user is the owner.  If not, see if the user has permission
    if { [db_string permission_check \
            "select count(*) from fs_files 
    where fs_files.file_id = :file_id 
    and fs_files.owner_id = :user_id"] > 0} {
	
	return 1
	
    } elseif {$group_id && [ad_user_group_authorized_admin_or_site_admin $user_id $group_id]} {

	return 1

    } else {

        return [ad_user_has_row_permission_p $user_id "write" $version_id "FS_VERSIONS"]
    }
}

ad_proc -private portals_fs_header_row_for_files { 
    {
	-title {}
	-author_p 0
    }
} {
    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date January 11, 2001
    taken and modified from /tcl/file-storage-defs.tcl (fs_header_row_for_files)
    interface significantly changed for education module

    Returns a table header row containing column names appropriate for
    a listing of files alone (i.e., not versions of files).  Name, Size,
    Type, Modified.

    If you set author_p to 1, you'll additionally get an author column.
} {
    set colspan 5
    if { $author_p } {
	incr colspan
    }

    set font "[ad_parameter FileInfoDisplayFontTag fs]"
    set header_color [ad_parameter HeaderColor fs]
    if { ![empty_string_p $title] } {
	append column_name_header_row "<tr><td colspan=$colspan bgcolor=#666666>
              $font &nbsp;<font color=white> $title
              </td>
          </tr>\n"
    }
    append column_name_header_row  "<tr><td bgcolor=$header_color>$font &nbsp;Name</td>
          <td bgcolor=$header_color align=left>$font &nbsp;Info&nbsp;</td>"

 
#    if { $author_p } {
#	append column_name_header_row "
#          <td bgcolor=$header_color align=left>$font &nbsp;Author&nbsp;</td>"
#    }
#    append column_name_header_row "
#          <td bgcolor=$header_color>$font &nbsp;Size&nbsp;</td>
#          <td bgcolor=$header_color>$font &nbsp;Type&nbsp;</td>"

     append column_name_header_row "
          <td bgcolor=$header_color width=40>$font &nbsp;Modified&nbsp;</td>
      </tr>
    "
    return $column_name_header_row
}

ad_proc -private portals_fs_row_for_one_file {
    {
	-n_pixels_in 0
	-file_id {}
	-folder_p f
	-folder_action {}
	-num_files {}
	-new_files {-1}
	-old_item_p {1}
	-client_file_name {}
	-n_kbytes {}
	-n_bytes {}
	-file_title {}
	-file_type {}
	-url {}
	-creation_date {}
	-version_id {}

	-links 1

	-author_p 0
	-owner_id 0
	-owner_name {}
	-user_url {/shared/community-member}

	-export_url_vars {}
	-folder_url {/file-storage/one-folder}
	-file_url {/file-storage/one-file}
    }
} { 
    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date January 11, 2001
    taken and modified from /tcl/file-storage-defs.tcl (fs_row_for_one_file)
    interface significantly changed for education module

    Returns one row of a HTML table displaying all the information about a file.
    Set links to 0 if you want this file to be output without links to manage it 
    (to display the folder you're currently in). 
  <p>   The first bunch of arguments are all standard stuff we want to
    know about the file. The n_pixels_in is the number of pixels you want this line 
    indented.
  <p>   links:  used for one-folder, which likes to show the current folder first, 
    without the hyperlinks. Set this to 0 if you don't want links from an entry 
   (only works for folders).
  <p>  export_url_vars: set this to the vars you want exported when a
    file or folder link is clicked. It should be a query string
    fragment. If you're unhappy with the default urls 'one-folder' or
    'one-file' (say, you're implementing admin pages where they're
    named differently), change them here. The export_url_vars will be
    appended.
} {
    set font "<font face=arial,helvetica size=-1>"
    set gifalign "align=middle"
    set header_color [ad_parameter HeaderColor fs]
    regsub " " $creation_date {\&nbsp;} creation_date_html
    regsub " " $file_title {\&nbsp;} file_title_html
  

    if { $n_pixels_in == 0 } {
	set spacer_gif ""    } else {
	set spacer_gif "<img src=\"/graphics/file-storage/spacer.gif\" width=$n_pixels_in height=1>"
    }

    if {$folder_p=="t"} {
        append file_html "<tr><td nowrap>&nbsp; $spacer_gif $font"

	if {$links} {append file_html "<a href=\"javascript:invokeAction($folder_action,$file_id);\">"}

	if ![string compare $folder_action "'expand'"] {
	    append file_html "<img border=0 src=/graphics/file-storage/ftv2folderclosed.gif $gifalign>"
	} elseif ![string compare $folder_action "'collapse'"] {
	    append file_html "<img border=0 src=/graphics/file-storage/ftv2folderopen.gif $gifalign>"
	}
	
	if {$links} { append file_html "</a>" }

        append file_html $file_title_html

	if {$num_files > 0} {
	    append file_html "
	    - $num_files file"
	    if {$num_files != 1} {
		append file_html "s"
	    }
	    if {$new_files >= 0} {
		append file_html ", $new_files new"
	    }
	}

	append file_html "
	</td>
	<td valign=top align=left>\[<a href=\"$folder_url?$export_url_vars\">Info</a>\]</td>
	<td>&nbsp;</td>
       </tr>\n"

    } elseif {[empty_string_p $n_bytes]} {

        append file_html "
	<tr>
	<td nowrap>&nbsp; $spacer_gif $font
	<a href=\"$url\"><img border=0 src=/graphics/file-storage/ftv2doc.gif $gifalign></a>
	<a href=\"$url\">$file_title_html</a>"
	
	if {$old_item_p < 0} {
	    append file_html " - new"
	}
	
	append file_html "&nbsp;</td> <td valign=top align=left>\[<a href=\"$file_url?$export_url_vars\">Info</a>\]</td>"
	    

        append file_html "
	<td valign=top>$font &nbsp;$creation_date_html&nbsp;</td>
	</tr>\n"

    } else {

        regexp {.*\\([^\\]+)} $client_file_name match client_file_name
	regsub -all {[^-_.0-9a-zA-Z]+} $client_file_name "_" pretty_file_name

        append file_html "
	<tr>
	<td nowrap>&nbsp; $spacer_gif $font
	<a href=\"/file-storage/download/$version_id/$pretty_file_name\"><img border=0 src=/graphics/file-storage/ftv2doc.gif $gifalign></a>
	<a href=\"/file-storage/download/$version_id/$pretty_file_name\">$file_title_html</a>"
	
	if {$old_item_p < 0} {

	    append file_html " - new"
	}
	
	append file_html "&nbsp;</td>
	<td valign=top align=left>$font \[<a href=\"$file_url?$export_url_vars\">Info</a>\]</td>
	<td valign=top>$font &nbsp;$creation_date_html&nbsp;</td>
	</tr>\n"
    }
    
    return $file_html
}

ad_proc portals_fs_get_n_past_days { {} } {} {
    if { [catch {uplevel 5 {ad_page_contract {} {{n_past_days:optional,integer -1}}}} errmsg] } {
	set n_past_days -1
    } elseif { [catch {upvar 5 n_past_days n_past_days} errmsg] } {
	set n_past_days -1
    }
    return $n_past_days
}

ad_proc portals_fs_new_items_slider { {} } {} {
    set n_past_days [portals_fs_get_n_past_days]

    set n_days_list [list 1 2 3 7 14 30]
    set slider_list [list]

#    append base_url "[ns_conn url]?"
#    set query [ns_conn query]
    # get rid of all n_past_days in url query data
#    regsub -all {&n_past_days=[^&]*} $query "" query
#    regsub -all {n_past_days=[^&]*} $query "" query
#    if ![empty_string_p $query] {
#	append base_url "$query&"
#    } 

    foreach n_days $n_days_list {
	if { $n_days == $n_past_days } {
	    lappend slider_list "<b>$n_days</b>" 
	} else {
	    lappend slider_list "<a href=\"javascript:markNewItems($n_days);\">$n_days</a>"
	}
    }

    append return_string "Mark files in last ([join $slider_list " | "]) days as new"
    if {$n_past_days > 0} {
	append return_string " | <a href=\"javascript:markNewItems(-1);\">Unmark all</a>"
    }

return $return_string
}

ad_proc portals_fs_folder_selection {user_id {group_id ""}  {public_p ""} {file_id ""}} {
    Write out th\e SELECT box that allows the user to move a file to another folder

    @author Eric J. Cholankeril
    @creation-date January 16, 2001

    (modified specifically for portals, so that if a group_id is provided, the top_level option doesn't show up)
} {
    portals_fs_folder_def_selection $user_id $group_id $public_p $file_id
}

ad_proc portals_fs_folder_def_selection {
    user_id
    {group_id ""}
    {public_p ""}
    {file_id ""}
    {folder_default ""}
} {
    @author Eric J. Cholankeril
    @creation-date January 16, 2001

    (modified specifically for portals, so that if a group_id is provided, the top_level option doesn't show up)
    Write out the SELECT box that allows the user to move a file to
    another folder, or - if folder_default is provided - create a new
    folder.
} {
    # Get the current location of the file (ie parent_id).
    if {![empty_string_p $file_id]} {
	set current_parent_id [db_string parent_get "select parent_id from fs_files where file_id=:file_id"]
	
	# We don't want to display any folders which are children
	# of the selected file, so use this clause to block them.
	set children_clause "and fs_files_tree.file_id not in (select file_id
	from fs_files
        where file_id != :file_id
	connect by prior file_id = parent_id
	start with file_id = :file_id)"
    } else {
	set current_parent_id ""
	set children_clause ""
    }

    if { [info exists group_id] && ![empty_string_p $group_id] && $public_p != "t"} {    

	set sql_query "select file_title as folder, fs_files_tree.file_id as new_parent,
	lpad('x',(the_level-1),'x') as spaces, NVL(parent_id,'') as parent_id
	from   fs_files_tree
	where  folder_p='t'
        and    (public_p <> 't' or public_p is null) 
        and    group_id = :group_id
	and    deleted_p = 'f' 
	$children_clause"

	set group_name [db_string group_name_get "select group_name from user_groups where group_id=:group_id"]
	set top_level ""

    } elseif {[info exists public_p] && $public_p == "t"}  {

	set sql_query "select file_title as folder, fs_files_tree.file_id as new_parent,
	lpad('x',the_level,'x') as spaces, NVL(parent_id,'') as parent_id
	from   fs_files_tree
	where folder_p='t'
	and owner_id = :user_id
        and public_p = 't' 
        and group_id is null
	and deleted_p = 'f' 
	$children_clause"

	set top_level "Shared user tree"
    } else {

	set sql_query "select file_title as folder, fs_files_tree.file_id as new_parent,
	lpad('x',the_level,'x') as spaces, NVL(parent_id,'') as parent_id
	from   fs_files_tree
	where folder_p='t'
	and owner_id = :user_id
        and public_p = 'f' 
        and group_id is null
	and deleted_p = 'f' 
	$children_clause"

	set top_level "Private user tree"

    }
    
    if ![empty_string_p $top_level] {
	if {[empty_string_p $current_parent_id] && [empty_string_p $folder_default]} {
	    set file_options "<option value=\"\" selected> $top_level </option>\n"
	} else {
	    set file_options "<option value=\"\" > $top_level </option>\n"
	}
    }
    set folder_count 0
    db_foreach file_list $sql_query {
	regsub -all x $spaces {\&nbsp;\&nbsp;} spaces

	incr folder_count
	if  { $current_parent_id == $new_parent && [empty_string_p $folder_default]} {
	    append file_options "<option value=$new_parent selected>$spaces $folder</option>\n"
	} elseif { $folder_default == $new_parent } {
	    append file_options "<option value=$new_parent selected>$spaces $folder</option>\n"
	} elseif {[info exists group_id] && ![empty_string_p $group_id] && $public_p != "t" && [empty_string_p $parent_id]} {
	    append file_options "<option value=$new_parent selected>$spaces $folder</option>\n"
	} else {
	    append file_options "<option value=$new_parent >$spaces $folder</option>\n"
	}
    }

    # if there are still no options available, this means that this is a group, and there are no folders available
    # (meaning that any folders have been deleted, or someone forgot to create them)
    if {![info exists file_options] || [empty_string_p $file_options]} {
	set file_options "<option value=\"\" selected> $group_name group tree</option>\n"
    }

    if { $folder_count > 8 } { 
	set size_count 8
    } else {
	set size_count [expr $folder_count +1]
    }
    set file_options_list "
    <select size=$size_count name=parent_id>
    $file_options
    </select>
    "

    return $file_options_list
}

ad_proc portals_fs_folder_box {user_id topmost_option} "Returns the folder box.
Arguments: user_id         the user who is logged in
           topmost_option  the option that should occur on top" {
    set options [nub [concat [list $topmost_option [fs_private_individual_option]] \
			  [ad_decode [fs_shared_option] "" [list] [list [fs_shared_option]]] \
			  [list [fs_public_option]] \
			  [fs_group_folders $user_id] \
			  [fs_private_folders $user_id]]]
    return "
    <form action=/file-storage/group>
    [ad_parameter FileInfoDisplayFontTag fs] 
    Go to 
    <select name=group_id>

    [join $options \n]

    </select> 
    <input type=submit value=go>
    </form>"
       }

ad_proc -public portals_file_storage_portlet {} {
    Interface between portals and file-storage.
    Display information about the current user/group's stored files.

    @creation-date July 2000
    @author basel@arsdigita.com
    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @cvs-id $Id: portals-file-storage-procs.tcl,v 1.25 2001/02/06 08:28:27 tarik Exp $
} {
    set return_url [ns_conn url]

    set user_id [ad_verify_and_get_user_id]

    if { [catch {uplevel 5 {ad_page_contract {} {{user_action:optional ""}}}} errmsg] } {
	set user_action ""
    } elseif { [catch {upvar 5 user_action user_action} errmsg] } {
	set user_action ""
    }   

    if { [catch {uplevel 5 {ad_page_contract {} {{folder_id_to_change:optional,integer -1}}}} errmsg] } {
	set folder_id_to_change -1
    } elseif { [catch {upvar 5 folder_id_to_change folder_id_to_change} errmsg] } {
	set folder_id_to_change -1
    }

    if { [catch {uplevel 5 {ad_page_contract {} {{state:optional [list]}}}} errmsg] } {
	set state [list]
    } elseif { [catch {upvar 5 state state} errmsg] } {
	set state [list]
    }

    # if this is a group, default to showing root folder plus *immediate* subfolders/files
    if {![string compare [portals_info type] group] && [empty_string_p $state]} {
	set group_id [portals_info group_id]
	if ![set root_folder_id [portals_fs_group_root_folder $group_id]] {
	    set state [db_list get_root_folder_ids "select file_id from fs_files where parent_id is null and group_id = :group_id and folder_p = 't'"]
	} else {
	    set state [list $root_folder_id]
	}
    }

    if {[info exists user_action] && [info exists folder_id_to_change] && $folder_id_to_change!=-1} {

	if ![string compare $user_action expand] {

	    lappend state $folder_id_to_change

	} elseif ![string compare $user_action collapse] {

	    # remove folder from list of expanded folders
	    set state_folder_location [lsearch -exact $state $folder_id_to_change]
	    if {$state_folder_location != -1} {
		set state [lreplace $state $state_folder_location $state_folder_location]
	    }	    
	    
	    # remove all subfolders from list of expanded folders
	    db_foreach remove_all_subfolders_from_state {
		select file_id from fs_files
		where folder_p = 't'
		connect by prior file_id = parent_id
		start with parent_id = :folder_id_to_change
	    } {
		set state_folder_location [lsearch -exact $state $file_id]
		if {$state_folder_location != -1} {
		    set state [lreplace $state $state_folder_location $state_folder_location]
		}
	    }
	}
    }

    if {[llength $state] == 1} {
	set state_sql_clause "and (fsf.parent_id = $state or fsf.parent_id is null"
    } elseif {![empty_string_p [join $state ""]]} {
	#if state is not empty, show all files with parents in state
	set state_sql_clause "and (fsf.parent_id in ([join $state ","]) or fsf.parent_id is null"
    } else {
	set state_sql_clause "and (fsf.parent_id is null"
    }

    if {![string compare [portals_info type] group] && [set group_id [portals_info group_id]] && [set root_folder_id [portals_fs_group_root_folder $group_id]]} {
	append state_sql_clause " or fsf.file_id = $root_folder_id"
    }

    append state_sql_clause ")"

    set page_content "
    <script language=\"JavaScript\">

    function invokeAction(action, folder_id) {
	form = window.document.forms\['folderActions'\];
 	form.user_action.value = action;
	form.folder_id_to_change.value = folder_id;
	form.submit();
 	return false;
    }

    function markNewItems(n_past_days) {
	form = window.document.forms\['folderActions'\];
	form.n_past_days.value = n_past_days;
	form.submit();
	return false;
    }

    function switchPersonalDocuments(action) {
	form = window.document.forms\['folderActions'\];
 	form.personal_action.value = action;
	form.submit();
 	return false;
    }

    function userCloseAllFolders() {
	form = window.document.forms\['folderActions'\];
	form.personal_action.value = 'collapse';
	form.state.value = '';
	form.submit();
	return false;
    }

    </script>
    "

    set num_select_clause "(select count(file_id)
    from fs_files fsf2
    where fsf2.folder_p(+) = 'f'
    and   fsf2.deleted_p(+) = 'f'
    and   (owner_id = :user_id
    or exists (select 1 from user_group_map ugm2
                  where fsf2.group_id = ugm2.group_id
                  and ugm2.user_id = :user_id))
    connect by prior fsf2.file_id = fsf2.parent_id
    start with fsf2.parent_id = fsf.file_id) as num_files"

    set n_past_days [portals_fs_get_n_past_days]


    # set default values if no files are to be marked as new
    set new_select_clause ""
    # no new files
    set new_files -1
    # everything is old
    set old_item_p 1

    # if new items slider not set to "all", then set appropriate parts of query
    if {$n_past_days > 0} {

	append new_select_clause "(select count(file_id)
	from fs_files fsf3
	where fsf3.folder_p(+) = 'f'
	and   fsf3.deleted_p(+) = 'f'
	and   exists (select 1 from fs_versions_latest fsvl3
	              where fsf3.file_id = fsvl3.file_id
	              and fsvl3.creation_date >= sysdate - $n_past_days)
	and   (owner_id = :user_id
	or exists (select 1 from user_group_map ugm3
                  where fsf3.group_id = ugm3.group_id
                  and ugm3.user_id = :user_id))
	connect by prior fsf3.file_id = fsf3.parent_id
	start with fsf3.parent_id = fsf.file_id) as new_files,
	sysdate - $n_past_days - fsvl.creation_date as old_item_p,"
    }

#	and ad_general_permissions.user_has_row_permission_p (:user_id, 'read', fsvl3.version_id(+), 'fs_versions') = 't'

    if {[portals_info type] =="group" } {
    
	#group portal
	set group_id [portals_info group_id]
	if { ![ad_user_group_member $group_id $user_id]&&![ad_user_group_authorized_admin_or_site_admin $user_id $group_id] } {
	    ad_return_error "Unauthorized" "You're not a member of this group"
	    return
	}

	set current_group_id $group_id
	set current_group_name [db_string dummy "select group_name from user_groups where group_id=$group_id"]


	set title "$current_group_name's group document tree"
	
	append page_content  "
	<script runat=client>
	function launch_window(file) {
	    window.open(file,'files','toolbar=no,location=no,directories=no,status=no,scrollbars=auto,resizable=yes,copyhistory=no,width=450,height=250')
	}
	</script>
    
	<ul>"

	if [ad_user_group_authorized_admin_or_site_admin $user_id $group_id] {
	    append controls_html_left  "
	    <li><a href=/file-storage/upload-new?[export_url_vars return_url group_id]>
	    Upload a new file</a> to this group
	    <li><a href=/file-storage/create-folder?[export_url_vars return_url group_id]>
	    Create New Folder</a> (for storing group files)"
	}

	# only the user portal needs the option to close all folders;
	# in the group portal, there is just one top level folder, so users can just click on that
	append controls_html_right "
	<li>[portals_fs_new_items_slider]
	<li>
	<form action=/file-storage/search method=post>
	"
    
	if { [ad_parameter UseIntermediaP fs 0] } {
	    append controls_html_right "Search file names and contents for: "
	} else {
	    append controls_html_right "Search file names for: "
	}
    
	append controls_html_right "<input name=search_text type=text size=20>[export_form_vars return_url group_id]<input type=submit value=Search></form>
	"

	if ![info exists controls_html_left] {
	    append page_content "
	    <ul>$controls_html_right</ul>
	    <blockquote>"
	} else {
	    append page_content "
	    <table bgcolor=white cellspacing=1 border=0 cellpadding=0>
	    <tr>
	    <td valign=top><ul>$controls_html_left</ul></td>
	    <td valign=top><ul>$controls_html_right</ul></td>
	    </tr>
	    </table>
	    <blockquote>"
	}
    
	# get the group's files from the database and parse the output 
	# to reflect the folder stucture

	set sorted_query "
	select /*+ RULE */ fsf.file_id,
	fsf.file_title,
	fsf.folder_p,
	fsf.depth * 24 as n_pixels_in,
	fsvl.n_bytes,
	to_char ( fsvl.creation_date, '[fs_date_picture]' ) as creation_date,
	   nvl ( fsvl.file_type, upper ( fsvl.file_extension ) || ' File' ) as file_type,
           fsf.sort_key,
           fsvl.version_id,
           fsvl.client_file_name, 
           fsvl.url,
           $new_select_clause
	   $num_select_clause
    from   fs_files fsf,
           fs_versions_latest fsvl
    where  fsf.file_id = fsvl.file_id
    and    fsf.deleted_p = 'f'
    and    fsf.group_id = :group_id
	   $state_sql_clause
    order by fsf.sort_key, fsf.folder_p desc, LOWER(fsf.file_title), fsvl.creation_date desc"

#    and    ad_general_permissions.user_has_row_permission_p (:user_id, 'read', fsvl.version_id, 'fs_versions') = 't'
            
	set file_html ""
	set file_count 0
	
	set font "[ad_parameter FileInfoDisplayFontTag fs]"
	set header_color [ad_parameter HeaderColor fs]
	
	append page_content "

	<form name=folderActions method=post action=\"$return_url\">

	<table border=0 bgcolor=white  cellpadding=0 cellspacing=0>
	<tr>
	<td><table bgcolor=white cellspacing=1 border=0 cellpadding=0>
	[portals_fs_header_row_for_files -title "$current_group_name's group document tree" -author_p 1]
	" 
    
	db_foreach dummy $sorted_query {
	    if ![string compare $folder_p "t"] {
		if {[lsearch $state $file_id] == -1} {
		    set folder_action "'expand'"
		} else {
		    set folder_action "'collapse'"
		}
	    } else {
		set folder_action ""
	    }

	    append file_html [portals_fs_row_for_one_file -n_pixels_in $n_pixels_in \
		    -file_id $file_id \
		    -folder_p $folder_p -client_file_name $client_file_name \
		    -folder_action $folder_action \
		    -num_files $num_files \
		    -new_files $new_files \
		    -old_item_p $old_item_p \
		    -file_title $file_title -url $url -creation_date $creation_date \
		    -n_bytes $n_bytes \
		    -version_id $version_id -file_type $file_type \
		    -file_url "/file-storage/one-file" \
		    -folder_url "/file-storage/one-folder" \
		    -export_url_vars "[export_url_vars file_id group_id return_url]&source=private_group"]
	    
	    incr file_count
	}


	# get any files of subgroups for this group as well

	set sorted_query "
	select /*+ RULE */ fsf.file_id,
	fsf.file_title,
	fsf.folder_p,
	fsf.depth * 24 as n_pixels_in,
	fsvl.n_bytes,
	to_char ( fsvl.creation_date, '[fs_date_picture]' ) as creation_date,
	   nvl ( fsvl.file_type, upper ( fsvl.file_extension ) || ' File' ) as file_type,
           fsf.sort_key,
           fsvl.version_id,
           fsvl.client_file_name, 
           fsvl.url,
	   $new_select_clause
	$num_select_clause
    from   fs_files fsf,
           fs_versions_latest fsvl,
	   user_groups ug,
	   user_group_map ugm
    where  fsf.file_id = fsvl.file_id
    and    fsf.deleted_p = 'f'
    and    fsf.group_id = ug.group_id
    and    ug.parent_group_id = :group_id
    and    ugm.group_id = ug.group_id
    and    ugm.user_id = :user_id
	   $state_sql_clause
           order by fsf.sort_key, fsf.folder_p desc, LOWER(fsf.file_title), fsvl.creation_date desc"

#    and    ad_general_permissions.user_has_row_permission_p (:user_id, 'read', fsvl.version_id, 'fs_versions') = 't'
            
	db_foreach dummy $sorted_query {
	    if ![string compare $folder_p "t"] {
		if {[lsearch $state $file_id] == -1} {
		    set folder_action "'expand'"
		} else {
		    set folder_action "'collapse'"
		}
	    } else {
		set folder_action ""
	    }

	    append file_html [portals_fs_row_for_one_file -n_pixels_in $n_pixels_in \
		    -file_id $file_id \
		    -folder_p $folder_p -client_file_name $client_file_name \
		    -folder_action $folder_action \
		    -num_files $num_files \
		    -new_files $new_files \
		    -old_item_p $old_item_p \
		    -file_title $file_title -url $url -creation_date $creation_date \
		    -n_bytes $n_bytes \
		    -version_id $version_id -file_type $file_type \
		    -file_url "/file-storage/one-file" \
		    -folder_url "/file-storage/one-folder" \
		    -export_url_vars "[export_url_vars file_id group_id return_url]&source=private_group"]
	    
	    incr file_count
	}
    
	if {$file_count!=0} {
	
	    append page_content $file_html
	
	} else {
	
	    append page_content "
	    <tr>
	    <td>&nbsp; No files available in this group. &nbsp;</td>
	    </tr>"
	    
	}
    
	append page_content "
	</td></tr></table></td></tr></table>
    <input type=hidden name=user_action value=\"\">
    <input type=hidden name=folder_id_to_change value=\"\">
    [export_form_vars n_past_days state]
	</form>
	</blockquote>
	
	This system lets you keep your files on [ad_system_name],
	access them from any computer connected to the internet, and
	collaborate with others on file creation and modification.
	"
	
	
	return $page_content
    }   else { 
    #user portal
    
	set cookies [get_cookie_set]
	set folders_open_p [ns_set get $cookies folders_open_p]
	if [empty_string_p $folders_open_p] {
	    set folders_open_p 1
	}
     
	if { [catch {uplevel 5 {ad_page_contract {} {{personal_action expand}}}} errmsg] } {
	    set personal_action expand
	} elseif { [catch {upvar 5 personal_action personal_action} errmsg] } {
	    set personal_action expand
	}

	set name_query "select first_names||' '||last_name as name 
	from   users 
	where  user_id = :user_id"
    
	set name [db_string dummy $name_query]
    
	set title "$name's document tree"
	
	set public_p "f"
	
	append controls_html_left  "
	<li><a href=/file-storage/upload-new?[export_url_vars return_url public_p]>Add a URL / Upload a new file</a>
	<li><a href=/file-storage/create-folder?[export_url_vars return_url public_p]>Create New Folder</a> (for storing personal files)
	"
	
	# only the user portal needs the option to close all folders;
	# in the group portal, there is just one top level folder, so users can just click on that
	append controls_html_right "
	<li><a href=\"javascript:userCloseAllFolders();\">Close all folders</a>
	<li>[portals_fs_new_items_slider]
	<li>
	<form action=/file-storage/search method=post>
	"
    
	if { [ad_parameter UseIntermediaP fs 0] } {
	    append controls_html_right "Search file names and contents for: "
	} else {
	    append controls_html_right "Search file names for: "
	}
    
	append controls_html_right "<input name=search_text type=text size=20>[export_form_vars return_url]<input type=submit value=Search></form>
	"

	append page_content "
	<table bgcolor=white cellspacing=1 border=0 cellpadding=0>
	<tr>
	<td valign=top><ul>$controls_html_left</ul></td>
	<td valign=top><ul>$controls_html_right</ul></td>
	</tr>
	</table>
	<blockquote>"
    
	# get the user's files from the database and parse the output to 
	# reflect the folder stucture
	

	set sorted_query "select /*+ RULE */ fsf.file_id,
	fsf.file_title,
	fsf.folder_p,
	(fsf.depth + 1) * 24 as n_pixels_in,
	fsvl.n_bytes,
	to_char ( fsvl.creation_date, '[fs_date_picture]' ) as creation_date,
	   nvl ( fsvl.file_type, upper ( fsvl.file_extension ) || ' File' ) as file_type,
           fsvl.version_id,
           fsvl.client_file_name, 
           fsvl.url,
	   $new_select_clause
	$num_select_clause
    from   fs_files fsf,
           fs_versions_latest fsvl
    where  fsf.file_id = fsvl.file_id
    and    fsf.owner_id = :user_id
    and    fsf.deleted_p = 'f'
    and    fsf.group_id is null
    and    (fsf.public_p = 'f' or fsf.public_p is null)
	   $state_sql_clause
    order by fsf.sort_key, fsf.folder_p desc, LOWER(fsf.file_title), fsvl.creation_date desc"

#    and    ad_general_permissions.user_has_row_permission_p (:user_id, 'read', fsvl.version_id, 'FS_VERSIONS') = 't'

	set file_html ""
	set group_id ""
	set file_count 0
	
	set font "[ad_parameter FileInfoDisplayFontTag fs]"
	
	set header_color [ad_parameter HeaderColor fs]
	
	# we start with an outer table to get little white lines in 
	# between the elements 
    
   	
	append page_content "
	<form name=folderActions method=post action=\"$return_url\">
	<table border=0 bgcolor=white  cellpadding=0 cellspacing=0>
	<tr>
	<td><table bgcolor=white cellspacing=1 border=0 cellpadding=0>
	[portals_fs_header_row_for_files -title "Your personal document tree"]
	"

	append file_html "
	<tr><td>&nbsp; "

	if ![string compare $personal_action collapse] {
	    append file_html "<a href=\"javascript:switchPersonalDocuments('expand');\"><img border=0 src=/graphics/file-storage/ftv2folderclosed.gif align=middle>"
	    append file_html "</a> My Personal Documents
	    </td>
	    <td align=left>&nbsp;</td>
	    <td>&nbsp;</td>
	    </tr>\n"
	} else {
	    append file_html "<a href=\"javascript:switchPersonalDocuments('collapse');\"><img border=0 src=/graphics/file-storage/ftv2folderopen.gif align=middle>"

	    append file_html "</a> My Personal Documents
	    </td>
	    <td align=left>&nbsp;</td>
	    <td>&nbsp;</td>
	    </tr>\n"
	    
	    db_foreach dummy $sorted_query {
		
		if ![string compare $folder_p "t"] {
		    if {[lsearch $state $file_id] == -1} {
			set folder_action "'expand'"
		    } else {
			set folder_action "'collapse'"
		    }
		} else {
		    set folder_action ""
		}
		
		append file_html [portals_fs_row_for_one_file -n_pixels_in $n_pixels_in \
			-file_id $file_id \
			-folder_p $folder_p -client_file_name $client_file_name \
			-folder_action $folder_action \
			-num_files $num_files \
			-new_files $new_files \
			-old_item_p $old_item_p \
			-file_title $file_title -url $url -creation_date $creation_date \
			-n_bytes $n_bytes \
			-version_id $version_id -file_type $file_type \
			-file_url "/file-storage/one-file" \
			-folder_url "/file-storage/one-folder" \
			-export_url_vars "[export_url_vars file_id group_id return_url]&source=private_individual"]
		
		incr file_count
	    }
	    
	}
		
	set sorted_query "
	select /*+ RULE */ fsf.file_id,
	fsf.file_title,
	fsf.folder_p,
	(fsf.depth) * 24 as n_pixels_in,
	n_bytes,
	to_char ( fsvl.creation_date, '[fs_date_picture]' ) as creation_date,
	nvl ( fsvl.file_type, upper ( fsvl.file_extension ) || ' File' ) as file_type,
	fsf.sort_key,
	fsvl.version_id,
	fsvl.client_file_name, 
	fsvl.url,
	$new_select_clause
	$num_select_clause
	from   fs_files fsf,
	fs_versions_latest fsvl,
	user_group_map ugm
	where  fsf.file_id = fsvl.file_id
	and    fsf.deleted_p = 'f'
	and    fsf.group_id = ugm.group_id
	and    ugm.user_id = :user_id
	and    fsf.group_id is not null
	$state_sql_clause
	order by fsf.sort_key, fsf.folder_p desc, LOWER(fsf.file_title), fsvl.creation_date desc"

#--	and    ad_general_permissions.user_has_row_permission_p (:user_id, 'read', fsvl.version_id, 'fs_versions') = 't'
	
	db_foreach dummy $sorted_query {
	    
	    if ![string compare $folder_p "t"] {
		if {[lsearch $state $file_id] == -1} {
		    set folder_action "'expand'"
		} else {
		    set folder_action "'collapse'"
		}
	    } else {
		set folder_action ""
	    }
	    
	    append file_html [portals_fs_row_for_one_file -n_pixels_in $n_pixels_in \
		    -file_id $file_id \
		    -folder_p $folder_p -client_file_name $client_file_name \
		    -folder_action $folder_action \
		    -num_files $num_files \
		    -new_files $new_files \
		    -old_item_p $old_item_p \
		    -file_title $file_title -url $url -creation_date $creation_date \
		    -n_bytes $n_bytes \
		    -version_id $version_id -file_type $file_type \
		    -file_url "/file-storage/one-file" \
		    -folder_url "/file-storage/one-folder" \
		    -export_url_vars "[export_url_vars file_id group_id return_url]&source=private_individual"]
	    
	    incr file_count
	}
	
	
	
	
	if {$file_count!=0} {
	    append page_content $file_html
	} else {
	    append page_content "
	    <tr>
	    <td>You don't have any files stored in the database. </td>
	    </tr>"
	}
    }


    append page_content "
    </td></tr></table></td></tr></table>
    <input type=hidden name=user_action value=\"\">
    <input type=hidden name=folder_id_to_change value=\"\">
    [export_form_vars n_past_days state personal_action]
    </form>
    </blockquote>
    
    This system lets you keep your files on [ad_system_name],
    access them from any computer connected to the internet, and
    collaborate with others on file creation and modification.

    "

    return $page_content
}


ad_proc portals_fs_group_root_folder {
    group_id
} {
    Takes in a group id and returns the root_folder_id if there is one, otherwise returns 0.
    If the root folder has been deleted, this procedure will undelete it.

    @author Eric J. Cholankeril (ejc@arsdigita.com)
    @creation-date January 29, 2000
} {
    db_1row get_group_info {
	select group_type from user_groups
	where group_id = :group_id
    }

    if {[lsearch -exact [list edu_class edu_community edu_subgroup] $group_type] != -1} {

	if [db_0or1row get_class_root_folder "
	select ei.root_folder_id, fsf.deleted_p from [set group_type]_info ei, fs_files fsf
	where fsf.file_id = ei.root_folder_id
	and ei.group_id = :group_id"] {

	    if ![string compare $deleted_p "t"] {
		db_dml switch_deleted_p "
		update fs_files set deleted_p = 'f' where file_id = :root_folder_id"
	    }
	} else {
	    set root_folder_id 0
	}

    } else {
	set root_folder_id 0
    }

    return $root_folder_id
}
