# packages/portals-threaded-bboard/portals-threaded-bboard-procs.tcl
#
# Library for connecting Portals and gc_bboard.

ad_library {
    Library defining the connection between gc_bboard and portals.

    @author Tzu-Mainn Chen (tzumainn@arsdigita.com)
    @author Ian Baker (ibaker@arsdigita.com)
    @cvs-id $Id: portals-threaded-bboard-procs.tcl,v 1.4 2001/02/02 21:48:49 tarik Exp $
}

ad_proc -public gc_bboard_portal_widget {} {
    Display the bboards in a portal portlet.  "New" messages are defined
    here as those posted within one day.
    
    @author Tzu-Mainn Chen (tzumainn@arsdigita.com)
    @cvs-id $Id: portals-threaded-bboard-procs.tcl,v 1.4 2001/02/02 21:48:49 tarik Exp $
} {
    if {[portals_info type]=="group"} {
	set group_id [portals_info group_id]
    } else {
	set group_id 0
    }

    set user_id [ad_verify_and_get_user_id]

    if { $group_id != 0 } {
	set sql_query "
	select topic_id, name, 
          (select count(m.comment_id)
	   from gc_comment_topic_map m, gc_bboard_messages c
           where m.topic_id = gc.topic_id
	   and m.comment_id = c.comment_id
	   and comment_date >= sysdate - 1) as n_messages
	from gc_bboard_topics gc
	where gc.active_p = 't'
	and gc.group_id in (select ug3.group_id
                            from user_groups ug3
                            start with ug3.group_id= :group_id
                            connect by prior ug3.group_id = ug3.parent_group_id)
	and exists (select 1 from user_group_map ugm
                    where ugm.group_id=gc.group_id
                    and ugm.user_id=:user_id)
        order by n_messages desc
	"
	#if [gc_bboard_check_admin $group_id] {
	#    ns_log warning "admin for $group_id"
	#}
    } else {
	set sql_query "
	select topic_id, name, (select count(m.comment_id) 
	                        from gc_comment_topic_map m, gc_bboard_messages c 
                                where m.topic_id = gc.topic_id 
                                and m.comment_id = c.comment_id 
                                and comment_date >= sysdate - 1) as n_messages
        from gc_bboard_topics gc 
        where gc.active_p = 't'
        and gc.group_id in (select group_id
                            from user_group_map
                            where user_id=:user_id)
        order by n_messages desc
	"
    }

    set html_fragment "<ul>"
    set n_topics 0
    db_foreach "message_list_select" $sql_query {
	append html_fragment "<li><a href=\"/threaded-bboard/one-topic.tcl?[export_url_vars topic_id]\">$name</a> ($n_messages new)"
    } if_no_rows {
	append html_fragment "<li><i>No bulletin boards available.</i>"
    }
    append html_fragment "</ul>"

    return "
    $html_fragment
    "
}

ad_proc -public gc_bboard_new_messages_portal_widget {} {
    New messages portal.

    @author Tzu-Mainn Chen (tzumainn@arsdigita.com)
    @cvs-id $Id: portals-threaded-bboard-procs.tcl,v 1.4 2001/02/02 21:48:49 tarik Exp $
} {
    if {[portals_info type]=="group"} {
	set group_id [portals_info group_id]
    } else {
	set group_id 0
    }

    set n_past_days [portals_get_slider "gc_bboard_nmpw" 1]

    set user_id [ad_verify_and_get_user_id]

    set sql_query "
    select gc.topic_id, name, c.comment_id, one_line_item_desc, c.user_id, (first_names || ' ' || last_name) as contributor, gc.group_id
    from (select * from gc_bboard_topics where active_p = 't' and ad_general_permissions.user_has_row_permission_p(:user_id, 'read', topic_id, 'gc_bboard_topics') = 't') gc,
      gc_comment_topic_map m,
      gc_bboard_messages c,
      users u
    where m.topic_id = gc.topic_id
    and m.comment_id = c.comment_id
    and c.user_id = u.user_id
    "

    # if they chose "All" on the slider, leave this clause out.
    if {$n_past_days != 0} {
        append sql_query "and comment_date >= sysdate - :n_past_days\n"
    }

    if { $group_id != 0 } {
	append sql_query "and gc.group_id = :group_id\n"
    }
    
    append sql_query "order by name, comment_date"

    set html_fragment "<ul>"
    set current_topic ""
    set n_topics 0

    db_foreach get_new_bboard_topic $sql_query {	
	incr n_topics
	if { $current_topic != $name } {
	    if { $n_topics > 1 } {
		append html_fragment "</ul>"
	    }
	    set current_topic $name
	    if { ![empty_string_p $group_id] } {
		append html_fragment "<li> <a href=\"[portals_group_url_link $group_id]/\">$name <ul>"
	    } else {
		append html_fragment "<li> $name <ul>"
	    }
	}
	
	append html_fragment "<li><a href=\"/threaded-bboard/one-message.tcl?[export_url_vars topic_id comment_id]\">$one_line_item_desc</a> - <a href=\"/shared/community-member.tcl?[export_url_vars user_id]\">$contributor</a>"
    }
    if { $n_topics == 0 } {
	append html_fragment "<li><i>No new messages.</i>"
    } else {
	append html_fragment
    }
    append html_fragment "</ul>"

    return "
    <b>New Bulletin Board Messages:</b>
    $html_fragment
    <p>
    ([portals_slider "gc_bboard_nmpw" [list 1 2 3 4 5 6 7 14 30 {"All" 0}] 1 ])
    "
}

ad_proc -public gc_bboard_customization_link {} {
    Displays link to add new bulletin board, if the user has permission. 
    
    @creation-date 7/19/2000
    @author ejc@arsdigita.com
    @cvs-id $Id: portals-threaded-bboard-procs.tcl,v 1.4 2001/02/02 21:48:49 tarik Exp $
} {
    set user_id [ad_verify_and_get_user_id]
    if {[portals_info type]=="group"} {
	set group_id [portals_info group_id]
	if [gc_bboard_check_admin $group_id] {
	    return "<a href=\"/threaded-bboard/admin/bboard-add?group_id=$group_id&return_url=[ad_urlencode [ad_conn url]]\"><img src=\"/portals/pics/edit.gif\" border=0 width=14 height=18></a>"
	} else {
	    return ""
	}
    } elseif {[ad_administrator_p $user_id]} {
	return "<a href=\"/threaded-bboard/admin?return_url=[ad_urlencode [ad_conn url]]\"><img src=\"/portals/pics/edit.gif\" border=0 width=14 height=18></a>"	
    } else {
	return ""
    }
}
