--
-- 00-portals-move-old.sql
--
-- When using this package with ACS 3.x, it's necessary to remove
-- the cruft that's left from the portals module that distributes
-- with it.
--
-- As users of the new portals module may likely be using the old
-- portals module, we at least preserve the data.
--
-- It might be good (if possible) to write a procedure for
-- transferring old portal data to the new portals module
-- in the future.
-- Ian Baker <ibaker@arsdigita.com> Fri Sep 22 17:38:04 PDT 2000

declare
  v_old_data_model_p     char(1);
begin
  -- are we using the old data model?  Find out by checking to see if the
  -- portal_pages table has a USER_ID column, since the new data model
  -- doesn't include one.
  select 't'
  into v_old_data_model_p
  from user_tab_columns
  where table_name = 'PORTAL_PAGES' and column_name = 'USER_ID';

  -- The control flow here isn't immediately obvious, but if the above query
  -- fails to return data (which it will in the case that there is no
  -- portal_pages_old table), control is transferred to the 'exception'
  -- section, bypassing the following code.  The if statement isn't really
  -- necessary, but it makes the intention clearer.
  if v_old_data_model_p = 't' then
    -- move tables and stuff.
    execute immediate 'rename portal_tables to portal_tables_old';
    execute immediate 'rename portal_pages to portal_pages_old';
    execute immediate 'rename portal_table_page_map to portal_table_page_map_old';
    execute immediate 'rename portal_tables_audit to portal_tables_audit_old';
    execute immediate 'drop trigger portal_tables_audit_trigger';

    -- There are sequences that are used in inserts to the above tables. 
    -- They don't conflict with anything in the new data model, but we
    -- rename them anyway for clarity.
    execute immediate 'rename portal_table_id_sequence to portal_table_id_sequence_old';
    execute immediate 'rename portal_page_id_sequence to portal_page_id_sequence_old';
    execute immediate 'rename portal_audit_id_sequence to portal_audit_id_sequence_old';

    -- it'll likely be necessary to create a new portable_table_page_map, to
    -- keep group deletes from failing, but that happens in 01-portals.sql
    -- where the new data model is defined.
  end if;
exception
  when no_data_found then null;
end;
/


