--
-- 01-portals-core.sql
--
-- aure@arsdigita.com (October 1999)
-- tarik@alatovic.com (July 2000)
-- crag@arsdigita.com (Septemeber 2000)
-- ibaker@arsdigita.com (Sep/Oct 2000)
-- tarik@alatovic.com (November 2000)
-- $Id: 01-portals-core.sql,v 1.3 2001/01/31 00:52:37 tarik Exp $


create sequence portal_id_sequence;

-- portal domains are used to ensure that portals of the same type or
-- group_type have a consistent look and url_root.
-- there are 2 types of portal domains: user and group.  group portal domains
-- must have an associated group type.

create table portal_domains (
	domain_id		integer
				constraint portal_domains_domain_id_pk primary key, 
	-- every domain is uniquely identified by the domain_name
	domain_name     	varchar(60)
				constraint portal_domains_domain_name_nn not null
				constraint portal_domains_domain_name_un unique,
	type			varchar(20) 
				constraint portal_domains_type_ck check (type in ('user','group'))
				constraint portal_domains_type_nn not null,
	group_type		constraint portal_domains_group_type_fk
				references user_group_types(group_type) on delete cascade,
	-- url_root must be url encoded
	url_root		varchar(200)
		                constraint portal_domains_url_root_un unique
		                constraint portal_domains_url_root_nn not null,
	constraint portal_domains_type_check_ck check ((type='user' and group_type is null) or (type='group' and group_type is not null)),
	constraint portal_domains_unique_un unique(type, group_type)
);

create table portal_domain_hierarchy (
	child_domain_id		constraint portal_domain_hierarchy_cdi_fk references portal_domains on delete cascade,
	parent_domain_id	constraint portal_domain_hierarchy_pdi_fk references portal_domains on delete cascade,
	constraint portal_domain_hierarchy_pk primary key(child_domain_id, parent_domain_id)
);

create table portal_domain_properties (
	-- define data feed that supplies administration page 
	domain_id		constraint portal_domain_props_di_fk 
                                references portal_domains on delete cascade
				constraint portal_domain_props_di_pk 
				primary key,
	portlet_header_color	varchar(20),
	td_header_html		varchar(1000)
);

create table portals (
	portal_id		integer 
	                        constraint portals_portal_id_pk primary key,
	-- we need parent_portal_id for supporting subportals
	parent_portal_id	constraint portals_parent_portal_id_fk references portals on delete cascade,
	-- url_identifier must be url encoded
	url_identifier		varchar(100)
				constraint portals_url_identifier_nn not null,
	default_p		char(1) default 'f'
				constraint portals_default_p_ck check(default_p in ('t', 'f')),
	domain_id		constraint portals_domain_id_fk references portal_domains on delete cascade
				constraint portals_domain_id_nn not null,
	portal_name             varchar(300),
	-- define ownership of the page - either as a group page or individual page
	group_id		constraint portals_group_id_fk references user_groups on delete cascade,
	user_id			constraint portals_user_id_fk references users on delete cascade,
	-- if this is a default portal we store neither user_id nor group_id
	-- if this is a user portal then we store user_id only
	-- it this is a group portal then we store group_id only
	constraint portals_type_check_ck check(((default_p='t') and (user_id is null) and (group_id is null))
                                               or ((default_p='f') and (((user_id is not null) and (group_id is null))
                                                                        or ((group_id is not null) and (user_id is null))))),
	-- within a domain every user can have exactly one portal
	-- within a domain every group can have exactly one portal
	-- within a domain there is at most one default portal 
	constraint portals_portal_unique_un unique(user_id, group_id, domain_id),
	-- url_identifier must be unique within a domain and parent portal
	constraint portals_url_identifier_un unique(domain_id, parent_portal_id, url_identifier)
);

create index portals_parent_portal_id_index on portals(parent_portal_id);
create index portals_group_id_index on portals(group_id);

create table portal_pages (
	page_id			integer 
	                        constraint portal_pages_page_id_pk primary key,
	portal_id		constraint portal_pages_portal_id_fk references portals on delete cascade
				constraint portal_pages_portal_id_nn not null,
	-- page_name may be null, in which case we use "Page #x" instead
        page_name		varchar(300),
	-- page_number determines the order of the page links in the nav bar
	-- the first page_number should be 1. 
        page_number             integer
);
create index portal_pages_portal_id_index on portal_pages(portal_id);

-- portal_portlets are sections of information that will appear as portlets
-- on the portals pages
create table portal_portlets (
	portlet_id		integer 
                                constraint portal_portlets_portlet_id_pk primary key,
	-- portlet content can be either html, adp, or tcl
	content_source_type	varchar(20)
				constraint pp_content_source_type_ck
				check(content_source_type in ('tcl', 'adp', 'html'))
				constraint pp_content_source_type_nn not null,
	content_source		clob
				constraint pp_content_source_nn	not null,
	-- admin_link can be specified by html, adp, or tcl
	admin_link_type		varchar(20) default 'html'
				constraint pp_admin_link_type_ck
				check(admin_link_type in ('tcl', 'adp', 'html'))
				constraint pp_admin_link_type_nn not null,
	admin_link_source	clob
);

-- in this table we store all the predefined_portlets
create table portal_predefined_portlets (
	portlet_id		constraint ppp_portlet_id_fk
				references portal_portlets on delete cascade
				constraint ppp_portlet_id_pk primary key,
	portlet_name		varchar(60)
				constraint ppp_portlet_name_nn not null
				constraint ppp_portlet_name_un unique
);

create table portal_domain_portlets (
	portlet_id              constraint pdp_portlet_id_fk 
				references portal_portlets on delete cascade
				constraint pdp_portlet_id_pk primary key,
	domain_id		constraint pdp_domain_id_fk 
				references portal_domains on delete cascade,
	-- limit to 60 characters so looks okay in UI
	portlet_name    	varchar(60)
				constraint pdp_portlet_name_nn not null,
	-- portlet_name is the unique name of the portlet within a domain
	constraint pdp_portlet_name_un unique(domain_id, portlet_name),
	-- if this domain portlet was created from predefined portlet we want to store the predefined_portlet_id
	-- we need the predefined_portlet_id when editing the portlet, or if we want to update some property of
	-- all domain portlets created from the predefined portlet
	-- if predefined_portlet_id is null, that this portlet is not a predefined portlet
	predefined_portlet_id	constraint pdp_predefined_porltet_id_fk
				references portal_predefined_portlets on delete set null,
	-- if portlet is required, user may not remove it from her customized portal
	required_p		char(1) default 'f'
				constraint portal_portlets_required_p_ck check(required_p in ('t', 'f'))
);

-- mapping between domain and control panel
create table portal_domain_c_panel_map (
	-- every domain can have at most one control panel
	domain_id		constraint pdcpm_domain_id_fk
				references portal_domains on delete cascade
				constraint pdcpm_domain_id_pk primary key,
	portlet_id		constraint pdcpm_portlet_id_fk
				references portal_domain_portlets on delete cascade
);

create table portal_portlet_page_map (
	portlet_id	   	constraint portal_portlet_page_map_ti_fk references portal_portlets on delete cascade
                                constraint portal_portlet_page_map_ti_nn not null,
	page_id			constraint portal_portlet_page_map_pi_fk references portal_pages on delete cascade
                                constraint portal_portlet_page_map_pi_nn not null,
	constraint portal_portlet_pk primary key(portlet_id, page_id),
	-- sort_key and page_side define location of the portlet on the page     	 
	-- this defines an order within this side of this page
	sort_key  	    	integer,
	-- side of the page the portlet will displayed on
	page_side       	char(1) 
                                constraint portal_portlet_page_map_ps_ck check (page_side in ('l','r'))
);
create index portal_portlet_page_map_pi_idx on portal_portlet_page_map(page_id);





















