-- by tarik@alatovic.com (November 2000)
--
-- $Id: 11-portal-api-spec.sql,v 1.2 2001/02/02 21:48:48 tarik Exp $

-- portals portal package contains PL/SQL API for manipulation of portal objects
create or replace package portal
as

-- creates new portal portal object
function create_new (
	v_domain_id		in integer,
	v_default_p		in char default 'f',
	v_portal_name		in varchar default null,
	v_group_id		in integer default null,
	v_user_id		in integer default null,
	v_parent_portal_id	in integer default null,
	v_url_identifier	in varchar default null
)
return integer;

-- deletes portal object identified by v_portal_id
procedure remove (
	v_portal_id		in integer
);

-- returns unique url identifier for a portal
function generate_unique_url_identifier(
	v_domain_id		in integer, 
	v_parent_portal_id	in integer default null,
	v_user_id 		in integer default null,
	v_group_id		in integer default null,
	v_default_p		in char default 'f'
)
return varchar;

function url_identifier_unique_p (
	v_domain_id		in integer, 
	v_parent_portal_id	in integer default null,
	v_url_identifier	in varchar
)
return integer;

-- returns list of portal ancestors for portal identified by portal_id
-- a space is used as separator
function get_portal_ancestor_list (
	v_portal_id		in integer
)
return varchar2;

-- returns base_url for a portal (e.g. /home, /class/15.301, /class/15.301/section/A)
function get_base_url (
	v_portal_id		in integer
)
return varchar2;

-- returns portal_id of portal identified by portal_type (user or group), id (user_id or group_id), and domain_id
function get_portal_id (
	v_portal_type		in varchar,
	v_id			in integer,
	v_domain_id		in integer
)
return integer;

function create_from_default (
	v_portal_type		in varchar,
	v_id			in integer,
	v_domain_id		in integer
)
return integer;

-- sets portal identified by portal_id to default portal configuration
procedure set_to_default_configuration (
	v_portal_id		in integer
);

-- returns 1 if v_url_character is alpha-numeric, or dot(.), dash(-), or underscore(_).
-- otherwise, it return 0.
function valid_url_character_p (
	v_url_character in char
)
return char;

-- transforms group_name to url_identifier
-- all non-valid url characters in group name are converted to dash(-).
-- (validity of url character is assesed using valid_url_character_p function)
-- all upper case letters in group_name will be converted to lower case.
-- since maximum length of url_identifier is 100,
-- the group_name will be trimmed to 95 characters to allow
-- for generation of unique url_identifier.
-- if v_group_name is null, word 'default' will be returned.

function url_identifier_from_group_name (
	v_group_name in varchar
)
return varchar;

end portal;
/
show errors
