-- by tarik@alatovic.com (November 2000)
--
-- $Id: 21-portal-api-body.sql,v 1.4 2001/02/04 23:39:56 tarik Exp $

create or replace package body portal as

-- creates new portal portal object
function create_new (
	v_domain_id		in integer,
	v_default_p		in char default 'f',
	v_portal_name		in varchar default null,
	v_group_id		in integer default null,
	v_user_id		in integer default null,
	v_parent_portal_id	in integer default null,
	v_url_identifier	in varchar default null

)
return integer
is
	v_portal_id		integer;
	v_url_identifier2	portals.url_identifier%TYPE;
begin
	select portal_id_sequence.nextval into v_portal_id from dual;
	
	v_url_identifier2:= v_url_identifier;
	if v_url_identifier2 is null then
		v_url_identifier2:= portal.generate_unique_url_identifier(v_domain_id => v_domain_id, v_parent_portal_id => v_parent_portal_id, v_user_id => v_user_id, v_group_id => v_group_id, v_default_p => v_default_p);
	end if;

	insert into portals
	(portal_id, default_p, domain_id, portal_name, group_id, user_id, parent_portal_id, url_identifier)
	values
	(v_portal_id, v_default_p, v_domain_id, v_portal_name, v_group_id, v_user_id, v_parent_portal_id, v_url_identifier2);
	
	return v_portal_id;
end create_new;

-- deletes portal object identified by v_portal_id
procedure remove (
	v_portal_id		in integer
)
is
begin
	delete from portals where portal_id=v_portal_id;
end remove;

function generate_unique_url_identifier(
	v_domain_id		in integer, 
	v_parent_portal_id	in integer default null,
	v_user_id 		in integer default null,
	v_group_id		in integer default null,
	v_default_p		in char default 'f'
)
return varchar
is
	v_portal_type		varchar(20);
	v_url_identifier_base	portals.url_identifier%TYPE;
	v_url_identifier	portals.url_identifier%TYPE;
	v_url_identifier_number integer;
begin
	if ((v_default_p='t') and (v_user_id is null) and (v_group_id is null)) then
		v_portal_type:='default_portal';
	elsif ((v_default_p='f') and (v_user_id is not null) and (v_group_id is null)) then
		v_portal_type:='user';
	elsif ((v_default_p='f') and (v_group_id is not null) and (v_user_id is null)) then
		v_portal_type:='group';
	else
		raise_application_error(-20000, 'portals.generate_unique_url_identifier: Invalid portal type');
	end if;

	if v_portal_type='default_portal' then
		return 'default-portal';
	end if;

	if v_portal_type='user' then
		-- user portal
		select user_id into v_url_identifier_base
		from users 
		where user_id=v_user_id;
	else
		select portal.url_identifier_from_group_name(group_name) into v_url_identifier_base
		from user_groups
		where group_id=v_group_id;
	end if;

	v_url_identifier_number:=0; 
	v_url_identifier:= v_url_identifier_base;

	while portal.url_identifier_unique_p(v_domain_id, v_parent_portal_id, v_url_identifier)=0 loop
		v_url_identifier_number:= v_url_identifier_number+1;
		v_url_identifier:= v_url_identifier_base || '-' || v_url_identifier_number;
	end loop;
	return v_url_identifier;
end generate_unique_url_identifier;

-- returns 1 if url identifier is unique within its domain and parent portal
-- otherwise, it returns 0
function url_identifier_unique_p (
	v_domain_id		in integer, 
	v_parent_portal_id	in integer default null,
	v_url_identifier	in varchar
)
return integer
is
	v_url_identifier_unique_p	integer;
begin
	begin
		select 0 into v_url_identifier_unique_p from portals
		where domain_id= v_domain_id
		and ((parent_portal_id= v_parent_portal_id) or ((parent_portal_id is null) and (v_parent_portal_id is null)))
		and url_identifier= v_url_identifier;
	exception
		when no_data_found then
			v_url_identifier_unique_p:=1;
	end;
	return v_url_identifier_unique_p;
end url_identifier_unique_p;

-- PDL : portals.get_portal_ancestors_list(portal_id)
-- initialize ancestor_list to empty string
-- initialize current_portal_id to portal_id 
-- while portal identified by current_portal_id has a parent portal
--	store portal_id of parent of current_portal_id into current_portal_id
-- 	append current_portal_id to portal_ancestor list
function get_portal_ancestor_list (
	v_portal_id		in integer
)
return varchar2
is
	v_current_portal_id		integer;
	v_portal_ancestor_list		varchar2(4000);
begin
	v_portal_ancestor_list:='';
	v_current_portal_id:= v_portal_id;

	while v_current_portal_id is not null loop
		begin
			select parent_portal_id into v_current_portal_id
			from portals
			where portal_id=v_current_portal_id;
		exception
			when no_data_found then
				raise_application_error(-20000, 'portals.get_portal_ancestor_list: portal_id ' || v_current_portal_id || ' does not exist');
		end;
		if v_current_portal_id is not null then
			v_portal_ancestor_list:= v_portal_ancestor_list || ' ' || v_current_portal_id;
		end if;
	end loop;
	
	return v_portal_ancestor_list;
end get_portal_ancestor_list;

-- PDL : portals.get_base_url(portal_id)
-- initialize base_url to empty string
-- initialize current_portal_id to portal_id 
-- while portal identified by current_portal_id has a parent portal
--	set current_portal_id to be equal to portal_id of parent of current_portal_id
-- 	append url_root of current_portal_id's domain to base_url
--      append url_identifier of current_portal_id to base_url
-- end while
-- if portal identified by portal_id is user portal
-- 	append url_root of that portal's domain to base_url
-- else if portal identified by portal_is group portal
--	append url_root of that portal's domain to base_url
--      append url_identifier of that portal to base_url
-- else
--      throw error that portal_type is invalid
-- end if
--
function get_base_url (
	v_portal_id		in integer
)
return varchar2
is
	v_current_portal_id	integer;
	v_base_url		varchar2(4000);
	v_url_identifier	portals.url_identifier%TYPE;
	v_url_root		portal_domains.url_root%TYPE;
	v_portal_type		varchar2(20);
begin
	v_base_url:='';
	v_current_portal_id:= v_portal_id;

	while v_current_portal_id is not null loop
		begin
			select parent_portal_id into v_current_portal_id
			from portals
			where portal_id=v_current_portal_id;
		exception
			when no_data_found then
				raise_application_error(-20000, 'portals.get_base_url: portal_id ' || v_current_portal_id || ' does not exist');
		end;
		if v_current_portal_id is not null then
			select p.url_identifier, pd.url_root into v_url_identifier, v_url_root
			from portals p, portal_domains pd
			where p.portal_id= v_current_portal_id
			and p.domain_id= pd.domain_id;

			v_base_url:= '/' || v_url_root || '/' || v_url_identifier || v_base_url;
		end if;
	end loop;

        select decode(default_p, 't', 'default_portal', decode(group_id, null, 'user', 'group')) into v_portal_type
	from portals
	where portal_id= v_portal_id;

	if v_portal_type='default_portal' then
		raise_application_error(-20000, 'portals.get_base_url: default portal doesn''t have a base_url');
	end if;

	select p.url_identifier, pd.url_root into v_url_identifier, v_url_root
	from portals p, portal_domains pd
	where p.portal_id= v_portal_id
	and p.domain_id= pd.domain_id;

	if v_portal_type='user' then
		v_base_url:= v_base_url || '/' || v_url_root;
		return v_base_url;
	end if;

	if v_portal_type='group' then
		v_base_url:= v_base_url || '/' || v_url_root || '/' || v_url_identifier;				
		return v_base_url;
	end if;	
end get_base_url;

-- PDL : portals.get_portal_id(portal_type, id, domain_id)
-- if portal_type is user then
-- 	set user_id to id
-- else if portal_type is group then
--	set group_id to id
-- else
--	throw error :  invalid portal type
-- end if
-- if portal_type is user then
--	if portal identified by user_id and domain_id exists then
--		return portal_id of that portal
--      else
--		create portal from default
--		return portal_id of newly created portal
--	end if
-- else
--	if portal identified by group_id and domain_id exists then
--		return portal_id of that portal
--      else
--		create portal from default
--		return portal_id of newly created portal
--	end if
-- end if
function get_portal_id (
	v_portal_type		in varchar,
	v_id			in integer,
	v_domain_id		in integer
)
return integer
is
	v_user_id		integer;
	v_group_id		integer;
	v_portal_id		integer;
begin
	if v_portal_type='user' then
		v_user_id:= v_id;
	elsif v_portal_type='group' then
		v_group_id:= v_id;
	else
		raise_application_error(-20000, 'portal.get_portal_id: Invalid portal type');
	end if;

	begin
		if v_portal_type='user' then
			select portal_id into v_portal_id
			from portals
			where user_id= v_user_id
			and domain_id= v_domain_id;
		else
			select portal_id into v_portal_id
			from portals
			where group_id= v_group_id
			and domain_id= v_domain_id;
		end if;
		return v_portal_id;
	exception
		when no_data_found then 
			return portal.create_from_default(v_portal_type => v_portal_type, v_id => v_id, v_domain_id => v_domain_id);
	end;
end get_portal_id;

function create_from_default (
	v_portal_type		in varchar,
	v_id			in integer,
	v_domain_id		in integer
)
return integer
is
	v_user_id		integer;
	v_group_id		integer;
	v_portal_id		integer;
	v_domain_type		portal_domains.type%TYPE;
	v_domain_group_type	user_group_types.group_type%TYPE;
	v_group_type		user_group_types.group_type%TYPE;
	v_top_level_domain_p		integer;
	v_parent_domain_id	integer;
	v_parent_domain_type	portal_domains.type%TYPE;
	v_parent_group_id	integer;
	v_parent_group_type	user_group_types.group_type%TYPE;
	v_parent_portal_id	integer;
	v_dummy			integer;

	type CurType is ref cursor;
	c1 CurType;
begin
	if v_portal_type='user' then
		v_user_id:= v_id;
	elsif v_portal_type='group' then
		v_group_id:= v_id;
	else
		raise_application_error(-20000, 'portal.create_from_default: Invalid portal type');
	end if;

	begin
		select type, group_type into v_domain_type, v_domain_group_type
		from portal_domains
		where domain_id= v_domain_id;	
	exception
		when no_data_found then
			raise_application_error(-20000, 'portal.create_from_default: domain_id ' || v_domain_id || 'does not exist');
	end;

	begin
		select pdh.parent_domain_id into v_dummy
		from portal_domain_hierarchy pdh
		where pdh.child_domain_id= v_domain_id
		and rownum=1;	

		v_top_level_domain_p:= 0;
	exception
		when no_data_found then
			v_top_level_domain_p:= 1;
	end;

	-- we are creating a top level portal
	if v_top_level_domain_p = 1 then 
		if v_portal_type='user' then
			if v_domain_type='user' then
				v_portal_id:= portal.create_new(v_domain_id => v_domain_id, v_user_id => v_user_id);
			else
				raise_application_error(-20000, 'portal.create_from_default: user portal cannot be added to group domain');
			end if;
		else 
			if v_domain_type='user' then
				raise_application_error(-20000, 'portal.create_from_default: group portal cannot be added to user domain');
			else
				select group_type into v_group_type
				from user_groups
				where group_id=v_group_id;
				if v_group_type= v_domain_group_type then
					v_portal_id:= portal.create_new(v_domain_id => v_domain_id, v_group_id => v_group_id);
				else
					raise_application_error(-20000, 'portal.create_from_default: group type ''' || v_group_type || ''' doesn''t match domain group type ''' || v_domain_group_type || '''');
				end if;
			end if;
		end if;
		portal.set_to_default_configuration(v_portal_id => v_portal_id);
		return v_portal_id;
	end if;


	-- portal hierarchies are only supported for group portals
	if v_portal_type='user' then
		raise_application_error(-20000, 'portal.create_from_default: user domain hierarchies are not supported because acs3.4 doesn''t support object hierarchies');
	end if;

	select ug1.group_id, ug1.group_type into v_parent_group_id, v_parent_group_type
	from user_groups ug1
	where ug1.group_id= (select ug2.parent_group_id 
                             from user_groups ug2
	                     where ug2.group_id=  v_group_id);

	if v_parent_group_id is null then
		raise_application_error(-20000, 'portal.create_from_default: portal hierarchy doesn''t match group hierarchy');
	end if;

	-- now, we have a valid parent_group_id and parent group_type

	-- we need to find domain id of parent portal. 
	-- this domain_id can be found in the intersection of 
	-- (1) parent domains of the newly created portal's domain, and
	-- (2) portal domains associated with the group_type of the parent user group of the newly created portal

	open c1 for 
	select pdh.parent_domain_id
	from portal_domain_hierarchy pdh
	where pdh.child_domain_id= v_domain_id
	intersect
	select pd.domain_id
	from portal_domains pd
	where pd.group_type= v_parent_group_type;

	fetch c1 into v_parent_domain_id;

	if c1%NOTFOUND then
		raise_application_error(-20000, 'portal.create_from_default: parent portal must have exactly one domain that is parent of newly created domain');
	end if;

	-- parent portal must have exactly one domain that is parent of newly created domain
	fetch c1 into v_dummy;
	if not c1%NOTFOUND then
		raise_application_error(-20000, 'portal.create_from_default: parent portal must have exactly one domain that is parent of newly created domain');
	end if;
	close c1;

	select type into v_parent_domain_type
	from portal_domains
	where domain_id= v_parent_domain_id;	
					
	if v_parent_domain_type='user' then
		raise_application_error(-20000, 'portal.create_from_default: user domain hierarchies are not supported because acs3.4 doesn''t support object hierarchies');
	end if;

	-- at this point we have valid parent_group_id and valid parent_domain_id, so we can go ahead and create a new portal
	v_parent_portal_id:= portal.get_portal_id('group', v_parent_group_id, v_parent_domain_id);
	v_portal_id:= portal.create_new(v_domain_id => v_domain_id, v_group_id => v_group_id, v_parent_portal_id => v_parent_portal_id);
	portal.set_to_default_configuration(v_portal_id => v_portal_id);
	return v_portal_id;
end create_from_default;

-- PDL : portal.set_to_default_configuration(portal_id)
-- delete all portal pages of the portal identified by portal_id
-- set domain_id to domain_id of portal identified by portal_id
-- for all pages of default portal
--	copy default portal page into new portal page
procedure set_to_default_configuration (
	v_portal_id		in integer
)
is 
	v_current_page_id	integer;
	v_default_portal_id	integer;

	type page_id_list_type is table of integer;
	page_id_list		page_id_list_type;
	
	type CurType is ref cursor;
	c1 CurType;
begin
	delete from portal_pages where portal_id= v_portal_id;

	begin
		select portal_id into v_default_portal_id
        	from portals
	        where domain_id=(select domain_id 
        	   		 from portals
				 where portal_id=v_portal_id)
		and default_p='t';
	exception
		when no_data_found then
			-- no default portal
			return;
	end;


	open c1 for
	select page_id
	from portal_pages
	where portal_id=v_default_portal_id;

	fetch c1 bulk collect into page_id_list;
	close c1;

	if not page_id_list.exists(1) then 
		-- if default portal doesn't have any pages then just return
		return;
	end if;

	for i in page_id_list.first..page_id_list.last loop
		v_current_page_id:= portal_page.copy(v_portal_id => v_portal_id, v_source_page_id => page_id_list(i));
	end loop;
end set_to_default_configuration;

function valid_url_character_p (
	v_url_character in char
)
return char
is 
	v_valid_characters_string	char(100);
begin
	if v_url_character=' ' then
		return 0;
	end if;

	v_valid_characters_string:= 'abcdefghijklmnopqrstuvwxyz0123456789-_.';
	if instr(v_valid_characters_string, lower(v_url_character))=0 then
		return 0;
	else 
		return 1;
	end if;
end valid_url_character_p;

function url_identifier_from_group_name (
	v_group_name in varchar
)
return varchar
is 
	v_original_url_identifier portals.url_identifier%TYPE;
	v_final_url_identifier portals.url_identifier%TYPE;
	v_current_char	char(1);
begin
	if v_group_name is null then
		return 'default';
	end if;

	v_original_url_identifier:= lower(substr(v_group_name, 1, 95));
	v_final_url_identifier:= '';

	for i in 1..length(v_original_url_identifier) loop
		v_current_char:= substr(v_original_url_identifier, i, 1);
		if portal.valid_url_character_p(v_url_character => v_current_char)=1 then
			v_final_url_identifier:= v_final_url_identifier || v_current_char;
		else
			v_final_url_identifier:= v_final_url_identifier || '-';
		end if;
	end loop;

	return v_final_url_identifier;
end url_identifier_from_group_name;

end portal;
/
show errors


