-- by tarik@alatovic.com (November 2000)
--
-- $Id: 22-portal-page-api-body.sql,v 1.2 2001/02/01 17:46:44 tarik Exp $

create or replace package body portal_page as

function create_new (
	v_portal_id		in integer,
	v_page_name		in varchar default null, 
	v_page_number		in integer
)
return integer
is 
	v_page_id		integer;
begin
	select portal_id_sequence.nextval into v_page_id from dual;

	insert into portal_pages
	(page_id, portal_id, page_name, page_number)
	values
	(v_page_id, v_portal_id, v_page_name, v_page_number);
	
	return v_page_id;
end create_new;

function id_from_page_number (
	v_portal_id		in integer default null,
	v_page_number		in integer
)
return integer
is
	v_page_id		integer;
	cursor c1 is 
	select page_id from portal_pages
	where portal_id=v_portal_id
	and page_number=v_page_number;
begin
	open c1;
	fetch c1 into v_page_id;

	if c1%NOTFOUND then
		close c1;
		return 0;
        else	
		close c1;
		return v_page_id;
	end if;
end id_from_page_number;

function exists_p (
	v_portal_id		in integer default null,
	v_page_number		in integer
)
return integer
is
	v_page_id		integer;
	cursor c1 is 
	select page_id from portal_pages
	where portal_id=v_portal_id
	and page_number=v_page_number;
begin
	open c1;
	fetch c1 into v_page_id;

	if c1%NOTFOUND then
		close c1;
		return 0;
        else	
		close c1;
		return 1;
	end if;
end exists_p;

procedure make_page_numbers_sequential (
	v_portal_id		in integer
)
is 
	type page_id_list_type is table of integer;
	page_id_list		page_id_list_type;

	type page_number_list_type is table of integer;
	page_number_list	page_number_list_type;	

	cursor c1 is 
	select page_id
	from portal_pages
	where portal_id=v_portal_id
	order by page_number
	for update;
begin
	open c1;
	fetch c1 bulk collect into page_id_list;
	close c1;

	if not page_id_list.exists(1) then 
		-- if portal doesn't have any pages then just return
		return;
	end if;

	page_number_list:= page_number_list_type();
	page_number_list.extend(page_id_list.last);
	for i in page_id_list.first..page_id_list.last loop
		page_number_list(i):=i;
	end loop;
		
	forall i in page_number_list.first..page_number_list.last
		update portal_pages set page_number= page_number_list(i)
		where page_id= page_id_list(i);
end;

procedure remove (
	v_page_id		in integer
)
is
begin
	delete from portal_pages where page_id=v_page_id;
end remove;

-- PDL : portal_page.copy(portal_id, source_page_id)
-- create a new portal page for portal identifed by portal_id
-- set page_number and page_name of new portal to be the same as page_name and page_number of source page
-- copy all portal page - portlet mappings from page identified by source_page_id to new portal page
-- return page_id of newly created portal page
function copy (
	v_portal_id		in integer,
	v_source_page_id	in integer
)
return integer
is 
	v_page_id		integer;
	v_source_page_name	portal_pages.page_name%TYPE;
	v_source_page_number	portal_pages.page_number%TYPE;

	v_portlet_id		integer;
	v_sort_key		portal_portlet_page_map.sort_key%TYPE;
	v_page_side		portal_portlet_page_map.page_side%TYPE;

	cursor c1 is 
	select portlet_id, sort_key, page_side
	from portal_portlet_page_map
	where page_id=v_source_page_id;
begin
	select page_name, page_number into v_source_page_name, v_source_page_number
	from portal_pages
	where page_id= v_source_page_id;
	v_page_id:= portal_page.create_new(v_portal_id => v_portal_id, v_page_name=>v_source_page_name, v_page_number=>v_source_page_number);

	open c1;	
	loop
		fetch c1 into v_portlet_id, v_sort_key, v_page_side;
		exit when c1%NOTFOUND;
		portal_portlet.move(v_portlet_id => v_portlet_id, v_page_id => v_page_id, v_page_side => v_page_side, v_sort_key => v_sort_key);		
	end loop;
	close c1;
	return v_page_id;
end copy;

end portal_page;
/
show errors
