-- by tarik@alatovic.com (November 2000)
--
-- $Id: 23-portal-portlet-api-body.sql,v 1.1.1.1 2001/01/24 18:03:34 tarik Exp $

create or replace package body portal_portlet as

function create_new (
	v_content_source_type	in varchar,
	v_content_source	in varchar,
	v_admin_link_type	in varchar default 'html',
	v_admin_link_source	in varchar default null
)
return integer
is
	v_portlet_id	integer;
begin
	select portal_id_sequence.nextval into v_portlet_id from dual;

	insert into portal_portlets
	(portlet_id, content_source_type, content_source, admin_link_type, admin_link_source)
	values
	(v_portlet_id, v_content_source_type, v_content_source, v_admin_link_type, v_admin_link_source);

	return v_portlet_id;
end create_new;

function create_predefined (
	v_portlet_name		in varchar,
	v_content_source_type	in varchar,
	v_content_source	in varchar,
	v_admin_link_type	in varchar default 'html',
	v_admin_link_source	in varchar default null
)
return integer
is
	v_portlet_id	integer;
begin
	v_portlet_id:=portal_portlet.create_new(v_content_source_type => v_content_source_type, v_content_source => v_content_source, v_admin_link_type => v_admin_link_type, v_admin_link_source => v_admin_link_source);

	insert into portal_predefined_portlets
	(portlet_id, portlet_name)
	values
	(v_portlet_id, v_portlet_name);

	return v_portlet_id;
end create_predefined;

function create_domain_portlet (
	v_portlet_name		in varchar,
	v_domain_id		in integer,
	v_content_source_type	in varchar,
	v_content_source	in varchar,
	v_admin_link_type	in varchar default 'html',
	v_admin_link_source	in varchar default null,
	v_control_panel_p	in char default 'f',
        v_required_p		in char default 'f'
)
return integer
is
	v_portlet_id	integer;
begin	
	v_portlet_id:=portal_portlet.create_new(v_content_source_type => v_content_source_type, v_content_source => v_content_source, v_admin_link_type => v_admin_link_type, v_admin_link_source => v_admin_link_source);

	insert into portal_domain_portlets
	(domain_id, portlet_id, portlet_name, required_p)
	values
	(v_domain_id, v_portlet_id, v_portlet_name, v_required_p);

	if v_control_panel_p='t' then
		insert into portal_domain_c_panel_map
		(portlet_id, domain_id)
		values
		(v_portlet_id, v_domain_id);
	end if;

	return v_portlet_id;

end create_domain_portlet;

function create_from_predefined_portlet (
	v_predefined_portlet_id in integer,
	v_portlet_name		in varchar,
	v_domain_id		in integer,
	v_control_panel_p	in char default 'f',
        v_required_p		in char default 'f'
)
return integer
is
	v_portlet_id		integer;
begin
	select portal_id_sequence.nextval into v_portlet_id from dual;

	insert into portal_portlets
	(portlet_id, content_source_type, content_source, admin_link_type, admin_link_source)
	select v_portlet_id, content_source_type, content_source, admin_link_type, admin_link_source
	from portal_portlets
	where portlet_id= v_predefined_portlet_id;

	insert into portal_domain_portlets
	(domain_id, portlet_id, portlet_name, required_p, predefined_portlet_id)
	values
	(v_domain_id, v_portlet_id, v_portlet_name, v_required_p, v_predefined_portlet_id);

	if v_control_panel_p='t' then
		insert into portal_domain_c_panel_map
		(portlet_id, domain_id)
		values
		(v_portlet_id, v_domain_id);
	end if;

	return v_portlet_id;
end create_from_predefined_portlet;

procedure update_domain_portlet (
	v_portlet_id		in integer,	
	v_predefined_portlet_id in integer,
	v_portlet_name		in varchar,
	v_content_source_type	in varchar,
	v_content_source	in varchar,
	v_admin_link_type	in varchar,
	v_admin_link_source	in varchar
)
is
begin	
	update	portal_portlets
	set 	content_source_type = v_content_source_type,
		content_source = v_content_source,
		admin_link_type = v_admin_link_type,
		admin_link_source = v_admin_link_source
	where	portlet_id = v_portlet_id;

	update	portal_domain_portlets
	set	portlet_name = v_portlet_name,
		predefined_portlet_id = v_predefined_portlet_id
	where	portlet_id = v_portlet_id;
end update_domain_portlet;

procedure delete (
	v_portlet_id		in integer
)
is
begin	
	delete from portal_portlets where portlet_id=v_portlet_id;
end delete;

function copy_domain_portlet (
	v_source_portlet_id	in integer
)
return integer
is
	v_portlet_id		integer;
begin
	select portal_id_sequence.nextval into v_portlet_id from dual;

	insert into portal_portlets
	(portlet_id, content_source_type, content_source, admin_link_type, admin_link_source)
	select v_portlet_id, content_source_type, content_source, admin_link_type, admin_link_source
	from portal_portlets
	where portlet_id= v_source_portlet_id;

	insert into portal_domain_portlets
	(domain_id, portlet_id, portlet_name, predefined_portlet_id)
	select domain_id, v_portlet_id, portlet_name, predefined_portlet_id
	from portal_domain_portlets
	where portlet_id= v_source_portlet_id;

	return v_portlet_id;
end copy_domain_portlet;

function control_panel_p (
	v_portlet_id	in integer,
	v_domain_id	in integer
)
return integer
is
	v_dummy		integer;

	cursor c1 is 
	select 1 from portal_domain_c_panel_map
	where portlet_id=v_portlet_id
	and domain_id=v_domain_id;
begin
	open c1;
	fetch c1 into v_dummy;

	if c1%NOTFOUND then
		close c1;
		return 0;
        else	
		close c1;
		return 1;
	end if;
end control_panel_p;

-- places the portlet identified by portlet id onto the page 
-- identified by page_id
procedure move (
	v_portlet_id		in integer,
	v_page_id		in integer,
	v_sort_key		in integer,
	v_page_side		in char
)
is
begin
	delete from portal_portlet_page_map 
	where page_id=v_page_id 
	and portlet_id=v_portlet_id;

	insert into portal_portlet_page_map
	(page_id, portlet_id, sort_key, page_side)
	values
	(v_page_id, v_portlet_id, v_sort_key, v_page_side);
end move;

procedure remove (
	v_portlet_id		in integer
)
is
begin
	delete from portal_portlets where portlet_id=v_portlet_id;
end remove;

end portal_portlet;
/
show errors

