-- by tarik@alatovic.com (November 2000)
--
-- $Id: 24-portal-install-api-body.sql,v 1.1.1.1 2001/01/24 18:03:34 tarik Exp $

create or replace package body portal_install as

procedure add_predefined_portlet (
	v_portlet_name		in varchar,
	v_content_source_type	in varchar,
	v_content_source	in varchar,
	v_admin_link_type	in varchar default 'html',
	v_admin_link_source	in varchar default null
)
is
	v_portlet_id		integer;
begin
	v_portlet_id:=	portal_portlet.create_predefined(v_portlet_name => v_portlet_name, v_content_source_type => v_content_source_type, v_content_source => v_content_source, v_admin_link_type => v_admin_link_type, v_admin_link_source => v_admin_link_source);

end add_predefined_portlet;

procedure add_predefined_domain_portlet (
	v_domain_name			in varchar,
	v_predefined_portlet_name	in varchar,
	v_portlet_name			in varchar default NULL,
	v_control_panel_p	in char default 'f',
        v_required_p		in char default 'f'
)
is
	v_domain_id		integer;
	v_portlet_id		integer;
	v_predefined_portlet_id	integer;
begin
	select domain_id into v_domain_id 
	from portal_domains 
	where domain_name=v_domain_name;

	select portlet_id into v_predefined_portlet_id
	from portal_predefined_portlets
	where portlet_name= v_predefined_portlet_name;

	if v_portlet_name is NULL then
		v_portlet_id:=portal_portlet.create_from_predefined_portlet(v_predefined_portlet_id => v_predefined_portlet_id, v_portlet_name => v_predefined_portlet_name, v_domain_id => v_domain_id, v_control_panel_p => v_control_panel_p, v_required_p => v_required_p);
	else 
		v_portlet_id:=portal_portlet.create_from_predefined_portlet(v_predefined_portlet_id => v_predefined_portlet_id, v_portlet_name => v_portlet_name, v_domain_id => v_domain_id, v_control_panel_p => v_control_panel_p, v_required_p => v_required_p);
	end if;

end add_predefined_domain_portlet;

procedure add_html_domain_portlet (
	v_domain_name		in varchar,
	v_portlet_name		in varchar,
	v_content_source	in varchar,
	v_admin_link_source	in varchar default null,
	v_control_panel_p	in char default 'f',
        v_required_p		in char default 'f'
)
is
	v_domain_id		integer;
	v_portlet_id		integer;
begin
	select domain_id into v_domain_id 
	from portal_domains 
	where domain_name=v_domain_name;

	v_portlet_id:=portal_portlet.create_domain_portlet(v_portlet_name => v_portlet_name, v_domain_id => v_domain_id, v_content_source_type => 'html', v_content_source => v_content_source, v_admin_link_type => 'html', v_admin_link_source => v_admin_link_source, v_control_panel_p => v_control_panel_p, v_required_p => v_required_p);
end add_html_domain_portlet;

procedure set_default_page (
	v_domain_name		in varchar,
	v_page_number		in integer,
	v_page_name		in varchar default NULL
)
is
	v_domain_id		integer;
	v_page_id		integer;

	type PortalCurType is ref cursor;
	portal_cv PortalCurType;
	v_default_portal_id	integer;
begin
	select domain_id into v_domain_id 
	from portal_domains 
	where domain_name=v_domain_name;

	open portal_cv for
	select portal_id 
	from portals
	where domain_id=v_domain_id and default_p='t';

	fetch portal_cv into v_default_portal_id;

	-- let's check if default portal is already defined
	if portal_cv%NOTFOUND then
		v_default_portal_id:=portal.create_new(v_domain_id => v_domain_id, v_default_p => 't');
        end if;
	close portal_cv;

	-- at this point, we have the portal_id of the default portal

	v_page_id:=portal_page.id_from_page_number(v_portal_id => v_default_portal_id, v_page_number=>v_page_number);

	if v_page_id=0 then 
		v_page_id:=portal_page.create_new(v_portal_id => v_default_portal_id, v_page_name=>v_page_name, v_page_number=>v_page_number);
	else 
		update portal_pages set page_name=v_page_name where page_id=v_page_id;
	end if;
end set_default_page;

procedure place_domain_portlet (
	v_domain_name		in varchar,
	v_portlet_name		in varchar,
	v_page_number		in integer,
	v_page_side		in char,
	v_sort_key		in integer
) 
is 
	v_domain_id		integer;
	v_default_portal_id	integer;
	v_page_id		integer;
	v_portlet_id		integer;

begin
	select domain_id into v_domain_id
	from portal_domains
	where domain_name=v_domain_name;

	select portal_id into v_default_portal_id
	from portals
	where domain_id=v_domain_id
	and default_p='t';

	v_page_id:= portal_page.id_from_page_number(v_portal_id => v_default_portal_id, v_page_number => v_page_number);
	if v_page_id = 0 then
		raise_application_error(-20000, 'portal_install.place_domain_portlet: Page doesn''t exist');
	end if;

	select portlet_id into v_portlet_id
	from portal_domain_portlets
	where domain_id=v_domain_id
	and portlet_name=v_portlet_name;

	insert into portal_portlet_page_map 
	(page_id, portlet_id, sort_key, page_side)
	values
	(v_page_id, v_portlet_id, v_sort_key, v_page_side);

	portal_page.make_page_numbers_sequential(v_portal_id => v_default_portal_id);	
	
end place_domain_portlet;

end portal_install;
/
show errors
