-- by tarik@alatovic.com (January 2001)
--
-- $Id: 30-portal-automatic-creation.sql,v 1.3 2001/01/30 20:52:07 tarik Exp $

-- automatic creation of portals when users and groups are created is 
-- somewhat complicated because row level triggers cannot see the tables
-- they are modifying (infamous ORA-04091 error)

---------------------------------------
-- PORTAL AUTOMATIC CREATION PACKAGE --
---------------------------------------

create or replace package portal_automatic_creation as

type domain_id_list_type is table of integer;
type new_id_array_type is table of integer index by binary_integer; 

empty_user_id_array   new_id_array_type;
empty_group_id_array   new_id_array_type;
new_user_id_array new_id_array_type; 
new_group_id_array new_id_array_type; 

procedure create_default_user_portals;
procedure create_default_group_portals;

end portal_automatic_creation;
/
show errors


create or replace package body portal_automatic_creation as

procedure create_default_user_portals
is
	v_domain_id	integer;
	v_portal_id	integer;

	v_domain_id_list		domain_id_list_type;

	cursor c1 is 
	select domain_id 
	from portal_domains
	where type='user';
begin
	open c1;	
	fetch c1 bulk collect into v_domain_id_list;
	close c1;

	if not v_domain_id_list.exists(1) then 
		return;
	end if;

	if not portal_automatic_creation.new_user_id_array.exists(1) then 
		return;
	end if;

	for i in portal_automatic_creation.new_user_id_array.first..portal_automatic_creation.new_user_id_array.last loop
		for j in v_domain_id_list.first..v_domain_id_list.last loop
			v_portal_id:= portal.create_from_default(v_portal_type => 'user', v_id => portal_automatic_creation.new_user_id_array(i), v_domain_id => v_domain_id_list(j));		 
		end loop;
	end loop;

end create_default_user_portals;

procedure create_default_group_portals
is
	v_domain_id	integer;
	v_portal_id	integer;
	v_group_id	integer;

	v_domain_id_list		domain_id_list_type;

	type CurType is ref cursor;
	c1 CurType;
begin
	if not portal_automatic_creation.new_group_id_array.exists(1) then 
		return;
	end if;

	for i in portal_automatic_creation.new_group_id_array.first..portal_automatic_creation.new_group_id_array.last loop
		open c1 for
		select pd.domain_id
		from portal_domains pd, user_groups ug
		where pd.type='group'
		and pd.group_type= ug.group_type
		and ug.group_id= portal_automatic_creation.new_group_id_array(i);
		fetch c1 bulk collect into v_domain_id_list;
		close c1;

		if v_domain_id_list.exists(1) then 
			for j in v_domain_id_list.first..v_domain_id_list.last loop
				v_portal_id:= portal.create_from_default(v_portal_type => 'group', v_id => portal_automatic_creation.new_group_id_array(i), v_domain_id => v_domain_id_list(j));		 
			end loop;
		end if;
	end loop;

end create_default_group_portals;

end portal_automatic_creation;
/
show errors

---------------------------------
-- AUTOMATIC CREATION TRIGGERS --
---------------------------------

create or replace trigger portals_default_user_portal1
before insert on users
begin 
	portal_automatic_creation.new_user_id_array := portal_automatic_creation.empty_user_id_array; 
end portals_default_user_portal1; 
/ 
show errors

create or replace trigger portals_default_user_portal2
after insert on users for each row
declare
begin
	portal_automatic_creation.new_user_id_array( portal_automatic_creation.new_user_id_array.count+1 ) := :new.user_id; 
end portals_default_user_portal2;
/
show errors

create or replace trigger portals_default_user_portal3
after insert on users
declare
begin
	portal_automatic_creation.create_default_user_portals;
end portals_default_user_portal3;
/
show errors

create or replace trigger portals_default_group_portal1
before insert on user_groups
begin 
	portal_automatic_creation.new_group_id_array := portal_automatic_creation.empty_group_id_array; 
end portals_default_group_portal1; 
/ 
show errors

create or replace trigger portals_default_group_portal2
after insert on user_groups for each row
declare
begin
	portal_automatic_creation.new_group_id_array( portal_automatic_creation.new_group_id_array.count+1 ) := :new.group_id; 
end portals_default_group_portal2;
/
show errors

create or replace trigger portals_default_group_portal3
after insert on user_groups
declare
begin
	portal_automatic_creation.create_default_group_portals;
end portals_default_group_portal3;
/
show errors
