# /packages/portals/admin-www/domain-edit.tcl
ad_page_contract {
    Show the users registered procs and filters that may interfere
    with using the passed in url_root.  This page may be called from
    domain-create-2.tcl or domain-manage.tcl.  

    @author crag@arsdigita.com
    @creation-date October 4 2000
    @cvs-id $Id: url-root-verify.tcl,v 1.1.1.1 2001/01/24 18:03:34 tarik Exp $
    
} {
    {domain_id:naturalnum,optional}
    url_root:notnull
    domain_action:notnull
    domain_name
    group_type:optional
    type:optional
}

page_validation {
    set url_root [string trim $url_root]
    set url_root [string trim $url_root "/"]
    if [regexp {\/} $url_root match] {
	error "you may not have \"/\" in your url root"
    }
    if [empty_string_p $url_root] {
	error "The url root can not be empty."
    }
    if [regexp {\s} $url_root match] {
	error "The url root should not contain any whitespace"
    }
    set www_path "[ad_parameter PathToACS]/www"
    set glob_pattern "$www_path/$url_root/"
    if [llength [glob -nocomplain $glob_pattern]] {
	error "The directory $www_path/$url_root already exists.  Either you need to move it, or use a different url root."
    }
    set glob_pattern "$www_path/$url_root.*"
    if [llength [glob -nocomplain $glob_pattern]] {
	error "A file in $www_path conflicts with the url root you provided.  Either you need to move the file, or use a different url root."
    }
    if { ![string match $domain_action "add"] && ![string match $domain_action "edit"] } {
	error "domain_action must be edit or add"
    }
    ### checks specific to for editing a domain
    if { [string match $domain_action "edit"] } {
	if { ![exists_and_not_null domain_id] } {
	    error "Expected a naturalnum for a domain_id and didn't get one."
	}
	set form_string "
	<form method=POST action=edit>
	[export_form_vars domain_id url_root] " 

	set context_bar [ad_admin_context_bar \
	[list "/admin/portals/" "Portals"] \
	[list "/admin/portals/domain-manage?domain_id=$domain_id" "Manage \"$domain_name\" Domain"] \
	"Update Url Root"]

    } else {

    ### checks specific to for creating a domain
	if { ! [exists_and_not_null type] } {
	    error "Expected a type and didn't get one."
	}
	if { ! [info exists group_type] } {
	    error "No value given for group_type."
	}
	set form_string "
	<form method=POST action=add-3>
	[export_form_vars group_type type url_root] " 

	set context_bar [ad_admin_context_bar \
	[list "/admin/portals/" "Portals"] \
	"Add Portal Domain"]
    }
}

########### get registered procs for the given url_root

set registered_procs_html ""

set match_method [list GET HEAD POST]

set registered_procs_html ""

foreach meth $match_method {
    foreach f [nsv_get rp_registered_procs "$meth"] {
	set method [lindex $f 0]
	set path [lindex $f 1]
	set proc [lindex $f 2]
	set args [lindex $f 3]
	if { $args == "" } {
	    set args "&nbsp;"
	}
	set debug [ad_decode [lindex $f 4] "t" "Yes" "No"]
	set inherit [ad_decode [lindex $f 5] "f" "Yes" "No"]
	set description [lindex $f 6]
	set file [file tail [lindex $f 7]]
	if { [empty_string_p $file] } {
	    set file "&nbsp;"
	}

	# (?q) means what follows is literal, in case you didn't know
	if { [regexp "(?q)/$url_root/" "$path/" match]  ||
                [regexp "(?q)$path/" "/$url_root/" match] } {
	    append registered_procs_html "  <tr>"
	    foreach name { method path proc file args inherit debug } {
		append registered_procs_html " <td>[set $name]</td> "
	    }
	    append registered_procs_html "  </tr>\n"
	}
    }
}
if [empty_string_p $registered_procs_html] {
    set registered_procs_html "<p><b>No registered procs match your specified url root (this is a good thing).</b><br>"
} else {
    set registered_procs_html "<br><b>Registered procedures that match \"$url_root\":</b>
<table>
  <tr>
   <th align=left bgcolor=#C0C0C0>Method</th>
   <th align=left bgcolor=#C0C0C0>Path</th>
   <th align=left bgcolor=#C0C0C0>Proc</th>
   <th align=left bgcolor=#C0C0C0>Defined in File</th>
   <th align=left bgcolor=#C0C0C0>Args</th>
   <th align=center bgcolor=#C0C0C0>Inherit?</th>
   <th align=center bgcolor=#C0C0C0>Debug?</th>
  </tr>
$registered_procs_html</table>"
}

########### get registered filters for the given url_root
set registered_filters_html ""
foreach k { preauth postauth trace } {
    foreach meth $match_method {
	foreach f [nsv_get rp_filters "$meth,$k"] {
	    set priority [lindex $f 0]
	    set kind [lindex $f 1]
	    set method [lindex $f 2]
	    set path [lindex $f 3]
	    set proc [lindex $f 4]
	    set args [lindex $f 5]
	    if { $args == "" } {
		set args "&nbsp;"
	    }
	    set debug [ad_decode [lindex $f 6] "t" "Yes" "No"]
	    set critical [ad_decode [lindex $f 7] "t" "Yes" "No"]
	    set description [lindex $f 8]
	    set file [file tail [lindex $f 9]]
	    if {[regexp "(?q)/$url_root/" "$path/" match] ||
                [regexp "(?q)$path/" "/$url_root/" match]} {
		append registered_filters_html "<tr>"
		foreach name { priority kind method path proc file args debug critical } {
		    append registered_filters_html "<td>[set $name]</td>"
		}
		append registered_filters_html "</tr>\n"
	    }
	}
    }
}
if [empty_string_p $registered_filters_html] {
    set registered_filters_html "<p><b>No registered filters match your specified url root (this is a good thing).</b><br>"
} else {
   set registered_filters_html "<br><b>Registered Filters that match \"$url_root\":</b>
<table>
  <tr>
    <th align=left bgcolor=#C0C0C0>Priority</th>
    <th align=left bgcolor=#C0C0C0>Kind</th>
    <th align=left bgcolor=#C0C0C0>Method</th>
    <th align=left bgcolor=#C0C0C0>Path</th>
    <th align=left bgcolor=#C0C0C0>Proc</th>
    <th align=left bgcolor=#C0C0C0>Defined in File</th>
    <th align=left bgcolor=#C0C0C0>Args</th>
    <th align=center bgcolor=#C0C0C0>Debug?</th>
    <th align=center bgcolor=#C0C0C0>Crit.?</th>
  </tr> 
  $registered_filters_html
</table>
"
}
doc_return 200 text/html "[ad_header "Exisiting Procs and Filters"]
<h3>Exisiting Procs and Filters that may conflict with Url Root \"$url_root\"</h3>
$context_bar
<hr>
<p>
$registered_procs_html
<p>
$registered_filters_html

<blockquote>
$form_string
<input type=submit value=\"Confirm New Url Root\">
</form>
</blockquote>
[ad_footer]
"

