# packages/portals/bookmarks-procs.tcl
#
# Procs that provide an interface between portals and the bookmarks module.
#
# Created during a breakup of module-portal-procs.tcl, which was created
# during a breakup of education-portal-procs.tcl by caroline@arsdigita.com
# on July 18, 2000.
#
# Ian Baker <ibaker@arsdigita.com> Thu Oct  5 11:17:49 PDT 2000
# Tarik Alatovic <tarik@alatovic.com>
#
# $Id: bookmarks-procs.tcl,v 1.1.1.1 2001/01/24 18:03:33 tarik Exp $

ad_library {
    Bookmarks procs used by the portal system.

    @creation-date July 2000
    @author caroline@arsdigita.com
    @cvs-id $Id: bookmarks-procs.tcl,v 1.1.1.1 2001/01/24 18:03:33 tarik Exp $
}

ad_proc -public portals_bookmarks_portlet {} {
    Displays bookmarks portal page.

    @creation-date July 2000
    @author caroline@arsdigita.com
    @cvs-id $Id: bookmarks-procs.tcl,v 1.1.1.1 2001/01/24 18:03:33 tarik Exp $
} {

    # Portal page to the bookmarks system
    #
    # modified by caroline@arsdigita.com from index page by #aure@arsdigita.com and dh@arsdigita.com
    
    set user_id [ad_verify_and_get_user_id]
    
    # get generic display parameters from the .ini file
    set folder_bgcolor [ad_parameter FolderBGColor bm]
    set bookmark_bgcolor [ad_parameter BookmarkBGColor bm]
    set folder_decoration [ad_parameter FolderDecoration bm]
    set hidden_decoration [ad_parameter HiddenDecoration bm]
    set dead_decoration [ad_parameter DeadDecoration bm]
    
    set edit_anchor "<font size=-2 face=\"verdana, arial, helvetica\">edit</font>"
    
    set return_url [ad_conn url]

    # ad_conn doesn't support this parameter.  -ib
    set query_url [ns_conn query] 
    if ![empty_string_p $query_url] {
	append return_url ?$query_url
    }
    if {[portals_info type]=="group"} {
	return ""
    } else {
	
	# the javascript function that spawns the bookmark window
	set javascript "
	<script runat=client>
	function launch_window(file) {
	    window.open(file,'bookmarks','toolbar=no,location=no,directories=no,status=no,scrollbars=auto,resizable=yes,copyhistory=no,width=350,height=480')
	}
	</script>
	"
	
	# display header and list of user options 
	append whole_page "
	
	<p>
	\[<a href=/bookmarks/import?return_url=$return_url>Add / Import</a> |
	<a href=/bookmarks/export?[export_url_vars return_url]>Export</a> |
	<a href=/bookmarks/create-folder?return_url=$return_url>Create New Folder</a> |
	<a href=/bookmarks/live-check?return_url=$return_url>Check Links</a> |
	<!-- <a href=\"javascript:launch_window('tree.html')\">Javascript version</a> |-->
	<a href=/bookmarks/public-bookmarks?[export_url_vars return_url]>View public bookmarks</a> \] <P>
	"
	
	set name [db_string bookmark_name "select first_names || ' ' || last_name as name from users where user_id = :user_id"]
	
	append whole_page "
	<table cellpadding=0 cellspacing=0 border=0>
	<tr>
	<td><img border=0 src=/bookmarks/pics/ftv2folderopen.gif align=top>${folder_decoration}Bookmarks for $name</td></td><td><a href=/bookmarks/toggle-open-close?action=close_all&return_url=$return_url>Close</a>/<a href=/bookmarks/toggle-open-close?action=open_all&return_url=$return_url>Open</a> All Folders
	</td>    </tr>
	</table>"
	
	set bookmark_query "
	select   bookmark_id, bm_list.url_id, 
	nvl(local_title, url_title) as bookmark_title, 
	hidden_p, complete_url,  
	last_live_date, last_checked_date, 
	folder_p, closed_p, length(parent_sort_key)*8 as indent_width 
          from     bm_list, bm_urls
	where    owner_id=:user_id
	and      in_closed_p='f'
	and      bm_list.url_id=bm_urls.url_id(+)
	order by parent_sort_key || local_sort_key
	"

	set bookmark_count 0
	set bookmark_list ""
	
	db_foreach bookmarks $bookmark_query {
	# decoration refers to color and font of the associated text
	    set decoration ""
	    
	    # make private links appear as defined in the .ini file
	    if {$hidden_p=="t"} {
		append decoration $hidden_decoration
	    }
	    
	    # make dead links appear  as defined in the .ini file
	    if {$last_checked_date!=$last_live_date} {
		append decoration $dead_decoration
	    }
	    
	    # make folder titles appear  as defined in the .ini file
	    if {$folder_p=="t"} {
		append decoration $folder_decoration
	    } 
	    
	    # dropping apostrophes and quotation marks from the javascript title
	    # that will be used in the fancy edit link below
	    regsub -all {'|"} $bookmark_title {} javascript_title
	    # this fancy edit link shows "Edit foo" in the status bar "
 	    set edit_link "<a onMouseOver=\"window.status='Edit $javascript_title'; return true;\" onMouseOut=\"window.status=' '; return true;\" href=/bookmarks/edit-bookmark?[export_url_vars bookmark_id return_url]>$edit_anchor</a>"
	    
	    
	    # define url, background color, and image depending on whether we are display a bookmark or folder
	    if {$folder_p=="f"} {
		set url $complete_url
		set bgcolor $bookmark_bgcolor
		set image "/bookmarks/pics/ftv2doc.gif"
	    } else {
		set bgcolor $folder_bgcolor
		set url "/bookmarks/toggle-open-close?[export_url_vars bookmark_id return_url]"
		
		# different images for whether or not the folder is open
		if {$closed_p=="t"} {
		    set image "/bookmarks/pics/ftv2folderclosed.gif"
		} elseif {$closed_p=="f" } {
		    set image "/bookmarks/pics/ftv2folderopen.gif"
		}
	    }
	    
	    append bookmark_list "
	    <table cellpadding=0 cellspacing=0 border=0>
	    <tr>
	    <td valign=top><img src=/bookmarks/pics/spacer.gif width=$indent_width height=1></td>
	    <td><a href=\"$url\"><img width=24 height=22 border=0 src=\"$image\" align=top></a></td>
	    <td><a href=\"$url\">$decoration[string trim $bookmark_title]</a></td>
	    <td>&nbsp;$edit_link</td>
	    </tr>
	    </table>"
	    
	    incr bookmark_count
	}
	
	# write the bookmarks if there are any to show
	if {$bookmark_count!=0} { 
	    append whole_page "$bookmark_list"
	} else {
	    append whole_page "You don't have any bookmarks stored in the database. <p>"
	}
	
	append whole_page "<form action=/bookmarks/search method=post>
	Search bookmarks for: <input name=search_text type=text size=20><input type=hidden name=return_url value=$return_url><input type=submit value=Search></form>
	<p>
	Key to bookmark display:
	<table> 
	<tr> 
	<td><ul><li> $hidden_decoration Private or hidden files or folders appear like this.</td>
	</tr> 
	<tr>
	<td><ul><li> $dead_decoration Links likely to be dead appear like this.</td>
	</tr> 
	</table>
	"
	return $whole_page
    }
}
