# packages/portals/faq-procs.tcl
#
# Pocs that provide an interface between portals and the faq module.
#
# Created during a breakup of module-portal-procs.tcl
#
# on July 18, 2000.
#
# Ian Baker <ibaker@arsdigita.com> Thu Oct  5 11:17:49 PDT 2000
# Tarik Alatovic <tarik@alatovic.com>
#
# $Id: faq-procs.tcl,v 1.8 2001/02/06 07:31:53 tarik Exp $

ad_library {
    FAQ procs used by the portal system.

    @creation-date September 2000
    @author crag@arsdigita.com
    @cvs-id $Id: faq-procs.tcl,v 1.8 2001/02/06 07:31:53 tarik Exp $
}

ad_proc -public portlets_faq_portlet {} {
    FAQ display procedure, suitable for inclusion in a portal portlet.

    @creation-date September 2000
    @author crag@arsdigita.com
    @return HTML fragment displaying faqs relevant to the scope of caller.
    @cvs-id $Id: faq-procs.tcl,v 1.8 2001/02/06 07:31:53 tarik Exp $
} {
    set html ""
    set faq_list []
    set user_id [ad_verify_and_get_user_id]

    if {[portals_info type]=="group"} {
	# group portal

	set group_id [portals_info group_id]
	set group_name [db_string news_group_name "select group_name from user_groups where group_id = :group_id"]
	set sql "
	select faq_id, faq_name, faqs.group_id as faq_group_id
	from faqs
	where faqs.scope = 'group' 
	and faqs.group_id in (select ug.group_id
                              from user_groups ug
                              start with ug.group_id= :group_id
                              connect by prior ug.group_id = ug.parent_group_id)
	order by faq_name"

	set counter 0
	db_foreach faqs $sql {
	    lappend faq_list "<a href=\"/faq/one?faq_id=$faq_id&group_id=$faq_group_id\">$faq_name</a>"
	    incr counter
	}
	
	if { $counter > 1} {
	    append html "         <ul><li>"
	    append html "[join $faq_list "\n        <li>"] \n      </ul>"
	} elseif { ! $counter } {
	    append html "         <ul><li> None Available </ul>"

	} else {  
	    # Display some questions
	    append html "<a href=\"/faq/one?faq_id=$faq_id&group_id=$faq_group_id\">$faq_name</a>"
	    set sql "
	    select question,
	    answer,
	    entry_id,
	    sort_key
	    from   faq_q_and_a
	    where  faq_id = :faq_id
	    order by sort_key"
	    append html "       <ul>\n"
	    set question_number 0
	    db_foreach faq_get_questions $sql {
		incr question_number
		append html "      <li><a href=/faq/one?faq_id=$faq_id&group_id=$faq_group_id#$question_number>$question</a>\n"
		if { $question_number > 15 } {
		    append html "     <li><a href=\"/faq/one?faq_id=$faq_id&group_id=$faq_group_id\">More...</a>"
		    break
		}
	    } if_no_rows {
		append html "      <li> No questions yet \n"
	    }
	    append html "   </ul>"
	}
    } else {
	# user portal

	if { [catch {uplevel 5 {ad_page_contract {} {{orderby:optional faq_name}}}} errmsg] } {
	    set orderby faq_name
	} elseif { [catch {upvar 5 orderby orderby} errmsg] } {
	    set orderby faq_name
	}

	set table_def {
	    {faq_name {Name} {} {<td><a href=\"/faq/one?[export_url_vars faq_id group_id]\">$faq_name</a></td>}}
	    {group_name {Group} {} {}}
	}

	set sql "
	select faqs.faq_id, faqs.faq_name, ug.group_name, ug.group_id
	from faqs, user_groups ug
	where faqs.scope = 'group'
	and faqs.group_id = ug.group_id
	and faqs.group_id in (select ug2.group_id
                              from user_groups ug2, user_group_map ugm
	                      where ug2.group_id= ugm.group_id
           	              and ugm.user_id = $user_id)
	[ad_order_by_from_sort_spec $orderby $table_def]"

	append table_html [ad_table -Torderby $orderby private_faq_table $sql $table_def]

	if {[info exists table_html] && ![empty_string_p $table_html]} {
	    append html "<ul><p> $table_html</ul>"
	}

	if [empty_string_p $html] {
	    append html "         <ul><li> None Available </ul>"
	}
    }
    return $html
}

# unused code
#    } else {  
	# Display some questions
#	append html "<a href=\"/faq/one?[export_url_vars faq_id]\">$faq_name</a>"
#	set sql "
#	select question,
#	       answer,
#               entry_id,
#               sort_key
#               from   faq_q_and_a
#               where  faq_id = :faq_id
#               order by sort_key"
#	append html "       <ul>\n"
#	set question_number 0
#	db_foreach faq_get_questions $sql {
#	    incr question_number
#	    append html "      <li><a href=/faq/one?[export_url_vars faq_id]#$question_number>$question</a>\n"
#	    if { $question_number > 15 } {
#		append html "     <li><a href=\"/faq/one?[export_url_vars faq_id]\">More...</a>"
#		break
#	    }
#	} if_no_rows {
#	    append html "      <li> No questions yet \n"
#	}
#	append html "   </ul>"
#    }


# crag@arsdigita.com 8-22-2000
ad_proc -public portals_faq_administration_link {} {
    Returns URL to the FAQ administration page for the given group if the user has permission.

    @creation-date September 2000
    @author crag@arsdigita.com
    @return a link to a FAQ maintainence page, or empty string if the user doesn't have permission.
    @cvs-id $Id: faq-procs.tcl,v 1.8 2001/02/06 07:31:53 tarik Exp $
} {
    set user_id [ad_verify_and_get_user_id]

    if { [string compare [portals_info type] "group"] } {
	return ""
    }
    set group_id [portals_info group_id]

    db_1row get_short_name "select short_name from user_groups where group_id = :group_id"

    if [ad_user_group_authorized_admin_or_site_admin $user_id $group_id] {
	return "<a href=\"/groups/admin/$short_name/faq\"><img src=\"/portals/pics/edit.gif\" border=0 width=14 height=18></a>"
    } else {
	return ""
    }
}





