# packages/portals/news-procs.tcl
#
# Procs that provide an interface between portals and the news module.
#
# Created during a breakup of module-portal-procs.tcl, which was created
# during a breakup of education-portal-procs.tcl by caroline@arsdigita.com
# on July 18, 2000.
#
# -Ian Baker <ibaker@arsdigita.com> Thu Oct  5 11:17:49 PDT 2000
# Tarik Alatovic <tarik@alatovic.com>
#
# $Id: news-procs.tcl,v 1.6 2001/02/13 02:44:28 caroline Exp $

ad_library {
    News procs used by the portal system.

    @creation-date July 2000
    @author caroline@arsdigita.com
    @cvs-id $Id: news-procs.tcl,v 1.6 2001/02/13 02:44:28 caroline Exp $
}

ad_proc -public portals_news_portlet {} {
    News display procedure, suitable for inclusion in a portal portlet. 
    Returns the list of news items relevant to the user.

    @creation-date July 2000
    @author caroline@arsdigita.com
    @return HTML fragment displaying recent news.
    @cvs-id $Id: news-procs.tcl,v 1.6 2001/02/13 02:44:28 caroline Exp $
} {
    #caroline@arsdigita.com took out the feature where the announcements disappear if you've seen them before. It tends to just confuse users.
    set user_id [ad_verify_and_get_user_id]
    
    set html ""
    #<blockquote>"
    set old_news_id "NULL"
    set old_group_id "NULL"
    set count 0
    set n_groups 0
    
    if {[portals_info type]=="group"} {
	set group_id [portals_info group_id]
	set subgroups [db_list subgroups {select ug.group_id 
	from user_groups ug, user_group_map ugm 
	where parent_group_id = :group_id
        and ugm.user_id = :user_id
        and ug.group_id = ugm.group_id}]

	    #just the announcements for this group
	db_foreach group_news "
	select distinct news.title, news_item_id as news_id, ng.scope, news.release_date, ug.group_name
	from  news_items news, user_groups ug, newsgroups ng
	where release_date <= sysdate
	and expiration_date > sysdate
	and news.approval_state = 'approved'
	and news.newsgroup_id = ng.newsgroup_id
	and ng.group_id = ug.group_id
	and ug.group_id = :group_id
	order by news.release_date asc" {
	    incr count
	    append news_html "<li><a href=/news/item?news_item_id=$news_id&group_id=$group_id&scope=group>$title</a>\n"
	    if {$count == 5} {
		append news_html "<p><center><a href=\"/news/index?scope=group&group_id=$group_id\">More...</a><p></center>"
		break
	    }
	}
	
	if {$count} {
	    append html "
	    <ul>
	    $news_html"
	} else {
	    set group_name [portals_info portal_name]
	    incr n_groups
	    append html "No new announcements for $group_name.<p>
	    <center><a href=\"/news/index?scope=group&group_id=$group_id\">Old Items</a></center>"
	}
	if {![llength $subgroups]} {
	    #there are no subgroups so we are done.
	    return "$html</ul></blockquote>"
	} else {
	    set groups_sql "and g.group_id in ([join $subgroups ","])"
	}
    } else {
	
	#Now we are in a user portal. First we do site wide news, note that it does not disappear once the user has seen it per request of sloan.

	db_foreach site_wide_news "
	select distinct news.title, news_item_id as news_id, ng.scope, release_date
	from  news_items news, newsgroups ng
	where release_date <= sysdate
	and expiration_date > sysdate
	and news.approval_state = 'approved'
	and news.newsgroup_id = ng.newsgroup_id
	and ng.scope in ('registered_users', 'public', 'all_users')
	order by release_date desc" {
	    incr count
	    append news_html "<li><a href=/news/item?news_item_id=$news_id>$title</a>"
	    if {$count == 5} {
		append news_html "<p><center><a href=\"/news/index\">More...</a></center>"
		break
	    }
	}
	
	if {$count} {
	    append html "
	    <ul>
	    $news_html
	    </ul>
	    "
	}
	set groups_sql "and m.group_id = g.group_id
	and m.user_id=users.user_id
	and users.user_id=:user_id"
	
    }
    set n_items 0
    db_foreach more_news "
    select distinct news.title, news_item_id as news_id,
    g.group_id, g.group_name, release_date 
    from user_groups g, user_group_map m, users, news_items news, newsgroups ng
    where release_date <= sysdate
    and expiration_date > sysdate
    and news.approval_state = 'approved'
    and ng.scope='group'
    $groups_sql
    and g.group_id in (select group_id
    from news_items n2, newsgroups ng2 
    where n2.newsgroup_id = ng2.newsgroup_id 
    and m.group_id=ng2.group_id) 
    and g.group_id=ng.group_id(+)
    and ng.newsgroup_id=news.newsgroup_id
    order by  release_date desc, g.group_name, news_item_id desc
    " {
	if {$old_group_id != $group_id} {
	    set old_group_id $group_id
	    
	    if {$n_groups} {
		append html "</ul>"
	    }
	    incr n_groups
	    set n_items 0
	    if {$group_id != ""} {
		append html "
		<li><b>$group_name</b></li>"
	    }
	    
	    append html "<ul>"
	}
	
    	
	if {$old_news_id!=$news_id} {
	    set old_news_id $news_id
	    append html "
	    <li><a href=/news/item?news_item_id=$news_id&group_id=$group_id&scope=group>$title</a></li>"
	    incr n_items
	    if {$n_items == 5} {
		append html "<p><center><a href=\"/news/index?scope=group&group_id=$group_id\">More...</a></center>"
		break
	    }
	}
    }
    if { $n_groups } {
	append html "</ul></ul>"
    }
    if {!$count && !$n_groups} {
	append html "There are no current annoucements"
    }
    

    return "<ul>$html</blockquote>"
}

#
ad_proc -public portals_news_administration_link {} { 
    Provides a link (relevant to scope) to add an item to news if you have permission to do so.

    @creation-date July 2000
    @author caroline@arsdigita.com
    @return a link to add an item to news, or empty string if the user doesn't have permission.
    @cvs-id $Id: news-procs.tcl,v 1.6 2001/02/13 02:44:28 caroline Exp $
} {
    set html ""
    set scope [portals_info type]
    set group_id [portals_info group_id]

    if { $scope == "group" } {
	if { [ad_scope_authorization_status $scope admin group_admin admin $group_id] == "authorized" } {
	    append html "<a href=\"/news/admin/index?[export_url_vars group_id scope]\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
	}
    } elseif {[ad_administrator_p]} {
	append html "<a href=\"/news/admin/\"><img src=\"/portals/pics/edit.gif\" border=0></a>"
    }
    return $html
}

