ad_library {
    Routines for manipulating portal domains.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-domain-api-procs.tcl,v 1.2 2001/01/31 00:52:38 tarik Exp $
}

ad_proc -public portals_domain_id_from_domain_name { domain_name } {
    @return returns domain_id for specifed domain_name. 
    @param domain_name

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/01/2000
} {
    return [db_string portals_domain_id_from_domain_name "select domain_id from portal_domains where domain_name=:domain_name"]
}

ad_proc -public portals_get_domain_id { type {group_type ""} } {
    @return if user domain (type=user) exists then domain_id of that domain is returned.
            if group domain (type=group and group_type=$group_type) exists then domain_id of that domain is returned.
            otherwise, 0 is returned.
    @param type
    @param group_type

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 02/03/2001
} {
    switch $type {
	user {
	    if [db_0or1row portals_get_user_domain_id "
	    select domain_id
	    from portal_domains
	    where type='user'
	    and rownum=1"] {
		return $domain_id
	    } else {
		return 0
	    }
	}
	group {
	    if [db_0or1row portals_get_group_domain_id "
	    select domain_id
	    from portal_domains
	    where type='group'
	    and group_type=:group_type
	    and rownum=1"] {
		return $domain_id
	    } else {
		return 0
	    }
	}
	default {
	    error "portals_get_domain_id: $type is invalid domain type."
	}
    }
}

ad_proc -public portals_get_default_domain_property { which } {
    @return default portal domain property
    @param which specifies domain_property (portlet_header_color, td_header_html)

    @error throws an error if $which is invalid

    @author Samuel Klein (sklein@arsdigita.com)
    @date 08/29/2000
} {
    portals_display_info
    switch $which {
	portlet_header_color {
	    return $header_bg
	}
	td_header_html {
	    return $header_td
	}
    }
}

ad_proc -public portals_get_domain_property { {-cached_p 1} which domain_id } {
    @return portal domain property
    @param which specifies domain_property (type, group_type, domain_name, url_root, portlet_header_color, td_header_html, portlet_count, default_portal_id)
    @param domain_id specifies domain

    @error throws an error if property specifed by which does not exist

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 08/29/2000
} {
    switch $which {
	type - group_type - domain_name - url_root {
	    if $cached_p {
		return [portals_memoize "portals_get_domain_property -cached_p 0 $which $domain_id"]
	    } else {
		return [db_string portal_domain_property "
		select $which
		from portal_domains 
		where domain_id=:domain_id"]
	    }
	}
	portlet_header_color - td_header_html {
	    if $cached_p {
		return [portals_memoize "portals_get_domain_property -cached_p 0 $which $domain_id"]
	    } else {
		if [db_0or1row portal_domain_display_property "
		select $which
		from portal_domain_properties
		where domain_id=:domain_id"] {
		    return [set [set which]]
		} else {
		    return [portals_get_default_domain_property $which]
		}	    
	    }
	}
	portlet_count {
	    return [db_string portal_get_portlet_count "
	    select count(*) 
	    from portal_portlets pp, portal_domain_portlets pdp
	    where pdp.domain_id=:domain_id
	    and pdp.portlet_id=pp.portlet_id"]
	}
	default_portal_id {
	    return [db_string default_portal_id "
	    select portal_id from portals where default_p='t' and domain_id=:domain_id" -default 0]
	}
	control_panel_portlet_id {
	    return [db_string control_panel_portlet_id "select 1 from portal_domain_c_panel_map where domain_id=:domain_id" -default 0]
	}
	control_panel_exists_p {
	    set control_panel_portlet_id [portals_get_domain_property control_panel_portlet_id $domain_id]
	    return [ad_decode $control_panel_portlet_id 0 0 1]
	}
	default {
	    error "portals_get_domain_property: $which is invalid property"
	}
    }
}

ad_proc -public portals_set_domain_property { which domain_id value} {
    @param which specifies domain_property (portlet_header_color, td_header_html, control_panel_portlet_id)
    @param domain_id specifies domain
    @param value specifies property value
    
    @error throws an error if property specifed by which does not exist
    @error results in database error if domain_id does not exist
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 08/29/2000
} {
    switch $which {
	type - group_type - domain_name - url_root {
	    if { [string compare $which url_root]==0 } {
		set value [ad_urlencode $value]
	    }

	    db_dml update_portal_domain_property "
	    update portal_domains 
	    set $which = :value
	    where domain_id=$domain_id"

	    portals_memoize_flush_for_domain_property $domain_id
	}
	portlet_header_color - td_header_html - control_panel_portlet_id {
	    set value [db_nullify_empty_string $value]

	    portals_memoize_flush_for_domain_property $domain_id

	    db_exec_plsql portals_set_domain_property "
	    begin
	    portal_domain.set_property(:domain_id, :which, :value);
	    end;
	    "
	}
	default {
	    error "portals_set_domain_property: $which is invalid portal property"
	}
    }
}

ad_proc -public portals_remove_portal_domain { domain_id } {
    Removes portal domain.

    @author tarik@alatovic.com
    @date 01/29/2001
    @param domain_id
} {
    set url_root [db_string remove_domain "select url_root from portal_domains where domain_id=:domain_id"]
    ad_register_proc * /$url_root rp_escape

    db_foreach portal_domains "
    select portal_id
    from portals
    where domain_id=:domain_id
    " {
	set page_id_list [portals_get_portal_property page_id_list $portal_id]
	foreach page_id $page_id_list {
	    portals_memoize_flush_for_page_property $page_id
	}
	portals_memoize_flush_for_portal_property $portal_id
    }
    portals_memoize_flush_for_domain_property $domain_id

    db_exec_plsql portal_domain_remove "
    begin
    portal_domain.remove(v_domain_id => :domain_id);
    end;"
}

ad_proc -public portals_revert_domain_portlets { domain_id } {
    Reverts all portals in a domain to default portal configuration. 

    @author tarik@alatovic.com
    @date 01/23/2001
    @param domain_id domain_id of the portal domain for which we are reverting all portals to default congifuration.
} {
    db_exec_plsql portals_revert_domain_portlets "
    begin
        portal_domain.revert_domain_portlets(v_domain_id => :domain_id);
    end;"

    db_foreach portals_domain_portals "
    select portal_id
    from portals
    where domain_id=:domain_id
    " {
	set page_id_list [portals_get_portal_property page_id_list $portal_id]
	foreach page_id $page_id_list {
	    portals_memoize_flush_for_page_property $page_id
	}
	portals_memoize_flush_for_portal_property $portal_id
    }
    return
}

ad_proc -private portals_memoize_init_for_domain_properties {} {
    Initializes memoize cache for portal domain properties.
    @author Tarik Alatovic
    @date 01/29/2001
} {
    ns_log Notice "Initializing Portal Domain Properties Cache ..."
    db_foreach portal_domain_property1 "
    select domain_id, type, group_type, domain_name, url_root
    from portal_domains
    " {
	portals_memoize_init "portals_get_domain_property -cached_p 0 type $domain_id" $type
	portals_memoize_init "portals_get_domain_property -cached_p 0 group_type $domain_id" $group_type
	portals_memoize_init "portals_get_domain_property -cached_p 0 domain_name $domain_id" $domain_name
	portals_memoize_init "portals_get_domain_property -cached_p 0 url_root $domain_id" $url_root
    }

    db_foreach portal_domain_property2 "
    select domain_id, portlet_header_color, td_header_html
    from portal_domain_properties
    " {
	portals_memoize_init "portals_get_domain_property -cached_p 0 portlet_header_color $domain_id" $portlet_header_color
	portals_memoize_init "portals_get_domain_property -cached_p 0 td_header_html $domain_id" $td_header_html
    }
    ns_log Notice "Done initializing portal domain cache."
}

ad_proc -private portals_memoize_flush_for_domain_property { domain_id } {
    Flushes cache for portals_get_domain_property.

    @author Tarik Alatovic
    @date 01/29/2001

    @param domain_id
} {
    portals_memoize_flush "portals_get_domain_property -cached_p 0 type $domain_id"
    portals_memoize_flush "portals_get_domain_property -cached_p 0 group_type $domain_id"
    portals_memoize_flush "portals_get_domain_property -cached_p 0 domain_name $domain_id"
    portals_memoize_flush "portals_get_domain_property -cached_p 0 url_root $domain_id"
    portals_memoize_flush "portals_get_domain_property -cached_p 0 portlet_header_color $domain_id"
    portals_memoize_flush "portals_get_domain_property -cached_p 0 td_header_html $domain_id"
}



