ad_library {
    Portal navigation procs.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-navigation-procs.tcl,v 1.3 2001/02/04 22:44:20 tarik Exp $
}

ad_proc -public portals_navigation { portal_id page_number } {
    @return HTML that contains links to portal pages within a portal.  
    The current page will be displayed as text rather than a link.

    @param portal_id
} {
    if ![portals_info portal_page_p] {
	# setting portal context for non-portal pages
	portals_set_portal_context $portal_id -1
    }

    set selected_page_number [portals_info page_number]
    set domain_id [portals_info domain_id]
    set base_url [portals_info base_url]
    set administer_permission_p [portals_info administer_permission_p]
    
    set nav_html ""
    portals_display_info
    
    # TabHeaderTD and TabSubHeaderTD don't exist in older .ini files.
    # assign them some default values:    
    if {[empty_string_p $tab_header_td]} {
        set tab_header_td "<td>"
    }
    if {[empty_string_p $tab_subheader_td]} {
        set tab_subheader_td "<td>"
    }

    # Find out the number of pages this portal has
    set num_pages [portals_get_portal_property page_count $portal_id]
    # find out the total number of pages
    # total number of pages = number of portal pages (if there is no control panel)
    # total number of pages = number of portal pages + 1 (if control panel for this domain exists)
    set control_panel_exists_p [portals_get_portal_property control_panel_exists_p $portal_id]
    if $control_panel_exists_p {
	incr num_pages
    }
    
    # set up the page tabs only if there is more than one page
    if {$num_pages > 1} {
	# if we want equal size tabs, regsub a width restriction into the td
	if {[ad_parameter EqualWidthTabsP portals]} {
	    regsub {<td} $tab_header_td "<td width=\"[expr round(100/$num_pages)]%\"" header_td
	    regsub {<td} $tab_subheader_td "<td width=\"[expr round(100/$num_pages)]%\"" subheader_td
	} else {
	    set header_td $tab_header_td
	    set subheader_td $tab_subheader_td
	}

	set page_id_list [portals_get_portal_property page_id_list $portal_id]

	foreach page_id $page_id_list {
	    set page_name [portals_get_page_property page_name $page_id]
	    set page_number [portals_get_page_property page_number $page_id]
	    if [empty_string_p $page_name] {
		set page_name "Page $page_number"
	    }

	    if {$page_number == $selected_page_number} {
		append nav_html "$header_td <center>$page_name</center></td>\n"
	    } else {
		append nav_html "$subheader_td <center><a href=\"$base_url/page-$page_number/\">$page_name</a></center></td>\n"
	    }
	}

	if { $administer_permission_p && $control_panel_exists_p } {
	    # if user has admin rights and there is a control panel, show it
	    if {$selected_page_number==0} {
		    append nav_html "$header_td <center>Control Panel</center></td>\n"
	    } else {
		append nav_html "
		$subheader_td <center><a href=\"$base_url/control-panel/\">Control Panel</a></center></td>\n"
	    }
	} 
    }

    return $nav_html
}

ad_proc -public portals_header { portal_id domain_id portals_navigation } {
    @author unknown
    @date summer 2000

    @return Header for portal pages.
} {
    portals_display_info

    if ![portals_info portal_page_p] {
	# setting portal context for non-portal pages
	portals_set_portal_context $portal_id -1
    }
    
    if [nsv_exists portals_template_header $domain_id] {
	set header_adp_file [nsv_get portals_template_header $domain_id]
    } else {
	set header_adp_file "[ad_parameter PathToACS]/packages/portals/www/templates/header.adp"
    } 
    
    # while the following may not seem very readable, it is important that there are no
    # extra spaces in this table
    return "
    <table width=\"100%\" border=0 cellspacing=0 cellpadding=2>
      <tr>
      <td align=left colspan=2>
      [ns_adp_parse -file $header_adp_file]
      </td>
      </tr>
     
      <tr>
      <td align=left valign=bottom>
      <table border=0 cellpadding=5>
        <tr>
        $portals_navigation
        </tr>
      </table>
      </td>
      </tr>
    </table>"
}

ad_proc -public portals_footer { portal_id domain_id portals_navigation } {
    In the future, a footer for a portal domain should be stored in portal_domains

    @author unknown
    @date summer 2000

    @returns Footer for portal pages.
} {
    # Get generic display information
    portals_display_info

    if ![portals_info portal_page_p] {
	# setting portal context for non-portal pages
	portals_set_portal_context $portal_id -1
    }
    
    if [nsv_exists portals_template_footer $domain_id] {
    	set footer_adp_file [nsv_get portals_template_footer $domain_id]
    } else {
	set footer_adp_file "[ad_parameter PathToACS]/packages/portals/www/templates/footer.adp"
    } 

    return "
    <table width=\"100%\" border=0 cellspacing=0 cellpadding=0>
      <tr>
      <td align=left valign=bottom>
      <table border=0 cellpadding=5>
        <tr>
        $portals_navigation
        </tr>
      </table>
      </td>
      </tr>
    </table>
    $font_tag 
    <p>
    [ns_adp_parse -file $footer_adp_file]
    "
}

