ad_library {
    Routines for manipulating portal pages.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-page-api-procs.tcl,v 1.2 2001/02/04 03:28:52 tarik Exp $
}

ad_proc -public portals_get_page_id { portal_id page_number } {
    @return returns page_id of the page identified by portal_id and page_number.
            if page doesn't exist, it returns an empty string.
    @param portal_id specifies portal to which this page belongs
    @param page_number specifies portal page number

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/01/2000
} {
    return [db_exec_plsql portals_get_page_id "
    begin
    :1 := portal_page.id_from_page_number(v_portal_id => :portal_id, v_page_number => :page_number);
    end;
    "]
}

ad_proc -public portals_page_exists_p { {} portal_id page_number } {
    @return returns 1 if page specified by portal_id and page_number exists, otherwise returns 0
    @param portal_id specifies portals
    @param page_number page_number 

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/01/2000
} {
    if { $page_number > 0 } {
	return [db_exec_plsql portals_page_exists_p "
	begin
	:1 := portal_page.exists_p(v_portal_id => :portal_id, v_page_number => :page_number);
	end;
	"]
    } else {
	return [portals_get_domain_property control_panel_exists_p [portals_get_portal_property domain_id $portal_id]]
    }
}

ad_proc -public portals_get_page_property {{-cached_p 1} which page_id} {
    @return returns specified property for a portal page
    @param which specifies portal page property (portal_id, page_name, page_number)
    @param page_id specifies portal page
    
    @error throws an error if property specifed by which does not exist
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/31/2000
} {
    switch $which {
	portal_id {
	    return [db_string portals_get_page_property "
	    select $which 
	    from portal_pages
	    where page_id=:page_id
	    "]
	}
	page_name - page_number  {
	    if $cached_p {
		return [portals_memoize "portals_get_page_property -cached_p 0 $which $page_id"]
	    } else {
		return [db_string portals_get_page_property "
		select $which 
		from portal_pages
		where page_id=:page_id
		"]
	    }
	}
	default {
	    error "portals_get_page_property: $which is unrecognized portals page property"
	}
    }
}

ad_proc -public portals_set_page_property {which value page_id} {
    @param which specifies portal page property (page_name, page_number)
    @param page_id specifies portal page
    
    @error throws an error if property specifed by which does not exist
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/31/2000
} {
    switch $which {
	page_name - page_number {
	    db_dml update_portal_page_property "
	    update portal_pages 
	    set $which = :value
	    where page_id=$page_id
	    "
	    portals_memoize_flush_for_page_property $page_id
	}
	default {
	    error "portals_set_page_property: $which is unrecognized portal page property"
	}
    }
}

ad_proc -public portals_create_portal_page {portal_id page_number page_name} {
    @return page_id of newly created portal page
    @param portal_id portal_id of portals to which the page belongs
    @param page_number for a page
    @param page_name portal page name
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/31/2000
} {
    # make sure a page doesn't exist here already
    if { [db_0or1row does_this_page_exist "select 1 from portal_pages where portal_id = :portal_id and page_number = :page_number"] } {
	error "Page number $page_number already exists for portal_id $portal_id"
    }
    
    set page_id [db_exec_plsql portal_create_page "
    begin
    :1 := portal_page.create_new(v_portal_id => :portal_id, v_page_number => :page_number, v_page_name => :page_name);
    end;
    "]

    return $page_id
}

ad_proc -public portals_delete_portal_pages {portal_id} {
    @param portal_id of portal whose pages we are deleting
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/31/2000
} {
    db_foreach portal_page_id_list "
    select page_id
    from portal_pages
    where portal_id=:portal_id" {
	portals_memoize_flush_for_page_property $page_id
    }
    
    db_dml delete_portal_pages "
    delete from portal_pages
    where portal_id=:portal_id
    "
}

ad_proc -private portals_memoize_init_for_page_properties {} {
    Initializes memoize cache for portal page properties.
    @author Tarik Alatovic
    @date 01/29/2001
} {
    ns_log Notice "Initializing Portal Page Properties Cache ..."
    db_foreach portal_page_property "
    select page_id, page_name, page_number
    from portal_pages
    " {
	portals_memoize_init "portals_get_page_property -cached_p 0 page_name $page_id" $page_name
	portals_memoize_init "portals_get_page_property -cached_p 0 page_number $page_id" $page_number
    }
    ns_log Notice "Done initializing portal page cache"
}

ad_proc -private portals_memoize_flush_for_page_property { page_id } {
    Flushes cache for portals_get_page_property.

    @author Tarik Alatovic
    @date 01/29/2001

    @param page_id
} {
    portals_memoize_flush "portals_get_page_property -cached_p 0 page_name $page_id"
    portals_memoize_flush "portals_get_page_property -cached_p 0 page_number $page_id"
}
