ad_library {
    Portal permission procs.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-permission-procs.tcl,v 1.1 2001/01/30 20:54:26 tarik Exp $
}

ad_proc -private portals_default_user_has_permission_p {portal_id permission} {
    Determines whether logged in user has a right to view or administer a portal page
    identified by portal_id.
    This is a default portals authorization procedure. Different authorization procedure
    can be registered for each portal domain using portals_register_permission_proc.

    @author tarik@ardigita.com
    @date november 2000

    @param portal_id
    @param permission is either view or administer
    @return returns 1 if user has the indicated permission, otherwise returns 0.
} {
    set logged_in_user_id [ad_verify_and_get_user_id]
    set portal_type [portals_get_portal_property type $portal_id]

    switch $portal_type {
	default_portal {
	    switch $permission {
		view - administer {
		    # only site-wide administrators can manage default portals	
		    if [ad_administrator_p $logged_in_user_id] {
			return 1
		    } else {
			return 0
		    }
		}
		default {
		    error "portals_default_user_has_permission_p: invalid permission type for default portal"
		}
	    }
	}
	group {
	    set portal_group_id [portals_get_portal_property group_id $portal_id]
	    switch $permission {
		view {
		    return [ad_user_group_member $portal_group_id $logged_in_user_id]
		}
		administer {
		    # yes, the order of arguments is different from above return
		    return [ad_user_group_authorized_admin $logged_in_user_id $portal_group_id]
		}
		default {
		    error "portals_default_user_has_permission_p: invalid permission type for group portal"
		}
	    }
	}
	user {
	    set portal_user_id [portals_get_portal_property user_id $portal_id]
	    switch $permission {
		view - administer {
		    if {$portal_user_id == $logged_in_user_id} {
			return 1
		    } else {
			return 0
		    }
		}
		default {
		    error "portals_default_user_has_permission_p: invalid permission type for user portal"
		}
	    }
	}
    }
}

ad_proc -public portals_user_has_permission_p { portal_id permission } {
    Checks whether logged in user has a right to view or administer the portal page identified by portal_id.

    @author tarik@alatovic.com
    @date november 2000
    
    @param portal_id
    @param permission is either view or administer
    @return 1 if user has indicated permission, otherwise returns 0.
} {
    set domain_id [portals_get_portal_property domain_id $portal_id]

    if [nsv_exists portal_domain_permission_procs $domain_id] {
	# domain specific permission procedure is registered
	set permission_proc [nsv_get portal_domain_permission_procs $domain_id]
    } else {
	set permission_proc portals_default_user_has_permission_p
    }
    return [eval "$permission_proc $portal_id $permission"]
}
	    
ad_proc -public portals_register_permission_proc { domain_name proc_name } {
    Registers permission procedure for portal domain identified by domain_name.
    
    Registered procedure must have exactly two parameters: (1) portal_id, 
    and (2) permission (view or administer). Take a look at the 
    portals_default_user_has_permission_p for an example or a registered procedure. 
    if no permission procedure is registered for a domain, then the default 
    portals_default_user_has_permission_p procedure will be used.
 
    @author tarik@alatovic.com
    @date november 2000
    
    @param domain_name is the name of the domain for which a procedure is being registered
    @param proc_name is the name of permission procedure that is being registered

    @see portals_default_user_has_permission_p
    @see portals_user_has_permission_p 
} {
    set domain_id [portals_domain_id_from_domain_name $domain_name]
    nsv_set portal_domain_permission_procs $domain_id $proc_name
    ns_log Notice "Portals: Registered $proc_name as portal permission procedure for domain $domain_name"
}

