ad_library {
    Routines for manipulating portal portlets.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-portlet-api-procs.tcl,v 1.2 2001/02/02 21:48:49 tarik Exp $
}

ad_proc -public portals_get_portlet_property {which portlet_id} {
    @return returns specified property for a portal page
    @param which specifies portal page property (domain_id, portlet_name, content_source_type, content_source, admin_link_type, admin_link_source, required_p, predefined_portlet_id)
    @param portlet_id specifies the portlet
    @error throws an error if portlet doesn't exist
    @error throws an error if property specifed by which does not exist
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 09/31/2000
} {
    switch $which {
	content_source_type - content_source - admin_link_type - admin_link_source {
	    return [db_string get_portlet_property "
	    select $which 
	    from portal_portlets
	    where portlet_id=:portlet_id"]
	}
	domain_id - portlet_name - required_p - predefined_portlet_id {
	    return [db_string get_domain_portlet_property "
	    select $which 
	    from portal_domain_portlets
	    where portlet_id=:portlet_id"]
	}
	default {
	    error "portals_get_portlet_property: $which is unrecognized portlet property"
	}
    }
}

ad_proc -public portals_set_portlet_property {which value portlet_id} {
    @param which specifies portlet property that we are setting (domain_id, portlet_name, content_source_type, content_source, admin_link_type, admin_link_source, required_p)
    @param value specifies new value for the property
    @param portlet_id specifies portlet
    
    @error throws an error if property specifed by which does not exist
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 12/24/2000
} {
    switch $which {
	content_source_type - content_source - admin_link_type - admin_link_source {
	    db_dml update_portlet_property "
	    update portal_portlets
	    set $which = :value
	    where portlet_id=$portlet_id
	    "
	}
	domain_id - portlet_name - required_p {
	    db_dml update_domain_portlet_property "
	    update portal_domain_portlets
	    set $which = :value
	    where portlet_id=$portlet_id
	    "
	}
	default {
	    error "portals_set_portlet_property: $which is unrecognized portlet property"
	}
    }
}

ad_proc -public portals_update_domain_portlet {portlet_id predefined_portlet_id portlet_name content_source_type content_source admin_link_type admin_link_source} {
    updates portlet identified by portlet_id to properties specified by other parameters

    @param portlet_id
    @param predefined_portlet_id
    @param portlet_name
    @param content_source_type
    @param content_source
    @param admin_link_type
    @param admin_link_source

    @author tarik@alatovic.com
    @date 12/24/2000
} {
    db_exec_plsql portals_update_domain_portlet "
    begin
    portal_portlet.update_domain_portlet(v_portlet_id => :portlet_id, v_predefined_portlet_id => :predefined_portlet_id, v_portlet_name => :portlet_name, v_content_source_type => :content_source_type, v_content_source => :content_source, v_admin_link_type => :admin_link_type, v_admin_link_source => :admin_link_source);
    end;"
    return
}

ad_proc -public portals_create_domain_portlet {portlet_name domain_id content_source_type content_source admin_link_type admin_link_source {control_panel_p f} {required_p f}} {
    @return portlet_id of newly created portlet
    @param portlet_name name of the portlet
    @param domain_id domain_id of the domain to which this portlet belongs
    @param content_source_type 
    @param content_source
    @param admin_link_type
    @param admin_link_source
    @param control_panel_p is this portlet a control panel for this domain
    @param required_p is this portlet required portlet
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 12/24/2000
} {
    set portlet_id [db_exec_plsql portals_create_domain_portlet "
    begin
    :1 := portal_portlet.create_domain_portlet (v_portlet_name => :portlet_name, v_domain_id => :domain_id, v_content_source_type => :content_source_type, v_content_source => :content_source, v_admin_link_type => :admin_link_type, v_admin_link_source => :admin_link_source, v_control_panel_p => :control_panel_p, v_required_p => :required_p);
    end;"]
    return $portlet_id
}

ad_proc -public portals_create_domain_portlet_from_predefined_portlet {portlet_name domain_id predefined_portlet_id {control_panel_p f} {required_p f}} {
    @return portlet_id of newly created portlet
    @param portlet_name name of the portlet
    @param domain_id domain_id of the domain to which this portlet belongs
    @param predefined_portlet_id porltet_id of the predefined portlet that we are copying
    @param control_panel_p is this portlet a control panel for this domain
    @param required_p is this portlet required portlet
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 12/24/2000
} {
    set portlet_id [db_exec_plsql portals_create_domain_portlet "
    begin
    :1 := portal_portlet.create_from_predefined_portlet (v_portlet_name => :portlet_name, v_domain_id => :domain_id, v_predefined_portlet_id => :predefined_portlet_id, v_control_panel_p => :control_panel_p, v_required_p => :required_p);
    end;"]
    return $portlet_id
}

ad_proc -public portals_delete_portlet {portlet_id} {
    deletes portlet identified by portlet_id
    @param portlet_id
    
    @author Tarik Alatovic (tarik@alatovic.com)
    @date 12/24/2000
} {
    db_exec_plsql portals_delete_portlet "
    begin
       portal_portlet.delete (v_portlet_id => :portlet_id);
    end;"
    return
}

ad_proc -public portals_move_portlet {portlet_id page_id page_side sort_key} {
    Moves portlet identified by portlet_id to page identified by page_id, and sets horizontal and vertical position
    of the portlet on the page using page_side and sort_key parameters.

    @param portlet_id identifies portlet that is being moved
    @param page_id identfies the page that portlet is being moved to
    @param page_side identifies the horizontal position of the portlet
    @param sort_key identifies the vertical position of the portlet

    @author Tarik Alatovic (tarik@alatovic.com)
    @date 11/29/2000
} {
    db_exec_plsql portals_move_portlet "
    begin
    portal_portlet.move(v_portlet_id => :portlet_id, v_page_id => :page_id, v_page_side => :page_side, v_sort_key => :sort_key);
    end;"
}

ad_proc -public portals_generate_portlet_html {portlet_name content_source_type content_source admin_link_type admin_link_source} {
    @author unknown
    @date unknown
    @return portlet HTML by either parsing adp data feed or evaluating tcl feed
} {
    portals_display_info

    # if portal domain is defined, then use domain specific display information
    global portals_info
    if [info exists portals_info(domain_id)] {
	set header_bg [portals_get_domain_property portlet_header_color [portals_info domain_id]]
	set header_td [portals_get_domain_property td_header_html [portals_info domain_id]]
    }

    switch $content_source_type {
	tcl {
	    if [catch { set content_html [eval $content_source] } errmsg] {
		ns_log Error "portals_display_page tried to evaluate tcl: \n\n$content_source\n\nand got hit with\n\n$errmsg\n"
		return ""
	    }
	}
	adp {
	    if [catch { set content_html [ns_adp_parse -string $content_source] } errmsg] {
		ns_log Error "portals_display_page tried to parse adp: \n\n$content_source\n\nand got hit with\n\n$errmsg\n"
		return ""
	    }
	}
	html {
	    set content_html $content_source
	}
	default {
	    error "portals_generate_portlet_html: $content_source_type is invalid content source type"
	}
    }

    # Modifies any <td>s or <th>s in an embedded table to have a standard
    # font tag after it so that this text also will conform to the portal
    # standard font.
    #  Note that by not closing the <font> tag, these regexps produce weird
    #  non-compliant HTML.  CSS would probably be a better way to deal with
    #  this.  -ib
    regsub -nocase -all {(<td[^>]*>)} $content_html {\1 font_tag} content_html
    regsub -nocase -all {(<th[^>]*>)} $content_html {\1 font_tag} content_html
    regsub -nocase -all {font_tag} $content_html $font_tag content_html

    # if content_html is empty, return an empty string (don't display the portlet)
    if [empty_string_p $content_html] {
	return ""
    }

    #next we generate the administration link
    if ![empty_string_p $admin_link_source] {
	switch $admin_link_type {
	    tcl {
		if [catch { set admin_link_html [eval $admin_link_source] } errmsg] {
		    ns_log Error "portals_display_page tried to evaluate tcl: \n\n$admin_link_source\n\nand got hit with\n\n$errmsg\n"
		    set admin_link_html ""		
		}
	    }
	    adp {
		if [catch { set admin_link_html [ns_adp_parse -string $admin_link_source] } errmsg] {
		    ns_log Error "portals_display_page tried to parse adp: \n\n$admin_link_source\n\nand got hit with\n\n$errmsg\n"
		    set admin_link_html ""
		}
	    }
	    html {
		set admin_link_html $admin_link_source
	    }
	    default {
		error "portals_generate_portlet_html: $admin_link_type is invalid admin_link_source_type"
	    }
	}
    } else {
	set admin_link_html ""
    }

    if {[empty_string_p $admin_link_html]} {
	# this is the default where administration link is not provided
	set admin_td "<td bgcolor=\"$header_bg\" align=right>&nbsp;</td>"
    } else {
	set admin_td "
	<td bgcolor=\"$header_bg\" align=right> 
	$admin_link_html
	</td>"
    }

    # it's bad for interior_table and end_table to share the same end_table,
    # since interior_table might not be defined.
    if {![empty_string_p $interior_table]} {
        set interior_end_table "</td>\n</tr>\n$end_table"
    } else {
        set interior_end_table {}
    }

    # and, of course, interior_table needs to be inside a <tr>, which
    # messes things up when it's not defined...
    if {![empty_string_p $interior_table]} {
	set interior_table "<tr>\n<td>\n$interior_table"
    }

    return "
<!-- Begin portlet '$portlet_name' -->
    $begin_table
        $interior_table
        <tr>
        $header_td 
        $portlet_name
        </td>
        $admin_td
        </tr>

        <tr>
        $normal_td
<!-- Begin content for '$portlet_name' -->
$content_html
<!-- End content for '$portlet_name' -->
        $interior_end_table
    </tr>
    $end_table
<!-- End portlet '$portlet_name' -->\n\n"
}
