ad_library {
    Portal widgets.

    @creation-date January 2001
    @author tarik@alatovic.com
    @cvs-id $Id: portal-widget-procs.tcl,v 1.1 2001/01/30 20:54:27 tarik Exp $
}

ad_proc -public portals_slider { key dimensions {default ""} {url ""} {separator " | "}} {
    <p>Return a list of links to $url, with ${key}_slider set to a value from
    $dimensions for each.  ${key}_slider's current (page variable) value
    will be left unlinked.  If ${key}_slider has no value, the link with
    value corresponding to $default will be left unlinked instead.</p>

    <p>Presumably one would use this to generate a dimensional slider.  For example:</p>

    <pre>
    ns_return "
    &lt;b&gt;View New Stuff&lt;/b&gt;
    $html_fragment_containing_the_new_stuff
    &lt;p&gt;
    Days? [portals_slider "my_module_new_stuff" [list 1 2 3 4 5 6 7 14 30 {"All" 0}] 1 ]
    "
    </pre>

    <p>Get the current value with portals_get_slider.</p>

    @param key The key by which the variable is identified.  Make sure it's unique.  $key may only contain word characters, or for the regular-expressionly minded, <tt>[\w]</tt>, or <tt>[A-Za-z0-9_]</tt>.
    @param dimensions A list of possible link values.  Each element may be either a list of key,value, or simply a value, in which case it will be used for both.
    @param default The default value for $key.
    @param url The URL to link to.  If left blank, the current URL is used.
    @param separator The string that should be inserted between each value in the list.
    @author Ian Baker (ibaker@arsdigita.com)
    @creation-date 10/23/2000
    @cvs-id $Id: portal-widget-procs.tcl,v 1.1 2001/01/30 20:54:27 tarik Exp $
} {
    #portals_get_slider does this, since $key becomes part of a Tcl
    #variable's name, so it'd be good to maintain consistency.
    regsub -all {[^\w]} $key "" key

    # get the current value.
    set current_value [portals_get_slider $key $default ]

    # set the URL.
    if {[empty_string_p $url]} {
        append url "[ad_conn url]?"
        # ad_conn doesn't support this parameter.
        append url "[ns_conn query]"
    }

    # remove previous occurances of $key.    
    regsub -all "(\[&?\])${key}_slider=.*?(&|$)" $url {\1} url

    # does the URL need a "?" or "&" at the end of it?
    # this could be done with one substution, but this is possibly a little
    # more clear.
    if {![regexp {[&\?]$} $url match]} {
        if {![regexp {\?} $url match]} {
            append url "?"
        } else {
            append url "&"
        }
    } 

    foreach dm $dimensions {
        # separate name/value, or just a single value?
        if {[llength $dm] > 1} {
            set d_key [lindex $dm 0]
            set d_val [lindex $dm 1]
        } else {
            set d_key $dm
            set d_val $dm
        }
        
        if { $current_value == $d_val } {
            lappend slider_list "<b>$d_key</b>"
        } else {
            lappend slider_list "<a href=\"${url}${key}_slider=$d_val\">$d_key</a>"
        }
    }
    return [join $slider_list $separator]
}

ad_proc -public portals_get_slider { key {default ""} } {
    Get a value provided by a dimensional slider, generated by
    portals_slider.  See its documentation for a complete explanation.

    @param key The key by which the value you want is identified.  $key may only contain word characters, or for the regular-expressionly minded, <tt>[\w]</tt>, or <tt>[A-Za-z0-9_]</tt>.
    @param default The default value for $key.
    @author Ian Baker (ibaker@arsdigita.com)
    @creation-date 10/23/2000
    @cvs-id $Id: portal-widget-procs.tcl,v 1.1 2001/01/30 20:54:27 tarik Exp $
} {
    # data comes from a trusted source, but it's better to be careful with expr.
    regsub -all {[^\w]} $key "" key

    # if there's a better way to do this (get the value of a form variable
    # when its name is stored in a Tcl variable), I'd like to know it.  -ib
    ad_page_variables [list [list "${key}_slider" ""]]

    set current_value [expr "\$${key}_slider"]
    if {[empty_string_p $current_value]} {
        return $default
    }
    return $current_value
}
