ad_library {
    Routines used by the portal system.

    @creation-date Septemeber 1999
    @author aure@arsdigita.com
    @author tarik@alatovic.com
    @cvs-id $Id: portals-procs.tcl,v 1.12 2001/02/07 05:40:39 tarik Exp $
}

proc reportTime {{label ""}} {
    global initialized_p
    global currentTime 
    global startTime 
    global counter

    if ![info exists initialized_p] {
	set counter 0
	set startTime [clock clicks -milliseconds]
	set currentTime [clock clicks -milliseconds]
	set initialized_p 1
    }

    set oldCurrentTime $currentTime
    set currentTime [clock clicks -milliseconds]
    #ns_log Notice "Time $label $counter: [expr $currentTime - $oldCurrentTime], [expr $currentTime - $startTime]"

    incr counter
}

ad_proc -private portals_process_request {} {
 Uses the URL to determine what portal page to show, returns the html.

 @author aure@arsdigita.com
 @date 1999
 @return portal html based on URL.
} {
    reportTime initial

    # we must have / at the end of url in order to have current directory properly set
    if  {![regexp {\/$} [ns_conn url]]} {
	ad_returnredirect "[ns_conn url]/"
	return
    }

ns_log Notice "URL: [ns_conn url]"

    # find page number
    set last_url_element [lindex [ns_conn urlv] [expr [ns_conn urlc] - 1]]
    if {[string compare $last_url_element control-panel]==0} {
	# control panel
	set page_number 0
	set url_list [map ad_urlencode [lrange [ns_conn urlv] 0 [expr [ns_conn urlc] - 2]]]
    } elseif [regexp {page-([0-9]+)} $last_url_element match page_number] {
	set url_list [map ad_urlencode [lrange [ns_conn urlv] 0 [expr [ns_conn urlc] - 2]]]
    } else {
	# if url doesn't finish with page-# or control-panel then first page of the portal is served
	set page_number 1
	set url_list [map ad_urlencode [ns_conn urlv]]
    }
    set num_url_elements [llength $url_list]
    
    # find portal_id
    set url_element_count 0
    set domain_element_p 1
    set user_id [ad_verify_and_get_user_id]
    set parent_portal_id [db_null]
    while { $url_element_count < $num_url_elements } {
	set url_element [lindex $url_list $url_element_count]
	if $domain_element_p {
	    set url_root_matches_p [db_0or1row url_root_matches_p "
	    select domain_id
	    from portal_domains
	    where url_root=:url_element"]
	    
	    if !$url_root_matches_p {
		ns_returnnotfound 
		return
	    }

	    # only registered users can access portals
	    if { $user_id==0 } {
		if [nsv_exists portals_template_unregistered_user_complaint $domain_id] {
		    set unregistered_user_complaint_adp_file [nsv_get portals_template_unregistered_user_complaint $domain_id]
		} else {
		    set unregistered_user_complaint_adp_file "[ad_parameter PathToACS]/packages/portals/www/templates/unregistered-user-complaint.adp"
		} 
		ReturnHeadersNoCache "text/html"
		ns_write "[ns_adp_parse -file $unregistered_user_complaint_adp_file]"
		return
	    }
	    set portal_type [portals_get_domain_property type $domain_id]
	    if { [string compare $portal_type user]==0 } {
		set portal_id [portals_get_portal_id user $user_id $domain_id]
	    }
	    
	    set domain_element_p 0
	} else {
	    if ![db_0or1row portals_process_request_get_portal_id "
	    select portal_id
	    from portals
	    where domain_id=:domain_id
	    and url_identifier=:url_element
	    and ((parent_portal_id=:parent_portal_id) or ((parent_portal_id is null) and (:parent_portal_id is null)))"] {
		ns_returnnotfound 
		return
	    }
	    set parent_portal_id $portal_id
	    set domain_element_p 1
	}
	incr url_element_count
    }

    # if this is a group portal, we want to show portal of non approved or non active group
    if { $portal_type=="group" } {
	if ![db_0or1row portal_group_approved_p "
	select 1
	from portals p, user_groups ug
	where p.portal_id=:portal_id
	and p.group_id=ug.group_id
	and ug.approved_p='t'
	and ug.active_p='t'
	"] {
	    ns_returnnotfound 
	    return
	}
    }

    # check if requested portal page exists
    if ![portals_page_exists_p $portal_id $page_number] {
	# if requested portal page does not exist offer users with a link
	# for customizing their portals
	ad_return_warning "Portal page does not exist" "
	<blockquote>
	Portal page $page_number does not exist for \"[portals_get_portal_property portal_name $portal_id]\" portal. 
	Click <a href=\"/portals/customize?portal_id=$portal_id\">here</a> to customize the portal content and layout.
	</blockquote>
	"
	return
    }

    reportTime parsing_url

    portals_set_portal_context $portal_id $page_number
    
    # return forbidden page if user is not allowed to view the portal page
    if { ![portals_info view_permission_p] } {
	if [nsv_exists portals_view_access_forbidden $domain_id] {
	    ReturnHeadersNoCache "text/html"
	    ns_write "[ns_adp_parse -file [nsv_get portals_view_access_forbidden $domain_id]]"
	    return
	} else {
	    return ns_returnforbidden
	}
    }

    # return forbidden page if user is not allowed to access the control p
    if { $page_number==0 && ![portals_info administer_permission_p] } {
	if [nsv_exists portals_admin_access_forbidden $domain_id] {
	    ReturnHeadersNoCache "text/html"
	    ns_write "[ns_adp_parse -file [nsv_get portals_admin_access_forbidden $domain_id]]"
	    return
	} else {
	    return ns_returnforbidden
	}
    }

    reportTime setting_portal_context

    if [catch {
	doc_return 200 text/html [portals_display_page]
	reportTime writing_to_connection
    } errMsg] {
	ns_log Error $errMsg
    }
    return
}

ad_proc -public portals_set_portal_context {portal_id page_number} {
    sets the context for currently served page. following variables can be accessed through portals_info procedure:
    domain_id, domain_name, url_root, portal_id, type, portal_name, base_url, portal_page_p, page_type, page_number, page_id if page_id exists
    (notice that control panel page is not a portal page and therefore doesn't have a page_id), view_permission_p,
    administer_permission_p, and user_id or a group_id depending on whether the portal belongs to a user or to a group
    
    @author Tarik Alatovic
    @date 12/22/2000
    @params portal_id portal_id of currently served portal
    @param page_number page_number of currently served portal. 
           page_number for a portal page is always a positive integer.
           page_number for control_panel is 0.
           page_number is -1 if we are setting a portal context for no particular page.
                       this is useful for administration preview pages and providing navigation bar for non-portal pages.
} {
    if [portals_info portals_context_set_p] {
	# is portal context is already set, then just return
	return
    }
    # this hack allows us to serve templating system pages inside portal
    portals_initialize_templating_system

    global portals_info

    # portal domain info
    set domain_id [portals_get_portal_property domain_id $portal_id]
    set portals_info(domain_id) $domain_id
    set portals_info(domain_name) [portals_get_domain_property domain_name $domain_id]
    set portals_info(url_root) [portals_get_domain_property url_root $domain_id]

    # portal info
    set portals_info(portal_id) $portal_id
    set portals_info(type) [portals_get_portal_property type $portal_id]

    set portals_info(portal_name) [portals_get_portal_property portal_name $portal_id]

    set portals_info(base_url) [portals_get_portal_property base_url $portal_id]

    set portals_info(customization_url) /portals/customize?portal_id=$portal_id

    # permissions
    set portals_info(view_permission_p) [portals_user_has_permission_p $portal_id view]
    set portals_info(administer_permission_p) [portals_user_has_permission_p $portal_id administer]

    # user_id, group_id
    switch $portals_info(type) {
	user {
	    set portals_info(user_id) [portals_get_portal_property user_id $portal_id]
	    set portals_info(group_id) ""
	}
	group {
	    set portals_info(user_id) ""
	    set portals_info(group_id) [portals_get_portal_property group_id $portal_id]
	}
    }

    # portal page info
    set portals_info(page_number) $page_number
    if { $page_number > 0 } {
	set portals_info(page_id) [portals_get_page_id $portal_id $page_number]
    } else { 
	set portals_info(page_id) 0
    }

    set portals_info(portals_context_set_p) 1

}

ad_proc -private portals_display_page {} {
   Helper proc for portals_process_request.

   @author unknown
   @date unknown
   @return HTML for the portal page corresponding to the arguments.
} {
    # Get generic display information
    set portal_name [portals_info portal_name]
    set domain_id [portals_info domain_id]
    set portal_id [portals_info portal_id]
    set page_id [portals_info page_id]
    set page_number [portals_info page_number]

    portals_display_info
    set left_side_width  [ad_parameter LeftSideWidth  portals]
    set right_side_width [ad_parameter RightSideWidth portals]
    
    if ![empty_string_p $left_side_width] {
	set left_side_width "width=\"$left_side_width\""
    }
    if ![empty_string_p $right_side_width] {
	set right_side_width "width=\"$right_side_width\""
    }

    set table_spacer "\n<!-- SPACER --> <table border=0 cellpadding=0 cellspacing=0><tr><td><img src=[ad_parameter SpacerImage portals] width=\"100%\" height=5></td></tr></table> <!-- END SPACER -->\n"

    reportTime "portals_display_page initialization"

    if {$page_number!=0} {
	set page_name [portals_get_page_property page_name $page_id]
	set portlet_list [db_list_of_lists portal_pages_info "
	select  ptpm.page_side, pdp.portlet_name, pt.content_source_type, pt.content_source, pt.admin_link_type, pt.admin_link_source
	from    portal_portlet_page_map ptpm, portal_domain_portlets pdp, portal_portlets pt
	where ptpm.page_id=:page_id
	and pt.portlet_id = ptpm.portlet_id
	and pdp.portlet_id= pt.portlet_id
	order by ptpm.page_side, ptpm.sort_key
	"]
    } else {
	# page_number=0 indicates administration page
	set page_name "Control Panel"

	if [db_0or1row control_panel "
	select pdp.portlet_name, pt.content_source_type, pt.content_source, pt.admin_link_type, pt.admin_link_source
	from portal_domain_portlets pdp, portal_portlets pt
	where pdp.domain_id=:domain_id
	and pdp.portlet_id=pt.portlet_id
	and portal_portlet.control_panel_p(pdp.portlet_id, :domain_id)=1"] {
	    set portlet_list [list [list l $portlet_name $content_source_type $content_source $admin_link_type $admin_link_source]]
	} else {
	    set portlet_list [list]
	}
    }

    reportTime "portals_display_page getting_portlet_content_source"

    set l_side_html ""
    set r_side_html ""

    foreach portlet_triplet $portlet_list {
	set page_side [lindex $portlet_triplet 0]
	set portlet_name [lindex $portlet_triplet 1]
	set content_source_type [lindex $portlet_triplet 2]
	set content_source [lindex $portlet_triplet 3]
	set admin_link_type [lindex $portlet_triplet 4]
	set admin_link_source [lindex $portlet_triplet 5]
	set portlet_html [portals_generate_portlet_html $portlet_name $content_source_type $content_source $admin_link_type $admin_link_source]
	reportTime $portlet_name
	if ![empty_string_p $portlet_html] {
	    append ${page_side}_side_html  "$portlet_html $table_spacer"
	}
    }

    set portals_navigation [portals_navigation $portal_id $page_number]

    reportTime portal_navigation_time

    set page_html "
    <html>
    <head>
    <title>$portal_name : $page_name</title>
    </head>

    $body_tag

    <table cellpadding=3 cellspacing=0 border=0 width=\"100%\">
    <tr>
       <td colspan=2>
       [portals_header $portal_id $domain_id $portals_navigation]
       </td>
    </tr>
    <tr>
<!-- begin left side -->
       <td $left_side_width valign=top>$l_side_html</td>
<!-- end left side/begin right side -->
       <td $right_side_width valign=top>$r_side_html</td>
<!-- end right side -->
    </tr>
    <tr>
       <td colspan=2>
       [portals_footer $portal_id $domain_id $portals_navigation]
       </td>
    </tr>
    </table>
    </body>
    </html>
    "

    reportTime assembling_portal_page
    return $page_html
}

ad_proc -private portals_initialize_templating_system {} {
    Hack procedure that lets us serve templating system files inside portals.

    @author tarik@alatovic.com
    @date summer 2000
} {
    global errorSet
    if ![info exists errorSet] {
	set errorSet [ns_set create]
    }
    #If we don't have the template packages installed this is a nop
    ad_call_proc_if_exists ad_locale_init
}

ad_proc -public portals_register_template {template_name domain_name path_to_template_adp_file} {
    registers template specified by template_name for portal domain identified by domain_name.

    @param template_name template_name can be one of the following: header, footer, unregistered_user_complaint
    @param domain_name
    @param path_to_template_adp_file
    
    @author tarik@alatovic.com
    @date 12/26/2000
} {
    set domain_id [portals_domain_id_from_domain_name $domain_name]
    switch $template_name {
	header {
	    nsv_set portals_template_header $domain_id $path_to_template_adp_file
	}
	footer {
	    nsv_set portals_template_footer $domain_id $path_to_template_adp_file
	}
	unregistered_user_complaint {
	    nsv_set portals_template_unregistered_user_complaint $domain_id $path_to_template_adp_file
	}
	view_access_forbidden {
	    nsv_set portals_view_access_forbidden $domain_id $path_to_template_adp_file
	}
	admin_access_forbidden {
	    nsv_set portals_view_access_forbidden $domain_id $path_to_template_adp_file
	}
	default {
	    error "portals_register_template: $template_name is unrecognized template name"
	}
    }
    ns_log Notice "portals_register_template: registered $path_to_template_adp_file as $template_name template for domain $domain_name"
}

ad_proc -private portals_return_unauthorized {} {

 Someone is probably trying to access a page in /portals/admin/ and doesn't have group admin permission to do so.

    @author crag@arsdigita.com
    @date October 2000
    @return Nice HTML page that user doesn't have access to the page the user hit.
} {

    set signatory [ad_system_owner]

    doc_return 200 text/html "
    [ad_header "Authorization Failed"]
    <h3>Authorization Failed</h3>
    <hr>
    <p>You are not allowed to access this page.  Perhaps you need to <a href=\"/register/?return_url=[ad_urlencode [ad_conn url]]\">log in</a>.  Please contact <a href=\"mailto:$signatory\"><i>$signatory</i></a> if you have any questions.
    </p>
    [ad_footer]
    "
}

ad_proc -public portals_parameter { parameter } {
    @author tarik@alatovic.com
    @date december 2000
    @which specifies portal parameter
    @return returns portal parameter if it exists. it portal parameter doesn't exist, a default value is returned.
} {  
    switch $parameter {
	MaxPagePortlets {
	    return [ad_parameter MaxPagePortlets portals 1000]
	}
	default {
	    error "portals_parameter: parameter $parameter is not defined"
	}
    }
}

ad_proc -public portals_info { which } {
    @author tarik@alatovic.com
    @date summer 2000
    @param which specifies property of currently served portal page, which is one of the following:
    <ul>
    <li>portals_context_set_p, portal_page_p, type, user_id, group_id, 
    <li>domain_id , domain_name, url_root,
    <li>portal_id, portal_name, base_url, customization_url, 
    <li>page_number, page_id,
    <li>view_permission_p, administer_permission_p
    </ul>

    @return Returns portal property.  If property specified by which does not exist, it returns an empty string.
} {
    global portals_info
    
    switch $which {
	portals_context_set_p {
	    if { [info exists portals_info(portals_context_set_p)] && $portals_info(portals_context_set_p) == 1 } {
		return 1
	    } else {
		return 0
	    }
	}
	portal_page_p {
	    if { [portals_info portals_context_set_p] && [portals_info page_number] >= 0 } {
		return 1
	    } else {
		return 0
	    }
	}
	default {
	    if { [info exists portals_info($which)] } {
		return $portals_info($which)
	    } else {
		return ""
	    }
	}
    }
}

ad_proc -private portals_preview_domain_portlet {domain_id portlet_name predefined_portlet_id html_source default_link_p html_link} {
    this function is used in admin pages for previewing the portlet for a specific portal domain.

    @return returns portlet html

    @param portlet_name
    @param predefined_portlet_id if predefined_portlet_id is 0 then the portlet is not a predefined portlet, and content_source and content_source_type are used to determine portlets content. otherwise, portlets content is set using html_source.
    @param html_source html_source is user specified html content of the portlet. html_source is not used for predefined portlets.
    @param default_link_p default_link_p is 1 if admin_link_type and admin_link_source of predefined portlet are used. otherwise, when html_link is used as portlet's admin_link, default_link_p is 0.
    @param html_link html_link is user specified html portlet link. html_link is not used when default_link_p is true.

    @error throws error if there are no portals in the domain specified by domain_id because portlet cannot be previewed without a portal context.

    @author tarik@alatovic.com
    @date 12/24/2000
} {
    # in order to preview the portlet, we must set the portal context information.
    # if this is a user domain, we show the portlet in the context of a portal
    # belonging to the currently logged in user.
    # if this is a group domain, we show the portlet in the context of a portal
    # belonging to the group with the smallest group_id within the domain
    set portal_type [portals_get_domain_property type $domain_id]
    switch $portal_type {
	user {
	    set portal_id [portals_get_portal_id user [ad_verify_and_get_user_id] $domain_id]	
	    set portal_exists_p 1
	}
	group {
	    set group_id [db_string smallest_group_id_within_domain "
	    select group_id 
	    from portals 
	    where domain_id=:domain_id
	    and rownum=1
	    order by group_id" -default 0]
	    if { $group_id>0 } {
		set portal_id [portals_get_portal_id group $group_id $domain_id]
		set portal_exists_p 1
	    } else {
		set portal_exists_p 0
	    }
	}
    }
    
    if $portal_exists_p {
	# at least one portal in this domain exists and we can preview the portlet for this portal
	
	# set the portal context
	portals_set_portal_context $portal_id -1
	
	if { $predefined_portlet_id>0 } {
	    set content_source_type [portals_get_portlet_property content_source_type $predefined_portlet_id]
	    set content_source [portals_get_portlet_property content_source $predefined_portlet_id]
	} else {
	    set content_source_type html
	    set content_source [util_close_html_tags $html_source]
	}
	
	if $default_link_p {
	    set admin_link_type [portals_get_portlet_property admin_link_type $predefined_portlet_id]
	    set admin_link_source [portals_get_portlet_property admin_link_source $predefined_portlet_id]
	} else {
	    set admin_link_type html
	    set admin_link_source [util_close_html_tags $html_link]
	}
	
	return [portals_generate_portlet_html $portlet_name $content_source_type $content_source $admin_link_type $admin_link_source]
    } else {
	error "portals_preview_domain_portlet: porltet cannot be previewed without a portal context"
    }
}

ad_proc -public portals_memoize {tcl_statement} {
    @author Tarik Alatovic
    @date   01/29/2001

    Same as util_memoize, but memoizes only if portal parameter CachingEnabledP is set to 1.
    Also, oldest_acceptable_value_in_seconds is set to [ad_parameter "SessionLifetime" "" 176800]
} {
    if [ad_parameter CachingEnabledP portals 1] {
	return [util_memoize $tcl_statement [ad_parameter "SessionLifetime" "" 176800]]
    } else {
	return [eval $tcl_statement]
    }
}

ad_proc -public portals_memoize_flush {tcl_statement} {
    @author Tarik Alatovic
    @date   01/29/2001

    Same as util_memoize_flush, but flushes only if portal parameter CachingEnabledP is set to 1.
} {
    if [ad_parameter CachingEnabledP portals 1] {
	return [util_memoize_flush $tcl_statement]
    }
}

ad_proc -public portals_memoize_init {tcl_statement value} {
    @author Tarik Alatovic
    @date   01/29/2001

    Same as util_memoize_seed, but seeds the memoize cache only on local server.
} {
    nsv_set util_memoize_cache_value $tcl_statement $value
    # store the time in seconds since 1970
    nsv_set util_memoize_cache_timestamp $tcl_statement [ns_time]
}

ad_proc -public portals_valid_url_identifier_p {url_identifier} {
    @return returns 1 if url_identifier doesn't contain any invalid characters; otherwise, it returns 0.
            only valid characters are alpha numeric characters, and dot(.), dash(-), an underscore(_).

    @author Tarik Alatovic
    @date   02/02/2001
} {
    if [regexp {[^a-zA-Z0-9\-\_\.]} $url_identifier] {
	return 0
    } else {
	return 1
    }
}

######################################################################
# DEPRECATED PROCEDURES #
######################################################################

ad_proc -deprecated ad_portals { which } {
    this procedure is earlier version of portals_info. we are providing it for compatibilty with previous portals releases.

    @author tarik@alatovic.com
    @date summer 2000
} {
    return [portals_info $which]
}

ad_proc -deprecated portals_page_p {} {
    if this page is a portal page returns 1, otherwise returns 0.

    @author unknown
    @date summer 2000
} {
    global portals_info 
    if [info exists portals_info] {
	return 1 
    } else {
	return 0
    }
}

ad_proc -private -deprecated portals_display_info {} { 
    Eventually, we want to get rid of this proc, and not be so reliant on .ini parameters.  Uplevels all the system specific display information  for the portals system.  
    
    Don't confuse this function with portals_info.
} {
    uplevel {
 	set system_name  [ad_parameter SystemName  portals]
	set body_tag     [ad_parameter BodyTag     portals]
	set begin_table  [ad_parameter BeginTable  portals]
	set interior_table  [ad_parameter InteriorTable  portals]
	set end_table    [ad_parameter EndTable    portals]
	set font_tag     [ad_parameter FontTag     portals]
	set header_td    [ad_parameter HeaderTD    portals]
	set subheader_td [ad_parameter SubHeaderTD portals]
	set tab_header_td    [ad_parameter TabHeaderTD    portals]
	set tab_subheader_td [ad_parameter TabSubHeaderTD portals]
	set normal_td    [ad_parameter NormalTD    portals]
	set header_bg    [ad_parameter HeaderBGColor portals]
    }
}

