ad_page_contract {
    Portal page customization.

    @author tarik@alatovic.com
    @param left
    @param right
    @param hiddennames
    @creation-date 10/8/1999
    @cvs-id $Id: customize-2.tcl,v 1.6 2001/02/04 22:44:21 tarik Exp $
} {
    left
    right
    hiddennames
    portal_id:naturalnum
} -validate {
    required_portlets_present {
	set portlet_id_list [list]
	foreach left_list $left {
	    foreach portlet_id $left_list {  
		lappend portlet_id_list $portlet_id
	    }   
	}
	foreach right_list $right {
	    foreach portlet_id $right_list {     
		lappend portlet_id_list $portlet_id
	    }   
	}

	set domain_id [portals_get_portal_property domain_id $portal_id]
	set portal_type [portals_get_portal_property type $portal_id]
	set default_portal_p [ad_decode $portal_type default_portal 1 0]

	# make sure required portlets have been selected
	set required_portlets [db_list get_required_portals "
	select pp.portlet_id
	from portal_portlets pp, portal_domain_portlets pdp 
	where pp.portlet_id=pdp.portlet_id
	and pdp.required_p = 't'
	and pdp.domain_id = :domain_id"]

	set missing_id_list [list]
	foreach p_id $required_portlets {
	    if { [lsearch -exact $portlet_id_list $p_id] == -1 } {
		lappend missing_id_list $p_id
	    }
	}
	if { [llength $missing_id_list] > 0 } {
	    set missing_portlets_list [db_list missing_portlets "
	    select portlet_name
	    from [ad_decode $default_portal_p 1 portal_predefined_portlets portal_domain_portlets]
	    where portlet_id in ([join $missing_id_list ", " ]) "]
	    
	    ad_complain "Required portlets are missing: [join $missing_portlets_list ", "] "
	}
    }
}
 
if ![portals_user_has_permission_p $portal_id administer] {
    portals_return_unauthorized
    ad_script_abort
}

set domain_id [portals_get_portal_property domain_id $portal_id]
# consolidate left, right, and hiddenames variables into portal_elements_list:
# portal_elements_list is a list of portal_page_elements
# portal_page_elements is a list of page_name, left_side_portlet_id_list and right_side_portlet_id_list
# left_side_portlet_id_list is a list of portal_ids on the left side of the portal page
# right_side_portlet_id_list is a list of portal_ids on the right side of the portal page

set i 0
foreach page_name $hiddennames {
    set left_side_portlet_id_list [lindex $left $i]
    set right_side_portlet_id_list [lindex $right $i]

    if { [expr [llength $left_side_portlet_id_list] + [llength $right_side_portlet_id_list]] > 0 } {
	# create a new page, only if there are some portlets on it
	lappend portal_elements_list [list $page_name $left_side_portlet_id_list $right_side_portlet_id_list]
    }
    incr i
}
    
db_transaction {
    # delete old portal configuration
    portals_delete_portal_pages $portal_id

    set page_number 1
    foreach portal_element $portal_elements_list {
	set page_name [lindex $portal_element 0]
	set left_side_portlet_id_list [lindex $portal_element 1]
	set right_side_portlet_id_list [lindex $portal_element 2]

	# create portal page
	set page_id [portals_create_portal_page $portal_id $page_number $page_name]

	# create left side portlets
	set sort_key 1
	foreach portlet_id $left_side_portlet_id_list {
	    portals_move_portlet $portlet_id $page_id l $sort_key
	    incr sort_key
	}
	    
	# create right side portlets
	set sort_key 1
	foreach portlet_id $right_side_portlet_id_list {
	    portals_move_portlet $portlet_id $page_id r $sort_key
	    incr sort_key
	}

	incr page_number
    }
}

if { [portals_get_portal_property type $portal_id]=="default_portal" } {
    set return_url "/admin/portals/domain/manage?[export_url_vars domain_id]"
} else {
    if [portals_get_portal_property control_panel_exists_p $portal_id] {
	set return_url [portals_get_portal_property base_url $portal_id]/control-panel/
    } else {
	set return_url [portals_get_portal_property base_url $portal_id]/
    }
}
ad_returnredirect $return_url








