ad_page_contract {
    Modifies URL Identifier

    @author befekadu@mit.edu
} {
    portal_id:naturalnum
    url_identifier:notnull
} -validate {
    url_identifier_valid_p -requires {url_identifier} {
	if ![portals_valid_url_identifier_p $url_identifier] {
	    ad_complain "URL Identifier can contain only alpha-numeric characters, dot(.), dash(-), and underscore(_)."
 	}
    }
    url_identifier_is_not_too_long -requires {url_identifier} {
	if { [string length $url_identifier] > 100 } {
	    ad_complain "Maximum length of URL identifier is 100 characters"
	}
    }
    url_identifier_is_available_p -requires {url_identifier} {
	set domain_id [portals_get_portal_property domain_id $portal_id]
	set parent_portal_id [db_nullify_empty_string [portals_get_portal_property parent_portal_id $portal_id]]

	set current_url_identifier [portals_get_portal_property url_identifier $portal_id]
	
	if { ([string compare $url_identifier $current_url_identifier]!=0) && ![db_exec_plsql url_identifier_unique_p "
	begin
	:1 := portal.url_identifier_unique_p(v_domain_id => :domain_id, v_parent_portal_id => :parent_portal_id, v_url_identifier => :url_identifier);
	end;
	"] } {
	    ad_complain "The URL you have chosen is already taken. Please choose another URL for this portal."
	}
    }
}

portals_set_portal_property url_identifier $portal_id [ad_urlencode $url_identifier]

if [portals_get_portal_property control_panel_exists_p $portal_id] {
    set return_url [portals_get_portal_property base_url $portal_id]/control-panel/
} else {
    set return_url [portals_get_portal_property base_url $portal_id]/
}
ad_returnredirect $return_url
