# /www/admin/users/approve.tcl

ad_page_contract {

    Process the approval of a new user account

    @cvs-id approve.tcl,v 3.3.2.3.2.6 2000/08/08 00:09:49 kevin Exp
} {
    user_id:integer,notnull
}


set admin_id [ad_verify_and_get_user_id]

db_1row user_info "
select first_names || ' ' || last_name as name, 
       user_state, 
       email_verified_date, 
       email, password 
from   users 
where  user_id = :user_id"

# Update the database based on the user's current state

switch $user_state {    

    need_admin_approv { 
	db_dml set_user_state_authorized "
	update users 
	set    approved_date  = sysdate, 
	       user_state     = 'need_email_verification',
	       approving_user = :admin_id
	where  user_id        = :user_id"
    }

    need_email_verification_and_admin_approv {
	db_dml set_user_state_need_email_verification "
	update users 
	set    approved_date  = sysdate, 
               user_state     = 'need_email_verification',
	       approving_user = :admin_id
	where  user_id        = :user_id"
    }

    rejected {

	if {[ad_parameter RegistrationRequiresEmailVerificationP "" 0] && \
		[empty_string_p $email_verified_date]} {
	    db_dml set_user_state_need_email_verification "
	    update users 
	    set    approved_date  = sysdate, 
                   user_state     = 'need_email_verification',
	           approving_user = :admin_id
	    where  user_id        = :user_id"
	} else {
	    db_dml set_user_state_authorized "
	    update users 
	    set    approved_date  = sysdate, 
	           user_state     = 'need_email_verification',
	           approving_user = :admin_id
	    where  user_id        = :user_id"
	}
    }

    default {
	ad_return_error "Invalid User State" "
	The user account you are attempting to approve is currently in
	an unrecognized state in the database."
	return
    }
}

set row_id [db_string user_new_2_rowid_for_email "select rowid from users where user_id = :user_id"]
# the user has to come back and activate their account

db_release_unused_handles

set notification_address [ad_parameter NewRegistrationEmailAddress "" [ad_system_owner]]

ns_sendmail $email $notification_address "Welcome to [ad_system_name]" "To confirm your registration, please go to [ad_parameter SystemURL]/register/email-confirm?[export_url_vars row_id]"
	    
# Redirect back to the need_admin_approv page so the administrator can
# continue with other users if necessary

doc_return 200 text/html "[ad_admin_header "User Approval"]

<h2>User Approved</h2>

[ad_admin_context_bar {"/admin/register/" "Admin Register"} "User Approved"]

<hr>

<p>$name has been approved.

<p>

[ad_admin_footer]
"















