# /www/shared/community-member.tcl

ad_page_contract {
    shows User A what User B has contributed to the community
    
    March 9, 2000: 
    February 1, 2000: Added check so that if this is an IntranetEnabled acs,
    we only only authorized intranet users to view community members other
    than themselves
    March 1, 1999:  philg edited this to suppress display of links that weren't live
    September 26, 1999:  philg added display of user-uploaded portraits
    November 1, 1999: philg trashed 90% of the code and replaced it with
    a call to ad_summarize_user_contributions

    @param user_id defaults to currently logged in user if there is one

    @cvs-id community-member.tcl,v 3.9.2.4 2000/07/25 09:25:23 kevin Exp
} {
    { user_id:integer "" }
}

if { [empty_string_p $user_id] } {
    set user_id [ad_get_user_id]
    if { $user_id == 0 } {
	# Don't know what to do! 
	ad_return_error "Missing user_id" "We need a user_id to display the community page"
	return
    }
}
set current_user_id [ad_maybe_redirect_for_registration]

if { ![db_0or1row user_information "select first_names, last_name, email, priv_email, 
url, banning_note, registration_date, user_state,
portrait_upload_date, portrait_original_width, portrait_original_height, portrait_client_file_name, bio,
portrait_thumbnail_width, portrait_thumbnail_height
from users, general_portraits gp
where users.user_id=:user_id
and gp.on_which_table(+)='USERS'
and gp.on_what_id(+)=users.user_id"] } {
    ad_return_error "No user found" "There is no community member with the user_id of $user_id"
    ns_log Notice "Could not find user_id $user_id in community-member.tcl from [ns_conn peeraddr]"
    return
}

#if ![empty_string_p $portrait_upload_date] {
    # there is a portrait 
#    if ![empty_string_p $portrait_thumbnail_width] {
	# there is a thumbnail version
#	set inline_portrait_html "<a href=\"portrait?[export_url_vars user_id]\"><img src=\"portrait-thumbnail-bits?[export_url_vars user_id]\" align=right width=$portrait_thumbnail_width height=$portrait_thumbnail_height></a>"
#    } else {
	# no thumbnail; let's see what we can do with the main image
#	if { ![empty_string_p $portrait_original_width] && $portrait_original_width < 300 } {
	    # let's show it inline
#	    set inline_portrait_html "<a href=\"portrait?[export_url_vars user_id]\"><img src=\"portrait-bits?[export_url_vars user_id]\" align=right width=$portrait_original_width height=$portrait_original_height></a>"
#	} else {
#	    set inline_portrait_html "<table width=100%><tr><td align=right>Portrait:  <a href=\"portrait?[export_url_vars user_id]\">$portrait_client_file_name</a></td></tr></table>"
#	}
#    }
#    set inline_portrait_html "
#    <tr>
#    <td align=center>$inline_portrait_html</td>
#    <td>&nbsp;</td>
#    </tr>
#   "
#} else {
#    set inline_portrait_html ""
#}

set page_content ""
if { $user_state == "deleted" } {
    append page_content "<blockquote><font color=red>this user is deleted</font></blockquote>\n"
}
if { $user_state == "banned" } {
    append page_content "<blockquote><font color=red>this user is deleted and
banned from the community for the following reason:
\"$banning_note\"</font></blockquote>\n"
}

# Let's see if we can show all intranet-specific information
set show_intranet_info_p 1
if { [im_enabled_p] && [ad_parameter KeepSharedInfoPrivate intranet 0] } {
    set current_user_id [ad_get_user_id]
    if { $current_user_id != $user_id && ![im_user_is_authorized_p $current_user_id] } {
	set show_intranet_info_p 0
    }
}

set show_intranet_info_p 0

if { $show_intranet_info_p } {
    append page_content [im_user_information $user_id]
} else {
    if { $priv_email <= [ad_privacy_threshold] } {
	append page_content "Email: <A HREF=\"mailto:$email\">$email</a><p>"
    }
    if ![empty_string_p $url] {
	if { ![regexp {http://} $url match] } {
	    set url "http://$url"
	}
	append page_content "Homepage:  <a href=\"$url\">$url</a><p>"
    }
    ## phone information
    if { [db_0or1row phone_select "select home_phone, work_phone, cell_phone
    from users_contact where user_id = :user_id"] } {
	if { ![empty_string_p $home_phone] } {
	    append page_content "Home phone: $home_phone<br>"
	}
	if { ![empty_string_p $work_phone] } {
	    append page_content "Work phone: $work_phone<br>"
	}
	if { ![empty_string_p $cell_phone] } {
	    append page_content "Cell phone: $cell_phone<br>"
	}
	append page_content "<p>"
    }
}

#append page_content "[uni_profile_links -title_tag "h3" $user_id]"

## Group info
# Append a list of all the user's groups
set sql "select ug.group_id, ug.group_name 
from user_groups ug
where ad_group_member_p ( :user_id, ug.group_id ) = 't'
order by lower(group_name)"
set groups "<ul>"
db_foreach groups_user_belong_to $sql {
    append groups "  <li> $group_name\n"
} if_no_rows {
    append groups "<li> None"
}
append groups "</ul>"

## edit links
set return_url "/shared/community-member?user_id=$user_id"

set text_edit_link ""
set edit_profile_link "&nbsp;"
if { $current_user_id == 0 } {
    append page_content "<blockquote>
If you were to <a href=\"/register/index?[export_url_vars return_url]\">log in</a>, you'd be able to get more information on your fellow community member.
</blockquote>
"
} elseif { $current_user_id == $user_id } {
    ## show edit links
    set text_edit_link "
    <a href=\"/pvt/password-update\">update password</a><br>
    <a href=\"/pvt/basic-info-update?[export_url_vars return_url]\">edit profile</a><br>"

#    <a href=\"/pvt/portrait/upload?[export_url_vars return_url]\">upload a picture</a>"

    set edit_profile_link "<a href=\"/pvt/basic-info-update?[export_url_vars return_url]\"><img src=\"/portals/pics/edit.gif\" width=14 height=18 border=0></a>"
}

#set the_moby_summary [ad_summarize_user_contributions $user_id "web_display"]
set the_moby_summary [gc_bboard_summarize_user_contributions $user_id]
if { [empty_string_p $the_moby_summary] } {
    set the_moby_summary "<ul><li>None</ul>"
}

db_release_unused_handles

#edu_header is a hack that looks to see if group_id is not equal to 0.
#Because we want user portal nav not group portal nav we force group_id to 0.
set group_id 0

# don't sign it with the publisher's email address!

ns_return 200 text/html "
[ad_header "$first_names $last_name"]

<h2>$first_names $last_name</h2> 

[ad_context_bar_ws_or_index "Community member"]

<hr>

<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">
 <tr valign=\"top\"> 
  <td colspan=\"2\"> 
   <table border=0 bgcolor=black cellpadding=1 cellspacing=0 width=100%><tr><td>
    <table width=\"100%\" bgcolor=\"#ffffff\" border=\"0\" cellpadding=\"5\" cellspacing=\"0\">
     <tr bgcolor=\"#FFFFCC\"> 
      <td><b><font face=\"Arial, Helvetica, sans-serif\" size=\"-1\">$first_names $last_name</font></b></td>
      <td><div align=right>$edit_profile_link</div></td>
     </tr>
     <tr bgcolor=\"#FFFFFF\">
      <td colspan=\"2\">
       $page_content
       $text_edit_link
      </td>
     </tr>
    </table>
   </td></tr></table>
   <img src=\"/portals/pics/spacer.gif\" width=\"1\" height=\"1\">

   <table border=0 bgcolor=black cellpadding=1 cellspacing=0 width=100%><tr><td>
    <table width=\"100%\" bgcolor=\"#ffffff\" border=\"0\" cellpadding=\"5\" cellspacing=\"0\">
     <tr bgcolor=\"#FFFFCC\"> 
      <td ><b><font face=\"Arial, Helvetica, sans-serif\" size=\"-1\">Contributions</font></b></td>
     </tr>
     <tr bgcolor=\"#FFFFFF\"> 
      <td>
       $the_moby_summary
      </td>
     </tr>
    </table>
   </td></tr></table>
  </td>
 </tr>
</table>
[ad_footer]
"



#    </table>
#   </td></tr></table>

#  </td>
#  <td valign=\"top\"> 
#   <table border=0 bgcolor=black cellpadding=1 cellspacing=0 width=100%><tr><td>
#    <table width=\"100%\" bgcolor=\"#ffffff\" border=\"0\" cellpadding=\"5\" cellspacing=\"0\">
#     <tr bgcolor=\"#FFFFCC\"> 
#      <td ><b><font face=\"Arial, Helvetica, sans-serif\" size=\"-1\">Groups to which this user belongs</font></b></td>
#     </tr>
#     <tr bgcolor=\"#FFFFFF\"> 
#      <td>
#       $groups
#      </td>
#     </tr>
#    </table>
#   </td></tr></table>
#  </td>
# </tr>
#</table>

#[ad_footer]
#"
