ad_page_contract {
    Enters a new user into the database.
    @cvs-id  user-new-2.tcl,v 3.10.2.10 2000/09/22 01:39:15 kevin Exp
} {
    {email:notnull}    
    {password:optional}
    {password_confirmation:optional}
    {first_names:notnull}
    {last_name:notnull}
    {url}
    {user_id:integer,notnull}
    {return_url [ad_pvt_home]}
} -errors {
    password:notnull {You must enter a password.}
    password_confirmation:notnull {You must enter your password twice.}
    first_names:notnull {You must enter a first name}
    last_name:notnull {You must enter a last name}
    email:notnull {You must enter an email address}
}   

ad_handle_spammers

set return_url [ad_get_client_property -default [ad_pvt_home] register return_url]

# Check if the email address makes sense
# We check it here, because this is the last chance the user has to change it
if { ![philg_email_valid_p $email] } {
    ad_return_complaint 1 "<li>The email address that you typed doesn't look right to us.  Examples of valid email addresses are
<ul>
<li>Alice1234@aol.com
<li>joe_smith@hp.com
<li>pierre@inria.fr
</ul>"
    return
}

set exception_count 0
set exception_text ""

if {[info exists first_names] && [string first "<" $first_names] != -1} {
    incr exception_count
    append exception_text "<li> You can't have a &lt; in your first name because it will look like an HTML tag and confuse other users."
}

if {[info exists last_name] && [string first "<" $last_name] != -1} {
    incr exception_count
    append exception_text "<li> You can't have a &lt; in your last name because it will look like an HTML tag and confuse other users."
}

if { [info exists url] && [string match $url "http://"] ==  1 } {
    # the user left the default hint for the url
    set url ""
}

if {[info exists url] && ![empty_string_p $url] && ![philg_url_valid_p $url] } {
    # there is a URL but it doesn't match our REGEXP
    incr exception_count
    append exception_text "<li>You URL doesn't have the correct form.  A valid URL would be something like \"http://photo.net/philg/\"."
}

if ![ad_parameter RegistrationProvidesRandomPasswordP "" 0]  {
    if { ![string equal $password $password_confirmation] } {
	append exception_text "<li>You must type the password the same way twice."
	incr exception_count
    }
}


# We've checked everything.
# If we have an error, return error page, otherwise, do the insert

if {$exception_count > 0} {
    ad_return_complaint $exception_count $exception_text
    return
}


regexp {(.*)@(.*)} [string tolower $email] match username server_name

set authorized_server_p [db_0or1row authorized_server_p "
select 1
from email_servers
where lower(server_name)=lower('@$server_name')"]

if {!$authorized_server_p } {
    set user_state "need_admin_approv"
} elseif {$authorized_server_p } {
    set user_state "need_email_verification"
}
# Autogenerate a password

if  {[ad_parameter RegistrationProvidesRandomPasswordP "" 0]} {
    set password [ad_generate_random_string]
}

# If we are encrypting passwords in the database, convert

if  [ad_parameter EncryptPasswordsInDBP "" 0] { 
    set password_for_database [ns_crypt $password [ad_crypt_salt]]
} else {
    set password_for_database $password
}

set peeraddr [ns_conn peeraddr]

set insert_statement  "
insert into users 
(user_id,
 email,
 password,
 first_names,
 last_name,
 url,
 registration_date,
 registration_ip, 
 user_state, 
 last_visit) 
values 
(:user_id,
 :email,
 :password_for_database,
 :first_names,
 :last_name,
 :url, 
  sysdate, 
 :peeraddr, 
 :user_state, 
  sysdate)"

# let's look for other required tables

set insert_statements_sup ""

# need $user_id below because we want to pull that literal value out of dual.

set other_tables [ad_parameter_all_values_as_list RequiredUserTable]
foreach table_name $other_tables {
    # Where not exists clause to avoid duplicate entry caused by 
    # triggers inserting into user_preferences.  Ticket #23595

    lappend insert_statements_sup "
    insert into $table_name (user_id) 
    select :user_id 
    from   dual 
    where  not exists (select user_id from $table_name where user_id = :user_id)"
}

set double_click_p 0
set failed_transaction_p 0

db_transaction {
    db_dml user_new_2_user_insert $insert_statement 
    foreach statement $insert_statements_sup {
	db_dml user_new_user_insert_supplement_tables $statement
    }
} on_error {
    if { [db_string user_new_2_user_count {
	select count(user_id) 
	from   users 
	where  user_id = :user_id
    }] == 0 } {
	ad_return_error "Insert Failed" "We were unable to create your user record in the database."
	# slightly nicer than return.
	ad_script_abort 
    } else {
	# assume this was a double click
	set double_click_p 1
    }
}

if { $authorized_server_p }  { 
    # the user won't be able to use the system until he has answered his email
    # so don't give an auth cookie, but instead tell him 
    # to read your email
    
    doc_return  200 text/html "
    [ad_header "Please read your email"]
    
    <h2>Please read your email</h2>
    
    <hr>
    
    Registration information for this service has been
    sent to $email.
    <p>
	Please read and follow the instructions in this email.
    
    [ad_footer]
    "
    
} elseif { !$authorized_server_p } {
    
    # this user won't be able to use the system until an admin has
    # approved him, so don't give an auth cookie, but instead tell him 
    # to wait
    
    doc_return  200 text/html "
    [ad_header "Awaiting Approval"]
    
    <h2>Awaiting Approval</h2>
    
    <hr>
    
    Your registration is in the database now.  A site administrator has
    been notified of your request to use the system.  Once you're
    approved, you'll get an email message and you can return to
    [ad_site_home_link] to use the service.
    
    [ad_footer]
    "
}

if !$double_click_p {
    set notification_address [ad_parameter NewRegistrationEmailAddress "" [ad_system_owner]]
    
    if {[ad_parameter NotifyAdminOfNewRegistrationsP]} {
	# we're supposed to notify the administrator when someone new registers
	
	set user_state [db_1row user_state {select user_state from users where user_id = :user_id}]
	ns_sendmail $notification_address $email "New self registration at [ad_url]" "
	$first_names $last_name ($email) registered as a user of 
	[ad_url]. The current user_state is $user_state.
	"
    }
    
    if { [ad_parameter RegistrationRequiresEmailVerificationP "" 0] } {
	if { $authorized_server_p } {
	    set row_id [db_string user_new_2_rowid_for_email "select rowid from users where user_id = :user_id"]
	    # the user has to come back and activate their account
	    
	    ns_sendmail $email $notification_address "Welcome to [ad_system_name]" "
	    Welcome to [ad_system_name]
	    
	    To confirm your registration, please go to [ad_parameter SystemURL]/register/email-confirm?[export_url_vars row_id]"
	    
	} else {
	    set http_or_https [ad_decode [ad_ssl_available_p] 1 "https://[ns_config ns/server/[ns_info server]/module/nsssl Hostname]" "http://[ns_config ns/server/[ns_info server]/module/nssock Hostname]"]
	    ns_sendmail $notification_address $email "User Approval Request" "The following user has asked for approval:
	    
	    $first_names $last_name, $email

    
	    Click <a href=\"$http_or_https/admin/register/approve?[export_url_vars user_id]\">here</a> in order to approve this user or click <a href=\"$http_or_https/admin/register/reject?[export_url_vars user_id]\">here in order to reject this user.
	    
	    Click <a href=\"$http_or_https/admin/register/view?user_state=need%5fadmin%5fapprov\">here</a> to see a list of the users who are still pending approval."
	}
    } elseif { [ad_parameter RegistrationProvidesRandomPasswordP "" 0] || [ad_parameter EmailRegistrationConfirmationToUserP "" 0] } {
	with_catch errmsg {
	    ns_sendmail $email $notification_address "Thank you for visiting [ad_system_name]" "Here's how you can log in at [ad_url]:
	    
	    Username:  $email
	    Password:  $password
	    "
	} {
	    ns_returnerror "error" "$error"
	    ns_log Warning "Error sending registration confirmation to $email in user-new-2.tcl"
	}
    }
}



















