-- /www/doc/sql/survey-simple.sql
--
-- based on student work from 6.916 in Fall 1999
-- which was in turn based on problem set 4
-- in http://photo.net/teaching/one-term-web.html
--
-- by philg@mit.edu and raj@alum.mit.edu on February 9, 2000
-- 
-- survey-simple.sql,v 1.14 2000/06/17 18:49:35 ron Exp 

-- we expect this to be replaced with a more powerful survey
-- module, to be developed by buddy@ucla.edu, so we prefix
-- all of our Oracle structures with "survsimp"

-- revised by beep, 8/23/00
-- for importing new features found in infirmation
-- this version is for direct install
-- survey-simple-rich-upgrade.sql is for the upgrade version

-- revised by dparker@arsdigita.com 12/04/00 for Sloan
-- This adds group scoping so it can be used with education stuff


create sequence survsimp_survey_id_sequence start with 1;

create table survsimp_surveys (
	survey_id		integer
				  constraint ss_survey_id_pk primary key,
	name			varchar(100) not null,
	-- short, non-editable name we can identify this survey by
	-- I am removing this because it is not used and is adding 
	-- complexity to the user experience
	--	short_name		varchar(20) unique not null,
	description		varchar(4000) not null,
        description_html_p      char(1) default 'f'
                                  constraint survsimp_sur_desc_html_p_ck check(description_html_p in ('t','f')),
	creation_user		not null 
				  constraint ss_creation_user_fk references users(user_id),
	creation_date	      	date default sysdate,
	enabled_p               char(1) default 'f' 
				  constraint ss_enabled_p_ck check(enabled_p in ('t','f')),
	--    define 4 basic layout styles:
	--       ol - every question is a list item in an ol tag
	--    table - every question is a row in a table
	--        p - every question is seperated by a <p> tag
	--     none - no formating around questions - each question is appended to
	--            the survey with no seperating tags.  The questions themselves
	--            have to include tags such as <p>, <li>, ...
	layout_type		varchar(25) default 'ol' not null
				  constraint ss_layout_type_ck 
	 			  check(layout_type in ('ol', 'table', 'p', 'none')),
	-- limit to one response per user
	single_response_p	char(1) default 'f' 
				  constraint ss_single_response_p_ck check(single_response_p in ('t','f')),
	response_editable_p	char(1) default 't' 
				  constraint ss_response_editable_p_ck check(response_editable_p in ('t','f')),
	-- if scope=all_users, this is the news for all newsgroups
        -- is scope=registered_users, this is the news for all registered users
	-- if scope=public, this is the news for the main newsgroup
	-- if scope=group, this is news associated with a group
        scope           varchar(20) not null,
	group_id	references user_groups,
	check ((scope='group' and group_id is not null) or
	(scope='public') or
	(scope='all_users') or
	(scope='registered_users')),
	constraint simpsurv_scope_name_un unique(group_id, name)
);

create sequence survsimp_question_id_sequence start with 1;
-- each question can be 

create table survsimp_questions (
	question_id		integer 
				  constraint sq_question_id_pk primary key,
	survey_id		not null 
				  constraint sq_survey_id_fk references survsimp_surveys,
	sort_key		integer not null,
	question_text		clob not null,
	-- can be 'text', 'shorttext', 'boolean', 'number', 'choice'
        abstract_data_type      varchar(30) not null,
	required_p		char(1) 
				  constraint sq_required_p_ck check (required_p in ('t','f')),
	active_p		char(1) 
				  constraint sq_active_p_ck check (active_p in ('t','f')),
	presentation_type	varchar(20) not null
				  constraint sq_presentation_type_ck
				  check(presentation_type in ('textbox','textarea','select','radio', 'checkbox', 'date', 'upload_file', 'none')),
	-- type of summary
	summary_type 		varchar(20)
				  constraint sq_summary_type_ck check(summary_type in ('sum','avg','concat')),
	-- for text, "small", "medium", "large" sizes
	-- for textarea, "rows=X cols=X"
	presentation_options	varchar(50),
	presentation_alignment	varchar(15) default 'below'
				constraint sq_presentation_alignment_ck
            			  check(presentation_alignment in ('below','beside')),       
	creation_user		references users not null,
	creation_date		date default sysdate
);


-- Categoization sucks because it jsut makes the user interface clunky.
-- I have removed it from this code.
-- dparker@arsdigita.com

-- Categorization:  We'd like each question to belong
-- to a category.  For example, if we write a survey
-- about a client project, we want to categorize questions
-- as "client" or "internal". Other surveys might want
-- to group questions according to category.
-- To categorize questions, we use the site wide
-- category system.

-- Categories will be stored in categories table
-- with category_type as "survsimp"

-- The site_wide_category_map table will map
-- categories to individual surveys.  The site_wide_category_map
-- will also map categories to individual questions.

-- We want to be able to categorize surveys.  We'll use site_wide_category_map
-- with category_type='survsimp_survey'


-- for when a question has a fixed set of responses

create sequence survsimp_choice_id_sequence start with 1;

create table survsimp_question_choices (
	choice_id		integer not null 
			  	  constraint sqc_choice_id_pk primary key,
	question_id		not null 
				  constraint sqc_question_id_fk references survsimp_questions,
	-- human readable 
	label			varchar(500),
	-- might be useful for averaging or whatever, generally null
	numeric_value		number,
	-- for choices where there is a range from say 1 - 10
	-- and have 1 and 10 labeld but the rest in the middle are not labled
				  constraint sqc_not_null_ck check (label is not null or numeric_value is not null),
	presentation_alignment	varchar(15) default 'right'
          			  constraint sqc_pres_type_ck check(presentation_alignment in ('right','left')),
	more_info_type 		varchar(30)
				  constraint sqc_more_info_type_ck check(more_info_type in ('','varchar','number')),
	-- lower is earlier 
	sort_order		integer
);





create sequence survsimp_response_id_sequence start with 1;

-- this records a response by one user to one survey
-- (could also be a proposal in which case we'll do funny 
--  things like let the user give it a title, send him or her
--  email if someone comments on it, etc.)
create table survsimp_responses (
	response_id		integer 
				  constraint sr_response_id_pk primary key,
	survey_id		not null 
				  constraint sr_survey_id_fk references survsimp_surveys,
	-- scope is user, public or group
	scope           	varchar(20),
	user_id			constraint sr_user_id_fk references users,
	group_id		constraint sr_group_id_fk references user_groups,
	  constraint survsimp_responses_scopecheck check 
		((scope='group' and group_id is not null) 
                 or (scope='public' and group_id is null)
		or (scope='user' and group_id is null)),
	title			varchar(100),
	submission_date		date default sysdate not null,
	ip_address		varchar(50),
	-- do we sent email if 
	notify_on_comment_p	char(1) default 'f'
				  constraint sr_notify_on_comment_p_ck check(notify_on_comment_p in ('t','f')),
	-- proposal can be public, private, or deleted
	proposal_state		varchar(30) default 'private'
				  constraint sr_proposal_state 
				  check(proposal_state in ('public','private', 'deleted'))
	-- This did not work for how we tried to use it
	-- (we wanted users to take the survey each week).
	-- If the survey should be unique to a user, this
	-- should be handled by an ini parameter
	-- unique (survey_id, user_id)
);

create index survsimp_response_ui_idx on survsimp_responses (user_id);


-- mbryzek: 3/27/2000
-- Sometimes you release a survey, and then later decide that 
-- you only want to include one response per user. The following
-- view includes only the latest response from all users
create or replace view survsimp_responses_unique as 
select r1.* from survsimp_responses r1
where r1.response_id=(select max(r2.response_id) 
                        from survsimp_responses r2
                       where r1.survey_id=r2.survey_id
                         and r1.user_id=r2.user_id);


-- this table stores the answers to each question for a survey
-- we want to be able to hold different data types in one long skinny table 
-- but we also may want to do averages, etc., so we can't just use CLOBs

create table survsimp_question_responses (
	response_id		not null 
				  constraint sqr_response_id_fk references survsimp_responses,
	question_id		not null 
				  constraint sqr_question_id_fk references survsimp_questions,
	-- if the user picked a canned response
	choice_id		constraint sqr_choice_id_fk references survsimp_question_choices,
	boolean_answer		char(1) 
				  constraint sqr_boolean_answer_ck check(boolean_answer in ('t','f')),
	clob_answer		clob,
	number_answer		number,
	varchar_answer		varchar(4000),
	date_answer		date,
	-- columns useful for attachments, column names
	-- lifted from file-storage.sql and bboard.sql
	-- this is where the actual content is stored
	attachment_answer	blob,
	-- file name including extension but not path
	attachment_file_name	varchar(500),
	attachment_file_type	varchar(100),	-- this is a MIME type (e.g., image/jpeg)
	attachment_file_extension varchar(50) 	-- e.g., "jpg"
);


create index survsimp_response_index on survsimp_question_responses (response_id, question_id);


-- We create a view that selects out only the last response from each
-- user to give us at most 1 response from all users.
create or replace view survsimp_question_responses_un as 
select qr.* 
  from survsimp_question_responses qr, survsimp_responses_unique r
 where qr.response_id=r.response_id;


begin
   administration_group_add ('Simple Survey System Staff', short_name_from_group_name('survsimp'), 'survsimp', NULL, 'f', '/survsimp/admin/');
end;
/












