# /www/survsimp/one.tcl
ad_page_contract {

    Display a questionnaire for one survey.

    @param  survey_id   id of displayed survey
    @param  return_url  optional URL user will be redirected to after completing the survey
    @param  group_id    parameter passed to following page
    @param  template    if supplied, used as a page-building template

    @author philg@mit.edu
    @date   February 9, 2000
    @cvs-id one.tcl,v 1.14.2.5 2000/07/23 16:53:33 seb Exp
} {
    {edit_previous_response_p "f"}
    response_id:optional
    survey_id:integer,notnull
    {return_url ""}
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer 

}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope all group_member none 

if { ![db_0or1row survey_params "select name, description, enabled_p, single_response_p, response_editable_p from survsimp_surveys where survey_id = :survey_id and [ad_scope_sql]" ] } {
    ad_return_error "Not Found" "You are not allowed to view this item"
    return
}

if {$enabled_p == "f"} {
    ad_return_error "Not Allowed" "this survey has been turned of by survey administrator"
    return
}


set num_responses [db_string responses_count "
select count(response_id)
  from survsimp_responses
  where user_id = :user_id
  and survey_id = :survey_id "]

db_release_unused_handles

if {$num_responses != 0} {
    set previous_responses_link "<a href=old-responses.tcl?[export_url_scope_vars]&survey_id=$survey_id>View previous responses"
} else {
    set previous_responses_link ""
}

if {$edit_previous_response_p == "f"} {
    if {$single_response_p == "t" && $num_responses != 0} {
	ad_return_error "Unacceptable" "You are not allowed to respond to this survery more than once."
	return
    }
    set submit_button "<input type=submit value=\"Submit Answers\">"
} else {
    if {$response_editable_p == "f"} {
	ad_return_error "Unacceptable" "You are not allowed to modify this answer."
	return
    }
    set submit_button "<input type=submit value=\"Modify Answers\">"
}


if {![exists_and_not_null response_id]} {           
    set response_id [db_string survsimp_sequence_next "select survsimp_response_id_sequence.nextval from dual"]
}

set page_content "
[ad_scope_header "$name"]
[ad_scope_page_title "$name"]
[ad_scope_context_bar [list "index.tcl?[export_url_scope_vars]" "Simple Survey"] "Take Survey"]

<hr>
<blockquote>
$description

<form enctype=multipart/form-data method=POST action=\"process-response\">
[export_form_scope_vars]
[export_form_vars survey_id return_url response_id edit_previous_response_p]
[survsimp_survey_display $survey_id $edit_previous_response_p $response_id]
<p>
<br>
<center>
$submit_button
</center>
</form>

</blockquote>


$previous_responses_link


<p>

[ad_scope_footer]
"
doc_return 200 text/html $page_content 












