# /www/survsimp/admin/question-add-3.tcl
ad_page_contract {
    Inserts a new question into the database.

    @param survey_id               integer denoting which survey we're adding question to
    @param question_id             id of new question
    @param after                   optional integer determining position of this question
    @param question_text           text of question
    @param abstract_data_type      string describing datatype we expect as answer
    @param presentation_type       string describing widget for providing answer
    @param presentation_alignment  string determining placement of answer widget relative to question text
    @param valid_responses         string containing possible choices, one per line
    @param textbox_size            width of textbox answer widget
    @param textarea_cols           number of columns for textarea answer widget
    @param textarea_rows           number of rows for textarea answer widget
    @param required_p              flag telling us whether an answer to this question is mandatory
    @param active_p                flag telling us whether this question will show up at all
    @param category_id             optional integer determining category of thsi question within survey

    @author Jin Choi (jsc@arsdigita.com) February 9, 2000
    @cvs-id question-add-3.tcl,v 1.8.2.5 2000/07/23 16:53:34 seb Exp
} {
    survey_id:integer,notnull
    question_id:integer,notnull
    after:integer,optional
    question_text:html
    abstract_data_type
    presentation_type
    {presentation_alignment "below"}
    valid_response_1:optional
    valid_response_2:optional
    {valid_responses ""}
    {textbox_size ""} 
    {textarea_cols:naturalnum ""} 
    {textarea_rows:naturalnum ""}
    {required_p t}
    {active_p t}
    {category_id:integer ""}
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none        

set count_responses [db_string count_responces_there "
select count(*) from survsimp_question_responses 
where question_id = :question_id"]

set count 0

# added by dparker@arsdigita.com
if {[info exist valid_response_1] && [info exist valid_response_2]} {
    set valid_responses "$valid_response_1 \n $valid_response_2"
}

set exception_count 0
set exception_text ""

if { [empty_string_p $question_text] } {
    incr exception_count
    append exception_text "<li>You did not enter a question."
}

if { $abstract_data_type == "choice" && [empty_string_p $valid_responses] } {
    incr exception_count
    append exception_text "<li>You did not enter a list of valid responses/choices."
}

if { $exception_count > 0 } {
    ad_return_complaint $exception_count $exception_text
    return
}



# Generate presentation_options.
set presentation_options ""
if { $presentation_type == "textarea" } {
    if { [exists_and_not_null textarea_rows] } {
	append presentation_options " rows=$textarea_rows"
    }
    if { [exists_and_not_null textarea_cols] } {
	append presentation_options " cols=$textarea_cols"
    }
} elseif { $presentation_type == "textbox" } {
    if { [exists_and_not_null textbox_size] } {
	# Will be "small", "medium", or "large".
	set presentation_options $textbox_size
    }
}

set update_survsimp_question_sql "update survsimp_questions set 
question_text=:question_text, abstract_data_type=:abstract_data_type, presentation_type=:presentation_type,
presentation_options=:presentation_options, required_p = :required_p
where question_id=:question_id"

# For questions where the user is selecting a canned response, insert
# the canned responses into survsimp_question_choices by parsing the valid_responses
# field.

if { $presentation_type == "checkbox" || $presentation_type == "radio" || $presentation_type == "select" } {
    if { $abstract_data_type == "choice" } {
	set responses [split $valid_responses "\n"]
	set count 0
	set response_list []
	foreach response $responses {
	    set trimmed_response [string trim $response]
	    if { [empty_string_p $trimmed_response] } {
		# skip empty lines
		continue
	    }
	    lappend response_list [list "$trimmed_response" "$count"]
	    incr count
	    
	}
    }
}
 


db_transaction {
    db_dml update_survsimp_question $update_survsimp_question_sql
    if {$count != 0} {
	set choice_id_to_update_list [db_list get_choice_id "
	select choice_id from survsimp_question_choices
	where question_id=:question_id
	order by sort_order"]
	set choice_count 0
	foreach one_response $response_list {
	    set choice_name [lindex $one_response 0]
	    set choice_value [lindex $one_response 1]
	    set choice_id_to_update [lindex $choice_id_to_update_list $choice_count]
	    if {[empty_string_p $choice_id_to_update]} {
		set insert_survsimp_question_choice_sql "insert into survsimp_question_choices 
		(choice_id, question_id, label, sort_order)
		values (survsimp_choice_id_sequence.nextval, :question_id, :choice_name, :choice_value)"	    
		db_dml insert_new_choice $insert_survsimp_question_choice_sql
	    } else {
		set update_survsimp_question_choice_sql "update survsimp_question_choices 
		set label=:choice_name where choice_id=:choice_id_to_update"
		db_dml update_new_choice $update_survsimp_question_choice_sql
	    }
	    incr choice_count
	}
	while {[llength $choice_id_to_update_list] >= $choice_count} {
	    set choice_id_to_delete [lindex $choice_id_to_update_list $choice_count]
	    set delete_sql "delete from survsimp_question_choices where choice_id = :choice_id_to_delete" 
	    db_dml delete_old_choice $delete_sql
	    incr choice_count
	}
    }
}
db_release_unused_handles
ad_returnredirect "one?survey_id=$survey_id&[export_url_scope_vars]"







