# /www/survsimp-scoped/admin/one-question.tcl
ad_page_contract {
    
    This page allows the administer a single survey.
    
    @param  survey_id integer denoting survey we're administering
    
    @author dparker@arsdigita.com
    @date   Dec 6, 2000
    @cvs-id one.tcl,v 1.14.2.5 2000/07/21 04:04:11 ron Exp
} {
    survey_id:integer,notnull
    question_id:integer,notnull
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none


set survey_info [db_list_of_lists get_survey_info "select group_id, creation_user from survsimp_surveys where survey_id=$survey_id"]

set survey_owner [lindex [lindex $survey_info 0] 0]
set surv_group_id [lindex [lindex $survey_info 0] 1]

if { ![ad_user_group_authorized_admin_or_site_admin $user_id $surv_group_id] && $survey_owner != $user_id } {
    ad_return_complaint 1 "You do not have permission to view this survey.  You were probably editing the URL, if not contact the administrator."
}

db_1row survsimp_question_properties "
select
  layout_type,
  enabled_p,
  sq.survey_id,
  sort_key,
  question_text,
  abstract_data_type,
  required_p,
  active_p,
  presentation_type,
  presentation_options,
  presentation_alignment,
  sq.creation_user,
  sq.creation_date
from
  survsimp_questions sq, survsimp_surveys ss
where
  sq.survey_id = ss.survey_id
  and sq.question_id = :question_id"

db_release_unused_handles

set page_content "
[ad_scope_admin_header "View/Edit one question"]
[ad_scope_admin_page_title "View/Edit one Question"]
[ad_scope_admin_context_bar [list "index?[export_url_scope_vars]" "Simple Survey Admin"] [list "one?[export_url_vars survey_id]&[export_url_scope_vars]" "Administer Survey"] "One question"]
<hr>
"



append page_content "
<blockquote>

<table width=100%>
<tr>
<td>
<h3>
This is how your question would look in the survey.
</h3>
<P>
<form>
[survsimp_question_display -layout_type $layout_type -single_question t  $question_id]
</form>
</td>
"


set count_responses [db_string count_responces_there "
select count(*) from survsimp_question_responses 
where question_id = :question_id"]

append page_content "    
<td>
<a href=one.tcl?survey_id=$survey_id&[export_url_scope_vars]> Return to the previous page </a> 
"
if {$count_responses != 0} {
    append page_content "<P> <a href=view-responses.tcl?survey_id=$survey_id&[export_url_scope_vars]> View response </a>"
}
append page_content "
<P> <a href=question-delete.tcl?question_id=$question_id&[export_url_scope_vars]> Delete this question </a>
</td>
</tr>
</table>
</blockquote>
"





db_1row survsimp_survey_properties "
select name, description
from survsimp_surveys
where survey_id = :survey_id"

db_release_unused_handles


# Display presentation options for sizing text input fields and textareas.

set extra_html ""

switch -- $abstract_data_type {
    "choice" {
	set pretty_data_type "Multiple Choice"
	db_foreach survsimp_question_choices "select label
	from survsimp_question_choices
	where question_id = :question_id
	order by sort_order" {
	    append options_html "$label \n"
	}
	set presentation_html "
	<tr> <th> Presentation Type </th> 
	<td> <br> <select name=presentation_type> 
	     <option value=select [ad_decode $presentation_type "select" "selected" ""]>Selection</option>
	     <option value=checkbox [ad_decode $presentation_type "checkbox" "selected" ""]>Checkbox</option>
	     <option value=radio [ad_decode $presentation_type "radio" "selected" ""]>Radio Buttons</option>
	     </select> <br><br>
	
	<tr> <th> Enter <b>choices</b><br> (one per line):
        <td> <textarea name=valid_responses rows=8 cols=35>$options_html</textarea> </td></tr>"

		
    }
    "shorttext" {
	set pretty_data_type "One line answer"	
	
	set presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	<tr> <th> Text box size </th>
	<td> <br><select name=textbox_size>
	     <option value=small [ad_decode $presentation_options "small" "selected" ""]>Small</option>
	     <option value=medium [ad_decode $presentation_options "medium" "selected" ""]>Medium</option>
	     <option value=large [ad_decode $presentation_options "large" "selected" ""]>Large</option>
	     </select><br><br>
</td></tr>
	"
	set extra_html "
	Size Examples<P>

	<input type=text size=10 value=\"Small\"><p>
	<input type=text size=40 value=\"Medium\"><p>
	<input type=text size=70 value=\"Large\">
	"
	

    }
    "text" {
	set pretty_data_type "Essay answer"
	regexp {rows=([0-9]*) cols=([0-9]*)} $presentation_options match n_row n_col
	    
	set presentation_html "
	<input type=hidden name=presentation_type value=textarea>
	<tr> <th> Text area size </th>
	<td> <br>
	Columns: <input name=textarea_cols size=5 value=$n_col> <br> <br>
	&nbsp &nbsp &nbsp
	Rows: <input name=textarea_rows size=5 value=$n_row> <br> <br>
	</td>
	</tr>"

    }
    "boolean" {
	
	set pretty_data_type "True / False"
    
	set presentation_html "
	<tr> <th> Presentation Type </th> 
	<td> <br> <select name=presentation_type> 
	     <option value=radio [ad_decode $presentation_type "radio" "selected" ""]>Radio Buttons</option>
	     <option value=select [ad_decode $presentation_type "select" "selected" ""]>Selection</option>
	     <option value=checkbox [ad_decode $presentation_type "checkbox" "selected" ""]>Checkbox</option>
	     </select> <br><br>
	</td></tr>"

    }
    "number" {
	set pretty_data_type "Number"
	
	set presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	<tr> <th> Restrictions </th>: 
	<td> <br>
	     <input type=radio name=number_type value=\"any\"> Any Number <br>
	     <input type=radio name=number_type value=\"integer\" checked> Integer 
	     <br> <br></td></tr>"
	
    }
    "blob" {
	set pretty_data_type "File Attachment"
	
	set presentation_html ""
	
	set extra_html "
	The user will be offered a text box to upload their file
	"
    }
    default {
	ad_return_complaint 1 "You must select a type of question to ask"
	return
    }
}


set display_header_html "
</center>
<br>
<br>
<h3>  Edit this Question </h3>
<center>
<blockquote>
<table border=0 width=80%>     

<tr> <td colspan=2 align=center> 
<P align=left>Question - Response type <b>$pretty_data_type </b>
<tr> <th> Enter Question : </th>
<td><textarea name=question_text rows=5 cols=70>$question_text</textarea>
</blockquote>
"

set display_footer_html "
<tr> <td align=center colspan=2><br> <input type=submit value=\"Edit Question\"> </td> </tr> 
</table>
</blockquote>
"

set required_p_html 	"<tr> <th> Is the question required </th> 
        <td> <select name=required_p>
	     <option value=t [ad_decode $required_p "t" "selected" ""] > Required </option>
	     <option value=f [ad_decode $required_p "f" "selected" ""]> Optional </option>
</select></td></tr>"


append page_content "
<blockquote>

<form action=\"one-question-edit\" method=post>
[export_form_scope_vars]
[export_form_vars survey_id question_id abstract_data_type after active_p category_id]
<center>

$display_header_html

$presentation_html

$required_p_html

$display_footer_html

</center>

</form>
<P>

$extra_html

</blockquote>

[ad_scope_admin_footer]
"


doc_return 200 text/html $page_content



