# /www/survsimp-scoped/admin/one.tcl
ad_page_contract {

    This page allows the administer a single survey.

    @param  survey_id integer denoting survey we're administering

    @author dparker@arsdigita.com
    @date   Dec 6, 2000
    @cvs-id one.tcl,v 1.14.2.5 2000/07/21 04:04:11 ron Exp
} {

    survey_id:integer
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none        


# Get the survey information.
db_0or1row survsimp_properties "
select name as survey_name, 
description as survey_description, 
first_names || ' ' || last_name as creator_name, creation_user, 
creation_date, enabled_p, single_response_p, response_editable_p
from survsimp_surveys, users
where survey_id = :survey_id
and creation_user = user_id
"

# check to validate the sql-statement

if {![info exists survey_name]} {
    set see_if_there [db_string count_suvery "select count(*) from survsimp_surveys where survey_id=:survey_id"]
    if {$see_if_there} {
	ad_return_complaint 1 "You do not have permission to view this survey.  You were probably editing the URL, if not contact the administrator."
    } else {
	ad_return_complaint 1 "That survey does not exist"
    }
}




set supported_categories [db_list survsimp_categoires "select category
from site_wide_category_map, categories
where site_wide_category_map.category_id = categories.category_id
and on_which_table = 'survsimp_surveys'
and on_what_id = :survey_id" ] 



if {$enabled_p == "t"} {
    set status_html "Status: this survey is live"
} else {
    set status_html "Status: this survey is <font color=red> disabled </font> until you make it live"
}

if {$response_editable_p == "f"} {
    set edit_response_html "User may NOT edit their previous responces"
} else {
    set edit_response_html "User may edit their previous responces "

}

if {$single_response_p == "t"} {
    set n_response_html "One response per user"
} else {
    set n_response_html "Multiple responses per user"
}


# count the number of responses
set count_responses [db_string check_double_click "select count(*) from survsimp_responses where survey_id=:survey_id"]


set page_content "
[ad_scope_admin_header "Administer Survey"]
[ad_scope_admin_page_title "$survey_name"]
[ad_scope_admin_context_bar [list "index?[export_url_scope_vars]" "Survey Admin"] "Administer Survey"]

<hr>

<blockquote>
<table width=80% border=0 cellspacing=0>
<tr bgcolor=e4e4e4>
  <td colspan=2 align=center> Settings for survey \"$survey_name\" </td> 
</tr>
<tr bgcolor=f2f2f2> 
  <td> $status_html </td>
  <td> Created by: <a href=\"/shared/community-member?user_id=$creation_user\">$creator_name</a> </td> 
</tr> 
<tr bgcolor=e4e4e4>
  <td> $n_response_html </td>
  <td> Created: [util_AnsiDatetoPrettyDate $creation_date] </td>
</tr>
<tr bgcolor=f2f2f2>
  <td> $edit_response_html </td>
  <td> There have been $count_responses responses</td>
</tr>
<tr>
  <td colspan=2> <table width=100% border=0 cellspacing=0> <tr bgcolor=ebebbb>
  <td align=center> <a href=\"view-survey.tcl?[export_url_vars survey_id]&[export_url_scope_vars]\"> View Survey </a> </td>
  <td align=center> <a href=\"survey-edit?[export_url_vars survey_id]&[export_url_scope_vars]\">
      Change survey settings</a> </td>
  <td align=center> <a href=\"view-responses.tcl?[export_url_vars survey_id]&[export_url_scope_vars]\"> Responses </a></td>
   </tr> </table> </td>
</tr>
</table>
<br>
<br>
"






# the add a question link

if {$enabled_p == "f"} {
    set text_blurb "If you are done creating and editing this survey : <br><a href=survey-activate.tcl?survey_id=$survey_id&[export_url_scope_vars]> make it go live</a>"
} else {
    set text_blurb "This survey is live.  Be careful when editing it."
}


append page_content "
<table width=80% border=0 cellspacing=0>
<tr bgcolor=eeeeee>
<td>

<form action=question-add.tcl>
[export_form_scope_vars]
[export_form_vars survey_id]

Add a Question. &nbsp  Response type = 

<select name=\"abstract_data_type\">
<option value=\"\"> Please Select </option>
<option value=\"choice\">Multiple Choice</option>
<option value=\"text\">Essay Answer</option>
<option value=\"shorttext\">One Line Answer</option>
<option value=\"number\">Number</option>
<option value=\"boolean\">True / False</option>
<option value=\"blob\">File Attachment</option>
</select>  

&nbsp &nbsp <INPUT TYPE=image SRC=\"admin-graphics/button.gif\" WIDTH=30 HEIGHT=20 BORDER=0>
</form>
</td>

<td valign=top>
$text_blurb 
</td>
</tr>
</table>
"


# Questions summary.

set questions_summary "<ol>"
set count 0

db_foreach sursimp_survey_questions "
select question_id, abstract_data_type, sort_key, question_text, required_p from survsimp_questions
where survey_id = :survey_id  
order by sort_key" {
    
    set required_text "&nbsp"
    if {$required_p == "f"} {
	set required_text "- <i> optional </i> &nbsp"
    }
    if {[string length $question_text] > 50 } {
	set trunc_question "[string range $question_text 0 50] . . . "
    } else {
	set trunc_question $question_text
    }
    
    switch -- $abstract_data_type {
	"choice" {
	    set pretty_data_type "Multiple Choice"
	}
	"text" {
	        set pretty_data_type "Essay answer"
	}
	"shorttext" {
	    set pretty_data_type "One line answer"
	}
	"number" {
	    set pretty_data_type "Number"
	}
	"boolean" {
	    set pretty_data_type "True / False"
	}
    	"blob" {
	    set pretty_data_type "File Attachment"
	}
    }

    append questions_summary "<li> $trunc_question  \(<i>$pretty_data_type</i>\) $required_text
    <a href=one-question.tcl?[export_url_vars survey_id question_id]&[export_url_scope_vars]>view\/edit</a>
    <p>"
    incr count
}  

if {$count >= 2} {
    append questions_summary "
    <a href=reorder-questions?survey_id=$survey_id&[export_url_scope_vars]> Change order of questions </a>"
}

append questions_summary </ol>


append page_content "

$questions_summary
</blockquote>
[ad_scope_admin_footer]
"

doc_return 200 text/html $page_content









