# /www/survsimp/admin/question-add-2.tcl
ad_page_contract {

    Based on the presentation type selected in previous form,
    gives the user various options on how to lay out the question.

    @param survey_id          integer determining survey we're dealing with
    @param after              optional integer determining placement of question
    @param question_text      text comprising this question
    @param presentation_type  string denoting widget used to provide answer
    @param active_p           flag indicating whether this question is active
    @param category_id        optional integer describing category of this question (within survey)

    @author Jin Choi (jsc@arsdigita.com)
    @date   February 9, 2000
    @cvs-id question-add-2.tcl,v 1.8.2.6 2000/07/23 16:53:34 seb Exp
} {

    survey_id:integer
    abstract_data_type
    {after:integer ""}
    {active_p t}
    {category_id:integer ""}
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
    
    
}



set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none


set question_id [db_string next_question_id "select survsimp_question_id_sequence.nextval from dual"]

db_1row survsimp_survey_properties "select name, description
from survsimp_surveys
where survey_id = :survey_id"

db_release_unused_handles


# Display presentation options for sizing text input fields and textareas.
set extra_html ""

switch -- $abstract_data_type {
    "choice" {
	set pretty_data_type "Multiple Choice"
	set old_presentation_html "
	<input type=hidden name=null_col>
	<tr> <td colspan=2 align=center> <b> Select the presentation options for this question <br> <br></td> </tr>
	<tr> <td valign=top width=50% align=center>
	Select a <b>presentaion type</b> for this response <p>
	<select name=presentation_type> 
	<option value=select>Select Box</option>
	<option value=checkbox>Checkbox</option>
	<option value=radio>Radio Buttons</option>
	</select>
	</td> <td align=center width=50%>
	Enter <b>choices</b> (one per line): <br>
	<textarea name=valid_responses rows=8 cols=35></textarea>                                                    
	</td> </tr>
	"
	set presentation_html "
	<tr> <th> Presentation Type </th> 
	<td>  <table> <tr>
	      <td>
	      <br> <select name=presentation_type> 
	      <option value=select>Select Box</option> 
	      <option value=checkbox>Checkbox</option>
     	      <option value=radio>Radio Buttons</option>
	      </select><br><br>
	      <td> &nbsp&nbsp&nbsp&nbsp
	      <td>
	      <font size=-1> A user may select multiple responses with a select box or a checkbox.  They can only select
	      one response with radio buttons</font>
	      </table>
	<tr> <th> Enter <b>choices</b><br> (one per line):
        <td> <textarea name=valid_responses rows=8 cols=35></textarea> "
    }
    "shorttext" {
	set pretty_data_type "One line answer"
	set old_presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	<tr> <td colspan=2 align=left> Select the <b>Size</b> of the text box for this question's response
	<tr> <td align=left>
	<select name=textbox_size>
	<option value=small>Small</option>
	<option value=medium>Medium</option>
	<option value=large>Large</option>
	</select>
	<td align=right>
	Size Examples<br>

	<input type=text size=10 value=\"Small\"><br>
	<input type=text size=40 value=\"Medium\"><br>
	<input type=text size=70 value=\"Large\">
	"
	set presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	<tr> <th> Size of text box for Response</th>
	<td> <br><select name=textbox_size>
	     <option value=small>Small</option>
	     <option value=medium>Medium</option>
	     <option value=large>Large</option>
	     </select><br><br></td></tr>"
	set extra_html "
	Size Examples<P>

	<input type=text size=10 value=\"Small\"><p>
	<input type=text size=40 value=\"Medium\"><p>
	<input type=text size=70 value=\"Large\">
	"
    }
    "text" {
	set pretty_data_type "Essay answer"
	set old_presentation_html "
	<input type=hidden name=presentation_type value=textarea>
	<tr> <td align=center colspan=2> Select the <b> size </b> for this question's response text area </p>
	     Columns: 
	     <input name=textarea_cols size=5 value=70> Rows: <input name=textarea_rows size=5 value=15></td></tr>  
	     	"
	set presentation_html "
	<input type=hidden name=presentation_type value=textarea>
	<tr> <th> Text area size </th>
	<td> <br>
	Columns: <input name=textarea_cols size=5 value=70> <br> <br>
	&nbsp &nbsp &nbsp
	Rows: <input name=textarea_rows size=5 value=15> <br> <br>
	</td>
	</tr>"
    }
    "boolean" {
	set pretty_data_type "True / False"
	set old_presentation_html " 
	<input type=hidden name=null_col>
	<tr> <td colspan=2 align=center>Select a <b>presentaion type</b> for this True / False response <p>
	     <select name=presentation_type>
	     <option value=radio>Radio Buttons</option>
	     <option value=select>Select Box</option>
	     <option value=checkbox>Checkbox</option>
	     </select></td></tr>
	"
	set presentation_html "
	<tr> <th> Presentation Type </th> 
	<td>  <table> <tr>
	      <td>
	      <br> <select name=presentation_type> 
	      <option value=radio>Radio Buttons</option>
	      <option value=select>Select Box</option> 
	      <option value=checkbox>Checkbox</option>
	      </select><br><br>
	      <td> &nbsp&nbsp&nbsp&nbsp
	      <td>
	      <font size=-1> A user may select multiple responses with a select box or a checkbox.  They can only select
	      one response with radio buttons</font>
	      </table>"

    }
    "number" {
	set pretty_data_type "Number"
	set old_presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	 <tr> <td width=50% align=center valign=top> The user will be offered a text box like this to input their answer 
	      <p><input type=textbox size=10>
	     <td width=35% align=center> 
	         <table>
	          <tr> <td> <b>Restrictions</b>: 
	          <td>
	          <input type=radio name=number_type value=\"any\"> Any Number <br>
	          <input type=radio name=number_type value=\"integer\" checked> Integer
	          </table></td></tr>
	"
	set presentation_html "
	<input type=hidden name=presentation_type value=textbox>
	<tr> <th> Restrictions </th>: 
	<td> <br>
	     <input type=radio name=number_type value=\"any\"> Any Number <br>
	     <input type=radio name=number_type value=\"integer\" checked> Integer 
	     <br> <br></td></tr>"
	set extra_html "
	<br>
	The user will be offered a text box like this to input their answer 
	<p><input type=textbox size=10>
	"


	
    }
    "blob" {
	set pretty_data_type "File Attachment"
	set old_presentation_html "
	<input type=hidden name=presentation_type value=upload_file>
	<tr> <td colspan=2 align=center>The user will be offered a text box like this to upload their file. <p>
	<input type=file></td></tr>
	
	"
	set presentation_html "
	<input type=hidden name=presentation_type value=upload_file>
	"
	
	set extra_html "
	The user will be offered a text box like this to upload their file. <p>
	<input type=file>
	"
	
    }
    default {
	ad_return_complaint 1 "You must select a type of question to ask"
	return
    }
}

# Set the question Display


set display_header_html "
<blockquote>
<table border=0 width=80%>     
<tr> <td align=center> 
Question - Response type<br> <b>$pretty_data_type </b></td><td></td></tr>
<tr> <th> Enter Question : </th>
<td><textarea name=question_text rows=5 cols=70></textarea>
</td></tr>
"

set display_footer_html "
<tr> <td align=center colspan=2><br> <input type=submit value=\"Add Question\"> </td> </tr> 
</table>
</blockquote>
"

set required_p_html "	<tr> <th> Is the question required </th> 
        <td> <select name=required_p>
	     <option value=t> Required </option>
	     <option value=f> Optional </option></select>
	</td></tr>"


set page_content "[ad_scope_admin_header "Add a $pretty_data_type question"]
[ad_scope_admin_page_title "$name"]
[ad_scope_admin_context_bar [list "?[export_url_scope_vars]" "Simple Survey Admin"] [list "one?[export_url_vars survey_id]&[export_url_scope_vars]" "Administer Survey"] "Add q $pretty_data_type question"]

<hr>
<blockquote>

<form action=\"question-add-3\" method=post>
[export_form_scope_vars]
[export_form_vars survey_id question_id abstract_data_type after active_p category_id ]
<center>

$display_header_html

$presentation_html
<tr><td colspan=2>&nbs</td></tr>
$required_p_html

$display_footer_html
</center>

$extra_html
</form>

</blockquote>

[ad_scope_admin_footer]
"

doc_return 200 text/html $page_content













