# /www/survsimp/admin/respondents.tcl
ad_page_contract {

    List respondents to this survey.

    @param    survey_id  which survey we're displaying respondents to

    @author   jsc@arsdigita.com
    @date     February 11, 2000
    @cvs-id   respondents.tcl,v 1.6.2.4 2000/07/21 04:04:19 ron Exp
} {
    {response_type "all"}
    survey_id:integer
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none

set respondents "<b>Users that resonded to this survey</b> - 
<a href=spam.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=responded>Email these users</a>
<ul>"


db_foreach survsimp_survey_respondents "
  select first_names || ' ' || last_name as name, u.user_id, email
    from users u, survsimp_responses r
      where u.user_id = r.user_id
        and survey_id = :survey_id
    group by u.user_id, email, first_names, last_name
    order by last_name" {

    append respondents "<li><a href=\"one-respondent?[export_url_vars user_id survey_id]&[export_url_scope_vars]\">$name ($email)</a>\n"
}


set delinquents "<b>Users That have not responded to this surver</b> -
<a href=spam.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=not_responded>Email these users</a>
<ul>"

if {$scope == "group"} {
    db_foreach not_responded "
    select first_names || ' ' || last_name as name, u.user_id, email
    from users u, user_group_map map, user_groups ug
    where u.user_id = map.user_id
    and ug.group_id = map.group_id
    and ug.group_id = :group_id
    and u.user_id not in (select user_id from survsimp_responses_unique where survey_id=:survey_id)" {

	append delinquents "<li><a href=\"shared/community-member?[export_url_vars user_id]&[export_url_scope_vars]\">
	$name ($email)</a>\n"
    }
} else {
    append delinquents "<li> Unable to determine"
}

set survey_name [db_string survsimp_name_from_id "select name as survey_name
from survsimp_surveys
where survey_id = :survey_id" ]

db_release_unused_handles

set page_content "
[ad_scope_admin_header "Respondents to Survey"]
[ad_scope_admin_page_title "$survey_name"]
[ad_scope_admin_context_bar [list "index?[export_url_scope_vars]" "Simple Survey Admin"] \
     [list "one?survey_id=$survey_id&[export_url_scope_vars]" "Administer Survey"] \
     [list "view-responses.tcl?survey_id=$survey_id&[export_url_scope_vars]" "Responses" ] "Respondents"]

<hr>
"

if {$response_type == "responded" || $response_type == "all"} {
    append page_content "$respondents </ul>"
}

if {$response_type == "not_responded" || $response_type == "all"} {
    append page_content "$delinquents </ul>"
}

append page_content "
[ad_scope_admin_footer]
"

doc_return 200 text/html $page_content








