# /www/survsimp/admin/responses-export.tcl
ad_page_contract {

  CSV export of responses to particular survey.

  @author  sebastian@arsdigita.com
  @date    July 2000
  @cvs-id  $Id: responses-export.tcl,v 1.2 2001/02/20 22:20:10 caroline Exp $

} {

  survey_id:integer,notnull
  {unique_users_p f}
  scope:optional
  group_id:optional,integer
  on_which_group:optional,integer
  on_what_id:optional,integer
  
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none
set question_index 0


db_foreach get_question_data_types {
  select question_id, abstract_data_type, sort_key
  from survsimp_questions
  where survey_id = :survey_id
  order by sort_key
} {

    incr question_index

    set question_index_to_id($question_index) $question_id

    set question_data_type($question_id) $abstract_data_type

    switch -- $abstract_data_type {
	"date" {
	    set question_column($question_id) "date_answer"
	}
	"text" {
	    set question_column($question_id) "clob_answer"
	}
	"shorttext" {
	    set question_column($question_id) "varchar_answer"
	}
	"boolean" {
	    set question_column($question_id) "boolean_answer"
	}
	"integer" -
	"number" {
	    set question_column($question_id) "number_answer"
	}
	"choice" {
	    set question_column($question_id) "label"
	}
	"blob" {
	    set question_column($question_id) "attachment_file_name"
	}
	default {
	    set question_column($question_id) "varchar_answer"
	}
    }
}


# mbryzek - 3/27/2000
# We need a way to limit the summary page to 1 response from 
# each user. We use views to select out only the latest response
# from any given user

if { [string compare $unique_users_p "t"] == 0 } {
    set responses_table "survsimp_responses_unique"
    set question_responses_table "survsimp_question_responses_un"
} else {
    set responses_table "survsimp_responses"
    set question_responses_table "survsimp_question_responses"
}



#  We're looping over all question responses in survsimp_question_responses

db_foreach get_all_survey_question_responses "
  select
    sqr.response_id,
    sqr.question_id,
    sqr.boolean_answer,
    sqr.number_answer,
    sqr.date_answer,
    sqr.varchar_answer,
    sqr.clob_answer,
    sqr.attachment_file_name,
    sqc.label
  from
    $responses_table sr,
    survsimp_question_responses sqr,
    survsimp_question_choices sqc
  where
    sr.survey_id = :survey_id
    and sr.response_id = sqr.response_id
    and sqr.question_id = sqc.question_id (+)
    and sqr.choice_id = sqc.choice_id (+)
  order by
    sqr.response_id,
    sqr.question_id,
    sqc.sort_order
" {

    set response_value [set $question_column($question_id)]
    #  Properly escape double quotes to make Excel & co happy
    regsub -all {"} $response_value {""} response_value

    #  Remove any CR or LF characters that may be present in text fields
    regsub -all {[\r\n]} $response_value {} response_value

    if { [info exists question_response($response_id,$question_id)] } {
	append question_response($response_id,$question_id) ",$response_value"
    } else {
	set question_response($response_id,$question_id) "$response_value"
    }

}


#  Run through all responses and print them with their details
#  (which have been retrieved by previous query).

set csv_export ""

db_foreach get_all_survey_responses "
  select
    u.email,
    u.first_names,
    u.last_name,
    sr.submission_date,
    sr.response_id,
    sr.ip_address,
    sr.user_id
  from
    $responses_table sr,
    users u
  where
    sr.survey_id = :survey_id
    and sr.user_id = u.user_id
  order by
    sr.submission_date
" {

    set one_response [list \
      $email $first_names $last_name $user_id $submission_date $ip_address \
      $response_id ]
    #  Properly escape double quotes to make Excel & co happy
    regsub -all {"} $one_response {""} one_response

    set response_row "\"[join $one_response {","}]\""

    foreach question_ndx [lsort -integer [array names question_index_to_id]] {
	set question_id $question_index_to_id($question_ndx)
	if { [exists_and_not_null question_response($response_id,$question_id)] } {
	    append response_row ",\"$question_response($response_id,$question_id)\""
	} else {
	    append response_row ","
	}
    }

    append csv_export "$response_row\r\n"

}

doc_return 200 application/text "
$csv_export"






