# /www/survsimp-scoped/admin/survey-create-2.tcl
ad_page_contract {

  Displays confirmation page for new survey creation or, if we
  just arrived from it, actually creates new survey.

  @param  survey_id    id of survey to be created
  @param  name         new survey title
  @param  description  new survey description
  @param  desc_html    whether the description is provided in HTML or not
  @param  checked_p    t if we arrived from confirmation page

  @author philg@mit.edu
  @date   February 9, 2000
  @cvs-id survey-create-2.tcl,v 1.6.2.4 2000/07/21 04:04:23 ron Exp

} {
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
    survey_id:integer,optional
    name
    description:html
    desc_html
    {checked_p "f"}
    
}



set exception_count 0
set exception_text ""

if { [empty_string_p $name] } {
    incr exception_count
    append exception_text "<li>You didn't enter a name for this survey.\n"
}

if { [empty_string_p $description] } {
    incr exception_count
    append exception_text "<li>You didn't enter a description for this survey.\n"
}

if {$exception_count > 0} {
    ad_return_complaint $exception_count $exception_text
    return
}

if {$checked_p == "f"} {
    set survey_id [db_string next_survey_id "select survsimp_survey_id_sequence.nextval from dual"]
    db_release_unused_handles

    set user_id [ad_verify_and_get_user_id]
    ad_scope_error_check
    ad_scope_authorize $scope admin group_admin none
    
    
    set page_content "
    [ad_scope_admin_header "Confirm New Survey Description"]
    [ad_scope_admin_page_title "Confirm New Survey Description"] 
    [ad_scope_admin_context_bar [list "index.tcl?[export_url_scope_vars]" "Simple Survey Admin"] "Confirm New Survey Description"]
    
    <hr>
    
    Here is how your survey description will appear:
    <blockquote><p>"

    switch $desc_html {
	"html" {
	    append page_content "$description"
	}
	
	"pre" {
	    regsub "\[ \012\015\]+\$" $description {} description
	    set description "<pre>[ns_quotehtml $description]</pre>"
	    append page_content "$description"
	}
	
	default {
	    append page_content "[util_convert_plaintext_to_html $description]"
	}
    }
    
    append page_content "<form method=post action=\"survey-create-2\">
    [export_form_scope_vars]
    [export_form_vars survey_id name description desc_html]
    <input type=hidden name=checked_p value=\"t\">
    <br><center><input type=submit value=\"Confirm\"></center>
    </form>
    
    </blockquote>

    <font size=-1 face=\"verdana, arial, helvetica\">
    Note: if the text above has a bunch of visible HTML tags then you probably
    should have selected \"HTML\" rather than \"Plain Text\". If it is all smashed together
    and you want the original line breaks saved then choose \"Preformatted Text\".
    Use your browser's Back button to return to the submission form.
    </font>
    
    [ad_footer]"
    
    
    doc_return 200 text/html $page_content
    return
} else {
    set user_id [ad_verify_and_get_user_id]
    ad_scope_error_check
    ad_scope_authorize $scope admin group_admin none
         
    if {[string compare $desc_html "plain"] == 0} {
	set description_html_p "f"
    } else {
	set description_html_p "t"
    }
    
    set create_survey_sql "insert into survsimp_surveys
      (survey_id, name, description, description_html_p, creation_user, enabled_p, single_response_p, response_editable_p, [ad_scope_cols_sql])
      values
      (:survey_id, :name, :description, :description_html_p, :user_id, 'f', 't', 't', [ad_scope_vals_sql])"

    db_dml create_survey $create_survey_sql

    ns_log notice "$create_survey_sql"
    
    db_release_unused_handles
    ad_returnredirect "one.tcl?survey_id=$survey_id&[export_url_scope_vars]"
}













