# /www/survsimp-scoped/admin/survey-edit-2.tcl
ad_page_contract {

      Displays confirmation page for new survey creation or, if we
      just arrived from it, actually creates new survey.

      @param  survey_id    id of survey to be created
      @param  name         new survey title
      @param  description  new survey description
      @param  desc_html    whether the description is provided in HTML or not
      @param  checked_p    t if we arrived from confirmation page

      @author philg@mit.edu
      @date   February 9, 2000
      @cvs-id survey-create-2.tcl,v 1.6.2.4 2000/07/21 04:04:23 ron Exp

} {
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
    survey_id:integer,notnull
    name:notnull
    description:allhtml,notnull
    desc_html:notnull
    single_response_p:notnull
    response_editable_p:notnull
    enabled_p:notnull
    layout_type:notnull
}  

set user_id [ad_verify_and_get_user_id]

set survey_info [db_list_of_lists get_survey_info "select group_id, creation_user from survsimp_surveys where survey_id=$survey_id"]

set survey_owner [lindex [lindex $survey_info 0] 0]
set surv_group_id [lindex [lindex $survey_info 0] 1]

if { ![ad_user_group_authorized_admin_or_site_admin $user_id $group_id] && $survey_owner != $user_id } {
    ad_return_complaint 1 "You do not have permission to view this survey.  You were probably editing the URL, if not contact the administrator."
}

ad_scope_error_check
ad_scope_authorize $scope admin group_admin none




              
switch $desc_html {
    "html" {
	set description_html_p "t"
    }
    
    "pre" {
	regsub "\[ \012\015\]+\$" $description {} description
	set description "<pre>[ns_quotehtml $description]</pre>"
	set description_html_p "t"
    }
    
    default {
	set description_html_p "f"
    }
}  


db_dml update_survey "update survsimp_surveys
   set name=:name, description=:description, description_html_p=:description_html_p, layout_type=:layout_type,
   response_editable_p=:response_editable_p, single_response_p=:single_response_p, enabled_p=:enabled_p
   where survey_id=:survey_id
"

db_release_unused_handles

ad_returnredirect "one.tcl?survey_id=$survey_id&[export_url_scope_vars]"











