# /www/survsimp/admin/responses.tcl
ad_page_contract {

    View summary of all responses to one survey.

    @param   survey_id       survey for which we're building list of responses

    @author  jsc@arsdigita.com
    @date    February 11, 2000
    @cvs-id  responses.tcl,v 1.5.2.5 2000/07/21 04:04:21 ron Exp
} {

    survey_id:integer
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer
    single_response_p:optional
}

set results ""
set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none

set survey_info [db_list_of_lists get_survey_info "select group_id, creation_user from survsimp_surveys where survey_id=$survey_id"]

set survey_owner [lindex [lindex $survey_info 0] 0]
set survey_group_id [lindex [lindex $survey_info 0] 1]

if { ![ad_user_group_authorized_admin_or_site_admin $user_id $survey_group_id] && $survey_owner != $user_id } {
    ad_return_complaint 1 "You do not have permission to view this survey.  You were probably editing the URL, if not contact the administrator."
}

db_1row survey_name "
select name as survey_name, single_response_p 
from survsimp_surveys
where survey_id = :survey_id"

set single_response_p f

# mbryzek - 3/27/2000
# We need a way to limit the summary page to 1 response from 
# each user. We use views to select out only the latest response
# from any given user
# why use this key?  jsut check the database.  If the administrator has
# selected single_response_p = "t" then jsut show the most recent respinse from 
# each user.  it amkes the page a lto easier to understand

if {$single_response_p == "ht" } {
    set responses_table "survsimp_responses_unique"
    set question_responses_table "survsimp_question_responses_un"
} else {
    set responses_table "survsimp_responses"
    set question_responses_table "survsimp_question_responses"
}


# determine how many users have answered this survey and how many havent.
set count_respondents [db_string count_respondents "
select count(user_id) from survsimp_responses_unique where survey_id=:survey_id"] 

set count_users_in_group [db_string count_users_in_group "
select count(*) 
from user_group_map map, survsimp_surveys ss
where ss.survey_id=:survey_id
and ss.group_id = map.group_id"]

if {$scope == "group"} {
    set count_not_responded [db_string count_not_responded "
    select count(*) 
    from user_group_map map, survsimp_surveys ss
    where ss.survey_id=:survey_id
    and ss.group_id = map.group_id
    and map.user_id not in (select user_id from survsimp_responses_unique where survey_id=:survey_id)"]
} else {
    set count_not_responded "Information Unavailable"
}


db_foreach survsimp_survey_question_list "select question_id, question_text, abstract_data_type
from survsimp_questions
where survey_id = :survey_id
order by sort_key" {
    append results "<li>$question_text
    <blockquote>
    "
    switch -- $abstract_data_type {
	"date" -
	"text" -
	"shorttext" {
	    append results "<a href=\"view-text-responses?question_id=$question_id&[export_url_scope_vars]\">View responses</a>\n"
	}
	"boolean" {
	    
	    db_foreach survsimp_boolean_summary "select count(*) as n_responses, decode(boolean_answer, 't', 'True', 'f', 'False') as boolean_answer
	    from $question_responses_table
	    where question_id = :question_id
	    group by boolean_answer
	    order by boolean_answer desc" { 
		append results "$boolean_answer: $n_responses<br>\n"
	    }
	}
	"number" {
	    db_foreach survsimp_number_summary "select count(*) as n_responses, number_answer
	    from $question_responses_table
	    where question_id = :question_id
	    group by number_answer
	    order by number_answer" {
		append results "$number_answer: $n_responses<br>\n"
	    }
	    db_1row survsimp_number_average "select avg(number_answer) as mean, stddev(number_answer) as standard_deviation
	    from $question_responses_table
	    where question_id = :question_id"
	    # truncate the answers
	    set stddev_dec [string first . $standard_deviation]
	    if {$stddev_dec != -1} {
		set stddev_trunc [string range $standard_deviation 0 [expr $stddev_dec + 2]]
	    } else {
		set stddev_trunc $standard_deviation
	    }
	    set mean_dec [string first . $standard_deviation]
	    if {$mean_dec != -1} {
		set mean_trunc [string range $mean 0 [expr $stddev_dec + 2]]
	    } else {
		set mean_trunc $mean
	    }

	    append results "<p>Mean: $mean_trunc<br>Standard Dev: $stddev_trunc<br>\n"
	    
	}
	"choice" {
	    db_foreach survsimp_survey_question_choices "select count(*) as n_responses, label, qc.choice_id
	    from $question_responses_table qr, survsimp_question_choices qc
	    where qr.choice_id = qc.choice_id
	    and qr.question_id = :question_id
	    group by label, sort_order, qc.choice_id
	    order by sort_order" {
		append results "$label: <a href=\"response-drill-down?[export_url_vars question_id choice_id]&[export_url_scope_vars]\">$n_responses</a><br>\n"
	    }
	}
	"blob" {
	    append results "<a href=\"view-text-responses?question_id=$question_id&[export_url_scope_vars]\">
	    View attachments</a>\n"
	}
    }
    append results "</blockquote>\n"
}


set n_responses [db_string survsimp_number_responses "select count(*)
from $responses_table
where survey_id = :survey_id"]

db_release_unused_handles

if { $n_responses == 0 } {
    set response_sentence "There have been no responses to this survey"
    set results ""
} elseif { $n_responses == 1 } {
    set response_sentence "There has been 1 response."
} else {
    if { [string compare $single_response_p "t"] == 0 } {
	set response_sentence "$n_responses distinct users have responded."
    } else {
	set response_sentence "There have been $n_responses responses."
    }
}

set page_content "
[ad_scope_admin_header "Responses to Survey"]
[ad_scope_admin_page_title "$survey_name"]
[ad_scope_admin_context_bar [list "index?[export_url_scope_vars]" "Simple Survey Admin"] \     [list "one?survey_id=$survey_id&[export_url_scope_vars]" "Administer Survey"] \
     "Responses"]

<hr>
<blockquote>
<center>
<table width=100%>
<tr bgcolor=e4e4e4>
  <td> Already responded </td> <td> $count_respondents users </td> 
  <td> <a href=respondents.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=responded>
       View these users </a> </td>
  <td> <a href=spam.tcl?survey_id=$survey_id&response_type=responded&[export_url_scope_vars]> Spam these users </a> </td>
</tr>
<tr bgcolor=f2f2f2>
  <td> Awaiting a response </td> <td> $count_not_responded users </td> 
  <td> <a href=respondents.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=not_responded>
       View these users </a> </td>
  <td> <a href=spam.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=not_responded> 
       Spam these users</a> </td>
</tr>
<tr bgcolor=e4e4e4> 
  <td>The whole group </td> <td> $count_users_in_group users </td> 
  <td> <a href=respondents.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=all>
       View these users </a> </td>
  <td> <a href=spam.tcl?[export_url_scope_vars]&[export_url_vars survey_id]&response_type=all> 
       Spam these users</a> </td>
</tr>
</table>

</center>

<P>
<a href=responses-export.tcl?survey_id=$survey_id&unique_users_p=$single_response_p&[export_url_scope_vars]> 
Export responses in CSV format</a>

</blockquote>

$response_sentence
<ul>
$results
</ul>

[ad_scope_admin_footer]
"

doc_return 200 text/html $page_content



