# /www/survsimp/one.tcl
ad_page_contract {

    Display a questionnaire for one survey.

    @param  survey_id   id of displayed survey
    @param  return_url  optional URL user will be redirected to after completing the survey
    @param  group_id    parameter passed to following page
    @param  template    if supplied, used as a page-building template

    @author philg@mit.edu
    @date   February 9, 2000
    @cvs-id one.tcl,v 1.14.2.5 2000/07/23 16:53:33 seb Exp
} {

    survey_id:integer,notnull
    {return_url ""}
    {template ""}
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer 

}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope admin group_admin none 

set survey_info [db_list_of_lists get_survey_info "select group_id, creation_user from survsimp_surveys where survey_id=$survey_id"]

set survey_owner [lindex [lindex $survey_info 0] 0]
set surv_group_id [lindex [lindex $survey_info 0] 1]

if { ![ad_user_group_authorized_admin_or_site_admin $user_id $surv_group_id] && $survey_owner != $user_id } {
    ad_return_complaint 1 "You do not have permission to view this survey.  You were probably editing the URL, if not contact the administrator."
}

if { ![db_0or1row survey_params "select name, description, single_response_p, response_editable_p from survsimp_surveys where survey_id = :survey_id" ] } {
    ad_return_error "Not Found" "You are not allowed to view this item"
    return
}



set form_html "

<form enctype=multipart/form-data method=POST action=\"process-response\">
[export_form_scope_vars]
[export_form_vars survey_id return_url]
"

db_release_unused_handles

append form_html "
[survsimp_survey_display $survey_id]
<p>

</form>
"


if {![empty_string_p $template]} {
    ad_return_template $template
} else {
    set page_content "
    [ad_scope_admin_header "$name"]
    [ad_scope_admin_page_title "$name"]
    [ad_scope_admin_context_bar [list "index.tcl?[export_url_scope_vars]" "Simple Survey Admin"] [list "one?[export_url_vars survey_id]&[export_url_scope_vars]" "Administer Survey"] "View Survey"]

    <hr>
    <blockquote>
    $description
    $form_html
    </blockquote>
   
      
    <p>
    
    [ad_scope_admin_footer]
    "
    doc_return 200 text/html $page_content 
}







