# /www/survsimp/one-respondent.tcl
ad_page_contract {

    Display the user's previous responses.

    @param   survey_id   id of survey for which responses are displayed
    @param   return_url  if provided, generate a 'return' link to that URL
    @param   group_id    if specified, display all the responses for all
                         users of that group

    @author  philg@mit.edu
    @date    February 9, 2000
    @cvs-id  one-respondent.tcl,v 1.8.2.4 2000/07/21 04:04:06 ron Exp
} {
    {orderby "html"}
    survey_id:integer,optional
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer 
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope all group_member none

set bind_vars [ns_set create]
ns_set put $bind_vars user_id $user_id

set missing_text "No Survey Responses of this type found."

set page_content "
[ad_scope_header "Old responses"]
[ad_scope_page_title "View/Edit old responses"]
[ad_scope_context_bar [list "index?[export_url_scope_vars]" "Surveys"] "Old Responses"]

<hr>

<blockquote>
"


if {$scope == "public"} {
    set dimensional {
	{	
	    scope_type "Survey Type" all {		
		{all "All" {} }
		{public "Site Wide" {where "ss.scope = 'public'"}}
		{group "Group" {where "ss.scope = 'group'"}}
	    }   
	} {
	    survey_state "Survey State" all {
		{all "All" {}}
		{editable "Open" {where "(enabled_p = 't' and (response_editable_p = 't' or single_response_p = 'f'))" }}
		{past  "Closed" {where "(enabled_p = 'f' or (single_response_p  = 'f' and response_editable_p ='f'))" }}
	    }   
	}
    }  
    
    set table_def {
	{
	    survey_name 
	    {Survey Name} 
	    {}
	    {<td><a href=view-one-response.tcl?[export_url_vars survey_id response_id scope group_id]> $survey_name </a>}
	} { group_name
	    {Community}
	    {}
	    {<td>[survsimp_util_group_link $group_name]}
	} {
	    submission_date "Date Submitted"
	    {submission_date $order}
	    {<td>[util_AnsiDatetoPrettyDate $submission_date]}
	} {
	    creation_date 
	    {Survey Creation Date}
	    {}
	    {<td>[util_AnsiDatetoPrettyDate $creation_date]}
	}
    }
    set dimensional_html "[ad_dimensional $dimensional] <P>"
    
    set selection_sql "
    select sr.response_id, ss.survey_id, sr.submission_date, ss.name as survey_name, ss.response_editable_p, 
    ss.single_response_p, ss.creation_date, ug.group_id, ug.group_name, ug.short_name, ug.group_type, ss.scope
    from survsimp_responses sr, survsimp_surveys ss, user_groups ug, user_group_map ugm
    where sr.survey_id=ss.survey_id 
    and ss.group_id = ug.group_id (+)
    and ss.group_id = ugm.group_id
    and ugm.user_id = :user_id
    and sr.user_id = :user_id
    [ad_dimensional_sql $dimensional]
    [ad_order_by_from_sort_spec $orderby $table_def]"

} else {

    set table_def {
	{
	    name "Survey Name" 
	    {name $order}
	    {<td><a href=view-one-response.tcl?[export_url_vars survey_id response_id]&[export_url_scope_vars]> $name </a>}
	} {
	    submission_date "Date Submitted"
	    {submission_date $order}
	    {<td>[util_AnsiDatetoPrettyDate $submission_date]}
	} {
	    creation_date "Survey Creation Date"
	    {creation_date $order}
	    {<td>[util_AnsiDatetoPrettyDate $creation_date]}
	}
    }
    
    if {[exists_and_not_null survey_id]} {
	set one_survey_sql "and ss.survey_id = $survey_id"
    } else {
	set one_survey_sql ""
    }

    set dimensional_html ""

    set selection_sql "
    select sr.response_id, ss.survey_id, sr.submission_date, ss.name, ss.response_editable_p, 
    ss.single_response_p, ss.creation_date
    from survsimp_responses sr, survsimp_surveys ss, user_group_map ugm
    where [ad_scope_sql ss]
    and sr.survey_id=ss.survey_id 
    and ss.group_id = ugm.group_id
    and ugm.user_id = :user_id
    and sr.user_id = :user_id
    $one_survey_sql
    [ad_order_by_from_sort_spec $orderby $table_def]"
}



append page_content "
<center>
$dimensional_html
[ad_table -Torderby $orderby -Tmissing_text $missing_text -bind $bind_vars get_web_service_table $selection_sql $table_def]
</center>
</blockquote>

[ad_scope_footer]
"

doc_return 200 text/html $page_content







