# /www/survsimp/one-respondent.tcl
ad_page_contract {

    Display the user's previous responses.

    @param   survey_id   id of survey for which responses are displayed
    @param   return_url  if provided, generate a 'return' link to that URL
    @param   group_id    if specified, display all the responses for all
                         users of that group

    @author  philg@mit.edu
    @date    February 9, 2000
    @cvs-id  one-respondent.tcl,v 1.8.2.4 2000/07/21 04:04:06 ron Exp
} {
    response_id:integer,notnull
    survey_id:integer,notnull
    {return_url ""}
    {group_id:integer ""}
    scope:optional
    group_id:optional,integer
    on_which_group:optional,integer
    on_what_id:optional,integer 
}

set user_id [ad_verify_and_get_user_id]
ad_scope_error_check
ad_scope_authorize $scope all group_member none

if { ![db_0or1row survsimp_survey_properties "select name, description, response_editable_p, single_response_p, enabled_p
from survsimp_surveys
where survey_id = :survey_id and [ad_scope_sql]"] } {
    ad_return_error "Not Allowed" "You can not view this survey"
    return
}

if {$response_editable_p == "f"} {
    if {$single_response_p == "t"} {
	set change_text "This was your response"
    } else {
	set change_text "You can not edit your old responses to this survey, but you can 
	<a href=add-edit-response.tcl?[export_url_scope_vars]&response_id=$response_id&edit_previous_response_p=f&survey_id=$survey_id>
	take to this survey again</a>."
    }
} else {
    if {$single_response_p == "t"} {
	set change_text "You can 
	<a href=add-edit-response.tcl?[export_url_scope_vars]&response_id=$response_id&edit_previous_response_p=t&survey_id=$survey_id> 
	edit your responses to this survey </a>."
    } else {
	set change_text "You can 
	<a href=add-edit-response.tcl?[export_url_scope_vars]&response_id=$response_id&edit_previous_response_p=t&survey_id=$survey_id> 
	edit your responses to this survey </a>, or you can 
	<a href=add-edit-response.tcl?[export_url_scope_vars]&response_id=$response_id&edit_previous_response_p=f&survey_id=$survey_id> 
	take this survey again</a>."
    }
}

if {$enabled_p == "f"} {
    set change_text "This was your response"
}


set page_content "
[ad_scope_header "View one response for survey $name"]
[ad_scope_page_title "View One response survey $name"]
[ad_scope_context_bar [list "index.tcl?[export_url_scope_vars]" "Surveys"] [list "old-responses" "Old Responses"] "Responses"]

<hr>

<b>
Description 
</b>
<blockquote>
$description 
</blockquote>
<p>

<table width=100% cellpadding=2 cellspacing=2 border=0>
<tr bgcolor=#f4f4f4>
<td>[survsimp_answer_summary_display $response_id 1]
<tr bgcolor=#e6e6e6>
<td>$change_text</td>
</tr>
</table><br>

[ad_scope_footer]
"



doc_return 200 text/html $page_content





