ad_library {
 Allows email bboard feature
 @Author: tzumainn@arsdigita.com, taken from code written by Henry Minksy
}

ad_proc gc_bboard_email_process {message} {
    Modified from ticket_email_process.  Takes an incoming message and inserts a message into the gc_bboard system and notifies the relevant users.
} {
    
    # extract the headers 
    set from_addr ""
    set date ""
    set subject ""
    set msgtext ""
    set msg_id ""
    set reply_to ""

    # We want to grab headers for 
    # Date: Thu, 11 Mar 1999 01:42:24 -0500
    # From: Henry Minsky <hqm@ai.mit.edu>
    # Subject: Re: test message

    set parsed_msg [parse_email_message $message]

    set msgbody        [ns_set iget $parsed_msg "message_body"]
    set from_header    [ns_set iget $parsed_msg "from"]
    set subject [ns_set iget $parsed_msg "subject"]
    set date_header    [ns_set iget $parsed_msg "date"]
    set reply_to       [ns_set iget $parsed_msg "reply-to"]
    set to_header       [ns_set iget $parsed_msg "to"]
    set cc_header       [ns_set iget $parsed_msg "cc"]

    # look for address of form "Reply-To: foo@bar.com" since Reply-To if present is 
    # generally canonical.

    if {![regexp -nocase  "(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $reply_to from_line from_addr]} {
	regexp -nocase  "(\[^<\]*)<(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $reply_to from_line from_name from_addr
    }
    if {[empty_string_p $from_addr]} { 
        # if we did not get Reply-To resort to From for the users address.
        if {![regexp -nocase  "(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $from_header from_line from_addr]} {
            regexp -nocase  "(\[^<\]*)<(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $from_header from_line from_name from_addr
        }
    }

    if {[empty_string_p $from_addr]} {
	ns_log Notice "gc_bboard_email_process could not parse from_addr from incoming message header: |$from_header| message=|$message|"
    }
    
    # see if we are starting a new thread or adding a reply to an
    # existing one
    set regexp_pattern "discussion-(.*)@[ad_parameter AlertEmailDomain gc-bboard]"
    if { [regexp -nocase $regexp_pattern $to_header match topic] } {
        set new_thread_p 1
        regsub -all "\\-" $topic " " topic

        # find the topic, and bail if not found
        if { ![db_0or1row "topic_id_select" "select topic_id from gc_bboard_topics where lower(name) = lower(:topic)"] } {
            ns_log Notice "EVIL MESSAGE gc_bboard_email_process could not find topic_id for topic $topic"
            return
        }
    } else {
        set new_thread_p 0

        # it's a reply in an existing thread (original code)

        # Figure out the user_id and parent_id from the From info.
        set to_addr {}
    
        if {![regexp -nocase  "(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $to_header to_line to_addr]} {
    	regexp -nocase  "(\[^<\]*)<(\[A-Za-z0-9._/%&!-\]+@\[A-Za-z0-9.-\]+)" $to_header to_line to_name to_addr
        }
    
        if {[empty_string_p $to_addr]} {
            # we bail here since w/o to_addr we do not know where to put it.
    	ns_log Notice "EVIL MESSAGE gc_bboard_email_process could not parse to_addr from incoming message header: |$to_header| message=|$message|"
    	return
        }
    
    
        # figure out which comment to book the comment on.
        set msg_id {} 
        set user_id {} 
    
        if {[regexp -nocase {bboard-robot-([0-9]+)-([0-9]+)@} $to_addr match parent_id user_id] 
        || [regexp -nocase {bboard-robot-([0-9]+)-([0-9]+)@} $cc_header match parent_id user_id] } { 
    	# if we get anything back the user and comment exist
    	if { ![db_0or1row "comment_id_select" "select comment_id as test from general_comments where comment_id = :parent_id"] } {
    	    ns_log Notice "gc_bboard_email_process could not find comment $parent_id message=|$message|"
    		return
    	}
            if { ![db_0or1row "user_name_select" "select first_names || ' ' || last_name || ' ' || email as who from users where user_id = :user_id"] } {
                ns_log Notice "gc_bboard_email_process could not find user_id $user_id message=|$message|"
                set user_id {} 
                set who $from_header
            }
        } else {  
            set who $from_header
        }
    # done with reply-specific processing (for now)
    }
        
    # We need to have some user_id we can use as the author of the comment
    if {![info exists user_id] || [empty_string_p $user_id]} {
        # We try to look up a user, based on their from address
	set user_id [db_string "user_id_select" "select user_id from users where lower(email) = lower(:from_addr)" -default ""]
        
        if {[empty_string_p $user_id]} {
            # failing that we put it in as system but include the headers since 
            set user_id [db_string "system_user_id_select" "select system_user_id from dual"]
            
            # Make a cleaner looking mail message, just reconstruct a couple of the headers
            append msgtext "From: <strong>[ns_quotehtml $from_header]</strong><br>"
            if {![empty_string_p $reply_to]} {
                append msgtext "Reply-to: <strong>[ns_quotehtml $reply_to]</strong><br>"
            }
            if {![empty_string_p $to_header]} {
                append msgtext "To: <strong>[ns_quotehtml $to_header]</strong><br>"
            }
            if {![empty_string_p $cc_header]} {
                append msgtext "CC: <strong>[ns_quotehtml $cc_header]</strong><br>"
            }
            if {![empty_string_p $date_header]} {
                append msgtext "Date: [ns_quotehtml $date_header]<br>"
            }

            append who " (unregistered saved as system user)"

            ns_log Notice "Could not find registered user $from_addr, using system user user_id=$user_id"

        }
        if { !$new_thread_p } {
            ns_log Notice "Could not find registered user for $to_addr, using user_id=$user_id"
        }
    }

    if {[empty_string_p $subject]} { 
        if { $new_thread_p } {
            # we can't do anything without a subject since it's the name of
            # the new thread
            ns_log Notice "EVIL MESSAGE subject is not set - cannot create new thread without a name!"
            return
        } else {
            set subject "To: [ns_quotehtml $to_header]"
        }
    }

    append msgtext "$msgbody"
    ## regexp out "bschool-bboard-robot wrote"
    set regexp-pattern "^(.*)[ad_parameter AlertEmailName gc-bboard]@[ad_parameter AlertEmailDomain gc-bboard](.*)\[wrote|wrote:\]"
    regexp -nocase $regexp_pattern $msgtext match msgtext

    if {!$new_thread_p && [empty_string_p $parent_id]} { 
        ns_log Notice "No ticket comment_id found for message:\n-------\n$message\n--------\n"

    } else {
        # as long as we have a message id we should insert 
        # the message.

        db_transaction {
            set comment_id [db_string "comment_id_select" "select general_comment_id_sequence.nextval from dual"]

            if { !$new_thread_p } {
	        set topic_id [db_string "topic_id_select" "select topic_id from gc_comment_topic_map where comment_id = :parent_id" -default ""]
            }

            # this is done in threaded-bboard/www/message-add*.tcl, and seems 
            # like it belongs here as well
            ad_require_permission  $user_id "write" $topic_id "gc_bboard_topics"

	    ## email comment is html
            if { $new_thread_p } {
	        gc_bboard_message_add $topic_id $comment_id "gc_bboard_topics" $topic_id $subject $msgtext $user_id "000.000.000.000" "t" "t" ""
            } else {
	        gc_bboard_message_add $topic_id $comment_id "general_comments" $parent_id $subject $msgtext $user_id "000.000.000.000" "t" "t" ""
            }

	    ## since user rpelied by email, assume that he wants email alerts
            set alert_id [db_string "alert_id_select" "select gc_bboard_alert_id_seq.nextval from dual"]
            gc_add_bboard_alerts $comment_id $alert_id $topic_id

	} on_error { 
            ns_log Notice "Insert of comment failed $errmsg"
        }
    
    }
    db_release_unused_handles

    return
}
    
