ad_library {
    gc-bboard system, plus alerts
    @Author: tzumainn@arsdigita.com, flattop@arsdigita.com for alerts
}

ad_proc gc_bboard_system_name {} {
} {
    set custom_name [ad_parameter SystemName bboard]
    if ![empty_string_p $custom_name] {
	return $custom_name 
    } else {
	return "[ad_parameter SystemName] Discussion Forums"
    }
}

ad_proc gc_bboard_message_add {
    {-subscribe_p ""}
    topic_id
    comment_id
    on_which_table
    on_what_id
    one_line_item_desc
    content
    user_id
    ip_address
    approved_p
    {html_p "f"}
    {one_line ""}
    {frequency ""}
} {
    adds a gc-bboard message

    @param -subscribe_p describes whether author wants alerts on message or not
    @param topic_id references the topic which the comment is placed under
    @param comment_id, @param on_which_table, @param on_what_id, @param one_line_item_desc, @param content, @param user_id, @param ip_address, @param approved_p, @param html_p, @param one_line - standard arguments for ad_general_comment_add    
} {
    db_transaction {
	ad_general_comment_add $comment_id $on_which_table $on_what_id $one_line_item_desc $content $user_id $ip_address $approved_p $html_p $one_line
	
	db_dml "bboard_p_update" "update general_comments
	set bboard_p = 't'
	where comment_id = :comment_id"
	
	db_dml "comment_topic_map_insert" "insert into gc_comment_topic_map
	(comment_id, topic_id)
	values
	(:comment_id, :topic_id)"

	if {$subscribe_p == "t"} {
	    db_dml "comment_subscription_insert" "insert into gc_comment_user_map
	    (comment_id, user_id, frequency)
	    values
	    (:comment_id, :user_id, :frequency)
	    "
	}
    }
}

ad_proc gc_bboard_message_list {
    {-count_messages_p 0
    -approved_p ""
    -max_bboard_display_depth ""
    -max_bboard_display_messages ""
    -reverse_p ""}
    on_what_id
    {on_which_table "gc_bboard_topics"}
} {
    returns a tcl list-of-lists of bboard message information
 
    @param on_which_table - a varchar that, along with on_what_id, will be matched in general_comments to determine which bboard node to start at.  Typical values are gc_bboard_topics (to process an entire topic) and general_comments (to receive a subtree of a topic tree).
    @param on_what_id - used with on_which_table to select the starting point of the query.
    @param count_messages_p - a boolean that instructs the procedure to count messages and new messages (inserted within the last 24 hours) branching off from each selected node.
    @param approved_p - a boolean that instructs the procedure to select approved, unapproved, or all messages.
    @param max_bboard_display_depth - an integer that tells the procedure what depth of messages to look for; it defaults to returning the whole tree.
    @param max_bboard_display_messages - an integer that tells the procedure the maximum number of messages to return.
    @param reverse_p - a boolean; if false, then the procedure returns the typica message tree, starting from the selected node.  If true, then the procedure takes the node and goes in reverse, returning a list of messages going back to the root of the message tree.
} {

    if { [empty_string_p $approved_p] } {
	set approved_clause ""
    } else {
	set approved_clause "where approved_p = :approved_p"
    }

    if { $count_messages_p } {
	set count_clause ", ([gc_bboard_count_messages_sql -approved_p $approved_p "gc.comment_id" "general_comments"]) as n_messages,
	([gc_bboard_count_messages_sql -n_past_days 1 -approved_p $approved_p "gc.comment_id" "general_comments"]) as n_new_messages"
	set select_count_clause ", n_messages, n_new_messages"
    } else {
	set count_clause ""
	set select_count_clause ""
    }

    if { [empty_string_p $max_bboard_display_depth] } {
	set depth_clause ""
    } else {
	set depth_clause "and level <= [expr $max_bboard_display_depth + 1]"
    }

    if { [empty_string_p $max_bboard_display_messages] } {
	set n_messages_clause ""
    } else {
	set n_messages_clause "and rownum <= $max_bboard_display_messages"
    }  

    if { $reverse_p == "t" } {
	set connect_by_clause "connect by prior on_what_id = comment_id
	and prior on_which_table = 'general_comments'
	and (on_which_table = 'general_comments' or on_which_table = 'gc_bboard_topics')"
	set start_with_clause "
	start with comment_id = (select on_what_id
	from gc_bboard_messages
	where comment_id = :on_what_id
	and on_which_table = 'general_comments')
	"
	set order_by_clause "order by seqnum desc"
    } else {
	set connect_by_clause "connect by prior comment_id = on_what_id
	and on_which_table = 'general_comments'"
	set start_with_clause "
	start with comment_id in (
	select comment_id from gc_bboard_messages
	where on_what_id = :on_what_id
	and on_which_table = :on_which_table)
	"
	set order_by_clause "order by seqnum asc"
    }


    set message_info_list [db_list_of_lists "message_info_select" "select comment_id, one_line_item_desc, c_date, gq.user_id, the_level, (first_names || ' ' || last_name), email, approved_p, content $select_count_clause
    from (select comment_id, one_line_item_desc, to_char(comment_date,'Month DD, HH12:MI A.M.') as c_date, gc.user_id, level as the_level, rownum as seqnum, approved_p, content $count_clause
    from (select * from gc_bboard_messages $approved_clause) gc
    $connect_by_clause
    $depth_clause
    $n_messages_clause
    $start_with_clause
    order by comment_date desc) gq, users
    where gq.user_id = users.user_id
    $order_by_clause
    "]

    return $message_info_list 
}

ad_proc gc_bboard_summarize_user_contributions {user_id} {
    lists of approved contributions to gc-bboard
} {
    set current_user_id [ad_verify_and_get_user_id]
    set html "<b>Bulletin Board Postings</b><ul>"
    set n_comments 0
    set n_topics 0
    set current_topic_id ""
    db_foreach "gc_bboard_select" "select t.topic_id, gc.comment_id, t.name, gc.one_line_item_desc, to_char(gc.comment_date,'Mon DD, YYYY') as comment_date
    from (select * from gc_bboard_messages where approved_p = 't') gc,
      (select * from gc_bboard_topics where active_p = 't'
      and ad_general_permissions.user_has_row_permission_p(:current_user_id, 'read', topic_id, 'gc_bboard_topics') = 't') t,
      gc_comment_topic_map map
    where gc.comment_id = map.comment_id
    and map.topic_id = t.topic_id
    and user_id = :user_id
    order by t.name, gc.comment_date desc" {
	if { $current_topic_id != $topic_id } {
	    set current_topic_id $topic_id
	    if { $n_topics } {
		append html "</ul>"
	    }
	    incr n_topics
	    append html "<li>$name<ul>"
	}

	append html "<li><a href=\"/threaded-bboard/one-message.tcl?[export_url_vars topic_id comment_id]\">$one_line_item_desc</a> - $comment_date"
    } if_no_rows {
	set html ""
    }

    db_release_unused_handles

    if { $n_topics } {
	append html "</ul></ul>"
    }

    return $html
}

ad_proc gc_bboard_count_messages_sql {{-approved_p "t"} {-n_past_days ""} on_what_id on_which_table} {
    returns sql for counting messages
} {
    if {[empty_string_p $n_past_days]} {
	set time_clause ""
    } else {
	set time_clause "
	and comment_date >= sysdate - $n_past_days
	"
    }

    if {[empty_string_p $approved_p]} {
	set approved_clause ""
    } else {
	set approved_clause "and approved_p = '$approved_p'"
    }

    return "
    select count(comment_id) from gc_bboard_messages
    where 1=1
    $time_clause
    $approved_clause
    connect by prior comment_id = on_what_id
    and on_which_table = 'general_comments'
    start with comment_id in (select comment_id
    from gc_bboard_messages
    where on_what_id = $on_what_id
    and on_which_table = '$on_which_table')"
}

## this needs to be deprecated, since I believe it pretty much does
## what ad_user_group_authorized_admin_or_site_admin does
ad_proc gc_bboard_check_admin {{} {group_id ""}} {} {
    set user_id [ad_verify_and_get_user_id]
    if { [empty_string_p $group_id] } {
	return [ad_administrator_p $user_id] 
    } else {
	return [ad_user_group_authorized_admin_or_site_admin $user_id $group_id]
    }
}

### LINK PROCS ###

ad_proc gc_bboard_admin_link {{} topic_id {group_id ""}} {} {
    if {[gc_bboard_check_admin $group_id]} {
	return "<a href=\"/threaded-bboard/admin/one-topic.tcl?[export_url_vars topic_id group_id]\">Administer Bulletin Board</a>"
    } else {
	return ""
    }
}

ad_proc gc_bboard_format_link {{-open_p 0} topic_id comment_id} {formats the link for a message} {
    return "one-message.tcl?[export_url_vars topic_id comment_id open_p]#message"
}

### FORMAT PROCS ###

ad_proc gc_bboard_display_message {{-graphic "plus.gif"} subject comment_date contributor user_id message {link ""} {reply_link ""} {n_total_messages ""} {n_new_messages ""}} {display format for one message} {
    set link_list [list]

    if { ![empty_string_p $reply_link] } {
	lappend link_list "<a href=\"$reply_link\"><b>reply</b></a>"
    }
    
    if {[empty_string_p $n_total_messages] && [empty_string_p $n_new_messages]} {
	set n_messages_html ""
    } else {
	set n_messages_html "($n_total_messages, $n_new_messages new)"
    }
	
    if {![empty_string_p $link] && $n_total_messages > 0 } {
	lappend link_list "<a href=\"$link\"><b><img src=\"/graphics/$graphic\" width=6 border=0 height=6></b></a> <a href=\"$link\"><b>responses</b></a> $n_messages_html"
    } elseif { ![empty_string_p $n_messages_html] } {
	lappend link_list "<b>responses</b> $n_messages_html"
    }

    set link_html [join $link_list " | "]

    return "
    <table width=90% border=0 cellspacing=3>
     <tr bgcolor=\"#ececec\"> 
      <td><b>$subject</b>; [gc_bboard_info_header $comment_date $contributor $user_id]</td>
     </tr>
     <tr bgcolor=\"#FFFFFF\">
      <td>
       <blockquote>
        <p>[ad_text_to_html $message]</p>
        <p><font size=2>$link_html</font></p>
       </blockquote>
      </td>
     </tr>
    </table>
    "
}

ad_proc gc_bboard_info_header {comment_date contributor user_id} {
    display short info header
} {
    return "<font size=\"-1\" color=\"#000000\"><a href=\"/shared/community-member.tcl?[export_url_vars user_id]\">$contributor</a>; $comment_date</font>"
}

### ALERTS PROCS ###

ad_proc gc_add_bboard_alerts {comment_id alert_id topic_id} {
    proc that handles alert insertion - modified from flattop@arsdigita.com's code
} {

    if { ![db_0or1row "user_id_select" "select user_id as contributor_id, content from gc_bboard_messages where comment_id = :comment_id"] } {
	set contributor_id ""
	set content ""
    }

    #insert into a queue to send subscibers alert
    set insert_alert_sql "insert into gc_bboard_alerts
    (alert_id, comment_id, topic_id)
    values
    (:alert_id, :comment_id, :topic_id)
    "

    catch {db_dml "alert_insert" $insert_alert_sql}
    #don't do anything
    #probably alert is already inserted

    #add thread subscriptions
    set insert_recipient_sql "insert into gc_comment_user_recipients
    (select distinct :comment_id as comment_id, user_id, frequency, 
    'comment' as alert_type from gc_comment_user_map
    where comment_id in
    (select on_what_id from gc_bboard_messages
    connect by prior on_what_id = comment_id
    and on_which_table = 'general_comments'
    start with comment_id = :comment_id))"

    catch {db_dml "recipient_insert" $insert_recipient_sql}
    #don't do anything

    #add topic subscriptions
    set insert_recipient_sql2 "insert into gc_comment_user_recipients
    (select distinct :comment_id as comment_id, user_id, frequency,
    'topic' as alert_type from gc_topic_user_map
    where topic_id = :topic_id)"
    
    db_dml "topic_alert_insert" $insert_recipient_sql2
    #don't do anything

    #add contributor subscriptions
    set insert_recipient_sql3 "insert into gc_comment_user_recipients
    select distinct :comment_id as comment_id, user_id, frequency,
    'contributor' as alert_type from gc_contributor_user_map
    where contributor_id = :contributor_id"
    
    catch {db_dml "contributor_alert_insert" $insert_recipient_sql3}
    #don't do anything

    #add keyword subscriptions
    #DRB: this was wrong in the delivered code, as it refered to the
    #contributor mapping table rather than the keyword mapping table.

    set insert_recipient_sql4 "insert into gc_comment_user_recipients
    (select distinct :comment_id as comment_id, user_id, frequency,
    'keyword' as alert_type from gc_keyword_user_map
    where '[DoubleApos [string tolower $content]]' like '%' || keyword || '%')
    "

    catch {db_dml "keyword_alert_insert" $insert_recipient_sql4}
    #don't do anything

    return 1
}

## tzumainn - adapted from. .. 
## /tcl/gc-bboard.tcl 
## flattop@mit.edu, 4/17/00
## procs to help send bboard alerts

ad_proc gc_send_bboard_alerts {} "Send bboard alerts to subscribers" {
    ns_log Notice "Sending alerts for gc-bboard on [ad_parameter SystemUrl]"

    set comment_id_sql "select uba.comment_id
    from gc_bboard_alerts uba, gc_bboard_messages gc
    where uba.comment_id = gc.comment_id
    and date_sent is null
    and approved_p = 't'"

    set comment_id_list [db_list "alert_select" $comment_id_sql]
    
    if {[empty_string_p $comment_id_list]} {
	# no alerts to send
	return 
    }

    set comment_user_sql "select distinct comment_id, user_id
    from gc_comment_user_recipients
    where comment_id in ([join $comment_id_list ","])
    and frequency = 'instant'
    order by comment_id"
    
    set current_comment_id ""
    set current_user_id_list ""
    
    db_foreach "user_alert_select" $comment_user_sql {
	if {$comment_id == $current_comment_id} {
	    lappend current_user_id_list $user_id
	} else {
	    if {![empty_string_p $current_comment_id]} {
		gc_bboard_send_alerts $current_user_id_list $current_comment_id
	    }
	    set current_comment_id $comment_id
	    set current_user_id_list [list $user_id]
	}
    }
    
    if {![empty_string_p $current_comment_id]} {
	gc_bboard_send_alerts $current_user_id_list $current_comment_id
    }

    #update the date sent in gc_bboard_alerts
    db_dml "alert_sent_update" "update gc_bboard_alerts 
    set date_sent = sysdate
    where comment_id in ([join $comment_id_list ","])"

    #delete the rows from the gc_comment_user_recipients
    db_dml "recipient_delete_instants" "delete from gc_comment_user_recipients
    where comment_id in ([join $comment_id_list ","])
    and frequency = 'instant'"
    
    ns_log Notice "Done sending alerts for gc-bboard."
}

proc pretty_frequency {ugly_frequency} {
    if { $ugly_frequency == "monthu" } {
	return "Monday/Thursday"
    } else {
	return $ugly_frequency
    }
}

ad_proc gc_send_digest_bboard_alerts { { frequency "daily"} } {
    Send digest gc_bboard alerts to subscribers
} {
    set pretty_frequency [pretty_frequency $frequency]
    ns_log Notice "Started sending $pretty_frequency alerts for gc-bboard on [ad_parameter SystemUrl]"

    
    switch $frequency {
	"daily" {
	    set n_days 1
	}
	"monthu" {
	    if { [db_string day_select "select to_char(sysdate,'day') from dual"] == "thursday" } {
		set n_days 3
	    } else {
		set n_days 4
	    }
	}
	"weekly" {
	    set n_days 7
	}
	default {
	    set n_days 0
	}
    }
    
    # filter on previous n days comments.. this just gives us a
    # smaller comment_list to work with before doing the real query
    set comment_id_sql "
    select uba.comment_id
    from  gc_bboard_alerts uba, gc_bboard_messages gc
    where uba.comment_id = gc.comment_id
    and   ((trunc(comment_date) >= trunc(sysdate - $n_days)
    and trunc(comment_date) < trunc(sysdate)) 
    or    date_sent is null)
    and   approved_p = 't'
    order by topic_id"
    
    set comment_id_list [db_list "alert_select" $comment_id_sql]
    
    if {[empty_string_p $comment_id_list]} {
	# no alerts to send
	return
    }
    

    # not using this anymore
    
    set comment_user_sql_old "select distinct gcur.comment_id, 
    users_alertable.user_id,
    users_alertable.email,
	    gbup.single_email_p, 
    gbup.default_view, 
    gctm.topic_id
    from gc_comment_user_recipients gcur,
    users_alertable,
    gc_bboard_user_prefs gbup,
    gc_comment_topic_map gctm
    where gcur.comment_id in ([join $comment_id_list ","])
    and gctm.comment_id = gcur.comment_id
    and frequency = :frequency
    and users_alertable.user_id = gcur.user_id
    and gbup.user_id = gcur.user_id
    order by user_id, gctm.topic_id, gcur.comment_id"


    # get the user_ids first; right now only using gcur to determine
    # who is getting alerts.

    set comment_user_sql "
    select distinct(ua.user_id),
	    ua.email,
            nvl(gbup.single_email_p, 'f') as single_email_p,
            nvl(gbup.default_view,'threaded') as default_view,
            gtum.topic_id
    from gc_comment_user_recipients gcur,
	    users_alertable ua,
	    gc_bboard_user_prefs gbup,
	    gc_topic_user_map gtum
    where gcur.frequency = :frequency
    and gtum.user_id (+) = ua.user_id
    and gtum.frequency (+) = :frequency
    and ua.user_id = gcur.user_id
    and gbup.user_id (+) = gcur.user_id
    order by user_id"

    set current_user_id ""
    set current_comment_list {}
    set last_topic_id ""

    # We also need to sort each thread, so we do a subquery

    db_foreach "user_alert_select" $comment_user_sql {
	if { $user_id == $current_user_id && $single_email_p == "t" } {
	    # same user, new topic so add the topic comments
	    set topic_comments [recent_topic_comments $topic_id $n_days]
	    if { ![empty_string_p $topic_comments] } {
		set temp [concat $current_comment_list $topic_comments]
		set current_comment_list $temp
	    }
	} else {
	    # new user or requested separate emails
	    # send the email, start the next one for this user

	    if { $user_id != $current_user_id} {
		# new user; send any additional comments at the end of summary
		if { ![empty_string_p $current_user_id] } {
		    if { [llength $current_comment_list] == 0 } {
			set current_comment_list [db_list more_comments_sel "
			select distinct(comment_id) from gc_comment_user_recipients
			where user_id = :current_user_id
			and   frequency = :frequency
			and   comment_id in ([join $comment_id_list ", "])"]
		    } else {
			set more_comments [db_list more_comments_sel "
			select distinct(comment_id) from gc_comment_user_recipients
			where user_id = :current_user_id
			and   frequency = :frequency
			and   comment_id not in ([join $current_comment_list ", "])
			and   comment_id in ([join $comment_id_list ", "])"]
			set temp [concat $current_comment_list $more_comments]
			set current_comment_list $temp
		    }
		}
	    }

  	    set error_code [gc_bboard_send_digest_alerts $current_comment_list $current_user_id $pretty_frequency $single_email_p]
  	    if { $error_code > 0 } {
  		ns_log "Notice" "Error code $error_code returned while sending digest alert to user $current_user_id"
  	    }

	    # send extra alert
	    if { $single_email_p == "f" && ![empty_string_p $current_user_id]} {
		set current_comment_list [db_list more_comments_sel "
		select distinct(comment_id) from gc_comment_user_recipients
		where user_id = :current_user_id
		and   frequency = :frequency
		and   comment_id in ([join $comment_id_list ", "])"]

  		set error_code [gc_bboard_send_digest_alerts $current_comment_list $current_user_id $pretty_frequency $single_email_p]
  		if { $error_code > 0 } {
  		    ns_log "Notice" "Error code $error_code returned while sending digest alert to user $current_user_id"
  		}
	    }
	    set current_user_id $user_id
	    set last_topic_id $topic_id
	    set current_comment_list [recent_topic_comments $topic_id $n_days]
	}
    }

    # send the last email(s)
    set single_email_p [db_string "get summary preference" "
    select single_email_p  from gc_bboard_user_prefs where user_id = :current_user_id" -default "f"]

    if { [llength $current_comment_list] > 0 } {
	set more_comments [db_list more_comments_sel "
	select distinct(comment_id) from gc_comment_user_recipients
	where user_id = :current_user_id
	and   frequency = :frequency
	and   comment_id not in ([join $current_comment_list ","])
	and   comment_id in ([join $comment_id_list ","])"]
	if { $single_email_p == "t" } {
	    set temp [concat $current_comment_list $more_comments]
	    set current_comment_list $temp
	}
    } else {
	set current_comment_list  [db_list more_comments_sel "
	select distinct(comment_id) from gc_comment_user_recipients
	where user_id = :current_user_id
	and   comment_id in ([join $comment_id_list ","])"]
    }

    if {![empty_string_p $current_user_id] && [llength $current_comment_list] > 0 } {
  	set error_code [gc_bboard_send_digest_alerts $current_comment_list $current_user_id $pretty_frequency $single_email_p]
  	if { $error_code > 0 } {
  	    error "Error code $error_code returned while sending digest alert to user $current_user_id"
  	}
    }
    if { $single_email_p == "f" } {
	set current_comment_list  [db_list more_comments_sel "
	select distinct(comment_id) from gc_comment_user_recipients
	where user_id = :current_user_id
	and   comment_id in ([join $comment_id_list ","])"]
  	set error_code [gc_bboard_send_digest_alerts $current_comment_list $current_user_id $pretty_frequency $single_email_p]
  	if { $error_code > 0 } {
  	    error "Error code $error_code returned while sending digest alert to user $current_user_id"
	}
    }

    #delete the rows from the gc_comment_user_recipients
    db_dml "recipient_delete_$frequency" "delete from gc_comment_user_recipients
    where comment_id in ([join $comment_id_list ","])
    and frequency = :frequency"
    ns_log Notice "Done sending $pretty_frequency alerts for gc-bboard."
    
}

ad_proc gc_bboard_send_alerts {user_id_list comment_id} {
    return 0 if there is no error
} {
    
    #there's a max length of sql statements: at most 1000 elements
    # so in this case, 1000 user_id
    # so do 800 just in case
    if {[llength $user_id_list] > 800} {
	gc_bboard_send_alerts [lrange $user_id_list 0 799] $comment_id
	gc_bboard_send_alerts [lrange $user_id_list 800 end] $comment_id
    }

    if {[empty_string_p $user_id_list]} {
	#just return if no recipients
	return 0
    }

    #get the users email address
    if {[catch {set user_email_id_list [db_list_of_lists "get_email_info" "select email, user_id from users where user_id in ([join $user_id_list ","])"]} errmsg]} {
	ns_log NOTICE "gc_bboard_send_alerts Error -- cannot get the user email addresses
	<blockquote>$errmsg</blockquote>"
	return 2
    }
    
    ns_log Notice "email is $user_email_id_list"

    set email_body "" 
    
    db_foreach "message_select" "
    select one_line_item_desc, content, t.topic_id, to_char(comment_date, 'MM/DD/YYYY, HH12:MI A.M.') as comment_date, t.name, (u.first_names || ' ' || u.last_name) as author_name
    from gc_bboard_messages gc, gc_comment_topic_map m, gc_bboard_topics t, users u
    where gc.comment_id = :comment_id
    and gc.comment_id = m.comment_id
    and m.topic_id = t.topic_id
    and gc.user_id = u.user_id" {
	
	set email_domain [ad_parameter AlertEmailDomain "gc-bboard"]
	set email_name [ad_parameter AlertEmailName "gc-bboard"]

	regsub " " [string tolower $name] "_" topic_email_name
	set reply_to_email "$email_name-$comment_id@$email_domain"
    #define the header
    set extra_headers [ns_set create]
    ns_set put $extra_headers "Content-Transfer-Encoding" "7bit"
    ns_set put $extra_headers "MIME-Version" "1.0"
    ns_set put $extra_headers "Content-Type" "text/plain; charset=us-ascii"
    ns_set put $extra_headers "Reply-to" $reply_to_email

    set email_from "$email_name@$email_domain"
	    set subject $one_line_item_desc
	    set bboard_link "[ad_parameter SystemUrl]/threaded-bboard/one-message.tcl?[export_url_vars topic_id comment_id]#message"
	
	append email_body "
Topic: $name
Thread: $one_line_item_desc
Message Posted on $comment_date by $author_name
---------------------------------

$content

---------------------------------
To post a response, reply to this email, or go to $bboard_link.
    "
}


    set return_code 0
    foreach user_email_id $user_email_id_list {
	set user_email [lindex $user_email_id 0]
	set user_id [lindex $user_email_id 1]
	set reply_to_email "$email_name-$comment_id-$user_id@$email_domain"

	#set reply_to_email "befekadu@mit.edu"

	ns_log Notice "$user_email, $reply_to_email, $subject, $content"

	#ns_sendmail $user_email $email_from $subject $email_body

	ns_set update $extra_headers "Reply-to" $reply_to_email
	if {[catch {ns_sendmail $user_email $email_from $subject $email_body $extra_headers} errmsg]} {
	    ns_log NOTICE "gc_bboard_send_alerts Error -- cannot send email:
	    ns_sendmail $user_email $email_from $subject $email_body $extra_headers
	    $errmsg"
	    set return_code 4
	}
    }    
    return $return_code
}

ad_proc gc_bboard_threaded_topic_alert { topic_id user_id frequency } {
    returns a string representing a threaded bboard alert 
} {
    set topic_string ""
    set html_topic_string "<table>"
    set message_info_list [gc_bboard_message_list -approved_p "t" -count_messages_p 0 -max_bboard_display_depth 0 $topic_id "gc_bboard_topics"]

    foreach message_info $message_info_list {

	set comment_id [lindex $message_info 0]
	set one_line_item_desc [lindex $message_info 1]
	set comment_date [lindex $message_info 2]
	set user_id [lindex $message_info 3]
	set level [lindex $message_info 4]
	set user_name [lindex $message_info 5]
	set user_email [lindex $message_info 6]
	set n_total_messages [lindex $message_info 9]
	set n_new_messages [lindex $message_info 10]

	if { $html_p == "t" } {
	    append html_topic_string "
    <tr>
     <td bgcolor=\"$bgcolor\">
     <b><a href=\"one-message.tcl?[export_url_vars topic_id comment_id]\">$one_line_item_desc</a>;</b> [gc_bboard_info_header $comment_date $user_name $user_id]
     </td>
    </tr>"
	} else {
	    append topic_string "
Thread:  $one_line_item_desc"
        }

	append html_topic_string "</table>"
    }
}


# send the alerts every 5 minutes
ad_schedule_proc -thread t 300 gc_send_bboard_alerts


ad_proc gc_bboard_send_digest_alerts {comment_id_list user_id frequency single_email_p} {
    return 0 if there is no error
} {
    set pretty_frequency [pretty_frequency $frequency]
    #there's a max length of sql statements: at most 1000 elements
    # so in this case, 1000 user_id
    # so do 800 just in case
    if {[llength $comment_id_list] > 800} {
	gc_bboard_send_digest_alerts [lrange $comment_id_list 0 799] $user_id
	gc_bboard_send_digest_alerts [lrange $comment_id_list 800 end] $user_id
    }

    if {[empty_string_p $comment_id_list]} {
	#just return if no recipients
	return 0
    }

    # get the users email address and summary preference
    if {![db_0or1row "get_email_info" "select email as user_email, user_id from users where user_id = :user_id"] } {
	ns_log NOTICE "gc_bboard_send_digest_alerts Error -- cannot get the email address for user_id $user_id from users; returning"
	return 2
    } 

    set email_domain [ad_parameter AlertEmailDomain "gc-bboard"]
    set email_name [ad_parameter AlertEmailName "gc-bboard"]

    set email_body ""
 
    set comment_sql "select  t.topic_id, to_char(comment_date, 'MM/DD/YYYY, HH12:MI A.M.') as comment_date, t.name, (ua.first_names || ' ' || ua.last_name) as author_name, gc.one_line_item_desc, gc.content
	from gc_bboard_messages gc, gc_comment_topic_map m, gc_bboard_topics t, users_alertable ua
	where gc.comment_id = :comment_id
	and gc.comment_id = m.comment_id
	and m.topic_id = t.topic_id
	and gc.user_id = ua.user_id"

    #define the header
    set extra_headers [ns_set create]
    ns_set put $extra_headers "Content-Transfer-Encoding" "7bit"
    ns_set put $extra_headers "MIME-Version" "1.0"
    ns_set put $extra_headers "Content-Type" "text/plain; charset=us-ascii"

    #define the "from" field
    set email_from "$email_name@$email_domain"

    if { $single_email_p == "f" } {
	# if this email is all for one topic
	set subject "$name $pretty_frequency summary"
    } else {
	set subject "[capitalize $pretty_frequency] summary for all forums"
    }
    
    # now loop through the comments
    set last_topic_id ""
    set last_thread ""
    set email_summary ""
    set thread_count 0
    foreach comment_id $comment_id_list {
	if {![db_0or1row "message_select" "$comment_sql"] } {
	    ns_log "Notice" "Message fetch failed for comment $comment_id from gc_send_digest_email_alerts."
	} else {
	    regsub " " [string tolower $name] "_" topic_email_name
	    set bboard_link "[ad_parameter SystemUrl]/threaded-bboard/one-message.tcl?[export_url_vars topic_id comment_id]#message"

	    if { $last_topic_id != $topic_id } {
		set last_topic_id $topic_id
		append email_body "\n==================================================================\n\nTopic: $name"
		if { $thread_count > 0 } {
		    if { $thread_count == 1 } {
			set plural "message"
		    } else {
			set plural "messages"
		    }
		    append email_summary "-- $thread_count $plural"
		    set thread_count 0
		}
		append email_summary "\n\nTopic: $name"
            }

	    # check for a new thread
	    set thread [find_parent_thread $comment_id]
            if { $last_thread != $thread } {
		set last_thread $thread
		set thread_name [db_string parent_title "select one_line_item_desc from gc_bboard_messages where comment_id = :thread"]
                append email_body "\n** Thread: $thread_name **"
		if { $thread_count > 0 } {
		    if { $thread_count == 1 } {
			set plural "message"
		    } else {
			set plural "messages"
		    }
		    append email_summary "-- $thread_count $plural"
		}
		append email_summary "\n** Thread: $thread_name"
		set thread_count 1
            } else {
		incr thread_count
	    }
	    append email_body "\n
Subject: $one_line_item_desc
Message Posted on $comment_date by $author_name
---------------------------------

$content

---------------------------------
Post a response via the web at $bboard_link.
Post a response by email to $email_name-$comment_id@$email_domain
*********************************
"
        }
    }
    
    if { $thread_count > 0 } {
	if { $thread_count == 1 } {
	    set plural "message"
	} else {
	    set plural "messages"
	}
	append email_summary "-- $thread_count $plural"
    }

    set return_code 0
    # not using reply-to
    #    set reply_to_email "$email_name-$comment_id-$user_id@$email_domain"
    #    ns_set update $extra_headers "Reply-to" $reply_to_email

    if {[catch {ns_sendmail $user_email $email_from $subject "$email_summary\n$email_body" $extra_headers} errmsg]} {
	ns_log NOTICE "gc_bboard_send_digest_alerts Error -- cannot send email:
	ns_sendmail $user_email $email_from $subject $email_body $extra_headers
	$errmsg"
	set return_code 4
    } else {
    ns_log Notice "Sent $pretty_frequency summary alert to $user_email from gc-bboard."
    }
    return $return_code
}

ad_proc recent_topic_comments { {topic_id ""} {n_days 0} } {
    return the recent comments for a topic
} {
    if { [empty_string_p $topic_id] } {
	return ""
    }

    # selects the comments depth-first
    #, one_line_item_desc, c_date, gq.user_id, the_level, (first_names || ' ' || last_name), email, approved_p, content

    set depth_sql "select comment_id
    from (select comment_id, one_line_item_desc, comment_date, gc.user_id, level as the_level, rownum as seqnum, approved_p, content
    from (select * from gc_bboard_messages where approved_p = 't') gc
    connect by prior comment_id = on_what_id
        and on_which_table = 'general_comments'
        start with comment_id in (
        select comment_id from gc_bboard_messages
        where on_what_id = :topic_id
        and on_which_table = 'gc_bboard_topics')
    order by comment_date desc) gq, users
    where gq.user_id = users.user_id
    and trunc(comment_date) >= trunc(sysdate - $n_days)
    and trunc(comment_date) < trunc(sysdate)
    order by seqnum asc
    "
    set topic_comments [db_list topic_comments_sel $depth_sql]
    
    if { [llength $topic_comments] == 0 } {
	return ""
    } else {
	return $topic_comments
    }

}

ad_proc find_parent_thread { comment_id } {
    gets the parent thread
} {
    # check if it's a thread
    if { [db_0or1row thread_select "select threads.comment_id 
    from gc_bboard_threads threads
    where comment_id = :comment_id"] } {
	return $comment_id
    } else {
	# find the parent, call recursively
	set parent_id [db_string "parent_sel" "select on_what_id
	from gc_bboard_messages where comment_id = :comment_id"]
	return [find_parent_thread $parent_id]
    }
}


#  select distinct(ua.user_id)
#  from users_alertable ua,
#       gc_topic_user_map gtum,
#       gc_comment_user_map gcom,
#       gc_keyword_user_map gkum,
#       gc_contributor_user_map gcum
#  where (ua.user_id = gtum.user_id (+)
#         and gtum.frequency (+) = 'daily')
#  and    (ua.user_id = gcom.user_id (+)
#         and gcom.frequency (+) = 'daily')
#  and    (ua.user_id = gkum.user_id (+)
#         and gkum.frequency (+) = 'daily')
#  and    (ua.user_id = gcum.user_id (+)
#         and gcum.frequency (+) = 'daily')


#  select distinct(user_id) 
#  from gc_comment_user_recipients

#  create or replace view gc_user_daily_alerts as select ua.user_id,
#  topic_id, comment_id, keyword, contributor_id from gc_topic_user_map
#  gtum,
#       gc_comment_user_map gcom,
#       gc_keyword_user_map gkum,
#       gc_contributor_user_map gcum,
#       users_alertable ua
#  where gtum.user_id (+) = ua.user_id
#  and   gcom.user_id (+)
#  and   ua.user_id = gkum.user_id (+)
#  and   ua.user_id = gcum.user_id (+)
#  and   gtum.frequency (+) = 'daily'
#  and   gcom.frequency (+) = 'daily'
#  and   gkum.frequency (+) = 'daily'
#  and   gcum.frequency (+) = 'daily'
#  order by gtum.user_id



#      set comment_user_sql3 "select distinct \
#  	    users_alertable.user_id,\
#  	    users_alertable.email, \
#  	    gbup.single_email_p, \
#  	    gbup.default_view, \
#  	    gctm.topic_id
#      from    users_alertable,\
#  	    gc_bboard_user_prefs gbup, \
#  	    gc_comment_topic_map gctm
#      where   frequency = :frequency\
#  	    and users_alertable.user_id = gcur.user_id\
#  	    and gbup.user_id = gcur.user_id
#      order by user_id, gctm.topic_id, gcur.comment_id"





#      set comment_user_sql "select distinct gcur.comment_id, 
#  	    users_alertable.user_id,
#  	    users_alertable.email, 
#  	    gbup.single_email_p, 
#  	    gbup.default_view,
#  	    gctm.topic_id,
#  topic_comment_id, one_line_item_desc
#  from (select comment_id as topic_comment_id, one_line_item_desc
#      from (select comment_id, one_line_item_desc, to_char(comment_date,'Month DD, HH12:MI A.M.') as c_date, gc.user_id, level as the_level, rownum as seqnum, approved_p, content
#      from (select * from gc_bboard_messages where approved_p = 't') gc
#      connect by prior comment_id = on_what_id
#          and on_which_table = 'general_comments'
#          start with comment_id in (
#          select comment_id from gc_bboard_messages
#          where on_what_id = gctm.topic_id
#          and on_which_table = 'gc_bboard_topics')
#      order by comment_date desc) gq, users
#      where gq.user_id = users.user_id
#  	and comment_id in ([join $comment_id_list ","])
#      order by seqnum asc),
#      from gc_comment_user_recipients gcur, users_alertable,
#      gc_bboard_user_prefs gbup, gc_comment_topic_map gctm
#      where gcur.comment_id in ([join $comment_id_list ","])
#      and gctm.comment_id = gcur.comment_id
#      and frequency = :frequency
#      and users_alertable.user_id = gcur.user_id
#      and gbup.user_id = gcur.user_id
#      order by user_id, gctm.topic_id"

#  ad_proc gc_bboard_send_digest_alerts_helper {comment_id_list user_id frequency {single_email_p "f"} } {
#      break it up for gc_bboard_send_digest_alerts
#  } {
#      if { $single_email_p == "t" } {
#  	gc_bboard_send_digest_alerts $comment_id_list $user_id $frequency $single_email_p
#      } else {
#  	set last_topic_id ""
#  	set topic_comment_id_list [list]
#  	foreach comment_id $comment_id_list {
#  	    set topic_id [db_string topic_select "select topic_id from gc_comment_topic_map where comment_id = :comment_id" -default ""]
#  	    if { $topic_id == $last_topic_id } {
#  		lappend topic_comment_id_list $comment_id 
#  	    } else {
#  		gc_bboard_send_digest_alerts $topic_comment_id_list $user_id $frequency $single_email_p
#  		set last_topic_id $topic_id
#  		set topic_comment_id_list [list $comment_id]
#  	}

#      }
#  }

#  	    db_foreach user_alert "
#  	    select unique(gba.comment_id),
#  	    gba.topic_id,
#  	    users_alertable.email, 
#  	    gc_bboard_topics.name
#  	    from   gc_comment_user_recipients gcur, users_alertable, gc_bboard_topics
#  	    where  gcur.user_id = users_alertable.user_id
#  	    and    gc_bboard_topics.topic_id = gba.topic_id
#  	    and gcur.frequency = :frequency
#  	    order by (user_id,topic_id,comment_id)" {
		


#  		# this is the outer loop where each row is an alert for one email address

#  		# do topic alerts first by default
		
#  		set comments_list [list]

#  		set topics [db_list topics_select "
#  		select topic_id from gc_topic_user_map
#  		where user_id = :user_id and frequency = :frequency"]
		
#  		foreach topic_id $topics {
#  		    lappend comments_list [db_list topic_comments_select "select comment_id
#  		    from gc_comment_topic_map m
#  		    where m.topic_id = :topic_id"]
#  		}

#  		# add keyword alerts
#  		set keywords [db_list keywords_select "
#  		select keyword from gc_keyword_user_map
#  		where user_id = :user_id and frequency = :frequency"]

#  		foreach keyword $keywords {
#  		    lappend comments_list [db_list keyword_comments_select "
#  		    select comment_id  from gc_bboard_messages
#  		    where  '[string tolower $content]' like '%' || keyword || '%'"]
#  		}

#  		# add contributor alerts
		
#  		# now look for actual message rows
#  		set topic_lists [lindex
		    
#  		    foreach comment_id $list {
			
		

#  	    }

#  	}


#  else {
#  	    # new user
#  	    if {![empty_string_p $current_user_id]} {
#  		# add keyword, comment, and contributor alerts
#  		set more_comments [db_list more_comments_sel "
#  		select distinct(comment_id) from gc_comment_user_recipients
#  		where comment_id not in ([join $current_comment_list])
#  		and   comment_id in ([join $comment_id_list])"]
#  		concat current_comment_list $more_comments
#  		set error_code [gc_bboard_send_digest_alerts $current_comment_list $current_user_id $pretty_frequency $single_email_p]
#  		if { $error_code > 0 } {
#  		    error "Error code $error_code returned while sending digest alert to user $current_user_id"
#  		}
#  	    }
#  	    set current_user_id $user_id
#  	    set current_comment_list [recent_topic_comments $topic_id $frequency]
#  	    } else {
#  		set current_comment_list [list $comment_id]
#  	    }
#  	}
#      }
    
