
-- GENERAL COMMENTS MODIFICATIONS

-- this version of bboard uses general_comments for content; this column
-- allows for easier indexing of bboard posts (vs. other general comments)
alter table general_comments add (bboard_p char(1) default 'f' check(bboard_p in ('t','f')));

-- changes were made December 2000 to add email features - jwong
--  added: gc_bboard_user_prefs, gc_bboard_threads
--  altered:  gc_topic_user_map, gc_comment_user_map, gc_contributor_user_map,
--         gc_keyword_user_map, gc_comment_user_recipients

create index gc_comment_date_idx on general_comments(comment_date);
create index gc_show_p_idx on general_comments(bboard_p, approved_p);
create index gc_comment_on_what_ids_idx on general_comments(comment_id, on_what_id);

create or replace view gc_bboard_messages
as select * from general_comments where bboard_p = 't';

-- view of all threads - jwong
create or replace view gc_bboard_threads
as select * from general_comments where bboard_p = 't'
and on_which_table = 'gc_bboard_topics';

create or replace view gc_bboard_thread_comment_map
as select threads.comment_id as thread_id, msgs.comment_id as comment_id, 
from gc_bboard_threads threads, gc_bboard_messages msgs
where msgs.on_what_id = threads.comment_id


-- NEW TABLES

create sequence gc_bboard_topics_id_seq;

create table gc_bboard_topics (
	topic_id   	integer primary key,
	name		varchar(100) unique not null,
	active_p 	char(1) default 'f' check(active_p in ('t','f')),
	max_bboard_display_depth integer default 2,
	max_bboard_display_messages integer default 10,
	creation_user	references users,
	creation_date   date default sysdate,
	creation_ip	varchar(50),
	group_id	references user_groups,
	auto_subscribe_p char(1) default 'f' check (auto_subscribe_p in ('t', 'f'))
);

create index gc_bboard_topics_group_id_idx on gc_bboard_topics(group_id);

-- denormalization to make the topic of each comment easily accessible
create table gc_comment_topic_map (
	comment_id	references general_comments,
	topic_id	references gc_bboard_topics,
	primary key(comment_id, topic_id)
);

-- USER PREFERENCES - added by jwong@arsdigita.com
-- stores gc_bboard preferences
create table gc_bboard_user_prefs (
	user_id		integer primary key references users,
	default_view	varchar(100)  default 'threaded',
	html_email_p	char(1)  default 'f' check(html_email_p in ('t','f')),
	single_email_p  char(1)  default 'f' check(single_email_p in ('t','f'))
);

-- BBOARD ALERTS TABLES - flattop@arsdigita.com
-- currently can handle based on thread/topic

-- we want per-message digest alerts, so add "frequency" to each map

create table gc_topic_user_map (
	topic_id	references gc_bboard_topics,
	user_id		references users,
	primary key (topic_id, user_id)
);

-- add frequency
alter table gc_topic_user_map drop primary key;
alter table gc_topic_user_map add (
	frequency  	varchar(100) default 'instant'
);
alter table gc_topic_user_map add (
	primary key (topic_id, user_id, frequency)
);


--gc_comment_user_map shows who is subscribed to a thread
create table gc_comment_user_map (
	comment_id	references general_comments,
	user_id		references users,
	primary key (comment_id, user_id)
);
-- add frequency
alter table gc_comment_user_map drop primary key;
alter table gc_comment_user_map add (
	frequency  	varchar(100) default 'instant'
);
alter table gc_comment_user_map add (
	primary key (comment_id, user_id, frequency)
);

--gc_contributor_user_map shows who is subscribed to an author
create table gc_contributor_user_map (
	contributor_id  references users,
	user_id		references users,
	primary key (contributor_id, user_id)
);
-- add frequency
alter table gc_contributor_user_map drop primary key;
alter table gc_contributor_user_map add (
	frequency  	varchar(100) default 'instant'
);
alter table gc_contributor_user_map add (
	primary key (contributor_id, user_id, frequency)
);

--gc_keyword_user_map shows who is subscribe to a keyword
create table gc_keyword_user_map (
	keyword         varchar(100) not null,
	user_id 	references users,
	primary key (keyword, user_id)
);
-- add frequency
alter table gc_keyword_user_map drop primary key;
alter table gc_keyword_user_map add (
	frequency  	varchar(100) default 'instant'
);
alter table gc_keyword_user_map add (
	primary key (keyword, user_id, frequency)
);
 
-- when a bboard entry is inserted, an insertion is done into this table as
-- well, so we know if a bboard entry needs to be processed for alerts
create sequence gc_bboard_alert_id_seq;
create table gc_bboard_alerts (
	alert_id	integer 
			constraint gc_bboard_alert_id_pk
			primary key,
	--didn't specify it to be unique since message might be edited
	comment_id	references general_comments not null,
	--if date_sent is null, that means not sent yet
	--check to see if approve before sending
	date_sent	date,
	topic_id 	references gc_bboard_topics not null
);
	
	

--  shows who should get an email for that message; entries are deleted once
-- an email is sent

-- NOTE: This can be expanded to allow for digest messages very easily; simply
-- add a user preferences table that allows digest and instant alerts.  If
-- a user wants digest alerts, save his rows in this table until the end of the
-- day; then send.
create table gc_comment_user_recipients (
	comment_id	references general_comments,
	user_id		references users
);


alter table gc_comment_user_recipients add (
	frequency	varchar(30) default 'instant' 
	   check (frequency in ('instant', 'daily', 'monthu', 'weekly')),
	alert_type	varchar(30) 
           check (alert_type in ('topic','comment','contributor','keyword'))
);


--a very useful function where you can know if the user is able to see a comment by just giving 
--the user id and the comment_id, and if there is no group, it returns 't'
-- NOTE:  This should use ad_general_permissions; permissioning should use
-- general_permissions, _not_ group_id.

create or replace function gcbt_user_group_p(v_user_id IN integer, v_comment_id IN integer)

return varchar2

IS 
	ad_group_p varchar2(1);
	group_id integer;
BEGIN

	select gc.group_id INTO group_id from gc_bboard_topics gc,gc_comment_topic_map map
	where map.comment_id=v_comment_id
	and map.topic_id=gc.topic_id;

IF group_id IS NULL THEN
	ad_group_p :='t';
ELSE
	
	select ad_group_member_p (v_user_id,group_id) into ad_group_p from dual;
END IF;
return ad_group_p;
END;
/
show errors

-- trigger to autosubscribe users to a group-related bboard on insert
create or replace trigger gc_bboard_auto_subscribe_tr
before insert on user_group_map
for each row
begin
  insert into gc_topic_user_map
  (topic_id, user_id)
  select topic_id, :new.user_id
  from gc_bboard_topics t
  where auto_subscribe_p = 't'
  and group_id = :new.group_id
  and not exists (select 1 from gc_topic_user_map m
    where m.user_id = :new.user_id
    and m.topic_id = t.topic_id);
end;
/
show errors







