# advanced-email-alerts.tcl

ad_page_contract {
    @creation-date 18 Jan 2001
    @author jwong
} {

}

ad_maybe_redirect_for_registration
set user_id [ad_get_user_id]

set return_url "advanced-email-alerts.tcl?[export_url_vars topic_id]"

set email [db_string "email_select" "select email from users where user_id = :user_id"]

set comment_info_list [db_list_of_lists "comment_subscribe_list" "\
	select cc_map.topic_id, \
	gc.comment_id,\ one_line_item_desc, uc.name, cu_map.frequency
from gc_bboard_messages gc, gc_comment_topic_map cc_map, 
gc_bboard_topics uc, gc_comment_user_map cu_map
where gc.approved_p = 't'
  and gc.comment_id = cu_map.comment_id
  and cu_map.user_id = :user_id
  and gc.comment_id = cc_map.comment_id
  and uc.active_p = 't'
  and uc.topic_id = cc_map.topic_id  
order by uc.name, gc.comment_id
"]

set contributor_info_list [db_list_of_lists "contributor_subsription_list" "
select contributor_id, (first_names || ' ' || last_name) as contributor_name, 
m.frequency
from gc_contributor_user_map m, users u
where m.user_id = :user_id
and contributor_id = u.user_id
order by contributor_name
"]

set keyword_list [db_list_of_lists "keyword_subscription_list" "
select keyword, frequency
from gc_keyword_user_map
where user_id = :user_id
order by keyword
"]

db_release_unused_handles

set n_topics 0
set old_topic_id ""
set subscribe_list_html ""

foreach comment_info $comment_info_list {
    set topic_id [lindex $comment_info 0]
    set comment_id [lindex $comment_info 1]
    set one_line_item_desc [lindex $comment_info 2]
    set name [lindex $comment_info 3]
    set frequency [lindex $comment_info 4]

    if { $topic_id != $old_topic_id } {
	incr n_topics
	if { $n_topics > 1 } {
	    append subscribe_list_html "<tr><td>&nbsp;</td></tr>"
	}
    }

	append subscribe_list_html "<tr>\n <td><a href=\"one-message.tcl?[export_url_vars topic_id comment_id]\">$one_line_item_desc</a>
  <td><form action=email-alerts-edit> 
  [export_form_vars topic_id comment_id frequency return_url] 
  <input type=hidden name=type value=message>
  <select name=new_frequency>
  [db_html_select_value_options -select_option $frequency "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select>
  <input type=submit value=\"Edit Alert\"></form></td>
  <td> <small>\[<a href=\"message-unsubscribe.tcl?comment_id=[lindex $comment_info 1]&[export_url_vars return_url]\">cancel alert</a>\]</small></td> \n</tr>"

set old_topic_id $topic_id
    
}

if { $n_topics == 0 } {
    append subscribe_list_html "<tr><td>&nbsp;No message alerts.</td></tr>"
}

set n_contributors 0
set contributor_list_html ""
foreach contributor_info $contributor_info_list {
    incr n_contributors

    set contributor_id [lindex $contributor_info 0]
    set contributor_name [lindex $contributor_info 1]
    set frequency [lindex $contributor_info 2]
    
    append contributor_list_html "<form action=\"email-alerts-edit\">
<tr>
  <td>$contributor_name </td>
  [export_form_vars keyword frequency return_url contributor_id]
  <input type=hidden name=type value=\"contributor\">
  <td><select name=new_frequency>  
  [db_html_select_value_options -select_option $frequency "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select>  
  <input type=submit value=\"Edit Alert\"></form></td>
  <td><small>\[<a href=\"contributor-unsubscribe.tcl?[export_url_vars contributor_id frequency return_url]\">cancel alert</a>\]</small></td>
</tr>"
}
if { $n_contributors == 0 } {
    append contributor_list_html "<tr><td>&nbsp;No contributor alerts.</td></tr>"
}

set target "/threaded-bboard/contributor-subscribe.tcl"
set passthrough {return_url frequency}

set n_keywords 0
set keyword_list_html ""
foreach keyword_freq $keyword_list {
    set keyword [lindex $keyword_freq 0]
    set frequency [lindex $keyword_freq 1]
    incr n_keywords
    
    append keyword_list_html "<form action=\"email-alerts-edit\" method=post>
<tr>
  <td> $keyword </td>
<input type=hidden name=type value=\"keyword\">
  [export_form_vars keyword frequency return_url]
  <td>  <select name=new_frequency>
  [db_html_select_value_options -select_option $frequency "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select>  
  <input type=submit value=\"Edit Alert\"></form></td>
  <td> <small>\[<a href=\"keyword-unsubscribe.tcl?[export_url_vars keyword frequency return_url]\">cancel alert</a>\]</small></td>
</tr>"
}
if { $n_keywords == 0 } {
    append keyword_list_html "<tr><td>&nbsp; No keyword alerts.</td></tr>"
}

set page_body "
[ad_header "Advanced Email Alerts"]
<h2>Advanced Email Alerts</h2>
[ad_context_bar_ws_or_index [list "./" [gc_bboard_system_name]] [list "email-alerts" "Email Alerts"] "Advanced Email Alerts"]
<hr>
<b>Advanced email alerts for $email:</b>
<blockquote>
<table>
<tr align=left><th>Messages:</th></tr>
$subscribe_list_html
</table>
<hr>
<table>
<tr align=left>
  <th>Keywords: </th></tr>
$keyword_list_html
</table>
<table>
<tr>
  <td><b>Add a new Keyword alert:</b>
  <form method=post action=\"keyword-subscribe.tcl\">
     [export_form_vars return_url]
</td></tr>
<tr>
  <td>Keyword: <input type=text name=keyword size=20 maxlength=100></td></tr>
<tr>
  <td>Frequency: <select name=frequency>  [db_html_select_value_options -select_option "instant" "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select>
  <input type=submit value=\"Add Alert\"></form>
  </td>
</tr>
</table>
<hr>
<table>
<tr align=left><th>Contributors:</th></tr>
    $contributor_list_html
</table>
<table>
<tr>
<td><b>Add a new contributor alert:</b>
    <form method=post action=\"/user-search.tcl\">     
     Frequency: <select name=frequency>  [db_html_select_value_options -select_option "instant" "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select><br>
     [export_form_vars target passthrough return_url]<br>
     Email: <input type=text name=email size=15> or 
     <br>Last Name: <input type=text name=last_name size=15>
     <input type=submit value=\"Search\">
    </form>
</td>
</tr>
</table>
   <p>
</blockquote>
[ad_footer]
"

doc_return 200 text/html $page_body