# /threaded-bboard/email-alerts.tcl

ad_page_contract {
    shows all the bboard topic alerts
    @author: jwong@arsdigita.com
} {
    {topic_id:naturalnum ""}
}

set back_topic_id $topic_id

ad_maybe_redirect_for_registration
set user_id [ad_get_user_id]

set return_url "email-alerts.tcl?[export_url_vars topic_id]"

if { ![db_0or1row prefs_select "
	select default_view, html_email_p, single_email_p
	from gc_bboard_user_prefs
	where user_id = :user_id"] } {
    set html_email_p "f"
    set single_email_p "f"
}

set email [db_string "email_select" "select email from users where user_id = :user_id"]

set back_topic_name [db_string "topic_name_select" "
  select name
    from gc_bboard_topics
   where topic_id=:topic_id
" -default ""]

set topic_info_list [db_list_of_lists "topic_select" "
	select b.topic_id, name, frequency
	from   gc_bboard_topics b,  gc_topic_user_map map
	where  b.active_p = 't'
	and    map.topic_id = b.topic_id 
	and    user_id = :user_id
	order by name"]


db_release_unused_handles

set n_topics 0
set topic_list_html "<table>"

foreach topic_info $topic_info_list {
    set topic_id [lindex $topic_info 0]
    set name [lindex $topic_info 1]
    set frequency [lindex $topic_info 2]
    incr n_topics

    set frequency_select "
<select name=new_frequency>
[db_html_select_value_options -select_option $frequency "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]</select>"

    append topic_list_html "
<tr>
 <td><a href=\"one-topic.tcl?[export_url_vars topic_id]\">$name</a></td>
 <td><form action=email-alerts-edit> [export_form_vars topic_id frequency return_url] <input type=hidden name=type value=topic>
  $frequency_select
  <input type=submit value=\"Edit Alert\"></form></td>
 <td><small>\[<a href=\"topic-unsubscribe.tcl?[export_url_vars topic_id frequency return_url]\">cancel alert</a>\]</small></td>
</tr>
"
}
if { $n_topics == 0 } {
    append topic_list_html "<tr><td> No topic alerts.</td></tr>"
}

append topic_list_html "</table>
"
if { ![empty_string_p $back_topic_name] } {
    set back_link_html "<a href=\"/threaded-bboard/one-topic.tcl?topic_id=[ad_urlencode $back_topic_id]\">Back to the $back_topic_name forum</a>"
} else {
    set back_link_html ""
}

set page_body "
[ad_header "Email Alerts"]
<h2>Email Alerts</h2>
[ad_context_bar_ws_or_index [list "./" [gc_bboard_system_name]] "Email Alerts"]
<hr>
<blockquote>
  <b>Current topic alerts for $email:</b>
  $topic_list_html
   <p>$back_link_html
</blockquote>

<blockquote>
<b>Your alert format</b>
<form action=\"email-preferences-edit\">
[export_form_vars return_url]
<ul>
   <li><b>Receive your email summaries <em>(does not apply to instant alerts)</em> as :</b><br>
   <input type=\"radio\" name=\"single_email_p\" value=\"f\" [ad_decode $single_email_p "f" "checked" ""]> Send one email per alert <br>
   <input type=\"radio\" name=\"single_email_p\" value=\"t\" [ad_decode $single_email_p "t" "checked" ""]> Send summary email including all alerts</td></li>
   <li>
   <b>Receive email as:</b>
   <input type=\"radio\" name=\"html_email_p\" value=\"f\" [ad_decode $html_email_p "f" "checked" ""]> Text
   <input type=\"radio\" name=\"html_email_p\" value=\"t\" [ad_decode $html_email_p "t" "checked" ""]> HTML </li>
</ul>
<input type=\"submit\" value=\"Submit\"></td>
</form>
</blockquote>

"

set new_alert_form "
<p>
<blockquote>
<form method=POST action=\"topic-subscribe.tcl\">
[export_form_vars return_url]
<b>Add a new topic alert</b>
<table>
<tr>
 <th align=\"right\">Topic:</th>
 <td><select name=topic_id>
"

if [ad_administrator_p] {
    set visible_bboard_query "select name, topic_id from gc_bboard_topics where active_p = 't' and topic_id not in (select topic_id from gc_topic_user_map where user_id = $user_id)"
} else {
    set visible_bboard_query "
    select name, topic_id from gc_bboard_topics gbt
    where (gbt.group_id is null or ad_group_member_p ($user_id, gbt.group_id ) = 't') and active_p = 't' and topic_id not in (select topic_id from gc_topic_user_map where user_id = $user_id) 
    "
}

db_foreach available_bboard $visible_bboard_query {
    append new_alert_form "<option value=$topic_id>$name \n"
} if_no_rows {
    append new_alert_form "<option value=\"\">None available</option>"
}

append new_alert_form "</select>
 </td>
</tr>
<tr>
 <th align=\"right\">Frequency:</th>
 <td><select name=\"frequency\">
[db_html_select_value_options "frequency" "select distinct frequency, pretty_frequency from gc_alert_frequencies"]
</select></td>
 <td><input type=submit value=\"Add My Alert\"></td></tr>
</table>
</form>
</blockquote>"

append page_body "
$new_alert_form
<a href=\"advanced-email-alerts\">Advanced alert options</a>
[ad_footer]
"


ns_return 200 text/html "$page_body"
