# one-flat-message.tcl 
# DRB for the Otter Group
# display the entire thread on one page, requested because the threaded view
# stinks.

ad_page_contract {
    @param: topic_id
    @param: comment_id
} {
    topic_id:naturalnum
    {comment_id:naturalnum ""}
}

set current_user_id [ad_verify_and_get_user_id]
ad_require_permission $current_user_id "read" $topic_id "gc_bboard_topics"

if {[empty_string_p $comment_id]} {
    ad_returnredirect "one-topic.tcl?[export_url_vars topic_id]"
    return
}

set return_url "one-flat-message.tcl?[export_url_vars topic_id comment_id]"

db_1row "topic_info_select" "select name, threaded_p, group_id from gc_bboard_topics where topic_id = :topic_id"

set message_info_list [db_list_of_lists "message_flat_info_select" "select comment_id, one_line_item_desc, comment_date, level, gc.user_id, (first_names || ' ' || last_name), email, content
    from (select * from general_comments
	  start with comment_id = :comment_id
	  connect by prior comment_id = on_what_id
	  and on_which_table = 'general_comments') gc,
    users u
    where u.user_id = gc.user_id
    order by comment_date asc"]

## process message and replies

set message_html ""
set message_desc ""
set count 0

foreach message_info $message_info_list {

    incr count
    set current_comment_id [lindex $message_info 0]
    set one_line_item_desc [lindex $message_info 1]
    set comment_date [lindex $message_info 2]
    set level [lindex $message_info 3]
    set user_id [lindex $message_info 4]
    set user_name [lindex $message_info 5]
    set user_email [lindex $message_info 6]
    set content [lindex $message_info 7]
    set n_total_messages [lindex $message_info 9]
    set n_new_messages [lindex $message_info 10]

    if { $count == 2} {
        append message_html "<p><b><font size=+1>Answers</font></b><p>"
    }

    append message_html "
    <table width=90% border=0 cellspacing=3>
     <tr bgcolor=\"#ececec\"> 
      <td>$one_line_item_desc; [gc_bboard_info_header $comment_date $user_name $user_id]</td>
     </tr>
     <tr bgcolor=\"#FFFFFF\">
      <td>
       <blockquote>
        <p>[ad_text_to_html $content]</p>
       </blockquote>
      </td>
     </tr>
    </table>
    "
}

set top_options "<form method=post action=\"bboard-filter.tcl\">
 [export_form_vars topic_id]
 <input type=hidden name=filter_by value=\"keyword\">
 <input type=text name=filter_value size=20 maxlength=100>
 <input type=submit value=\"Search\">
</form><br>"

if {[db_string "comment_user_map_count" "select count(*) from gc_comment_user_map where user_id = :current_user_id and comment_id = :comment_id"] > 0} {
    append top_options "<a href='message-unsubscribe.tcl?[export_url_vars comment_id return_url]'>Stop notifying me of new responses</a><p>"
} else {
    append top_options "<a href='message-subscribe.tcl?[export_url_vars comment_id return_url]'>Notify me of new responses</a><p>"
}

db_release_unused_handles

set parent_id $comment_id

ns_return 200 text/html "
[ad_header $message_desc]
<h2>$message_desc</h2>
[ad_context_bar_ws_or_index [list "./" "Bulletin Boards"] [list "one-topic.tcl?[export_url_vars topic_id]" $name] $message_desc]
<hr>
<div align=\"right\">
$top_options
</div>
<font size=-1>$message_html</font>
<p><center>
<form method=get action=\"message-add.tcl\">
[export_form_vars topic_id parent_id return_url]
<input type=submit value=\"Contribute an answer\">
</form>
[ad_footer]
"
