# /threaded-bboard/subscription.tcl

ad_page_contract {
    show all the user subscription
    @author: flattop@arsdigita.com
} {
    {topic_id:naturalnum ""}
}

set back_topic_id $topic_id

ad_maybe_redirect_for_registration
set user_id [ad_get_user_id]

set return_url "subscription.tcl?[export_url_vars topic_id]"

set email [db_string "email_select" "select email from users where user_id = :user_id"]

set back_topic_name [db_string "topic_name_select" "
  select name
    from gc_bboard_topics
   where topic_id=:topic_id
" -default ""]

set topic_info_list [db_list_of_lists "topic_select" "
select b.topic_id, name, frequency
from gc_bboard_topics b,  gc_topic_user_map map
where b.active_p = 't'
and map.topic_id = b.topic_id 
and user_id = :user_id
order by name"]

set subscribe_info_list [db_list_of_lists "comment_subscribe_list" "
select cc_map.topic_id, gc.comment_id, one_line_item_desc, uc.name, cu_map.frequency
from gc_bboard_messages gc, gc_comment_topic_map cc_map, 
gc_bboard_topics uc, gc_comment_user_map cu_map
where gc.approved_p = 't'
  and gc.comment_id = cu_map.comment_id
  and cu_map.user_id = :user_id
  and gc.comment_id = cc_map.comment_id
  and uc.active_p = 't'
  and uc.topic_id = cc_map.topic_id  
order by uc.name, gc.comment_id
"]

set contributor_info_list [db_list_of_lists "contributor_subsription_list" "
select contributor_id, (first_names || ' ' || last_name) as contributor_name, 
m.frequency
from gc_contributor_user_map m, users u
where m.user_id = :user_id
and contributor_id = u.user_id
order by contributor_name
"]

set keyword_list [db_list_of_lists "keyword_subscription_list" "
select keyword, frequency
from gc_keyword_user_map
where user_id = :user_id
order by keyword
"]

db_release_unused_handles

set n_topics 0
set old_topic_id ""
set subscribe_list_html "<ul>"
set file_name "message-unsubscribe"
foreach subscribe_info $subscribe_info_list {
    set topic_id [lindex $subscribe_info 0]
    set comment_id [lindex $subscribe_info 1]
    set one_line_item_desc [lindex $subscribe_info 2]
    set name [lindex $subscribe_info 3]
    set frequency [lindex $subscribe_info 4]

    if { $topic_id != $old_topic_id } {
	incr n_topics
	if { $n_topics > 1 } {
	    append subscribe_list_html "</ul>"
	}
	append subscribe_list_html "<li>Bulletin Board: <a href=\"one-topic.tcl?[export_url_vars topic_id]\"><b>$name</b></a><ul>"
}
	append subscribe_list_html "<li><a href=\"one-message.tcl?comment_id=[lindex $subscribe_info 1]&[export_url_vars topic_id]\">[lindex $subscribe_info 2]</a> \n - [capitalize [pretty_frequency $frequency]] <small>\[<a href=\"message-unsubscribe.tcl?comment_id=[lindex $subscribe_info 1]&[export_url_vars return_url]\">cancel alert</a></small>
 |
<small><a href=\"edit-alerts.tcl?[export_url_vars topic_id return_url frequency file_name comment_id]\">modify</a>\]</small><br>"

set old_topic_id $topic_id
    
}

if { $n_topics == 0 } {
    append subscribe_list_html "<li>No message alerts."
} else {
    append subscribe_list_html "</ul>"
}
append subscribe_list_html "</ul>"

set n_topics 0
set topic_list_html "<ul>"
set file_name "topic-unsubscribe"
foreach topic_info $topic_info_list {
    set topic_id [lindex $topic_info 0]
    set name [lindex $topic_info 1]
    set frequency [lindex $topic_info 2]
    incr n_topics

    append topic_list_html "<li> <a href=\"one-topic.tcl?[export_url_vars topic_id]\">$name</a> - [capitalize [pretty_frequency $frequency]] <small>\[<a href=\"topic-unsubscribe.tcl?[export_url_vars topic_id return_url frequency]\">cancel alert</a>\</small> |
<small>\<a href=\"edit-alerts.tcl?[export_url_vars topic_id return_url frequency file_name]\">modify</a>\]</small><br> "
}
if { $n_topics == 0 } {
    append topic_list_html "<li> No topic alerts."
}
append topic_list_html "</ul>"

set n_contributors 0
set contributor_list_html "<ul>"
set file_name "contributor-unsubscribe"
foreach contributor_info $contributor_info_list {
    incr n_contributors

    set contributor_id [lindex $contributor_info 0]
    set contributor_name [lindex $contributor_info 1]
    set frequency [lindex $contributor_info 2]
    
    append contributor_list_html "<li>$contributor_name - [capitalize [pretty_frequency $frequency]] <small>\[<a href=\"contributor-unsubscribe.tcl?[export_url_vars contributor_id frequency return_url]\">cancel alert</a></small>
 |
<small><a href=\"edit-alerts.tcl?[export_url_vars topic_id return_url frequency file_name contributor_id]\">modify</a>\]</small><br> "
}
if { $n_contributors == 0 } {
    append contributor_list_html "<li> No contributor alerts."
}
append contributor_list_html "</ul>"

set n_keywords 0
set keyword_list_html "<ul>"
set file_name "keyword-unsubscribe"
foreach keyword_freq $keyword_list {
    set keyword [lindex $keyword_freq 0]
    set frequency [lindex $keyword_freq 1]
    incr n_keywords
    
    append keyword_list_html "<li> $keyword - [capitalize [pretty_frequency $frequency]] <small>\[<a href=\"keyword-unsubscribe.tcl?[export_url_vars keyword frequency return_url]\">cancel alert</a></small>
 |
<small><a href=\"edit-alerts.tcl?[export_url_vars topic_id return_url frequency file_name keyword]\">modify</a>\]</small><br>"

}
if { $n_keywords == 0 } {
    append keyword_list_html "<li> No keyword alerts."
}
append keyword_list_html "</ul>"

if { ![empty_string_p $back_topic_name] } {
    set back_link_html "<a href=\"/threaded-bboard/one-topic.tcl?topic_id=[ad_urlencode $back_topic_id]\">Back to the $back_topic_name bulletin board</a>"
} else {
    set back_link_html ""
}
set target "/threaded-bboard/contributor-subscribe.tcl"
set passthrough {return_url frequency}

ns_return 200 text/html "
[ad_header "Email Alerts"]
<h2>Email Alerts</h2>
[ad_context_bar_ws_or_index {"index.tcl" "Bulletin Boards"} "Email Alerts"]
<hr>
<blockquote>
  <a href=\"preferences-edit\">Change my alert preferences</a><br>
  <b>Current email alerts for $email:</b>
   <ul>
    <li>Bulletin Boards <small>\[<i><a href=\"add-topic-alerts\">Add New Bulletin Board Alert</a>\]</small>:</i> $topic_list_html
    <li>Messages: $subscribe_list_html
    <li><form method=post action=\"keyword-subscribe.tcl\">
     [export_form_vars return_url]
     Keywords: <input type=text name=keyword size=20 maxlength=100><br>
     <input type=radio name=\"frequency\" value=\"instant\" checked>Instant\
     <input type=radio name=\"frequency\" value=\"daily\">Daily
     <input type=radio name=\"frequency\" value=\"monthu\">Monday/Thursday
     <input type=radio name=\"frequency\" value=\"weekly\">Weekly
     <input type=submit value=\"Add\">
     </form>
      $keyword_list_html
     <p>
    <li>Contributors: $contributor_list_html
   <p>
    <form method=post action=\"/user-search.tcl\">     Add<br>
     <input type=radio name=\"frequency\" value=\"instant\" checked>Instant\
     <input type=radio name=\"frequency\" value=\"daily\">Daily
     <input type=radio name=\"frequency\" value=\"monthu\">Monday/Thursday
     <input type=radio name=\"frequency\" value=\"weekly\">Weekly
     [export_form_vars target passthrough return_url]<br>
     Email: <input type=text name=email size=15> or 
     <br>Last Name: <input type=text name=last_name size=15>
     <input type=submit value=\"Search\">
    </form>
   <p>
 </ul>
   <p>$back_link_html
</blockquote>
[ad_footer]
"