# /packages/register/admin-www/add-users-to-group-2.tcl

ad_page_contract {
    @cvs-id add-users-to-group-2.tcl,v 3.5.2.6.2.4 2001/01/09
    @author befekadu ayenew (befekadu@mit.edu)
} {
    existing_role:optional
    new_role:optional
    group_id:notnull,naturalnum
    key_list:notnull
} -validate { 
    role_exists {
    if {[empty_string_p $existing_role] && [empty_string_p $new_role] } {
	ad_complain "You need to specify a value for the role."
    }
}
} -errors {
    role_exists { You need to specify a value for the role}
}


set list_of_keys [split $key_list ":"]
set sql_key_list [join $list_of_keys ","]

set already_existing_members [db_list_of_lists existing_group_members "select u.user_id, first_names || ' ' || last_name as full_name, role from users_active u, user_group_map ug
where u.user_id in ($sql_key_list)
and group_id = :group_id
and u.user_id = ug.user_id"]

# so for eg. if they back up to the add page and try to add the same users again they get sent back to the first add page where they will get warnings

if { [llength $already_existing_members] != 0} {
    ad_returnredirect add-users-to-group?[export_url_vars group_id key_list]
    return
}

if {[info exists existing_role]} {
    set role $existing_role
}

if {[info exists new_role] && ![empty_string_p $new_role] } {
    set role $new_role
}

set mapping_user [ad_get_user_id]

set mapping_ip_address [ns_conn peeraddr]

set list_of_keys [split $key_list ":"]
set sql_key_list [join $list_of_keys ","]


set i 0
while { $i < [llength $list_of_keys] } {
    set user_id [lindex $list_of_keys $i]
    
    db_transaction {
	ns_log Notice "bq: role of $role; exist $existing_role"
	
	db_dml ug_insert_user "insert into user_group_map (group_id, user_id, role, mapping_user, mapping_ip_address) 
	select :group_id, :user_id, :role, :mapping_user, :mapping_ip_address from dual"
	# Extra fields
	    set sql "select field_name from all_member_fields_for_group where group_id = :group_id"
	
	db_foreach all_field_name $sql {
	    if { [exists_and_not_null $field_name] } {
		set value_of_field_name [set $field_name]
		ns_log Notice "filed_name: $field_name ; value_of: $value_of_field_name"
		db_dml user_insert "insert into user_group_member_field_map
		(group_id, user_id, field_name, field_value)
		values (:group_id, :user_id, :field_name, :value_of_field_name)"
	    }
	}
    } on_error {
	ad_return_error "Database Error" "Error while trying to insert user into a user group.
	
	Database error message was:	
	<blockquote>
	<pre>
	$errmsg
	</pre>
	</blockquote>	
	
	[ad_admin_footer]"
    }
    incr i
}

ad_returnredirect ../ug/group?group_id=$group_id







