# /packages/register/admin-www/add-users-to-group.tcl

ad_page_contract {
    @cvs-id add-users-to-group.tcl,v 3.5.2.6.2.4 2001/01/09
    @author befekadu ayenew (befekadu@mit.edu)
} {
    group_id:notnull,naturalnum
    key_list:notnull
} 

set list_of_keys [split $key_list ":"]
set sql_key_list [join $list_of_keys ","]

db_1row user_group_properties "select group_name, multi_role_p from user_groups where group_id = :group_id"

set selected_users "select first_names || ' ' || last_name as full_name from users_active where user_id in ($sql_key_list)"

set authorized_users [db_list authorized_users_select $selected_users]


#make sure there are no deleted users
if { [llength $authorized_users] != [llength $list_of_keys] } {
    set key_list [join $authorized_users ":"]
    if { ![empty_string_p $key_list] } {
	ad_returnredirect add-users-to-group?[export_url_vars key_list group_id]
	return
    } else {
	ad_return_warning "User is deleted" "You should not be trying to add deleted users.  Please go back, select the users and try again."
	return
    }
    
}

set already_existing_members [db_list_of_lists existing_group_members "select u.user_id, first_names || ' ' || last_name as full_name, role from users_active u, user_group_map ug
where u.user_id in ($sql_key_list)
and group_id = :group_id
and u.user_id = ug.user_id"]


if { [llength $already_existing_members] == 1} {
    set updated_list_of_keys ""
    foreach member $list_of_keys {
	if { $member != [lindex [lindex $already_existing_members 0] 0] } {
	    lappend updated_list_of_keys $member
	}
    }
    set key_list [join $updated_list_of_keys ":"]
    set warning "[lindex [lindex $already_existing_members 0] 1] is already a member ([lindex [lindex $already_existing_members 0] 2]) of this group."
    if { [llength $list_of_keys] > 1} {
	append warning "<p>If you want to go ahead and add the other people to this group click <a href=\"add-users-to-group?[export_url_vars key_list group_id]\">here</a>."
    }
    ad_return_warning "User already belongs to this group" $warning
    return


} elseif { [llength $already_existing_members] > 1} {

    set warning_head "Already Existing members:"
    set warning_text "The following people are already members of this group:<p>"
    set existing_user_id_list ""
    foreach member $already_existing_members {
	append warning_text "<li>[lindex $member 1] ([lindex $member 2])"
	lappend existing_user_id_list [lindex $member 0]
    }
	
    set existing_mem_sql_list [join $existing_user_id_list ","]
    set updated_key_list [db_list updated_key_list "select user_id from dual, users_active where user_id in ($sql_key_list) and user_id not in ($existing_mem_sql_list)"]
    set key_list [join $updated_key_list ":"]

    if { [expr [llength $list_of_keys] - [llength $already_existing_members]] > 0 } {
	append warning_text "<p>If you want to go ahead and add the other people to this group click <a href=\"add-users-to-group?[export_url_vars key_list group_id]\">here</a>."
    }
    ad_return_warning "$warning_head" "$warning_text "
    return
} else {



if {[info exists role] && ![empty_string_p $role]} {
    set title "Add $name as $role"
} else {
    set title "Specify Role and Any Extra Fields"
}

set page_html "[ad_admin_header "$title"]


<h2>$title</h2>
[ad_admin_context_bar [list "" "Users"] "Add Users to <a href=\"group?group_id=$group_id\">$group_name</a>"]

<hr>
"

db_foreach select_users $selected_users {
    append page_html "<li>$full_name"
}
    
append page_html "
<form method=get action=\"add-users-to-group-2\">
[export_form_vars group_id key_list return_url]
<table>
"

if { [info exists role] && ![empty_string_p $role] } {
    append page_html "[export_form_vars role]"
} else {
    
    if { [string compare $multi_role_p "t"] == 0 } {
	set existing_roles [db_list user_group_roles "select role from user_group_roles where group_id = :group_id"]
	if {[lsearch $existing_roles "administrator"] == -1 } {
	    lappend existing_roles "administrator"
	}
	if { [llength $existing_roles] > 0 } {
	    append page_html "<tr><th>Role<td><select name=existing_role>
	    [ad_generic_optionlist $existing_roles $existing_roles ""]
	    </select>
	    "
	}
	append page_html "</tr>"
    } else {
	set existing_roles [db_list user_group_distinct_roles "select distinct role from user_group_map where group_id = :group_id"]
	if {[lsearch $existing_roles "administrator"] == -1 } {
	    lappend existing_roles "administrator"
	}
	if {[lsearch $existing_roles "all"] == -1 } {
	    lappend existing_roles "all"
	}
	
	append page_html "<tr><th>Existing role</th><td>
	<select name=existing_role>
	<option value=\"\">choose an existing role
	"
	if { [lsearch $existing_roles member] == -1 } {
	    append page_html "<option value=\"member\">ordinary member; no special attributes\n"
	}
	if { [llength $existing_roles] > 0 } {
	    append page_html "
	    <option>[join $existing_roles "\n<option>"]"
	}
	append page_html "</select>
	</tr>
	<tr><td colspan=2 align=center>or</tr>
	<tr>
	<td>
	Define a new role for this group:
	<td>
	<input type=text name=new_role size=30>
	</tr>
	"
    }
}

# Additional fields

db_foreach user_group_member_fields "select group_id, field_name, field_type
from all_member_fields_for_group
where group_id = :group_id
order by sort_key" {
    append page_html "<tr><th>$field_name
<td>[ad_user_group_type_field_form_element $field_name $field_type]
</tr>
"
}

append page_html "
</table>
<p>

<center>
<input type=submit value=\"Confirm\">
</center>
</form>

[ad_admin_footer]
"
doc_return  200 text/html $page_html

}
