# this scripts generates sql load files for education
# NOTE: make sure that .info files of all packages are up to date
#       before running this script

set ordered_package_key_list [list calendar file-storage news survey threaded-bboard stock-quotes weather register manage-users portals portals-calendar portals-file-storage portals-stock-quotes portals-threaded-bboard portals-weather survey-portals education evaluation]

append load_education_script "
<pre>
-- Education Load Script
-- This script does four things: 
-- (1) removes data models of acs modules that conflict with new education packages,
-- (2) loads data models of all packages that education package is using,
-- (3) loads education data model, 
-- (4) enables all packages that education is using (including education)

"

# first generate script for droping old news, file-storage, survsimp
append load_education_script "
-- droping old news module
drop table newsgroups cascade constraints;
drop sequence newsgroup_id_sequence;
drop table news_items cascade constraints;
drop sequence news_item_id_sequence;

-- droping old file storage
drop sequence fs_file_id_seq;
drop table fs_files cascade constraints;
drop sequence fs_version_id_seq;
drop table fs_versions cascade constraints;
drop view fs_versions_latest;
drop view fs_files_tree;
delete from general_permission_types where table_name='FS_VERSIONS';
commit;

-- dropping old survsimp
drop sequence survsimp_survey_id_sequence;
drop table survsimp_surveys cascade constraints;
drop sequence survsimp_question_id_sequence;
drop table survsimp_questions cascade constraints;
drop sequence survsimp_choice_id_sequence;
drop table survsimp_question_choices cascade constraints;
drop sequence survsimp_response_id_sequence;
drop table survsimp_responses cascade constraints;
drop view survsimp_responses_unique;
drop table survsimp_question_responses cascade constraints;
drop view survsimp_question_responses_un;

-- load data models of packages education depends on and data model of education
"

foreach package_key $ordered_package_key_list {
    db_foreach apm_data_model_files_load "
    select path
    from   apm_package_files
    where  version_id in (select version_id
                          from apm_package_versions
     		          where installed_p='t'
	 	          and data_model_loaded_p='f'
		          and package_id in (select package_id 
			 		     from apm_packages
			 		     where package_key=:package_key))
    and   file_type = 'data_model'
    order  by path" {
	append load_education_script "@ ../../../packages/$package_key/$path
"
    }
}

append load_education_script "
-- enable all education packages
"

append load_education_script "execute apm_insure_package_enabled('calendar');
"

foreach package_key $ordered_package_key_list {
    append load_education_script "execute apm_insure_package_enabled('$package_key');
"
}

append load_education_script "
commit;"
append load_education_script "</pre>"

doc_return 200 text/html $load_education_script

