create or replace procedure fs_order_files
is 
	v_file_id		integer;
	v_folder_p		char(1);
	v_parent_id		integer;
	v_last_parent_id	integer;	
	v_level			integer;
	v_current_sort_key	integer;

	type integer_list_type is table of integer;
	file_id_list		integer_list_type;
	level_list		integer_list_type;
	parent_id_list		integer_list_type;
	sort_key_list		integer_list_type;

	type char_list_type is table of char(1);
	folder_p_list		char_list_type;

	cursor c1 is 
	select file_id, the_level, folder_p, parent_id
	from fs_files_tree;
begin
	open c1;
	fetch c1 bulk collect into file_id_list, level_list, folder_p_list, parent_id_list;
	close c1;

	if not file_id_list.exists(1) then 
		-- if there are no files then just return
		return;
	end if;

	sort_key_list:= integer_list_type();
	sort_key_list.extend(file_id_list.last);

	v_last_parent_id:= 0;
	v_current_sort_key:= 1;

	for i in file_id_list.first..file_id_list.last loop
		v_folder_p:= folder_p_list(i);
		v_parent_id:= parent_id_list(i);

		if ((v_parent_id != v_last_parent_id) or (v_parent_id is null) or (v_folder_p='t')) then
    			v_current_sort_key:= v_current_sort_key + 1;
		end if;

		v_last_parent_id:= v_parent_id;

		sort_key_list(i):= v_current_sort_key;
	end loop;
		
	forall i in sort_key_list.first..sort_key_list.last
		update fs_files 
                set sort_key = sort_key_list(i), 
                    depth = level_list(i) - 1
	        where file_id = file_id_list(i);
end fs_order_files;
/
show errors

